@@ -95,7 +95,7 @@ TODO general:
 #include "emu.h"
 #include "g65816.h"
 
-INLINE g65816i_cpu_struct *get_safe_token(running_device *device)
+INLINE g65816i_cpu_struct *get_safe_token(device_t *device)
 {
 	assert(device != NULL);
 	assert(device->type() == G65816 || device->type() == _5A22);
@@ -318,10 +318,8 @@ static CPU_DISASSEMBLE( g65816 )
 	return g65816_disassemble(buffer, (pc & 0x00ffff), (pc & 0xff0000) >> 16, oprom, FLAG_M, FLAG_X);
 }
 
-static STATE_POSTLOAD( g65816_restore_state )
+static void g65816_restore_state(g65816i_cpu_struct *cpustate)
 {
-	g65816i_cpu_struct *cpustate = (g65816i_cpu_struct *)param;
-
 	// restore proper function pointers
 	g65816i_set_execution_mode(cpustate, (FLAG_M>>4) | (FLAG_X>>4));
 
@@ -340,32 +338,32 @@ static CPU_INIT( g65816 )
 	cpustate->program = device->space(AS_PROGRAM);
 	cpustate->cpu_type = CPU_TYPE_G65816;
 
-	state_save_register_device_item(device, 0, cpustate->a);
-	state_save_register_device_item(device, 0, cpustate->b);
-	state_save_register_device_item(device, 0, cpustate->x);
-	state_save_register_device_item(device, 0, cpustate->y);
-	state_save_register_device_item(device, 0, cpustate->s);
-	state_save_register_device_item(device, 0, cpustate->pc);
-	state_save_register_device_item(device, 0, cpustate->ppc);
-	state_save_register_device_item(device, 0, cpustate->pb);
-	state_save_register_device_item(device, 0, cpustate->db);
-	state_save_register_device_item(device, 0, cpustate->d);
-	state_save_register_device_item(device, 0, cpustate->flag_e);
-	state_save_register_device_item(device, 0, cpustate->flag_m);
-	state_save_register_device_item(device, 0, cpustate->flag_x);
-	state_save_register_device_item(device, 0, cpustate->flag_n);
-	state_save_register_device_item(device, 0, cpustate->flag_v);
-	state_save_register_device_item(device, 0, cpustate->flag_d);
-	state_save_register_device_item(device, 0, cpustate->flag_i);
-	state_save_register_device_item(device, 0, cpustate->flag_z);
-	state_save_register_device_item(device, 0, cpustate->flag_c);
-	state_save_register_device_item(device, 0, cpustate->line_irq);
-	state_save_register_device_item(device, 0, cpustate->line_nmi);
-	state_save_register_device_item(device, 0, cpustate->ir);
-	state_save_register_device_item(device, 0, cpustate->irq_delay);
-	state_save_register_device_item(device, 0, cpustate->stopped);
+	device->save_item(NAME(cpustate->a));
+	device->save_item(NAME(cpustate->b));
+	device->save_item(NAME(cpustate->x));
+	device->save_item(NAME(cpustate->y));
+	device->save_item(NAME(cpustate->s));
+	device->save_item(NAME(cpustate->pc));
+	device->save_item(NAME(cpustate->ppc));
+	device->save_item(NAME(cpustate->pb));
+	device->save_item(NAME(cpustate->db));
+	device->save_item(NAME(cpustate->d));
+	device->save_item(NAME(cpustate->flag_e));
+	device->save_item(NAME(cpustate->flag_m));
+	device->save_item(NAME(cpustate->flag_x));
+	device->save_item(NAME(cpustate->flag_n));
+	device->save_item(NAME(cpustate->flag_v));
+	device->save_item(NAME(cpustate->flag_d));
+	device->save_item(NAME(cpustate->flag_i));
+	device->save_item(NAME(cpustate->flag_z));
+	device->save_item(NAME(cpustate->flag_c));
+	device->save_item(NAME(cpustate->line_irq));
+	device->save_item(NAME(cpustate->line_nmi));
+	device->save_item(NAME(cpustate->ir));
+	device->save_item(NAME(cpustate->irq_delay));
+	device->save_item(NAME(cpustate->stopped));
 
-	state_save_register_postload(device->machine, g65816_restore_state, cpustate);
+	device->machine().save().register_postload(save_prepost_delegate(FUNC(g65816_restore_state), cpustate));
 }
 
 /**************************************************************************
@@ -406,7 +404,7 @@ static CPU_SET_INFO( g65816 )
 
 
 
-void g65816_set_read_vector_callback(running_device *device, read8_space_func read_vector)
+void g65816_set_read_vector_callback(device_t *device, read8_space_func read_vector)
 {
 	g65816i_cpu_struct *cpustate = get_safe_token(device);
 	READ_VECTOR = read_vector;
@@ -434,15 +432,15 @@ CPU_GET_INFO( g65816 )
 		case CPUINFO_INT_MIN_CYCLES:				info->i = 1;							break;
 		case CPUINFO_INT_MAX_CYCLES:				info->i = 20; /* rough guess */			break;
 
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_PROGRAM:	info->i = 8;					break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_PROGRAM: info->i = 24;					break;
-		case DEVINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_PROGRAM: info->i = 0;					break;
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_DATA:	info->i = 0;					break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_DATA:	info->i = 0;					break;
-		case DEVINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_DATA:	info->i = 0;					break;
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_IO:	info->i = 0;					break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_IO:	info->i = 0;					break;
-		case DEVINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_IO:	info->i = 0;					break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_PROGRAM:	info->i = 8;					break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_PROGRAM: info->i = 24;					break;
+		case DEVINFO_INT_ADDRBUS_SHIFT + AS_PROGRAM: info->i = 0;					break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_DATA:	info->i = 0;					break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_DATA:	info->i = 0;					break;
+		case DEVINFO_INT_ADDRBUS_SHIFT + AS_DATA:	info->i = 0;					break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_IO:	info->i = 0;					break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_IO:	info->i = 0;					break;
+		case DEVINFO_INT_ADDRBUS_SHIFT + AS_IO:	info->i = 0;					break;
 
 		case CPUINFO_INT_INPUT_STATE + G65816_LINE_IRQ:		info->i = LINE_IRQ;					break;
 		case CPUINFO_INT_INPUT_STATE + G65816_LINE_NMI:		info->i = LINE_NMI;					break;
