@@ -117,7 +117,7 @@ static void set_irq_line(h6280_Regs* cpustate, int irqline, int state);
 /* include the macros */
 #include "h6280ops.h"
 
-INLINE h6280_Regs *get_safe_token(running_device *device)
+INLINE h6280_Regs *get_safe_token(device_t *device)
 {
 	assert(device != NULL);
 	assert(device->type() == H6280);
@@ -132,36 +132,37 @@ static CPU_INIT( h6280 )
 {
 	h6280_Regs* cpustate = get_safe_token(device);
 
-	state_save_register_device_item(device, 0, cpustate->ppc.w.l);
-	state_save_register_device_item(device, 0, cpustate->pc.w.l);
-	state_save_register_device_item(device, 0, cpustate->sp.w.l);
-	state_save_register_device_item(device, 0, cpustate->zp.w.l);
-	state_save_register_device_item(device, 0, cpustate->ea.w.l);
-	state_save_register_device_item(device, 0, cpustate->a);
-	state_save_register_device_item(device, 0, cpustate->x);
-	state_save_register_device_item(device, 0, cpustate->y);
-	state_save_register_device_item(device, 0, cpustate->p);
-	state_save_register_device_item_array(device, 0, cpustate->mmr);
-	state_save_register_device_item(device, 0, cpustate->irq_mask);
-	state_save_register_device_item(device, 0, cpustate->timer_status);
-	state_save_register_device_item(device, 0, cpustate->timer_ack);
-	state_save_register_device_item(device, 0, cpustate->clocks_per_cycle);
-	state_save_register_device_item(device, 0, cpustate->timer_value);
-	state_save_register_device_item(device, 0, cpustate->timer_load);
-	state_save_register_device_item(device, 0, cpustate->nmi_state);
-	state_save_register_device_item(device, 0, cpustate->irq_state[0]);
-	state_save_register_device_item(device, 0, cpustate->irq_state[1]);
-	state_save_register_device_item(device, 0, cpustate->irq_state[2]);
-	state_save_register_device_item(device, 0, cpustate->irq_pending);
+	device->save_item(NAME(cpustate->ppc.w.l));
+	device->save_item(NAME(cpustate->pc.w.l));
+	device->save_item(NAME(cpustate->sp.w.l));
+	device->save_item(NAME(cpustate->zp.w.l));
+	device->save_item(NAME(cpustate->ea.w.l));
+	device->save_item(NAME(cpustate->a));
+	device->save_item(NAME(cpustate->x));
+	device->save_item(NAME(cpustate->y));
+	device->save_item(NAME(cpustate->p));
+	device->save_item(NAME(cpustate->mmr));
+	device->save_item(NAME(cpustate->irq_mask));
+	device->save_item(NAME(cpustate->timer_status));
+	device->save_item(NAME(cpustate->timer_ack));
+	device->save_item(NAME(cpustate->clocks_per_cycle));
+	device->save_item(NAME(cpustate->timer_value));
+	device->save_item(NAME(cpustate->timer_load));
+	device->save_item(NAME(cpustate->nmi_state));
+	device->save_item(NAME(cpustate->irq_state[0]));
+	device->save_item(NAME(cpustate->irq_state[1]));
+	device->save_item(NAME(cpustate->irq_state[2]));
+	device->save_item(NAME(cpustate->irq_pending));
 
 	#if LAZY_FLAGS
-	state_save_register_device_item(device, 0, cpustate->NZ);
+	device->save_item(NAME(cpustate->NZ));
 	#endif
-	state_save_register_device_item(device, 0, cpustate->io_buffer);
+	device->save_item(NAME(cpustate->io_buffer));
 
 	cpustate->irq_callback = irqcallback;
 	cpustate->device = device;
 	cpustate->program = device->space(AS_PROGRAM);
+	cpustate->direct = &cpustate->program->direct();
 	cpustate->io = device->space(AS_IO);
 }
 
@@ -178,6 +179,7 @@ static CPU_RESET( h6280 )
 	cpustate->irq_callback = save_irqcallback;
 	cpustate->device = device;
 	cpustate->program = device->space(AS_PROGRAM);
+	cpustate->direct = &cpustate->program->direct();
 	cpustate->io = device->space(AS_IO);
 
 	/* set I and B flags */
@@ -286,7 +288,7 @@ static void set_irq_line(h6280_Regs* cpustate, int irqline, int state)
 READ8_HANDLER( h6280_irq_status_r )
 {
 	int status;
-	h6280_Regs *cpustate = get_safe_token(space->cpu);
+	h6280_Regs *cpustate = get_safe_token(&space->device());
 
 	switch (offset&3)
 	{
@@ -305,7 +307,7 @@ READ8_HANDLER( h6280_irq_status_r )
 
 WRITE8_HANDLER( h6280_irq_status_w )
 {
-	h6280_Regs *cpustate = get_safe_token(space->cpu);
+	h6280_Regs *cpustate = get_safe_token(&space->device());
 	cpustate->io_buffer=data;
 	switch (offset&3)
 	{
@@ -324,15 +326,15 @@ WRITE8_HANDLER( h6280_irq_status_w )
 READ8_HANDLER( h6280_timer_r )
 {
 	/* only returns countdown */
-	h6280_Regs *cpustate = get_safe_token(space->cpu);
-	return ((cpustate->timer_value/1024)&0x7F)|(cpustate->io_buffer&0x80);
+	h6280_Regs *cpustate = get_safe_token(&space->device());
+	return ((cpustate->timer_value >> 10)&0x7F)|(cpustate->io_buffer&0x80);
 }
 
 WRITE8_HANDLER( h6280_timer_w )
 {
-	h6280_Regs *cpustate = get_safe_token(space->cpu);
+	h6280_Regs *cpustate = get_safe_token(&space->device());
 	cpustate->io_buffer=data;
-	switch (offset) {
+	switch (offset & 1) {
 		case 0: /* Counter preload */
 			cpustate->timer_load=cpustate->timer_value=((data&127)+1)*1024;
 			return;
@@ -351,18 +353,18 @@ static CPU_TRANSLATE( h6280 )
 {
 	h6280_Regs* cpustate = get_safe_token(device);
 
-	if (space == ADDRESS_SPACE_PROGRAM)
+	if (space == AS_PROGRAM)
 		*address = TRANSLATED(*address);
 
 	return TRUE;
 }
 
-UINT8 h6280io_get_buffer(running_device *device)
+UINT8 h6280io_get_buffer(device_t *device)
 {
 	h6280_Regs* cpustate = get_safe_token(device);
 	return cpustate->io_buffer;
 }
-void h6280io_set_buffer(running_device *device, UINT8 data)
+void h6280io_set_buffer(device_t *device, UINT8 data)
 {
 	h6280_Regs* cpustate = get_safe_token(device);
 	cpustate->io_buffer=data;
@@ -436,16 +438,16 @@ CPU_GET_INFO( h6280 )
 		case CPUINFO_INT_MIN_CYCLES:					info->i = 2;							break;
 		case CPUINFO_INT_MAX_CYCLES:					info->i = 17 + 6*65536;					break;
 
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_PROGRAM:	info->i = 8;					break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_PROGRAM: info->i = 21;					break;
-		case DEVINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_PROGRAM: info->i = 0;					break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_PROGRAM:	info->i = 8;					break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_PROGRAM: info->i = 21;					break;
+		case DEVINFO_INT_ADDRBUS_SHIFT + AS_PROGRAM: info->i = 0;					break;
 		case CPUINFO_INT_LOGADDR_WIDTH_PROGRAM: info->i = 16;					break;
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_DATA:	info->i = 0;					break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_DATA:	info->i = 0;					break;
-		case DEVINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_DATA:	info->i = 0;					break;
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_IO:		info->i = 8;					break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_IO:		info->i = 2;					break;
-		case DEVINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_IO:		info->i = 0;					break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_DATA:	info->i = 0;					break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_DATA:	info->i = 0;					break;
+		case DEVINFO_INT_ADDRBUS_SHIFT + AS_DATA:	info->i = 0;					break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_IO:		info->i = 8;					break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_IO:		info->i = 2;					break;
+		case DEVINFO_INT_ADDRBUS_SHIFT + AS_IO:		info->i = 0;					break;
 
 		case CPUINFO_INT_INPUT_STATE + 0:				info->i = cpustate->irq_state[0];		break;
 		case CPUINFO_INT_INPUT_STATE + 1:				info->i = cpustate->irq_state[1];		break;
