@@ -460,32 +460,32 @@ INLINE tms0980_state *get_safe_token(device_t *device)
 }
 
 
-static ADDRESS_MAP_START(tms0980_internal_rom, ADDRESS_SPACE_PROGRAM, 16)
+static ADDRESS_MAP_START(tms0980_internal_rom, AS_PROGRAM, 16)
 	AM_RANGE( 0x0000, 0x0FFF ) AM_ROM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START(tms0980_internal_ram, ADDRESS_SPACE_DATA, 8)
+static ADDRESS_MAP_START(tms0980_internal_ram, AS_DATA, 8)
 	AM_RANGE( 0x0000, 0x0FFF ) AM_RAM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START(program_10bit_8, ADDRESS_SPACE_PROGRAM, 8)
+static ADDRESS_MAP_START(program_10bit_8, AS_PROGRAM, 8)
 	AM_RANGE( 0x000, 0x3ff ) AM_ROM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START(program_11bit_8, ADDRESS_SPACE_PROGRAM, 8)
+static ADDRESS_MAP_START(program_11bit_8, AS_PROGRAM, 8)
 	AM_RANGE( 0x000, 0x7ff ) AM_ROM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START(data_6bit, ADDRESS_SPACE_DATA, 8)
+static ADDRESS_MAP_START(data_6bit, AS_DATA, 8)
 	AM_RANGE( 0x00, 0x3f ) AM_RAM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START(data_7bit, ADDRESS_SPACE_DATA, 8)
+static ADDRESS_MAP_START(data_7bit, AS_DATA, 8)
 	AM_RANGE( 0x00, 0x7f ) AM_RAM
 ADDRESS_MAP_END
 
@@ -494,7 +494,7 @@ static void cpu_init_tms_common( legacy_cpu_device *device, const UINT32* decode
 {
 	tms0980_state *cpustate = get_safe_token( device );
 
-	cpustate->config = (const tms0980_config *) device->baseconfig().static_config();
+	cpustate->config = (const tms0980_config *) device->static_config();
 
 	assert( cpustate->config != NULL );
 
@@ -507,38 +507,38 @@ static void cpu_init_tms_common( legacy_cpu_device *device, const UINT32* decode
 	cpustate->program = device->space( AS_PROGRAM );
 	cpustate->data = device->space( AS_PROGRAM );
 
-	state_save_register_device_item( device, 0, cpustate->prev_pc );
-	state_save_register_device_item( device, 0, cpustate->prev_pa );
-	state_save_register_device_item( device, 0, cpustate->pc );
-	state_save_register_device_item( device, 0, cpustate->pa );
-	state_save_register_device_item( device, 0, cpustate->sr );
-	state_save_register_device_item( device, 0, cpustate->pb );
-	state_save_register_device_item( device, 0, cpustate->a );
-	state_save_register_device_item( device, 0, cpustate->x );
-	state_save_register_device_item( device, 0, cpustate->y );
-	state_save_register_device_item( device, 0, cpustate->dam );
-	state_save_register_device_item( device, 0, cpustate->ca );
-	state_save_register_device_item( device, 0, cpustate->cb );
-	state_save_register_device_item( device, 0, cpustate->cs );
-	state_save_register_device_item( device, 0, cpustate->r );
-	state_save_register_device_item( device, 0, cpustate->o );
-	state_save_register_device_item( device, 0, cpustate->cki_bus );
-	state_save_register_device_item( device, 0, cpustate->p );
-	state_save_register_device_item( device, 0, cpustate->n );
-	state_save_register_device_item( device, 0, cpustate->adder_result );
-	state_save_register_device_item( device, 0, cpustate->carry_in );
-	state_save_register_device_item( device, 0, cpustate->status );
-	state_save_register_device_item( device, 0, cpustate->status_latch );
-	state_save_register_device_item( device, 0, cpustate->special_status );
-	state_save_register_device_item( device, 0, cpustate->call_latch );
-	state_save_register_device_item( device, 0, cpustate->add_latch );
-	state_save_register_device_item( device, 0, cpustate->branch_latch );
-	state_save_register_device_item( device, 0, cpustate->subcycle );
-	state_save_register_device_item( device, 0, cpustate->ram_address );
-	state_save_register_device_item( device, 0, cpustate->ram_data );
-	state_save_register_device_item( device, 0, cpustate->rom_address );
-	state_save_register_device_item( device, 0, cpustate->opcode );
-	state_save_register_device_item( device, 0, cpustate->decode );
+	device->save_item( NAME(cpustate->prev_pc) );
+	device->save_item( NAME(cpustate->prev_pa) );
+	device->save_item( NAME(cpustate->pc) );
+	device->save_item( NAME(cpustate->pa) );
+	device->save_item( NAME(cpustate->sr) );
+	device->save_item( NAME(cpustate->pb) );
+	device->save_item( NAME(cpustate->a) );
+	device->save_item( NAME(cpustate->x) );
+	device->save_item( NAME(cpustate->y) );
+	device->save_item( NAME(cpustate->dam) );
+	device->save_item( NAME(cpustate->ca) );
+	device->save_item( NAME(cpustate->cb) );
+	device->save_item( NAME(cpustate->cs) );
+	device->save_item( NAME(cpustate->r) );
+	device->save_item( NAME(cpustate->o) );
+	device->save_item( NAME(cpustate->cki_bus) );
+	device->save_item( NAME(cpustate->p) );
+	device->save_item( NAME(cpustate->n) );
+	device->save_item( NAME(cpustate->adder_result) );
+	device->save_item( NAME(cpustate->carry_in) );
+	device->save_item( NAME(cpustate->status) );
+	device->save_item( NAME(cpustate->status_latch) );
+	device->save_item( NAME(cpustate->special_status) );
+	device->save_item( NAME(cpustate->call_latch) );
+	device->save_item( NAME(cpustate->add_latch) );
+	device->save_item( NAME(cpustate->branch_latch) );
+	device->save_item( NAME(cpustate->subcycle) );
+	device->save_item( NAME(cpustate->ram_address) );
+	device->save_item( NAME(cpustate->ram_data) );
+	device->save_item( NAME(cpustate->rom_address) );
+	device->save_item( NAME(cpustate->opcode) );
+	device->save_item( NAME(cpustate->decode) );
 }
 
 
@@ -1121,9 +1121,9 @@ static CPU_GET_INFO( tms_generic )
 		case CPUINFO_INT_MIN_CYCLES:									info->i = 1; break;
 		case CPUINFO_INT_MAX_CYCLES:									info->i = 6; break;
 
-		case DEVINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_PROGRAM:			info->i = 0; break;
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_DATA:			info->i = 8 /* 4 */; break;
-		case DEVINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_DATA:			info->i = 0; break;
+		case DEVINFO_INT_ADDRBUS_SHIFT + AS_PROGRAM:			info->i = 0; break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_DATA:			info->i = 8 /* 4 */; break;
+		case DEVINFO_INT_ADDRBUS_SHIFT + AS_DATA:			info->i = 0; break;
 
 		case CPUINFO_INT_PREVIOUSPC:									info->i = ( ( cpustate->prev_pa << 7 ) | cpustate->prev_pc ) << 1; break;
 		case CPUINFO_INT_PC:											info->i = ( ( cpustate->pa << 7 ) | cpustate->pc ) << 1; break;
@@ -1171,13 +1171,13 @@ CPU_GET_INFO( tms0980 )
 	{
 		case CPUINFO_INT_MIN_INSTRUCTION_BYTES:							info->i = 2; break;
 		case CPUINFO_INT_MAX_INSTRUCTION_BYTES:							info->i = 2; break;
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_PROGRAM:			info->i = 16 /* 9 */; break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_PROGRAM:			info->i = 12; break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_DATA:			info->i = 7; break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_PROGRAM:			info->i = 16 /* 9 */; break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_PROGRAM:			info->i = 12; break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_DATA:			info->i = 7; break;
 		case CPUINFO_INT_PREVIOUSPC:									info->i = ( ( cpustate->prev_pa << 7 ) | cpustate->prev_pc ) << 1; break;
 		case CPUINFO_INT_PC:											info->i = ( ( cpustate->pa << 7 ) | cpustate->pc ) << 1; break;
-		case DEVINFO_PTR_INTERNAL_MEMORY_MAP + ADDRESS_SPACE_PROGRAM:					info->internal_map16 = ADDRESS_MAP_NAME( tms0980_internal_rom ); break;
-		case DEVINFO_PTR_INTERNAL_MEMORY_MAP + ADDRESS_SPACE_DATA:						info->internal_map8 = ADDRESS_MAP_NAME( tms0980_internal_ram ); break;
+		case DEVINFO_PTR_INTERNAL_MEMORY_MAP + AS_PROGRAM:					info->internal_map16 = ADDRESS_MAP_NAME( tms0980_internal_rom ); break;
+		case DEVINFO_PTR_INTERNAL_MEMORY_MAP + AS_DATA:						info->internal_map8 = ADDRESS_MAP_NAME( tms0980_internal_ram ); break;
 		case CPUINFO_FCT_INIT:											info->init = CPU_INIT_NAME( tms0980 ); break;
 		case CPUINFO_FCT_DISASSEMBLE:									info->disassemble = CPU_DISASSEMBLE_NAME( tms0980 ); break;
 		case DEVINFO_STR_NAME:											strcpy( info->s, "TMS0980" ); break;
@@ -1194,13 +1194,13 @@ CPU_GET_INFO( tms1000 )
 	{
 		case CPUINFO_INT_MIN_INSTRUCTION_BYTES:							info->i = 1; break;
 		case CPUINFO_INT_MAX_INSTRUCTION_BYTES:							info->i = 1; break;
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_PROGRAM:			info->i = 8; break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_PROGRAM:			info->i = 10; break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_DATA:			info->i = 6; break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_PROGRAM:			info->i = 8; break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_PROGRAM:			info->i = 10; break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_DATA:			info->i = 6; break;
 		case CPUINFO_INT_PREVIOUSPC:									info->i = ( cpustate->prev_pa << 6 ) | tms1000_pc_decode[ cpustate->prev_pc ]; break;
 		case CPUINFO_INT_PC:											info->i = ( cpustate->pa << 6 ) | tms1000_pc_decode[ cpustate->pc ]; break;
-		case DEVINFO_PTR_INTERNAL_MEMORY_MAP + ADDRESS_SPACE_PROGRAM:					info->internal_map8 = ADDRESS_MAP_NAME( program_10bit_8 ); break;
-		case DEVINFO_PTR_INTERNAL_MEMORY_MAP + ADDRESS_SPACE_DATA:						info->internal_map8 = ADDRESS_MAP_NAME( data_6bit ); break;
+		case DEVINFO_PTR_INTERNAL_MEMORY_MAP + AS_PROGRAM:					info->internal_map8 = ADDRESS_MAP_NAME( program_10bit_8 ); break;
+		case DEVINFO_PTR_INTERNAL_MEMORY_MAP + AS_DATA:						info->internal_map8 = ADDRESS_MAP_NAME( data_6bit ); break;
 		case CPUINFO_FCT_INIT:											info->init = CPU_INIT_NAME( tms1000 ); break;
 		case CPUINFO_FCT_DISASSEMBLE:									info->disassemble = CPU_DISASSEMBLE_NAME( tms1000 ); break;
 		case DEVINFO_STR_NAME:											strcpy( info->s, "TMS1000" ); break;
@@ -1249,13 +1249,13 @@ CPU_GET_INFO( tms1100 )
 
 	switch(state)
 	{
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_PROGRAM:			info->i = 8; break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_PROGRAM:			info->i = 11; break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_DATA:			info->i = 7; break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_PROGRAM:			info->i = 8; break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_PROGRAM:			info->i = 11; break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_DATA:			info->i = 7; break;
 		case CPUINFO_INT_PREVIOUSPC:									info->i = ( cpustate->prev_pa << 6 ) | tms1000_pc_decode[ cpustate->prev_pc ]; break;
 		case CPUINFO_INT_PC:											info->i = ( cpustate->pa << 6 ) | tms1000_pc_decode[ cpustate->pc ]; break;
-		case DEVINFO_PTR_INTERNAL_MEMORY_MAP + ADDRESS_SPACE_PROGRAM:					info->internal_map8 = ADDRESS_MAP_NAME( program_11bit_8 ); break;
-		case DEVINFO_PTR_INTERNAL_MEMORY_MAP + ADDRESS_SPACE_DATA:						info->internal_map8 = ADDRESS_MAP_NAME( data_7bit ); break;
+		case DEVINFO_PTR_INTERNAL_MEMORY_MAP + AS_PROGRAM:					info->internal_map8 = ADDRESS_MAP_NAME( program_11bit_8 ); break;
+		case DEVINFO_PTR_INTERNAL_MEMORY_MAP + AS_DATA:						info->internal_map8 = ADDRESS_MAP_NAME( data_7bit ); break;
 		case CPUINFO_FCT_INIT:											info->init = CPU_INIT_NAME( tms1100 ); break;
 		case CPUINFO_FCT_DISASSEMBLE:									info->disassemble = CPU_DISASSEMBLE_NAME( tms1100 ); break;
 		case DEVINFO_STR_NAME:											strcpy( info->s, "TMS1100" ); break;
