@@ -24,7 +24,7 @@ struct _unsp_state
 	UINT8 saved_sb;
 
 	legacy_cpu_device *device;
-	const address_space *program;
+	address_space *program;
 	int icount;
 
 	unspimp_state *impstate;
