@@ -1700,77 +1700,77 @@ static CPU_INIT( upd7810 )
 {
 	upd7810_state *cpustate = get_safe_token(device);
 
-	cpustate->config = *(const UPD7810_CONFIG*) device->baseconfig().static_config();
+	cpustate->config = *(const UPD7810_CONFIG*) device->static_config();
 	cpustate->irq_callback = irqcallback;
 	cpustate->device = device;
 	cpustate->program = device->space(AS_PROGRAM);
 	cpustate->direct = &cpustate->program->direct();
 	cpustate->io = device->space(AS_IO);
 
-	state_save_register_device_item(device, 0, cpustate->ppc.w.l);
-	state_save_register_device_item(device, 0, cpustate->pc.w.l);
-	state_save_register_device_item(device, 0, cpustate->sp.w.l);
-	state_save_register_device_item(device, 0, cpustate->psw);
-	state_save_register_device_item(device, 0, cpustate->op);
-	state_save_register_device_item(device, 0, cpustate->op2);
-	state_save_register_device_item(device, 0, cpustate->iff);
-	state_save_register_device_item(device, 0, cpustate->ea.w.l);
-	state_save_register_device_item(device, 0, cpustate->va.w.l);
-	state_save_register_device_item(device, 0, cpustate->bc.w.l);
-	state_save_register_device_item(device, 0, cpustate->de.w.l);
-	state_save_register_device_item(device, 0, cpustate->hl.w.l);
-	state_save_register_device_item(device, 0, cpustate->ea2.w.l);
-	state_save_register_device_item(device, 0, cpustate->va2.w.l);
-	state_save_register_device_item(device, 0, cpustate->bc2.w.l);
-	state_save_register_device_item(device, 0, cpustate->de2.w.l);
-	state_save_register_device_item(device, 0, cpustate->hl2.w.l);
-	state_save_register_device_item(device, 0, cpustate->cnt.d);
-	state_save_register_device_item(device, 0, cpustate->tm.d);
-	state_save_register_device_item(device, 0, cpustate->ecnt.d);
-	state_save_register_device_item(device, 0, cpustate->etm.d);
-	state_save_register_device_item(device, 0, cpustate->ma);
-	state_save_register_device_item(device, 0, cpustate->mb);
-	state_save_register_device_item(device, 0, cpustate->mcc);
-	state_save_register_device_item(device, 0, cpustate->mc);
-	state_save_register_device_item(device, 0, cpustate->mm);
-	state_save_register_device_item(device, 0, cpustate->mf);
-	state_save_register_device_item(device, 0, cpustate->tmm);
-	state_save_register_device_item(device, 0, cpustate->etmm);
-	state_save_register_device_item(device, 0, cpustate->eom);
-	state_save_register_device_item(device, 0, cpustate->sml);
-	state_save_register_device_item(device, 0, cpustate->smh);
-	state_save_register_device_item(device, 0, cpustate->anm);
-	state_save_register_device_item(device, 0, cpustate->mkl);
-	state_save_register_device_item(device, 0, cpustate->mkh);
-	state_save_register_device_item(device, 0, cpustate->zcm);
-	state_save_register_device_item(device, 0, cpustate->pa_out);
-	state_save_register_device_item(device, 0, cpustate->pb_out);
-	state_save_register_device_item(device, 0, cpustate->pc_out);
-	state_save_register_device_item(device, 0, cpustate->pd_out);
-	state_save_register_device_item(device, 0, cpustate->pf_out);
-	state_save_register_device_item(device, 0, cpustate->cr0);
-	state_save_register_device_item(device, 0, cpustate->cr1);
-	state_save_register_device_item(device, 0, cpustate->cr2);
-	state_save_register_device_item(device, 0, cpustate->cr3);
-	state_save_register_device_item(device, 0, cpustate->txb);
-	state_save_register_device_item(device, 0, cpustate->rxb);
-	state_save_register_device_item(device, 0, cpustate->txd);
-	state_save_register_device_item(device, 0, cpustate->rxd);
-	state_save_register_device_item(device, 0, cpustate->sck);
-	state_save_register_device_item(device, 0, cpustate->ti);
-	state_save_register_device_item(device, 0, cpustate->to);
-	state_save_register_device_item(device, 0, cpustate->ci);
-	state_save_register_device_item(device, 0, cpustate->co0);
-	state_save_register_device_item(device, 0, cpustate->co1);
-	state_save_register_device_item(device, 0, cpustate->irr);
-	state_save_register_device_item(device, 0, cpustate->itf);
-	state_save_register_device_item(device, 0, cpustate->ovc0);
-	state_save_register_device_item(device, 0, cpustate->ovc1);
-	state_save_register_device_item(device, 0, cpustate->ovcf);
-	state_save_register_device_item(device, 0, cpustate->ovcs);
-	state_save_register_device_item(device, 0, cpustate->edges);
-	state_save_register_device_item(device, 0, cpustate->int1);
-	state_save_register_device_item(device, 0, cpustate->int2);
+	device->save_item(NAME(cpustate->ppc.w.l));
+	device->save_item(NAME(cpustate->pc.w.l));
+	device->save_item(NAME(cpustate->sp.w.l));
+	device->save_item(NAME(cpustate->psw));
+	device->save_item(NAME(cpustate->op));
+	device->save_item(NAME(cpustate->op2));
+	device->save_item(NAME(cpustate->iff));
+	device->save_item(NAME(cpustate->ea.w.l));
+	device->save_item(NAME(cpustate->va.w.l));
+	device->save_item(NAME(cpustate->bc.w.l));
+	device->save_item(NAME(cpustate->de.w.l));
+	device->save_item(NAME(cpustate->hl.w.l));
+	device->save_item(NAME(cpustate->ea2.w.l));
+	device->save_item(NAME(cpustate->va2.w.l));
+	device->save_item(NAME(cpustate->bc2.w.l));
+	device->save_item(NAME(cpustate->de2.w.l));
+	device->save_item(NAME(cpustate->hl2.w.l));
+	device->save_item(NAME(cpustate->cnt.d));
+	device->save_item(NAME(cpustate->tm.d));
+	device->save_item(NAME(cpustate->ecnt.d));
+	device->save_item(NAME(cpustate->etm.d));
+	device->save_item(NAME(cpustate->ma));
+	device->save_item(NAME(cpustate->mb));
+	device->save_item(NAME(cpustate->mcc));
+	device->save_item(NAME(cpustate->mc));
+	device->save_item(NAME(cpustate->mm));
+	device->save_item(NAME(cpustate->mf));
+	device->save_item(NAME(cpustate->tmm));
+	device->save_item(NAME(cpustate->etmm));
+	device->save_item(NAME(cpustate->eom));
+	device->save_item(NAME(cpustate->sml));
+	device->save_item(NAME(cpustate->smh));
+	device->save_item(NAME(cpustate->anm));
+	device->save_item(NAME(cpustate->mkl));
+	device->save_item(NAME(cpustate->mkh));
+	device->save_item(NAME(cpustate->zcm));
+	device->save_item(NAME(cpustate->pa_out));
+	device->save_item(NAME(cpustate->pb_out));
+	device->save_item(NAME(cpustate->pc_out));
+	device->save_item(NAME(cpustate->pd_out));
+	device->save_item(NAME(cpustate->pf_out));
+	device->save_item(NAME(cpustate->cr0));
+	device->save_item(NAME(cpustate->cr1));
+	device->save_item(NAME(cpustate->cr2));
+	device->save_item(NAME(cpustate->cr3));
+	device->save_item(NAME(cpustate->txb));
+	device->save_item(NAME(cpustate->rxb));
+	device->save_item(NAME(cpustate->txd));
+	device->save_item(NAME(cpustate->rxd));
+	device->save_item(NAME(cpustate->sck));
+	device->save_item(NAME(cpustate->ti));
+	device->save_item(NAME(cpustate->to));
+	device->save_item(NAME(cpustate->ci));
+	device->save_item(NAME(cpustate->co0));
+	device->save_item(NAME(cpustate->co1));
+	device->save_item(NAME(cpustate->irr));
+	device->save_item(NAME(cpustate->itf));
+	device->save_item(NAME(cpustate->ovc0));
+	device->save_item(NAME(cpustate->ovc1));
+	device->save_item(NAME(cpustate->ovcf));
+	device->save_item(NAME(cpustate->ovcs));
+	device->save_item(NAME(cpustate->edges));
+	device->save_item(NAME(cpustate->int1));
+	device->save_item(NAME(cpustate->int2));
 }
 
 #include "7810tbl.c"
@@ -2143,15 +2143,15 @@ CPU_GET_INFO( upd7810 )
 		case CPUINFO_INT_MIN_CYCLES:					info->i = 1;							break;
 		case CPUINFO_INT_MAX_CYCLES:					info->i = 40;							break;
 
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_PROGRAM:	info->i = 8;					break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_PROGRAM: info->i = 16;					break;
-		case DEVINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_PROGRAM: info->i = 0;					break;
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_DATA:	info->i = 0;					break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_DATA:	info->i = 0;					break;
-		case DEVINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_DATA:	info->i = 0;					break;
-		case DEVINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_IO:		info->i = 8;					break;
-		case DEVINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_IO:		info->i = 8;					break;
-		case DEVINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_IO:		info->i = 0;					break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_PROGRAM:	info->i = 8;					break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_PROGRAM: info->i = 16;					break;
+		case DEVINFO_INT_ADDRBUS_SHIFT + AS_PROGRAM: info->i = 0;					break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_DATA:	info->i = 0;					break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_DATA:	info->i = 0;					break;
+		case DEVINFO_INT_ADDRBUS_SHIFT + AS_DATA:	info->i = 0;					break;
+		case DEVINFO_INT_DATABUS_WIDTH + AS_IO:		info->i = 8;					break;
+		case DEVINFO_INT_ADDRBUS_WIDTH + AS_IO:		info->i = 8;					break;
+		case DEVINFO_INT_ADDRBUS_SHIFT + AS_IO:		info->i = 0;					break;
 
 		case CPUINFO_INT_INPUT_STATE + INPUT_LINE_NMI:	info->i = (IRR & INTNMI) ? ASSERT_LINE : CLEAR_LINE; break;
 		case CPUINFO_INT_INPUT_STATE + UPD7810_INTF1:	info->i = (IRR & INTF1) ? ASSERT_LINE : CLEAR_LINE; break;
