@@ -132,10 +132,10 @@ static const rgb_t crosshair_colors[] =
 ***************************************************************************/
 
 static void crosshair_exit(running_machine &machine);
-static void crosshair_load(running_machine *machine, int config_type, xml_data_node *parentnode);
-static void crosshair_save(running_machine *machine, int config_type, xml_data_node *parentnode);
+static void crosshair_load(running_machine &machine, int config_type, xml_data_node *parentnode);
+static void crosshair_save(running_machine &machine, int config_type, xml_data_node *parentnode);
 
-static void animate(screen_device &device, void *param, bool vblank_state);
+static void animate(running_machine &machine, screen_device &device, bool vblank_state);
 
 
 /***************************************************************************
@@ -148,7 +148,7 @@ static void animate(screen_device &device, void *param, bool vblank_state);
     structures for the given player
 -------------------------------------------------*/
 
-static void create_bitmap(running_machine *machine, int player)
+static void create_bitmap(running_machine &machine, int player)
 {
 	int x, y;
 	char filename[20];
@@ -156,23 +156,24 @@ static void create_bitmap(running_machine *machine, int player)
 
 	/* if we have a bitmap and texture for this player, kill it */
 	global_free(global.bitmap[player]);
-	machine->render().texture_free(global.texture[player]);
+	machine.render().texture_free(global.texture[player]);
 
+	emu_file crossfile(machine.options().crosshair_path(), OPEN_FLAG_READ);
 	if (global.name[player][0] != 0)
 	{
 		/* look for user specified file */
 		sprintf(filename, "%s.png", global.name[player]);
-		global.bitmap[player] = render_load_png(OPTION_CROSSHAIRPATH, NULL, filename, NULL, NULL);
+		global.bitmap[player] = render_load_png(crossfile, NULL, filename, NULL, NULL);
 	}
 	else
 	{
 		/* look for default cross?.png in crsshair\game dir */
 		sprintf(filename, "cross%d.png", player + 1);
-		global.bitmap[player] = render_load_png(OPTION_CROSSHAIRPATH, machine->gamedrv->name, filename, NULL, NULL);
+		global.bitmap[player] = render_load_png(crossfile, machine.system().name, filename, NULL, NULL);
 
 		/* look for default cross?.png in crsshair dir */
 		if (global.bitmap[player] == NULL)
-			global.bitmap[player] = render_load_png(OPTION_CROSSHAIRPATH, NULL, filename, NULL, NULL);
+			global.bitmap[player] = render_load_png(crossfile, NULL, filename, NULL, NULL);
 	}
 
 	/* if that didn't work, use the built-in one */
@@ -197,7 +198,7 @@ static void create_bitmap(running_machine *machine, int player)
 	}
 
 	/* create a texture to reference the bitmap */
-	global.texture[player] = machine->render().texture_alloc(render_texture::hq_scale);
+	global.texture[player] = machine.render().texture_alloc(render_texture::hq_scale);
 	global.texture[player]->set_bitmap(global.bitmap[player], NULL, TEXFORMAT_ARGB32);
 }
 
@@ -207,10 +208,10 @@ static void create_bitmap(running_machine *machine, int player)
     bitmaps and such
 -------------------------------------------------*/
 
-void crosshair_init(running_machine *machine)
+void crosshair_init(running_machine &machine)
 {
 	/* request a callback upon exiting */
-	machine->add_notifier(MACHINE_NOTIFY_EXIT, crosshair_exit);
+	machine.add_notifier(MACHINE_NOTIFY_EXIT, machine_notify_delegate(FUNC(crosshair_exit), &machine));
 
 	/* clear all the globals */
 	memset(&global, 0, sizeof(global));
@@ -219,8 +220,8 @@ void crosshair_init(running_machine *machine)
 	global.auto_time = CROSSHAIR_VISIBILITY_AUTOTIME_DEFAULT;
 
 	/* determine who needs crosshairs */
-	for (const input_port_config *port = machine->m_portlist.first(); port != NULL; port = port->next())
-		for (const input_field_config *field = port->fieldlist; field != NULL; field = field->next)
+	for (input_port_config *port = machine.m_portlist.first(); port != NULL; port = port->next())
+		for (input_field_config *field = port->fieldlist().first(); field != NULL; field = field->next())
 			if (field->crossaxis != CROSSHAIR_AXIS_NONE)
 			{
 				int player = field->player;
@@ -234,18 +235,18 @@ void crosshair_init(running_machine *machine)
 				global.visible[player] = (CROSSHAIR_VISIBILITY_DEFAULT == CROSSHAIR_VISIBILITY_OFF) ? FALSE : TRUE;
 
 				/* for now, use the main screen */
-				global.screen[player] = machine->primary_screen;
+				global.screen[player] = machine.primary_screen;
 
 				create_bitmap(machine, player);
 			}
 
 	/* register callbacks for when we load/save configurations */
 	if (global.usage)
-		config_register(machine, "crosshairs", crosshair_load, crosshair_save);
+		config_register(machine, "crosshairs", config_saveload_delegate(FUNC(crosshair_load), &machine), config_saveload_delegate(FUNC(crosshair_save), &machine));
 
 	/* register the animation callback */
-	if (machine->primary_screen != NULL)
-		machine->primary_screen->register_vblank_callback(animate, NULL);
+	if (machine.primary_screen != NULL)
+		machine.primary_screen->register_vblank_callback(vblank_state_delegate(FUNC(animate), &machine));
 }
 
 
@@ -273,7 +274,7 @@ static void crosshair_exit(running_machine &machine)
     if any crosshairs are used
 -------------------------------------------------*/
 
-int crosshair_get_usage(running_machine *machine)
+int crosshair_get_usage(running_machine &machine)
 {
 	return global.usage;
 }
@@ -285,7 +286,7 @@ int crosshair_get_usage(running_machine *machine)
     Note: auto_time is common for all players
 -------------------------------------------------*/
 
-void crosshair_get_user_settings(running_machine *machine, UINT8 player, crosshair_user_settings *settings)
+void crosshair_get_user_settings(running_machine &machine, UINT8 player, crosshair_user_settings *settings)
 {
 	settings->auto_time = global.auto_time;
 	settings->used = global.used[player];
@@ -300,7 +301,7 @@ void crosshair_get_user_settings(running_machine *machine, UINT8 player, crossha
     Note: auto_time is common for all players
 -------------------------------------------------*/
 
-void crosshair_set_user_settings(running_machine *machine, UINT8 player, crosshair_user_settings *settings)
+void crosshair_set_user_settings(running_machine &machine, UINT8 player, crosshair_user_settings *settings)
 {
 	int changed = FALSE;
 
@@ -324,7 +325,7 @@ void crosshair_set_user_settings(running_machine *machine, UINT8 player, crossha
     animate - animates the crosshair once a frame
 -------------------------------------------------*/
 
-static void animate(screen_device &device, void *param, bool vblank_state)
+static void animate(running_machine &machine, screen_device &device, bool vblank_state)
 {
 	int player;
 
@@ -345,7 +346,7 @@ static void animate(screen_device &device, void *param, bool vblank_state)
 	{
 		/* read all the lightgun values */
 		if (global.used[player])
-			input_port_get_crosshair_position(device.machine, player, &global.x[player], &global.y[player]);
+			input_port_get_crosshair_position(device.machine(), player, &global.x[player], &global.y[player]);
 
 		/* auto visibility */
 		if (global.mode[player] == CROSSHAIR_VISIBILITY_AUTO)
@@ -404,7 +405,7 @@ void crosshair_render(screen_device &screen)
     given player's crosshair
 -------------------------------------------------*/
 
-void crosshair_set_screen(running_machine *machine, int player, device_t *screen)
+void crosshair_set_screen(running_machine &machine, int player, device_t *screen)
 {
 	global.screen[player] = screen;
 }
@@ -415,7 +416,7 @@ void crosshair_set_screen(running_machine *machine, int player, device_t *screen
     configuration file
 -------------------------------------------------*/
 
-static void crosshair_load(running_machine *machine, int config_type, xml_data_node *parentnode)
+static void crosshair_load(running_machine &machine, int config_type, xml_data_node *parentnode)
 {
 	/* Note: crosshair_load() is only registered if croshairs are used */
 
@@ -474,7 +475,7 @@ static void crosshair_load(running_machine *machine, int config_type, xml_data_n
     configuration file
 -------------------------------------------------*/
 
-static void crosshair_save(running_machine *machine, int config_type, xml_data_node *parentnode)
+static void crosshair_save(running_machine &machine, int config_type, xml_data_node *parentnode)
 {
 	/* Note: crosshair_save() is only registered if crosshairs are used */
 
