@@ -30,10 +30,8 @@
  *
  *************************************/
 
-#define MDRV_CPU_VBLANK_INT_HACK(_func, _rate) \
-	TOKEN_UINT32_PACK2(MCONFIG_TOKEN_DIEXEC_VBLANK_INT, 8, _rate, 24), \
-	TOKEN_PTR(cpu_interrupt, _func), \
-	TOKEN_PTR(stringptr, NULL), \
+#define MCFG_CPU_VBLANK_INT_HACK(_func, _rate) \
+	device_execute_interface::static_set_vblank_int(*device, _func, NULL, _rate); \
 
 
 
@@ -52,19 +50,4 @@
 
 
 
-/*************************************
- *
- *  Graphics decoding. Drivers should
- *  use the new gfx_element_mark_dirty()
- *  to explicitly mark tiles dirty, and
- *  gfx_element_get_data() to fetch a
- *  pointer to the data (and undirty
- *  the tile)
- *
- *************************************/
-
-void decodechar(const gfx_element *gfx, UINT32 code, const UINT8 *src);
-
-
-
 #endif	/* __DEPRECAT_H__ */
