@@ -81,7 +81,7 @@ resource_pool &machine_get_pool(running_machine &machine)
 {
 	// temporary to get around include dependencies, until CPUs
 	// get a proper device class
-	return machine.m_respool;
+	return machine.respool();
 }
 
 
@@ -95,29 +95,24 @@ resource_pool &machine_get_pool(running_machine &machine)
 //-------------------------------------------------
 
 device_list::device_list(resource_pool &pool)
-	: tagged_device_list<device_t>(pool),
-	  m_machine(NULL)
+	: tagged_list<device_t>(pool)
 {
 }
 
 
 //-------------------------------------------------
-//  import_config_list - import a list of device
-//  configs and allocate new devices
+//  set_machine_all - once the machine is created,
+//  tell every device about it
 //-------------------------------------------------
 
-void device_list::import_config_list(const device_config_list &list, running_machine &machine)
+void device_list::set_machine_all(running_machine &machine)
 {
-	// remember the machine for later use
+	// add exit and reset callbacks
 	m_machine = &machine;
 
-	// append each device from the configuration list
-	for (const device_config *devconfig = list.first(); devconfig != NULL; devconfig = devconfig->next())
-	{
-		device_t *newdevice = devconfig->alloc_device(*m_machine);
-		append(devconfig->tag(), newdevice);
-		newdevice->find_interfaces();
-	}
+	// iterate over devices and set their machines as well
+	for (device_t *device = first(); device != NULL; device = device->next())
+		device->set_machine(machine);
 }
 
 
@@ -129,35 +124,56 @@ void device_list::import_config_list(const device_config_list &list, running_mac
 void device_list::start_all()
 {
 	// add exit and reset callbacks
-	assert(m_machine != NULL);
-	m_machine->add_notifier(MACHINE_NOTIFY_RESET, static_reset);
-	m_machine->add_notifier(MACHINE_NOTIFY_EXIT, static_exit);
+	machine().add_notifier(MACHINE_NOTIFY_RESET, machine_notify_delegate(FUNC(device_list::reset_all), this));
+	machine().add_notifier(MACHINE_NOTIFY_EXIT, machine_notify_delegate(FUNC(device_list::exit), this));
 
 	// add pre-save and post-load callbacks
-	state_save_register_presave(m_machine, static_pre_save, this);
-	state_save_register_postload(m_machine, static_post_load, this);
+	machine().save().register_presave(save_prepost_delegate(FUNC(device_list::presave_all), this));
+	machine().save().register_postload(save_prepost_delegate(FUNC(device_list::postload_all), this));
 
-	// iterate over devices to start them
+	// start_new_devices does all the necessary work
+	start_new_devices();
+}
+
+
+//-------------------------------------------------
+//  start_new_devices - start any unstarted devices
+//-------------------------------------------------
+
+void device_list::start_new_devices()
+{
+	assert(m_machine != NULL);
+
+	// iterate through the devices
 	device_t *nextdevice;
 	for (device_t *device = first(); device != NULL; device = nextdevice)
 	{
-		// attempt to start the device, catching any expected exceptions
+		// see if this device is what we want
 		nextdevice = device->next();
-		try
+		if (!device->started())
 		{
-			mame_printf_verbose("Starting %s '%s'\n", device->name(), device->tag());
-			device->start();
-		}
+			// attempt to start the device, catching any expected exceptions
+			try
+			{
+				// if the device doesn't have a machine yet, set it first
+				if (device->m_machine == NULL)
+					device->set_machine(machine());
 
-		// handle missing dependencies by moving the device to the end
-		catch (device_missing_dependencies &)
-		{
-			// if we're the end, fail
-			mame_printf_verbose("  (missing dependencies; rescheduling)\n");
-			if (nextdevice == NULL)
-				throw emu_fatalerror("Circular dependency in device startup; unable to start %s '%s'\n", device->name(), device->tag());
-			detach(device);
-			append(device->tag(), device);
+				// now start the device
+				mame_printf_verbose("Starting %s '%s'\n", device->name(), device->tag());
+				device->start();
+			}
+
+			// handle missing dependencies by moving the device to the end
+			catch (device_missing_dependencies &)
+			{
+				// if we're the end, fail
+				mame_printf_verbose("  (missing dependencies; rescheduling)\n");
+				if (nextdevice == NULL)
+					throw emu_fatalerror("Circular dependency in device startup; unable to start %s '%s'\n", device->name(), device->tag());
+				detach(*device);
+				append(device->tag(), *device);
+			}
 		}
 	}
 }
@@ -169,15 +185,89 @@ void device_list::start_all()
 
 void device_list::reset_all()
 {
-	// iterate over devices and stop them
+	// iterate over devices and reset them
 	for (device_t *device = first(); device != NULL; device = device->next())
 		device->reset();
 }
 
 
-void device_list::static_reset(running_machine &machine)
+//-------------------------------------------------
+//  stop_all - stop all the devices in the
+//  list
+//-------------------------------------------------
+
+void device_list::stop_all()
 {
-	machine.m_devicelist.reset_all();
+	// iterate over devices and stop them
+	for (device_t *device = first(); device != NULL; device = device->next())
+		device->stop();
+
+	// leave with no machine
+	m_machine = NULL;
+}
+
+
+//-------------------------------------------------
+//  first - return the first device of the given
+//  type
+//-------------------------------------------------
+
+device_t *device_list::first(device_type type) const
+{
+	device_t *cur;
+	for (cur = super::first(); cur != NULL && cur->type() != type; cur = cur->next()) ;
+	return cur;
+}
+
+
+//-------------------------------------------------
+//  count - count the number of devices of the
+//  given type
+//-------------------------------------------------
+
+int device_list::count(device_type type) const
+{
+	int num = 0;
+	for (const device_t *curdev = first(type); curdev != NULL; curdev = curdev->typenext()) num++;
+	return num;
+}
+
+
+//-------------------------------------------------
+//  indexof - return the index of the given device
+//  among its kind
+//-------------------------------------------------
+
+int device_list::indexof(device_type type, device_t &object) const
+{
+	int num = 0;
+	for (device_t *cur = first(type); cur != NULL; cur = cur->typenext(), num++)
+		if (cur == &object) return num;
+	return -1;
+}
+
+
+//-------------------------------------------------
+//  indexof - return the index of the given device
+//  among its kind
+//-------------------------------------------------
+
+int device_list::indexof(device_type type, const char *tag) const
+{
+	device_t *object = find(tag);
+	return (object != NULL && object->type() == type) ? indexof(type, *object) : -1;
+}
+
+
+//-------------------------------------------------
+//  find - find a device by type + index
+//-------------------------------------------------
+
+device_t *device_list::find(device_type type, int index) const
+{
+	for (device_t *cur = first(type); cur != NULL; cur = cur->typenext())
+		if (index-- == 0) return cur;
+	return NULL;
 }
 
 
@@ -185,343 +275,45 @@ void device_list::static_reset(running_machine &machine)
 //  static_exit - tear down all the devices
 //-------------------------------------------------
 
-void device_list::static_exit(running_machine &machine)
+void device_list::exit()
 {
 	// first let the debugger save comments
-	if ((machine.debug_flags & DEBUG_FLAG_ENABLED) != 0)
-		debug_comment_save(&machine);
+	if ((machine().debug_flags & DEBUG_FLAG_ENABLED) != 0)
+		debug_comment_save(machine());
+
+	// stop all the devices before we go away
+	stop_all();
 
 	// then nuke the devices
-	machine.m_devicelist.reset();
+	reset();
 }
 
 
 //-------------------------------------------------
-//  static_pre_save - tell all the devices we are
+//  presave_all - tell all the devices we are
 //  about to save
 //-------------------------------------------------
 
-void device_list::static_pre_save(running_machine *machine, void *param)
+void device_list::presave_all()
 {
-	device_list *list = reinterpret_cast<device_list *>(param);
-	for (device_t *device = list->first(); device != NULL; device = device->next())
+	for (device_t *device = first(); device != NULL; device = device->next())
 		device->pre_save();
 }
 
 
 //-------------------------------------------------
-//  static_post_load - tell all the devices we just
+//  postload_all - tell all the devices we just
 //  completed a load
 //-------------------------------------------------
 
-void device_list::static_post_load(running_machine *machine, void *param)
+void device_list::postload_all()
 {
-	device_list *list = reinterpret_cast<device_list *>(param);
-	for (device_t *device = list->first(); device != NULL; device = device->next())
+	for (device_t *device = first(); device != NULL; device = device->next())
 		device->post_load();
 }
 
 
 
-//**************************************************************************
-//  DEVICE INTERFACE CONFIGURATION
-//**************************************************************************
-
-//-------------------------------------------------
-//  device_config_interface - constructor
-//-------------------------------------------------
-
-device_config_interface::device_config_interface(const machine_config &mconfig, device_config &devconfig)
-	: m_device_config(devconfig),
-	  m_machine_config(mconfig),
-	  m_interface_next(NULL)
-{
-	device_config_interface **tailptr;
-	for (tailptr = &devconfig.m_interface_list; *tailptr != NULL; tailptr = &(*tailptr)->m_interface_next) ;
-	*tailptr = this;
-}
-
-
-//-------------------------------------------------
-//  ~device_config_interface - destructor
-//-------------------------------------------------
-
-device_config_interface::~device_config_interface()
-{
-}
-
-
-//-------------------------------------------------
-//  interface_config_complete - perform any
-//  operations now that the configuration is
-//  complete
-//-------------------------------------------------
-
-void device_config_interface::interface_config_complete()
-{
-	// do nothing by default
-}
-
-
-//-------------------------------------------------
-//  interface_validity_check - default validation
-//  for a device after the configuration has been
-//  constructed
-//-------------------------------------------------
-
-bool device_config_interface::interface_validity_check(const game_driver &driver) const
-{
-	return false;
-}
-
-
-
-//**************************************************************************
-//  DEVICE CONFIGURATION
-//**************************************************************************
-
-//-------------------------------------------------
-//  device_config - constructor for a new
-//  device configuration
-//-------------------------------------------------
-
-device_config::device_config(const machine_config &mconfig, device_type type, const char *name, const char *tag, const device_config *owner, UINT32 clock, UINT32 param)
-	: m_next(NULL),
-	  m_owner(const_cast<device_config *>(owner)),
-	  m_interface_list(NULL),
-	  m_type(type),
-	  m_clock(clock),
-	  m_machine_config(mconfig),
-	  m_static_config(NULL),
-	  m_name(name),
-	  m_tag(tag),
-	  m_config_complete(false)
-{
-	// derive the clock from our owner if requested
-	if ((m_clock & 0xff000000) == 0xff000000)
-	{
-		assert(m_owner != NULL);
-		m_clock = m_owner->m_clock * ((m_clock >> 12) & 0xfff) / ((m_clock >> 0) & 0xfff);
-	}
-}
-
-
-//-------------------------------------------------
-//  ~device_config - destructor
-//-------------------------------------------------
-
-device_config::~device_config()
-{
-}
-
-
-//-------------------------------------------------
-//  config_complete - called when the
-//  configuration of a device is complete
-//-------------------------------------------------
-
-void device_config::config_complete()
-{
-	// first notify the interfaces
-	for (device_config_interface *intf = m_interface_list; intf != NULL; intf = intf->interface_next())
-		intf->interface_config_complete();
-
-	// then notify the device itself
-	device_config_complete();
-}
-
-
-//-------------------------------------------------
-//  validity_check - validate a device after the
-//  configuration has been constructed
-//-------------------------------------------------
-
-bool device_config::validity_check(const game_driver &driver) const
-{
-	bool error = false;
-
-	// validate via the interfaces
-	for (device_config_interface *intf = m_interface_list; intf != NULL; intf = intf->interface_next())
-		if (intf->interface_validity_check(driver))
-			error = true;
-
-	// let the device itself validate
-	if (device_validity_check(driver))
-		error = true;
-
-	return error;
-}
-
-
-//-------------------------------------------------
-//  device_config_complete - perform any
-//  operations now that the configuration is
-//  complete
-//-------------------------------------------------
-
-void device_config::device_config_complete()
-{
-	// do nothing by default
-}
-
-
-//-------------------------------------------------
-//  device_validity_check - validate a device after
-//  the configuration has been constructed
-//-------------------------------------------------
-
-bool device_config::device_validity_check(const game_driver &driver) const
-{
-	// indicate no error by default
-	return false;
-}
-
-
-//-------------------------------------------------
-//  rom_region - return a pointer to the implicit
-//  rom region description for this device
-//-------------------------------------------------
-
-const rom_entry *device_config::rom_region() const
-{
-	return NULL;
-}
-
-
-//-------------------------------------------------
-//  machine_config - return a pointer to a machine
-//  config constructor describing sub-devices for
-//  this device
-//-------------------------------------------------
-
-machine_config_constructor device_config::machine_config_additions() const
-{
-	return NULL;
-}
-
-
-
-//**************************************************************************
-//  LIVE DEVICE INTERFACES
-//**************************************************************************
-
-//-------------------------------------------------
-//  device_interface - constructor
-//-------------------------------------------------
-
-device_interface::device_interface(running_machine &machine, const device_config &config, device_t &device)
-	: m_interface_next(NULL),
-	  m_device(device)
-{
-	device_interface **tailptr;
-	for (tailptr = &device.m_interface_list; *tailptr != NULL; tailptr = &(*tailptr)->m_interface_next) ;
-	*tailptr = this;
-}
-
-
-//-------------------------------------------------
-//  ~device_interface - destructor
-//-------------------------------------------------
-
-device_interface::~device_interface()
-{
-}
-
-
-//-------------------------------------------------
-//  interface_pre_start - called before the
-//  device's own start function
-//-------------------------------------------------
-
-void device_interface::interface_pre_start()
-{
-	// do nothing by default
-}
-
-
-//-------------------------------------------------
-//  interface_post_start - called after the
-//  device's own start function
-//-------------------------------------------------
-
-void device_interface::interface_post_start()
-{
-	// do nothing by default
-}
-
-
-//-------------------------------------------------
-//  interface_pre_reset - called before the
-//  device's own reset function
-//-------------------------------------------------
-
-void device_interface::interface_pre_reset()
-{
-	// do nothing by default
-}
-
-
-//-------------------------------------------------
-//  interface_post_reset - called after the
-//  device's own reset function
-//-------------------------------------------------
-
-void device_interface::interface_post_reset()
-{
-	// do nothing by default
-}
-
-
-//-------------------------------------------------
-//  interface_pre_save - called prior to saving the
-//  state, so that registered variables can be
-//  properly normalized
-//-------------------------------------------------
-
-void device_interface::interface_pre_save()
-{
-	// do nothing by default
-}
-
-
-//-------------------------------------------------
-//  interface_post_load - called after the loading a
-//  saved state, so that registered variables can
-//  be expaneded as necessary
-//-------------------------------------------------
-
-void device_interface::interface_post_load()
-{
-	// do nothing by default
-}
-
-
-//-------------------------------------------------
-//  interface_clock_changed - called when the
-//  device clock is altered in any way; designed
-//  to be overridden by the actual device
-//  implementation
-//-------------------------------------------------
-
-void device_interface::interface_clock_changed()
-{
-	// do nothing by default
-}
-
-
-//-------------------------------------------------
-//  interface_debug_setup - called to allow
-//  interfaces to set up any debugging for this
-//  device
-//-------------------------------------------------
-
-void device_interface::interface_debug_setup()
-{
-	// do nothing by default
-}
-
-
-
 //**************************************************************************
 //  LIVE DEVICE MANAGEMENT
 //**************************************************************************
@@ -532,25 +324,65 @@ void device_interface::interface_debug_setup()
 //  from the provided config
 //-------------------------------------------------
 
-device_t::device_t(running_machine &_machine, const device_config &config)
-	: machine(&_machine),
-	  m_machine(_machine),
-	  m_debug(NULL),
+device_t::device_t(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock)
+	: m_debug(NULL),
 	  m_execute(NULL),
 	  m_memory(NULL),
 	  m_state(NULL),
 	  m_next(NULL),
-	  m_owner((config.m_owner != NULL) ? _machine.m_devicelist.find(config.m_owner->tag()) : NULL),
+	  m_owner(owner),
 	  m_interface_list(NULL),
+	  m_type(type),
+	  m_configured_clock(clock),
+	  m_machine_config(mconfig),
+	  m_static_config(NULL),
+	  m_input_defaults(NULL),
+	  m_name(name),
 	  m_started(false),
-	  m_clock(config.m_clock),
+	  m_clock(clock),
 	  m_region(NULL),
-	  m_baseconfig(config),
-	  m_unscaled_clock(config.m_clock),
+	  m_unscaled_clock(clock),
 	  m_clock_scale(1.0),
-	  m_attoseconds_per_clock((config.m_clock == 0) ? 0 : HZ_TO_ATTOSECONDS(config.m_clock)),
-	  m_auto_finder_list(NULL)
+	  m_attoseconds_per_clock((clock == 0) ? 0 : HZ_TO_ATTOSECONDS(clock)),
+	  m_auto_finder_list(NULL),
+	  m_machine(NULL),
+	  m_save(NULL),
+	  m_tag(tag),
+	  m_config_complete(false)
 {
+	static_set_clock(*this, clock);
+}
+
+
+device_t::device_t(const machine_config &mconfig, device_type type, const char *name, const char *shortname, const char *tag, device_t *owner, UINT32 clock)
+	: m_debug(NULL),
+	  m_execute(NULL),
+	  m_memory(NULL),
+	  m_state(NULL),
+	  m_next(NULL),
+	  m_owner(owner),
+	  m_interface_list(NULL),
+	  m_type(type),
+	  m_configured_clock(clock),
+	  m_machine_config(mconfig),
+	  m_static_config(NULL),
+	  m_input_defaults(NULL),
+	  m_name(name),
+	  m_shortname(shortname),
+	  m_searchpath(shortname),
+	  m_started(false),
+	  m_clock(clock),
+	  m_region(NULL),
+	  m_unscaled_clock(clock),
+	  m_clock_scale(1.0),
+	  m_attoseconds_per_clock((clock == 0) ? 0 : HZ_TO_ATTOSECONDS(clock)),
+	  m_auto_finder_list(NULL),
+	  m_machine(NULL),
+	  m_save(NULL),
+	  m_tag(tag),
+	  m_config_complete(false)
+{
+	static_set_clock(*this, clock);
 }
 
 
@@ -560,7 +392,6 @@ device_t::device_t(running_machine &_machine, const device_config &config)
 
 device_t::~device_t()
 {
-	auto_free(&m_machine, m_debug);
 }
 
 
@@ -577,7 +408,7 @@ const memory_region *device_t::subregion(const char *_tag) const
 
 	// build a fully-qualified name
 	astring tempstring;
-	return m_machine.region(subtag(tempstring, _tag));
+	return machine().region(subtag(tempstring, _tag));
 }
 
 
@@ -594,7 +425,7 @@ device_t *device_t::subdevice(const char *_tag) const
 
 	// build a fully-qualified name
 	astring tempstring;
-	return m_machine.device(subtag(tempstring, _tag));
+	return mconfig().devicelist().find((const char *)subtag(tempstring, _tag));
 }
 
 
@@ -611,12 +442,92 @@ device_t *device_t::siblingdevice(const char *_tag) const
 
 	// build a fully-qualified name
 	astring tempstring;
-	return m_machine.device(siblingtag(tempstring, _tag));
+	return mconfig().devicelist().find((const char *)siblingtag(tempstring, _tag));
 }
 
 
 //-------------------------------------------------
-//  set_clock - sets the given device's raw clock
+//  static_set_clock - set/change the clock on
+//  a device
+//-------------------------------------------------
+
+void device_t::static_set_clock(device_t &device, UINT32 clock)
+{
+	// derive the clock from our owner if requested
+	if ((clock & 0xff000000) == 0xff000000)
+	{
+		assert(device.m_owner != NULL);
+		clock = device.m_owner->m_configured_clock * ((clock >> 12) & 0xfff) / ((clock >> 0) & 0xfff);
+	}
+
+	device.m_clock = device.m_unscaled_clock = device.m_configured_clock = clock;
+	device.m_attoseconds_per_clock = (clock == 0) ? 0 : HZ_TO_ATTOSECONDS(clock);
+}
+
+
+//-------------------------------------------------
+//  config_complete - called when the
+//  configuration of a device is complete
+//-------------------------------------------------
+
+void device_t::config_complete()
+{
+	// first notify the interfaces
+	for (device_interface *intf = m_interface_list; intf != NULL; intf = intf->interface_next())
+		intf->interface_config_complete();
+
+	// then notify the device itself
+	device_config_complete();
+
+	// then mark ourselves complete
+	m_config_complete = true;
+}
+
+
+//-------------------------------------------------
+//  validity_check - validate a device after the
+//  configuration has been constructed
+//-------------------------------------------------
+
+bool device_t::validity_check(emu_options &options, const game_driver &driver) const
+{
+	bool error = false;
+
+	// validate via the interfaces
+	for (device_interface *intf = m_interface_list; intf != NULL; intf = intf->interface_next())
+		if (intf->interface_validity_check(options, driver))
+			error = true;
+
+	// let the device itself validate
+	if (device_validity_check(options, driver))
+		error = true;
+
+	return error;
+}
+
+
+//-------------------------------------------------
+//  reset - reset a device
+//-------------------------------------------------
+
+void device_t::reset()
+{
+	// let the interfaces do their pre-work
+	for (device_interface *intf = m_interface_list; intf != NULL; intf = intf->interface_next())
+		intf->interface_pre_reset();
+
+	// reset the device
+	device_reset();
+
+	// let the interfaces do their post-work
+	for (device_interface *intf = m_interface_list; intf != NULL; intf = intf->interface_next())
+		intf->interface_post_reset();
+}
+
+
+//-------------------------------------------------
+//  set_unscaled_clock - sets the given device's
+//  unscaled clock
 //-------------------------------------------------
 
 void device_t::set_unscaled_clock(UINT32 clock)
@@ -629,7 +540,7 @@ void device_t::set_unscaled_clock(UINT32 clock)
 
 
 //-------------------------------------------------
-//  set_clockscale - sets a scale factor for the
+//  set_clock_scale - sets a scale factor for the
 //  device's clock
 //-------------------------------------------------
 
@@ -650,12 +561,12 @@ void device_t::set_clock_scale(double clockscale)
 attotime device_t::clocks_to_attotime(UINT64 numclocks) const
 {
 	if (numclocks < m_clock)
-		return attotime_make(0, numclocks * m_attoseconds_per_clock);
+		return attotime(0, numclocks * m_attoseconds_per_clock);
 	else
 	{
 		UINT32 remainder;
 		UINT32 quotient = divu_64x32_rem(numclocks, m_clock, &remainder);
-		return attotime_make(quotient, (UINT64)remainder * (UINT64)m_attoseconds_per_clock);
+		return attotime(quotient, (UINT64)remainder * (UINT64)m_attoseconds_per_clock);
 	}
 }
 
@@ -672,15 +583,36 @@ UINT64 device_t::attotime_to_clocks(attotime duration) const
 
 
 //-------------------------------------------------
-//  find_interfaces - locate fast interfaces
+//  timer_alloc - allocate a timer for our device
+//  callback
 //-------------------------------------------------
 
-void device_t::find_interfaces()
+emu_timer *device_t::timer_alloc(device_timer_id id, void *ptr)
 {
-	// look up the common interfaces
-	m_execute = dynamic_cast<device_execute_interface *>(this);
-	m_memory = dynamic_cast<device_memory_interface *>(this);
-	m_state = dynamic_cast<device_state_interface *>(this);
+	return machine().scheduler().timer_alloc(*this, id, ptr);
+}
+
+
+//-------------------------------------------------
+//  timer_set - set a temporary timer that will
+//  call our device callback
+//-------------------------------------------------
+
+void device_t::timer_set(attotime duration, device_timer_id id, int param, void *ptr)
+{
+	machine().scheduler().timer_set(duration, *this, id, param, ptr);
+}
+
+
+//-------------------------------------------------
+//  set_machine - notify that the machine now
+//  exists
+//-------------------------------------------------
+
+void device_t::set_machine(running_machine &machine)
+{
+	m_machine = &machine;
+	m_save = &machine.save();
 }
 
 
@@ -690,8 +622,8 @@ void device_t::find_interfaces()
 
 void device_t::start()
 {
-	// populate the region field
-	m_region = m_machine.region(tag());
+	// populate the machine and the region field
+	m_region = machine().region(tag());
 
 	// find all the registered devices
 	for (auto_finder_base *autodev = m_auto_finder_list; autodev != NULL; autodev = autodev->m_next)
@@ -702,19 +634,19 @@ void device_t::start()
 		intf->interface_pre_start();
 
 	// remember the number of state registrations
-	int state_registrations = state_save_get_reg_count(machine);
+	int state_registrations = machine().save().registration_count();
 
 	// start the device
 	device_start();
 
 	// complain if nothing was registered by the device
-	state_registrations = state_save_get_reg_count(machine) - state_registrations;
+	state_registrations = machine().save().registration_count() - state_registrations;
 	device_execute_interface *exec;
 	device_sound_interface *sound;
 	if (state_registrations == 0 && (interface(exec) || interface(sound)))
 	{
 		logerror("Device '%s' did not register any state to save!\n", tag());
-		if ((m_machine.gamedrv->flags & GAME_SUPPORTS_SAVE) != 0)
+		if ((machine().system().flags & GAME_SUPPORTS_SAVE) != 0)
 			fatalerror("Device '%s' did not register any state to save!", tag());
 	}
 
@@ -726,22 +658,48 @@ void device_t::start()
 	notify_clock_changed();
 
 	// if we're debugging, create a device_debug object
-	if ((m_machine.debug_flags & DEBUG_FLAG_ENABLED) != 0)
+	if ((machine().debug_flags & DEBUG_FLAG_ENABLED) != 0)
 	{
-		m_debug = auto_alloc(&m_machine, device_debug(*this));
+		m_debug = auto_alloc(machine(), device_debug(*this));
 		debug_setup();
 	}
 
 	// register our save states
-	state_save_register_device_item(this, 0, m_clock);
-	state_save_register_device_item(this, 0, m_unscaled_clock);
-	state_save_register_device_item(this, 0, m_clock_scale);
+	save_item(NAME(m_clock));
+	save_item(NAME(m_unscaled_clock));
+	save_item(NAME(m_clock_scale));
 
 	// we're now officially started
 	m_started = true;
 }
 
 
+//-------------------------------------------------
+//  stop - stop a device
+//-------------------------------------------------
+
+void device_t::stop()
+{
+	// let the interfaces do their pre-work
+	for (device_interface *intf = m_interface_list; intf != NULL; intf = intf->interface_next())
+		intf->interface_pre_stop();
+
+	// stop the device
+	device_stop();
+
+	// let the interfaces do their post-work
+	for (device_interface *intf = m_interface_list; intf != NULL; intf = intf->interface_next())
+		intf->interface_post_stop();
+
+	// free any debugging info
+	auto_free(machine(), m_debug);
+
+	// we're now officially stopped, and the machine is off-limits
+	m_started = false;
+	m_machine = NULL;
+}
+
+
 //-------------------------------------------------
 //  debug_setup - set up for debugging
 //-------------------------------------------------
@@ -757,25 +715,6 @@ void device_t::debug_setup()
 }
 
 
-//-------------------------------------------------
-//  reset - reset a device
-//-------------------------------------------------
-
-void device_t::reset()
-{
-	// let the interfaces do their pre-work
-	for (device_interface *intf = m_interface_list; intf != NULL; intf = intf->interface_next())
-		intf->interface_pre_reset();
-
-	// reset the device
-	device_reset();
-
-	// let the interfaces do their post-work
-	for (device_interface *intf = m_interface_list; intf != NULL; intf = intf->interface_next())
-		intf->interface_post_reset();
-}
-
-
 //-------------------------------------------------
 //  pre_save - tell the device and its interfaces
 //  that we are about to save
@@ -808,6 +747,84 @@ void device_t::post_load()
 }
 
 
+//-------------------------------------------------
+//  notify_clock_changed - notify all interfaces
+//  that the clock has changed
+//-------------------------------------------------
+
+void device_t::notify_clock_changed()
+{
+	// first notify interfaces
+	for (device_interface *intf = m_interface_list; intf != NULL; intf = intf->interface_next())
+		intf->interface_clock_changed();
+
+	// then notify the device
+	device_clock_changed();
+}
+
+
+//-------------------------------------------------
+//  device_config_complete - perform any
+//  operations now that the configuration is
+//  complete
+//-------------------------------------------------
+
+void device_t::device_config_complete()
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  device_validity_check - validate a device after
+//  the configuration has been constructed
+//-------------------------------------------------
+
+bool device_t::device_validity_check(emu_options &options, const game_driver &driver) const
+{
+	// indicate no error by default
+	return false;
+}
+
+
+//-------------------------------------------------
+//  rom_region - return a pointer to the implicit
+//  rom region description for this device
+//-------------------------------------------------
+
+const rom_entry *device_t::device_rom_region() const
+{
+	// none by default
+	return NULL;
+}
+
+
+//-------------------------------------------------
+//  machine_config - return a pointer to a machine
+//  config constructor describing sub-devices for
+//  this device
+//-------------------------------------------------
+
+machine_config_constructor device_t::device_mconfig_additions() const
+{
+	// none by default
+	return NULL;
+}
+
+
+
+//-------------------------------------------------
+//  input_ports - return a pointer to the implicit
+//  input ports description for this device
+//-------------------------------------------------
+
+ioport_constructor device_t::device_input_ports() const
+{
+	// none by default
+	return NULL;
+}
+
+
 //-------------------------------------------------
 //  device_reset - actually handle resetting of
 //  a device; designed to be overriden by the
@@ -820,6 +837,17 @@ void device_t::device_reset()
 }
 
 
+//-------------------------------------------------
+//  device_stop - clean up anything that needs to
+//  happen before the running_machine goes away
+//-------------------------------------------------
+
+void device_t::device_stop()
+{
+	// do nothing by default
+}
+
+
 //-------------------------------------------------
 //  device_pre_save - called prior to saving the
 //  state, so that registered variables can be
@@ -879,22 +907,6 @@ void device_t::device_timer(emu_timer &timer, device_timer_id id, int param, voi
 }
 
 
-//-------------------------------------------------
-//  notify_clock_changed - notify all interfaces
-//  that the clock has changed
-//-------------------------------------------------
-
-void device_t::notify_clock_changed()
-{
-	// first notify interfaces
-	for (device_interface *intf = m_interface_list; intf != NULL; intf = intf->interface_next())
-		intf->interface_clock_changed();
-
-	// then notify the device
-	device_clock_changed();
-}
-
-
 //-------------------------------------------------
 //  register_auto_finder - add a new item to the
 //  list of stuff to find after we go live
@@ -948,7 +960,7 @@ device_t *device_t::auto_finder_base::find_device(device_t &base, const char *ta
 
 void *device_t::auto_finder_base::find_shared_ptr(device_t &base, const char *tag)
 {
-	return memory_get_shared(*base.machine, tag);
+	return memory_get_shared(base.machine(), tag);
 }
 
 
@@ -959,6 +971,173 @@ void *device_t::auto_finder_base::find_shared_ptr(device_t &base, const char *ta
 size_t device_t::auto_finder_base::find_shared_size(device_t &base, const char *tag)
 {
 	size_t result = 0;
-	memory_get_shared(*base.machine, tag, result);
+	memory_get_shared(base.machine(), tag, result);
 	return result;
 }
+
+
+
+//**************************************************************************
+//  LIVE DEVICE INTERFACES
+//**************************************************************************
+
+//-------------------------------------------------
+//  device_interface - constructor
+//-------------------------------------------------
+
+device_interface::device_interface(device_t &device)
+	: m_interface_next(NULL),
+	  m_device(device)
+{
+	device_interface **tailptr;
+	for (tailptr = &device.m_interface_list; *tailptr != NULL; tailptr = &(*tailptr)->m_interface_next) ;
+	*tailptr = this;
+}
+
+
+//-------------------------------------------------
+//  ~device_interface - destructor
+//-------------------------------------------------
+
+device_interface::~device_interface()
+{
+}
+
+
+//-------------------------------------------------
+//  interface_config_complete - perform any
+//  operations now that the configuration is
+//  complete
+//-------------------------------------------------
+
+void device_interface::interface_config_complete()
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  interface_validity_check - default validation
+//  for a device after the configuration has been
+//  constructed
+//-------------------------------------------------
+
+bool device_interface::interface_validity_check(emu_options &options, const game_driver &driver) const
+{
+	return false;
+}
+
+
+//-------------------------------------------------
+//  interface_pre_start - called before the
+//  device's own start function
+//-------------------------------------------------
+
+void device_interface::interface_pre_start()
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  interface_post_start - called after the
+//  device's own start function
+//-------------------------------------------------
+
+void device_interface::interface_post_start()
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  interface_pre_reset - called before the
+//  device's own reset function
+//-------------------------------------------------
+
+void device_interface::interface_pre_reset()
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  interface_post_reset - called after the
+//  device's own reset function
+//-------------------------------------------------
+
+void device_interface::interface_post_reset()
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  interface_pre_stop - called before the
+//  device's own stop function
+//-------------------------------------------------
+
+void device_interface::interface_pre_stop()
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  interface_post_stop - called after the
+//  device's own stop function
+//-------------------------------------------------
+
+void device_interface::interface_post_stop()
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  interface_pre_save - called prior to saving the
+//  state, so that registered variables can be
+//  properly normalized
+//-------------------------------------------------
+
+void device_interface::interface_pre_save()
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  interface_post_load - called after the loading a
+//  saved state, so that registered variables can
+//  be expaneded as necessary
+//-------------------------------------------------
+
+void device_interface::interface_post_load()
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  interface_clock_changed - called when the
+//  device clock is altered in any way; designed
+//  to be overridden by the actual device
+//  implementation
+//-------------------------------------------------
+
+void device_interface::interface_clock_changed()
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  interface_debug_setup - called to allow
+//  interfaces to set up any debugging for this
+//  device
+//-------------------------------------------------
+
+void device_interface::interface_debug_setup()
+{
+	// do nothing by default
+}
