@@ -68,207 +68,25 @@ const int TRIGGER_SUSPENDTIME	= -4000;
 //**************************************************************************
 
 //-------------------------------------------------
-//  device_config_execute_interface - constructor
+//  device_execute_interface - constructor
 //-------------------------------------------------
 
-device_config_execute_interface::device_config_execute_interface(const machine_config &mconfig, device_config &devconfig)
-	: device_config_interface(mconfig, devconfig),
+device_execute_interface::device_execute_interface(const machine_config &mconfig, device_t &device)
+	: device_interface(device),
+	  m_cothread(cothread_entry_delegate(FUNC(device_execute_interface::run_thread_wrapper), this)),
 	  m_disabled(false),
 	  m_vblank_interrupt(NULL),
 	  m_vblank_interrupts_per_frame(0),
 	  m_vblank_interrupt_screen(NULL),
 	  m_timed_interrupt(NULL),
-	  m_timed_interrupt_period(0)
-{
-}
-
-
-//-------------------------------------------------
-//  device_config_execute_interface - destructor
-//-------------------------------------------------
-
-device_config_execute_interface::~device_config_execute_interface()
-{
-}
-
-
-//-------------------------------------------------
-//  execute_clocks_to_cycles - convert the number
-//  of clocks to cycles, rounding down if necessary
-//-------------------------------------------------
-
-UINT64 device_config_execute_interface::execute_clocks_to_cycles(UINT64 clocks) const
-{
-	return clocks;
-}
-
-
-//-------------------------------------------------
-//  execute_cycles_to_clocks - convert the number
-//  of cycles to clocks, rounding down if necessary
-//-------------------------------------------------
-
-UINT64 device_config_execute_interface::execute_cycles_to_clocks(UINT64 cycles) const
-{
-	return cycles;
-}
-
-
-//-------------------------------------------------
-//  execute_min_cycles - return the smallest number
-//  of cycles that a single instruction or
-//  operation can take
-//-------------------------------------------------
-
-UINT32 device_config_execute_interface::execute_min_cycles() const
-{
-	return 1;
-}
-
-
-//-------------------------------------------------
-//  execute_max_cycles - return the maximum number
-//  of cycles that a single instruction or
-//  operation can take
-//-------------------------------------------------
-
-UINT32 device_config_execute_interface::execute_max_cycles() const
-{
-	return 1;
-}
-
-
-//-------------------------------------------------
-//  execute_input_lines - return the total number
-//  of input lines for the device
-//-------------------------------------------------
-
-UINT32 device_config_execute_interface::execute_input_lines() const
-{
-	return 0;
-}
-
-
-//-------------------------------------------------
-//  execute_default_irq_vector - return the default
-//  IRQ vector when an acknowledge is processed
-//-------------------------------------------------
-
-UINT32 device_config_execute_interface::execute_default_irq_vector() const
-{
-	return 0;
-}
-
-
-//-------------------------------------------------
-//  interface_process_token - token processing for
-//  the sound interface
-//-------------------------------------------------
-
-bool device_config_execute_interface::interface_process_token(UINT32 entrytype, const machine_config_token *&tokens)
-{
-	switch (entrytype)
-	{
-		// disable a device
-		case MCONFIG_TOKEN_DIEXEC_DISABLE:
-			m_disabled = true;
-			return true;
-
-		// VBLANK interrupt
-		case MCONFIG_TOKEN_DIEXEC_VBLANK_INT:
-			TOKEN_UNGET_UINT32(tokens);
-			TOKEN_GET_UINT32_UNPACK2(tokens, entrytype, 8, m_vblank_interrupts_per_frame, 24);
-			m_vblank_interrupt = TOKEN_GET_PTR(tokens, cpu_interrupt);
-			m_vblank_interrupt_screen = TOKEN_GET_STRING(tokens);
-			return true;
-
-		// timed interrupt
-		case MCONFIG_TOKEN_DIEXEC_PERIODIC_INT:
-			m_timed_interrupt = TOKEN_GET_PTR(tokens, cpu_interrupt);
-			TOKEN_EXTRACT_UINT64(tokens, m_timed_interrupt_period);
-			return true;
-	}
-
-	return false;
-}
-
-
-//-------------------------------------------------
-//  interface_validity_check - validation for a
-//  device after the configuration has been
-//  constructed
-//-------------------------------------------------
-
-bool device_config_execute_interface::interface_validity_check(const game_driver &driver) const
-{
-	const device_config *devconfig = crosscast<const device_config *>(this);
-	bool error = false;
-
-	/* validate the interrupts */
-	if (m_vblank_interrupt != NULL)
-	{
-		if (screen_count(m_machine_config) == 0)
-		{
-			mame_printf_error("%s: %s device '%s' has a VBLANK interrupt, but the driver is screenless!\n", driver.source_file, driver.name, devconfig->tag());
-			error = true;
-		}
-		else if (m_vblank_interrupt_screen != NULL && m_vblank_interrupts_per_frame != 0)
-		{
-			mame_printf_error("%s: %s device '%s' has a new VBLANK interrupt handler with >1 interrupts!\n", driver.source_file, driver.name, devconfig->tag());
-			error = true;
-		}
-		else if (m_vblank_interrupt_screen != NULL && m_machine_config.m_devicelist.find(m_vblank_interrupt_screen) == NULL)
-		{
-			mame_printf_error("%s: %s device '%s' VBLANK interrupt with a non-existant screen tag (%s)!\n", driver.source_file, driver.name, devconfig->tag(), m_vblank_interrupt_screen);
-			error = true;
-		}
-		else if (m_vblank_interrupt_screen == NULL && m_vblank_interrupts_per_frame == 0)
-		{
-			mame_printf_error("%s: %s device '%s' has a VBLANK interrupt handler with 0 interrupts!\n", driver.source_file, driver.name, devconfig->tag());
-			error = true;
-		}
-	}
-	else if (m_vblank_interrupts_per_frame != 0)
-	{
-		mame_printf_error("%s: %s device '%s' has no VBLANK interrupt handler but a non-0 interrupt count is given!\n", driver.source_file, driver.name, devconfig->tag());
-		error = true;
-	}
-
-	if (m_timed_interrupt != NULL && m_timed_interrupt_period == 0)
-	{
-		mame_printf_error("%s: %s device '%s' has a timer interrupt handler with 0 period!\n", driver.source_file, driver.name, devconfig->tag());
-		error = true;
-	}
-	else if (m_timed_interrupt == NULL && m_timed_interrupt_period != 0)
-	{
-		mame_printf_error("%s: %s device '%s' has a no timer interrupt handler but has a non-0 period given!\n", driver.source_file, driver.name, devconfig->tag());
-		error = true;
-	}
-
-	return error;
-}
-
-
-
-//**************************************************************************
-//  EXECUTING DEVICE MANAGEMENT
-//**************************************************************************
-
-//-------------------------------------------------
-//  device_execute_interface - constructor
-//-------------------------------------------------
-
-device_execute_interface::device_execute_interface(running_machine &machine, const device_config &config, device_t &device)
-	: device_interface(machine, config, device),
-	  m_machine(machine),
-	  m_execute_config(dynamic_cast<const device_config_execute_interface &>(config)),
+	  m_timed_interrupt_period(attotime::zero),
 	  m_nextexec(NULL),
 	  m_driver_irq(0),
 	  m_timedint_timer(NULL),
 	  m_iloops(0),
 	  m_partial_frame_timer(NULL),
-	  m_profiler(0),
-	  m_icount(NULL),
+	  m_profiler(PROFILER_IDLE),
+	  m_icountptr(NULL),
 	  m_cycles_running(0),
 	  m_cycles_stolen(0),
 	  m_suspend(0),
@@ -284,11 +102,14 @@ device_execute_interface::device_execute_interface(running_machine &machine, con
 	  m_attoseconds_per_cycle(0)
 {
 	memset(&m_localtime, 0, sizeof(m_localtime));
+
+	// configure the fast accessor
+	device.m_execute = this;
 }
 
 
 //-------------------------------------------------
-//  ~device_execute_interface - destructor
+//  device_execute_interface - destructor
 //-------------------------------------------------
 
 device_execute_interface::~device_execute_interface()
@@ -296,6 +117,51 @@ device_execute_interface::~device_execute_interface()
 }
 
 
+//-------------------------------------------------
+//  static_set_disable - configuration helper to
+//  set the disabled state of a device
+//-------------------------------------------------
+
+void device_execute_interface::static_set_disable(device_t &device)
+{
+	device_execute_interface *exec;
+	if (!device.interface(exec))
+		throw emu_fatalerror("MCFG_DEVICE_DISABLE called on device '%s' with no execute interface", device.tag());
+	exec->m_disabled = true;
+}
+
+
+//-------------------------------------------------
+//  static_set_vblank_int - configuration helper
+//  to set up VBLANK interrupts on the device
+//-------------------------------------------------
+
+void device_execute_interface::static_set_vblank_int(device_t &device, device_interrupt_func function, const char *tag, int rate)
+{
+	device_execute_interface *exec;
+	if (!device.interface(exec))
+		throw emu_fatalerror("MCFG_DEVICE_VBLANK_INT called on device '%s' with no execute interface", device.tag());
+	exec->m_vblank_interrupt = function;
+	exec->m_vblank_interrupts_per_frame = rate;
+	exec->m_vblank_interrupt_screen = tag;
+}
+
+
+//-------------------------------------------------
+//  static_set_periodic_int - configuration helper
+//  to set up periodic interrupts on the device
+//-------------------------------------------------
+
+void device_execute_interface::static_set_periodic_int(device_t &device, device_interrupt_func function, attotime rate)
+{
+	device_execute_interface *exec;
+	if (!device.interface(exec))
+		throw emu_fatalerror("MCFG_DEVICE_PERIODIC_INT called on device '%s' with no execute interface", device.tag());
+	exec->m_timed_interrupt = function;
+	exec->m_timed_interrupt_period = rate;
+}
+
+
 //-------------------------------------------------
 //  executing - return true if this device is
 //  within its execute function
@@ -303,7 +169,7 @@ device_execute_interface::~device_execute_interface()
 
 bool device_execute_interface::executing() const
 {
-	return (this == m_machine.scheduler().currently_executing());
+	return (this == device().machine().scheduler().currently_executing());
 }
 
 
@@ -314,7 +180,7 @@ bool device_execute_interface::executing() const
 
 INT32 device_execute_interface::cycles_remaining() const
 {
-	return executing() ? *m_icount : 0;
+	return executing() ? *m_icountptr : 0;
 }
 
 
@@ -330,9 +196,9 @@ void device_execute_interface::eat_cycles(int cycles)
 		return;
 
 	// clamp cycles to the icount and update
-	if (cycles > *m_icount)
-		cycles = *m_icount;
-	*m_icount -= cycles;
+	if (cycles > *m_icountptr)
+		cycles = *m_icountptr;
+	*m_icountptr -= cycles;
 }
 
 
@@ -348,7 +214,7 @@ void device_execute_interface::adjust_icount(int delta)
 		return;
 
 	// aply the delta directly
-	*m_icount += delta;
+	*m_icountptr += delta;
 }
 
 
@@ -361,16 +227,16 @@ void device_execute_interface::adjust_icount(int delta)
 void device_execute_interface::abort_timeslice()
 {
 	// ignore if not the executing device
-	if (this != m_machine.scheduler().currently_executing())
+	if (this != device().machine().scheduler().currently_executing())
 		return;
 
 	// swallow the remaining cycles
-	if (m_icount != NULL)
+	if (m_icountptr != NULL)
 	{
-		int delta = *m_icount;
+		int delta = *m_icountptr;
 		m_cycles_stolen += delta;
 		m_cycles_running -= delta;
-		*m_icount -= delta;
+		*m_icountptr -= delta;
 	}
 }
 
@@ -419,7 +285,7 @@ if (TEMPLOG) printf("resume %s (%X)\n", device().tag(), reason);
 
 
 //-------------------------------------------------
-//  spinuntil_time - burn cycles for a specific
+//  spin_until_time - burn cycles for a specific
 //  period of time
 //-------------------------------------------------
 
@@ -431,7 +297,7 @@ void device_execute_interface::spin_until_time(attotime duration)
 	suspend_until_trigger(TRIGGER_SUSPENDTIME + timetrig, true);
 
 	// then set a timer for it
-	timer_set(&m_machine, duration, this, TRIGGER_SUSPENDTIME + timetrig, static_timed_trigger_callback);
+	device().machine().scheduler().timer_set(duration, FUNC(static_timed_trigger_callback), TRIGGER_SUSPENDTIME + timetrig, this);
 	timetrig = (timetrig + 1) % 256;
 }
 
@@ -480,9 +346,9 @@ attotime device_execute_interface::local_time() const
 	attotime result = m_localtime;
 	if (executing())
 	{
-		assert(m_cycles_running >= *m_icount);
-		int cycles = m_cycles_running - *m_icount;
-		result = attotime_add(result, cycles_to_attotime(cycles));
+		assert(m_cycles_running >= *m_icountptr);
+		int cycles = m_cycles_running - *m_icountptr;
+		result += cycles_to_attotime(cycles);
 	}
 	return result;
 }
@@ -497,14 +363,101 @@ UINT64 device_execute_interface::total_cycles() const
 {
 	if (executing())
 	{
-		assert(m_cycles_running >= *m_icount);
-		return m_totalcycles + m_cycles_running - *m_icount;
+		assert(m_cycles_running >= *m_icountptr);
+		return m_totalcycles + m_cycles_running - *m_icountptr;
 	}
 	else
 		return m_totalcycles;
 }
 
 
+//-------------------------------------------------
+//  run_thread_wrapper - wrapper for our cothread
+//  which just calls run and then returns to the
+//  scheduler thread, over and over
+//-------------------------------------------------
+
+void device_execute_interface::run_thread_wrapper()
+{
+	// loop infinitely
+	device_scheduler &scheduler = device().machine().scheduler();
+	while (1)
+    {
+    	// call the classic run function, then swap back to the scheduler's thread
+    	execute_run();
+        scheduler.make_active();
+    }
+}
+
+
+//-------------------------------------------------
+//  execute_clocks_to_cycles - convert the number
+//  of clocks to cycles, rounding down if necessary
+//-------------------------------------------------
+
+UINT64 device_execute_interface::execute_clocks_to_cycles(UINT64 clocks) const
+{
+	return clocks;
+}
+
+
+//-------------------------------------------------
+//  execute_cycles_to_clocks - convert the number
+//  of cycles to clocks, rounding down if necessary
+//-------------------------------------------------
+
+UINT64 device_execute_interface::execute_cycles_to_clocks(UINT64 cycles) const
+{
+	return cycles;
+}
+
+
+//-------------------------------------------------
+//  execute_min_cycles - return the smallest number
+//  of cycles that a single instruction or
+//  operation can take
+//-------------------------------------------------
+
+UINT32 device_execute_interface::execute_min_cycles() const
+{
+	return 1;
+}
+
+
+//-------------------------------------------------
+//  execute_max_cycles - return the maximum number
+//  of cycles that a single instruction or
+//  operation can take
+//-------------------------------------------------
+
+UINT32 device_execute_interface::execute_max_cycles() const
+{
+	return 1;
+}
+
+
+//-------------------------------------------------
+//  execute_input_lines - return the total number
+//  of input lines for the device
+//-------------------------------------------------
+
+UINT32 device_execute_interface::execute_input_lines() const
+{
+	return 0;
+}
+
+
+//-------------------------------------------------
+//  execute_default_irq_vector - return the default
+//  IRQ vector when an acknowledge is processed
+//-------------------------------------------------
+
+UINT32 device_execute_interface::execute_default_irq_vector() const
+{
+	return 0;
+}
+
+
 //-------------------------------------------------
 //  execute_burn - called after we consume a bunch
 //  of cycles for artifical reasons (such as
@@ -528,6 +481,61 @@ void device_execute_interface::execute_set_input(int linenum, int state)
 }
 
 
+//-------------------------------------------------
+//  interface_validity_check - validation for a
+//  device after the configuration has been
+//  constructed
+//-------------------------------------------------
+
+bool device_execute_interface::interface_validity_check(emu_options &options, const game_driver &driver) const
+{
+	bool error = false;
+
+	/* validate the interrupts */
+	if (m_vblank_interrupt != NULL)
+	{
+		if (device().mconfig().devicelist().count(SCREEN) == 0)
+		{
+			mame_printf_error("%s: %s device '%s' has a VBLANK interrupt, but the driver is screenless!\n", driver.source_file, driver.name, device().tag());
+			error = true;
+		}
+		else if (m_vblank_interrupt_screen != NULL && m_vblank_interrupts_per_frame != 0)
+		{
+			mame_printf_error("%s: %s device '%s' has a new VBLANK interrupt handler with >1 interrupts!\n", driver.source_file, driver.name, device().tag());
+			error = true;
+		}
+		else if (m_vblank_interrupt_screen != NULL && device().mconfig().devicelist().find(m_vblank_interrupt_screen) == NULL)
+		{
+			mame_printf_error("%s: %s device '%s' VBLANK interrupt with a non-existant screen tag (%s)!\n", driver.source_file, driver.name, device().tag(), m_vblank_interrupt_screen);
+			error = true;
+		}
+		else if (m_vblank_interrupt_screen == NULL && m_vblank_interrupts_per_frame == 0)
+		{
+			mame_printf_error("%s: %s device '%s' has a VBLANK interrupt handler with 0 interrupts!\n", driver.source_file, driver.name, device().tag());
+			error = true;
+		}
+	}
+	else if (m_vblank_interrupts_per_frame != 0)
+	{
+		mame_printf_error("%s: %s device '%s' has no VBLANK interrupt handler but a non-0 interrupt count is given!\n", driver.source_file, driver.name, device().tag());
+		error = true;
+	}
+
+	if (m_timed_interrupt != NULL && m_timed_interrupt_period == attotime::zero)
+	{
+		mame_printf_error("%s: %s device '%s' has a timer interrupt handler with 0 period!\n", driver.source_file, driver.name, device().tag());
+		error = true;
+	}
+	else if (m_timed_interrupt == NULL && m_timed_interrupt_period != attotime::zero)
+	{
+		mame_printf_error("%s: %s device '%s' has a no timer interrupt handler but has a non-0 period given!\n", driver.source_file, driver.name, device().tag());
+		error = true;
+	}
+
+	return error;
+}
+
+
 //-------------------------------------------------
 //  interface_pre_start - work to be done prior to
 //  actually starting a device
@@ -536,9 +544,9 @@ void device_execute_interface::execute_set_input(int linenum, int state)
 void device_execute_interface::interface_pre_start()
 {
 	// fill in the initial states
-	int index = m_machine.m_devicelist.index(&m_device);
+	int index = device().machine().devicelist().indexof(m_device);
 	m_suspend = SUSPEND_REASON_RESET;
-	m_profiler = index + PROFILER_DEVICE_FIRST;
+	m_profiler = profile_type(index + PROFILER_DEVICE_FIRST);
 	m_inttrigger = index + TRIGGER_INT;
 
 	// fill in the input states and IRQ callback information
@@ -546,21 +554,20 @@ void device_execute_interface::interface_pre_start()
 		m_input[line].start(this, line);
 
 	// allocate timers if we need them
-	if (m_execute_config.m_vblank_interrupts_per_frame > 1)
-		m_partial_frame_timer = timer_alloc(&m_machine, static_trigger_partial_frame_interrupt, (void *)this);
-	if (m_execute_config.m_timed_interrupt_period != 0)
-		m_timedint_timer = timer_alloc(&m_machine, static_trigger_periodic_interrupt, (void *)this);
+	if (m_vblank_interrupts_per_frame > 1)
+		m_partial_frame_timer = device().machine().scheduler().timer_alloc(FUNC(static_trigger_partial_frame_interrupt), (void *)this);
+	if (m_timed_interrupt_period != attotime::zero)
+		m_timedint_timer = device().machine().scheduler().timer_alloc(FUNC(static_trigger_periodic_interrupt), (void *)this);
 
 	// register for save states
-	state_save_register_device_item(&m_device, 0, m_suspend);
-	state_save_register_device_item(&m_device, 0, m_nextsuspend);
-	state_save_register_device_item(&m_device, 0, m_eatcycles);
-	state_save_register_device_item(&m_device, 0, m_nexteatcycles);
-	state_save_register_device_item(&m_device, 0, m_trigger);
-	state_save_register_device_item(&m_device, 0, m_totalcycles);
-	state_save_register_device_item(&m_device, 0, m_localtime.seconds);
-	state_save_register_device_item(&m_device, 0, m_localtime.attoseconds);
-	state_save_register_device_item(&m_device, 0, m_iloops);
+	m_device.save_item(NAME(m_suspend));
+	m_device.save_item(NAME(m_nextsuspend));
+	m_device.save_item(NAME(m_eatcycles));
+	m_device.save_item(NAME(m_nexteatcycles));
+	m_device.save_item(NAME(m_trigger));
+	m_device.save_item(NAME(m_totalcycles));
+	m_device.save_item(NAME(m_localtime));
+	m_device.save_item(NAME(m_iloops));
 }
 
 
@@ -572,7 +579,7 @@ void device_execute_interface::interface_pre_start()
 void device_execute_interface::interface_post_start()
 {
 	// make sure somebody set us up the icount
-	assert_always(m_icount != NULL, "m_icount never initialized!");
+	assert_always(m_icountptr != NULL, "m_icountptr never initialized!");
 }
 
 
@@ -587,7 +594,7 @@ void device_execute_interface::interface_pre_reset()
 	m_totalcycles = 0;
 
 	// enable all devices (except for disabled devices)
-	if (!m_execute_config.disabled())
+	if (!disabled())
 		resume(SUSPEND_ANY_REASON);
 	else
 		suspend(SUSPEND_REASON_DISABLE, true);
@@ -606,29 +613,29 @@ void device_execute_interface::interface_post_reset()
 		m_input[line].reset();
 
 	// reconfingure VBLANK interrupts
-	if (m_execute_config.m_vblank_interrupts_per_frame > 0 || m_execute_config.m_vblank_interrupt_screen != NULL)
+	if (m_vblank_interrupts_per_frame > 0 || m_vblank_interrupt_screen != NULL)
 	{
 		// get the screen that will trigger the VBLANK
 
 		// new style - use screen tag directly
 		screen_device *screen;
-		if (m_execute_config.m_vblank_interrupt_screen != NULL)
-			screen = downcast<screen_device *>(m_machine.device(m_execute_config.m_vblank_interrupt_screen));
+		if (m_vblank_interrupt_screen != NULL)
+			screen = downcast<screen_device *>(device().machine().device(m_vblank_interrupt_screen));
 
 		// old style 'hack' setup - use screen #0
 		else
-			screen = screen_first(m_machine);
+			screen = device().machine().first_screen();
 
 		assert(screen != NULL);
-		screen->register_vblank_callback(static_on_vblank, NULL);
+		screen->register_vblank_callback(vblank_state_delegate(FUNC(device_execute_interface::on_vblank), this));
 	}
 
 	// reconfigure periodic interrupts
-	if (m_execute_config.m_timed_interrupt_period != 0)
+	if (m_timed_interrupt_period != attotime::zero)
 	{
-		attotime timedint_period = UINT64_ATTOTIME_TO_ATTOTIME(m_execute_config.m_timed_interrupt_period);
+		attotime timedint_period = m_timed_interrupt_period;
 		assert(m_timedint_timer != NULL);
-		timer_adjust_periodic(m_timedint_timer, timedint_period, 0, timedint_period);
+		m_timedint_timer->adjust(timedint_period, 0, timedint_period);
 	}
 }
 
@@ -655,13 +662,40 @@ void device_execute_interface::interface_clock_changed()
 	m_divisor = attos;
 
 	// re-compute the perfect interleave factor
-	m_machine.scheduler().compute_perfect_interleave();
+	device().machine().scheduler().compute_perfect_interleave();
 }
 
 
 //-------------------------------------------------
-//  get_minimum_quantum - return the minimum
-//  quantum required for this device
+//  static_standard_irq_callback - IRQ acknowledge
+//  callback; handles HOLD_LINE case and signals
+//  to the debugger
+//-------------------------------------------------
+
+IRQ_CALLBACK( device_execute_interface::static_standard_irq_callback )
+{
+	return device_execute(device)->standard_irq_callback(irqline);
+}
+
+int device_execute_interface::standard_irq_callback(int irqline)
+{
+	// get the default vector and acknowledge the interrupt if needed
+	int vector = m_input[irqline].default_irq_callback();
+	LOG(("static_standard_irq_callback('%s', %d) $%04x\n", m_device.tag(), irqline, vector));
+
+	// if there's a driver callback, run it to get the vector
+	if (m_driver_irq != NULL)
+		vector = (*m_driver_irq)(&m_device, irqline);
+
+	// notify the debugger
+	debugger_interrupt_hook(&m_device, irqline);
+	return vector;
+}
+
+
+//-------------------------------------------------
+//  minimum_quantum - return the minimum quantum
+//  required for this device
 //-------------------------------------------------
 
 attoseconds_t device_execute_interface::minimum_quantum() const
@@ -693,46 +727,27 @@ TIMER_CALLBACK( device_execute_interface::static_timed_trigger_callback )
 //  for this screen
 //-------------------------------------------------
 
-void device_execute_interface::static_on_vblank(screen_device &screen, void *param, bool vblank_state)
+void device_execute_interface::on_vblank(screen_device &screen, bool vblank_state)
 {
-	// VBLANK starting
-	if (vblank_state)
-	{
-		device_execute_interface *exec = NULL;
-		for (bool gotone = screen.machine->m_devicelist.first(exec); gotone; gotone = exec->next(exec))
-			exec->on_vblank_start(screen);
-	}
-}
+	// ignore VBLANK end
+	if (!vblank_state)
+		return;
 
-void device_execute_interface::on_vblank_start(screen_device &screen)
-{
 	// start the interrupt counter
 	if (!suspended(SUSPEND_REASON_DISABLE))
 		m_iloops = 0;
 	else
 		m_iloops = -1;
 
-	// the hack style VBLANK decleration always uses the first screen
-	bool interested = false;
-	if (m_execute_config.m_vblank_interrupts_per_frame > 1)
-		interested = true;
+	// generate the interrupt callback
+	if (!suspended(SUSPEND_REASON_HALT | SUSPEND_REASON_RESET | SUSPEND_REASON_DISABLE))
+		(*m_vblank_interrupt)(&m_device);
 
-	// for new style declaration, we need to compare the tags
-	else if (m_execute_config.m_vblank_interrupt_screen != NULL)
-		interested = (strcmp(screen.tag(), m_execute_config.m_vblank_interrupt_screen) == 0);
-
-	// if interested, call the interrupt handler
-	if (interested)
+	// if we have more than one interrupt per frame, start the timer now to trigger the rest of them
+	if (m_vblank_interrupts_per_frame > 1 && !suspended(SUSPEND_REASON_DISABLE))
 	{
-		if (!suspended(SUSPEND_REASON_HALT | SUSPEND_REASON_RESET | SUSPEND_REASON_DISABLE))
-			(*m_execute_config.m_vblank_interrupt)(&m_device);
-
-		// if we have more than one interrupt per frame, start the timer now to trigger the rest of them
-		if (m_execute_config.m_vblank_interrupts_per_frame > 1 && !suspended(SUSPEND_REASON_DISABLE))
-		{
-			m_partial_frame_period = attotime_div(m_machine.primary_screen->frame_period(), m_execute_config.m_vblank_interrupts_per_frame);
-			timer_adjust_oneshot(m_partial_frame_timer, m_partial_frame_period, 0);
-		}
+		m_partial_frame_period = device().machine().primary_screen->frame_period() / m_vblank_interrupts_per_frame;
+		m_partial_frame_timer->adjust(m_partial_frame_period);
 	}
 }
 
@@ -751,18 +766,18 @@ void device_execute_interface::trigger_partial_frame_interrupt()
 {
 	// when we hit 0, reset to the total count
 	if (m_iloops == 0)
-		m_iloops = m_execute_config.m_vblank_interrupts_per_frame;
+		m_iloops = m_vblank_interrupts_per_frame;
 
 	// count one more "iloop"
 	m_iloops--;
 
 	// call the interrupt handler if we're not suspended
 	if (!suspended(SUSPEND_REASON_HALT | SUSPEND_REASON_RESET | SUSPEND_REASON_DISABLE))
-		(*m_execute_config.m_vblank_interrupt)(&m_device);
+		(*m_vblank_interrupt)(&m_device);
 
 	// set up to retrigger if there's more interrupts to generate
 	if (m_iloops > 1)
-		timer_adjust_oneshot(m_partial_frame_timer, m_partial_frame_period, 0);
+		m_partial_frame_timer->adjust(m_partial_frame_period);
 }
 
 
@@ -779,35 +794,8 @@ TIMER_CALLBACK( device_execute_interface::static_trigger_periodic_interrupt )
 void device_execute_interface::trigger_periodic_interrupt()
 {
 	// bail if there is no routine
-	if (m_execute_config.m_timed_interrupt != NULL && !suspended(SUSPEND_REASON_HALT | SUSPEND_REASON_RESET | SUSPEND_REASON_DISABLE))
-		(*m_execute_config.m_timed_interrupt)(&m_device);
-}
-
-
-//-------------------------------------------------
-//  static_standard_irq_callback - IRQ acknowledge
-//  callback; handles HOLD_LINE case and signals
-//  to the debugger
-//-------------------------------------------------
-
-IRQ_CALLBACK( device_execute_interface::static_standard_irq_callback )
-{
-	return device_execute(device)->standard_irq_callback(irqline);
-}
-
-int device_execute_interface::standard_irq_callback(int irqline)
-{
-	// get the default vector and acknowledge the interrupt if needed
-	int vector = m_input[irqline].default_irq_callback();
-	LOG(("static_standard_irq_callback('%s', %d) $%04x\n", m_device.tag(), irqline, vector));
-
-	// if there's a driver callback, run it to get the vector
-	if (m_driver_irq != NULL)
-		vector = (*m_driver_irq)(&m_device, irqline);
-
-	// notify the debugger
-	debugger_interrupt_hook(&m_device, irqline);
-	return vector;
+	if (m_timed_interrupt != NULL && !suspended(SUSPEND_REASON_HALT | SUSPEND_REASON_RESET | SUSPEND_REASON_DISABLE))
+		(*m_timed_interrupt)(&m_device);
 }
 
 
@@ -846,9 +834,9 @@ void device_execute_interface::device_input::start(device_execute_interface *exe
 
 	reset();
 
-	state_save_register_device_item(m_device, m_linenum, m_stored_vector);
-	state_save_register_device_item(m_device, m_linenum, m_curvector);
-	state_save_register_device_item(m_device, m_linenum, m_curstate);
+	m_device->save_item(NAME(m_stored_vector), m_linenum);
+	m_device->save_item(NAME(m_curvector), m_linenum);
+	m_device->save_item(NAME(m_curstate), m_linenum);
 }
 
 
@@ -906,7 +894,7 @@ if (TEMPLOG) printf("setline(%s,%d,%d,%d)\n", m_device->tag(), m_linenum, state,
 
 		// if this is the first one, set the timer
 		if (event_index == 0)
-			timer_call_after_resynch(&m_execute->m_machine, (void *)this, 0, static_empty_event_queue);
+			m_execute->device().machine().scheduler().synchronize(FUNC(static_empty_event_queue), 0, (void *)this);
 	}
 }
 
