@@ -39,15 +39,13 @@
 
 #include "emu.h"
 #include "ui.h"
-#include "pool.h"
 #include "zippath.h"
-#include "hashfile.h"
 
 
 //**************************************************************************
 //  DEVICE CONFIG IMAGE INTERFACE
 //**************************************************************************
-const image_device_type_info device_config_image_interface::m_device_info_array[] =
+const image_device_type_info device_image_interface::m_device_info_array[] =
 	{
 		{ IO_CARTSLOT,	"cartridge",	"cart" }, /*  0 */
 		{ IO_FLOPPY,	"floppydisk",	"flop" }, /*  1 */
@@ -66,34 +64,56 @@ const image_device_type_info device_config_image_interface::m_device_info_array[
 		{ IO_MAGTAPE,	"magtape",		"magt" }, /* 14 */
 	};
 
+
+//**************************************************************************
+//  DEVICE IMAGE INTERFACE
+//**************************************************************************
+
 //-------------------------------------------------
-//  device_config_image_interface - constructor
+//  device_image_interface - constructor
 //-------------------------------------------------
 
-device_config_image_interface::device_config_image_interface(const machine_config &mconfig, device_config &devconfig)
-	: device_config_interface(mconfig, devconfig)
+device_image_interface::device_image_interface(const machine_config &mconfig, device_t &device)
+	: device_interface(device),
+	  m_file(NULL),
+	  m_mame_file(NULL),
+	  m_full_software_name(NULL),
+	  m_software_info_ptr(NULL),
+	  m_software_part_ptr(NULL),
+      m_readonly(false),
+      m_created(false),
+	  m_formatlist(NULL),
+	  m_is_loading(FALSE)
 {
 }
 
 
 //-------------------------------------------------
-//  ~device_config_image_interface - destructor
+//  ~device_image_interface - destructor
 //-------------------------------------------------
 
-device_config_image_interface::~device_config_image_interface()
+device_image_interface::~device_image_interface()
 {
-}
+   image_device_format **formatptr = &m_formatlist;
 
+	/* free all entries */
+	while (*formatptr != NULL)
+	{
+		image_device_format *entry = *formatptr;
+		*formatptr = entry->m_next;
+		global_free(entry);
+	}
+}
 
 //-------------------------------------------------
 //  find_device_type - search trough list of
 //  device types to extact data
 //-------------------------------------------------
 
-const image_device_type_info *device_config_image_interface::find_device_type(iodevice_t type)
+const image_device_type_info *device_image_interface::find_device_type(iodevice_t type)
 {
 	int i;
-	for (i = 0; i < ARRAY_LENGTH(device_config_image_interface::m_device_info_array); i++)
+	for (i = 0; i < ARRAY_LENGTH(device_image_interface::m_device_info_array); i++)
 	{
 		if (m_device_info_array[i].m_type == type)
 			return &m_device_info_array[i];
@@ -105,7 +125,7 @@ const image_device_type_info *device_config_image_interface::find_device_type(io
 //  device_typename - retrieves device type name
 //-------------------------------------------------
 
-const char *device_config_image_interface::device_typename(iodevice_t type)
+const char *device_image_interface::device_typename(iodevice_t type)
 {
 	const image_device_type_info *info = find_device_type(type);
 	return (info != NULL) ? info->m_name : NULL;
@@ -116,7 +136,7 @@ const char *device_config_image_interface::device_typename(iodevice_t type)
 //  brief type name
 //-------------------------------------------------
 
-const char *device_config_image_interface::device_brieftypename(iodevice_t type)
+const char *device_image_interface::device_brieftypename(iodevice_t type)
 {
 	const image_device_type_info *info = find_device_type(type);
 	return (info != NULL) ? info->m_shortname : NULL;
@@ -126,10 +146,10 @@ const char *device_config_image_interface::device_brieftypename(iodevice_t type)
 //  device_typeid - retrieves device type id
 //-------------------------------------------------
 
-iodevice_t device_config_image_interface::device_typeid(const char *name)
+iodevice_t device_image_interface::device_typeid(const char *name)
 {
 	int i;
-	for (i = 0; i < ARRAY_LENGTH(device_config_image_interface::m_device_info_array); i++)
+	for (i = 0; i < ARRAY_LENGTH(device_image_interface::m_device_info_array); i++)
 	{
 		if (!mame_stricmp(name, m_device_info_array[i].m_name) || !mame_stricmp(name, m_device_info_array[i].m_shortname))
 			return m_device_info_array[i].m_type;
@@ -142,57 +162,16 @@ iodevice_t device_config_image_interface::device_typeid(const char *name)
     using this device's partial hash if appropriate
 -------------------------------------------------*/
 
-void device_config_image_interface::device_compute_hash(char *dest, const void *data, size_t length, unsigned int functions) const
+void device_image_interface::device_compute_hash(hash_collection &hashes, const void *data, size_t length, const char *types) const
 {
 	/* retrieve the partial hash func */
 	device_image_partialhash_func partialhash = get_partial_hash();
 
 	/* compute the hash */
 	if (partialhash)
-		partialhash(dest, (const unsigned char*)data, length, functions);
+		partialhash(hashes, (const unsigned char*)data, length, types);
 	else
-		hash_compute(dest, (const unsigned char*)data, length, functions);
-}
-
-
-//**************************************************************************
-//  DEVICE image INTERFACE
-//**************************************************************************
-
-/*-------------------------------------------------
-    memory_error - report a memory error
--------------------------------------------------*/
-
-static void memory_error(const char *message)
-{
-    fatalerror("%s", message);
-}
-
-
-//-------------------------------------------------
-//  device_image_interface - constructor
-//-------------------------------------------------
-
-device_image_interface::device_image_interface(running_machine &machine, const device_config &config, device_t &device)
-	: device_interface(machine, config, device),
-	  m_image_config(dynamic_cast<const device_config_image_interface &>(config)),
-	  m_file(NULL),
-	  m_mame_file(NULL),
-	  m_full_software_name(NULL),
-	  m_software_info_ptr(NULL),
-	  m_software_part_ptr(NULL)
-{
-	m_mempool = pool_alloc_lib(memory_error);
-}
-
-
-//-------------------------------------------------
-//  ~device_image_interface - destructor
-//-------------------------------------------------
-
-device_image_interface::~device_image_interface()
-{
-    pool_free_lib(m_mempool);
+		hashes.compute(reinterpret_cast<const UINT8 *>(data), length, types);
 }
 
 /*-------------------------------------------------
@@ -202,13 +181,13 @@ device_image_interface::~device_image_interface()
 
 image_error_t device_image_interface::set_image_filename(const char *filename)
 {
-    m_name = filename;
+    m_image_name = filename;
     zippath_parent(&m_working_directory, filename);
-	m_basename = m_name.cpy(m_name);
+	m_basename.cpy(m_image_name);
 
-	int loc1 = m_name.rchr(0,'\\');
-	int loc2 = m_name.rchr(0,'/');
-	int loc3 = m_name.rchr(0,':');
+	int loc1 = m_image_name.rchr(0,'\\');
+	int loc2 = m_image_name.rchr(0,'/');
+	int loc3 = m_image_name.rchr(0,':');
 	int loc = MAX(loc1,MAX(loc2,loc3));
 	if (loc!=-1) {
 		m_basename = m_basename.substr(loc + 1,m_basename.len()-loc);
@@ -384,7 +363,6 @@ bool device_image_interface::try_change_working_directory(const char *subdir)
 
 void device_image_interface::setup_working_directory()
 {
-    const game_driver *gamedrv;
 	char *dst = NULL;
 
 	osd_get_full_path(&dst,".");
@@ -395,10 +373,10 @@ void device_image_interface::setup_working_directory()
     if (try_change_working_directory("software"))
     {
         /* now down to a directory for this computer */
-        gamedrv = device().machine->gamedrv;
-        while(gamedrv && !try_change_working_directory(gamedrv->name))
+        int gamedrv = driver_list::find(device().machine().system());
+        while(gamedrv != -1 && !try_change_working_directory(driver_list::driver(gamedrv).name))
         {
-            gamedrv = driver_get_compatible(gamedrv);
+            gamedrv = driver_list::compatible_with(gamedrv);
         }
     }
 	osd_free(dst);
@@ -432,7 +410,7 @@ UINT8 *device_image_interface::get_software_region(const char *tag)
 		return NULL;
 
 	sprintf( full_tag, "%s:%s", device().tag(), tag );
-	return device().machine->region( full_tag )->base();
+	return device().machine().region( full_tag )->base();
 }
 
 
@@ -445,7 +423,7 @@ UINT32 device_image_interface::get_software_region_length(const char *tag)
     char full_tag[256];
 
     sprintf( full_tag, "%s:%s", device().tag(), tag );
-    return device().machine->region( full_tag )->bytes();
+    return device().machine().region( full_tag )->bytes();
 }
 
 
@@ -469,35 +447,6 @@ const char *device_image_interface::get_feature(const char *feature_name)
 	return NULL;
 }
 
-/****************************************************************************
-  Memory allocators
-
-  These allow memory to be allocated for the lifetime of a mounted image.
-  If these (and the above accessors) are used well enough, they should be
-  able to eliminate the need for a unload function.
-****************************************************************************/
-
-void *device_image_interface::image_malloc(size_t size)
-{
-    return image_realloc(NULL, size);
-}
-
-char *device_image_interface::image_strdup(const char *src)
-{
-	return pool_strdup_lib(m_mempool, src);
-}
-
-void *device_image_interface::image_realloc(void *ptr, size_t size)
-{
-    return pool_realloc_lib(m_mempool, ptr, size);
-}
-
-void device_image_interface::image_freeptr(void *ptr)
-{
-	pool_object_remove(m_mempool, ptr, 0);
-}
-
-
 /****************************************************************************
   Hash info loading
 
@@ -505,65 +454,13 @@ void device_image_interface::image_freeptr(void *ptr)
   to be loaded
 ****************************************************************************/
 
-/*-------------------------------------------------
-    hash_data_extract_crc32 - extract crc32 value
-    from hash string
--------------------------------------------------*/
-
-static UINT32 hash_data_extract_crc32(const char *d)
-{
-	UINT32 crc = 0;
-	UINT8 crc_bytes[4];
-
-	if (hash_data_extract_binary_checksum(d, HASH_CRC, crc_bytes) == 1)
-	{
-		crc = (((UINT32) crc_bytes[0]) << 24)
-			| (((UINT32) crc_bytes[1]) << 16)
-			| (((UINT32) crc_bytes[2]) << 8)
-			| (((UINT32) crc_bytes[3]) << 0);
-	}
-	return crc;
-}
-
-int device_image_interface::read_hash_config(const char *sysname)
-{
-    hash_file *hashfile = NULL;
-    const hash_info *info = NULL;
-
-    /* open the hash file */
-    hashfile = hashfile_open(sysname, FALSE, NULL);
-    if (!hashfile)
-        goto done;
-
-    /* look up this entry in the hash file */
-    info = hashfile_lookup(hashfile, m_hash.cstr());
-
-    if (!info)
-        goto done;
-
-    /* copy the relevant entries */
-    m_longname     = info->longname        ? astring(info->longname)	  : "";
-    m_manufacturer = info->manufacturer    ? astring(info->manufacturer)  : "";
-    m_year         = info->year            ? astring(info->year)          : "";
-    m_playable     = info->playable        ? astring(info->playable)      : "";
-    m_pcb          = info->pcb             ? astring(info->pcb)           : "";
-    m_extrainfo    = info->extrainfo       ? astring(info->extrainfo)     : "";
-
-done:
-    if (hashfile != NULL)
-        hashfile_close(hashfile);
-    return !hashfile || !info;
-}
-
-
-
-void device_image_interface::run_hash(void (*partialhash)(char *, const unsigned char *, unsigned long, unsigned int),
-    char *dest, unsigned int hash_functions)
+void device_image_interface::run_hash(void (*partialhash)(hash_collection &, const unsigned char *, unsigned long, const char *),
+    hash_collection &hashes, const char *types)
 {
     UINT32 size;
     UINT8 *buf = NULL;
 
-    *dest = '\0';
+    hashes.reset();
     size = (UINT32) length();
 
     buf = (UINT8*)malloc(size);
@@ -574,9 +471,9 @@ void device_image_interface::run_hash(void (*partialhash)(char *, const unsigned
     fread(buf, size);
 
     if (partialhash)
-        partialhash(dest, buf, size, hash_functions);
+        partialhash(hashes, buf, size, types);
     else
-        hash_compute(dest, buf, size, hash_functions);
+        hashes.compute(buf, size, types);
 
     /* cleanup */
     free(buf);
@@ -587,17 +484,14 @@ void device_image_interface::run_hash(void (*partialhash)(char *, const unsigned
 
 void device_image_interface::image_checkhash()
 {
-    const game_driver *drv;
-    char hash_string[HASH_BUF_SIZE];
     device_image_partialhash_func partialhash;
-    int rc;
 
     /* only calculate CRC if it hasn't been calculated, and the open_mode is read only */
-    if (!m_hash && !m_writeable && !m_created)
+    if (m_hash.first() == NULL && m_readonly && !m_created)
     {
         /* do not cause a linear read of 600 megs please */
         /* TODO: use SHA/MD5 in the CHD header as the hash */
-        if (m_image_config.image_type() == IO_CDROM)
+        if (image_type() == IO_CDROM)
             return;
 
 		/* Skip calculating the hash when we have an image mounted through a software list */
@@ -607,18 +501,7 @@ void device_image_interface::image_checkhash()
         /* retrieve the partial hash func */
         partialhash = get_partial_hash();
 
-        run_hash(partialhash, hash_string, HASH_CRC | HASH_MD5 | HASH_SHA1);
-
-        m_hash = hash_string;
-
-        /* now read the hash file */
-        drv = device().machine->gamedrv;
-        do
-        {
-            rc = read_hash_config(drv->name);
-            drv = driver_get_compatible(drv);
-        }
-        while(rc && (drv != NULL));
+        run_hash(partialhash, m_hash, hash_collection::HASH_TYPES_ALL);
     }
     return;
 }
@@ -628,8 +511,7 @@ UINT32 device_image_interface::crc()
     UINT32 crc = 0;
 
 	image_checkhash();
-    if (m_hash)
-        crc = hash_data_extract_crc32(m_hash.cstr());
+    m_hash.crc(crc);
 
     return crc;
 }
@@ -650,9 +532,9 @@ UINT32 device_image_interface::crc()
 -------------------------------------------------*/
 void device_image_interface::battery_load(void *buffer, int length, int fill)
 {
-    astring *fname = astring_assemble_4(astring_alloc(), device().machine->gamedrv->name, PATH_SEPARATOR, m_basename_noext, ".nv");
+    astring *fname = astring_assemble_4(astring_alloc(), device().machine().system().name, PATH_SEPARATOR, m_basename_noext, ".nv");
 
-    image_battery_load_by_name(astring_c(fname), buffer, length, fill);
+    image_battery_load_by_name(device().machine().options(), astring_c(fname), buffer, length, fill);
     astring_free(fname);
 }
 
@@ -664,9 +546,490 @@ void device_image_interface::battery_load(void *buffer, int length, int fill)
 -------------------------------------------------*/
 void device_image_interface::battery_save(const void *buffer, int length)
 {
-    astring *fname = astring_assemble_4(astring_alloc(), device().machine->gamedrv->name, PATH_SEPARATOR, m_basename_noext, ".nv");
+    astring *fname = astring_assemble_4(astring_alloc(), device().machine().system().name, PATH_SEPARATOR, m_basename_noext, ".nv");
 
-    image_battery_save_by_name(astring_c(fname), buffer, length);
+    image_battery_save_by_name(device().machine().options(), astring_c(fname), buffer, length);
     astring_free(fname);
 }
 
+//-------------------------------------------------
+//  uses_file_extension - update configuration
+//  based on completed device setup
+//-------------------------------------------------
+
+bool device_image_interface::uses_file_extension(const char *file_extension) const
+{
+    bool result = FALSE;
+
+	if (file_extension[0] == '.')
+        file_extension++;
+
+	/* find the extensions */
+	astring extensions(file_extensions());
+	char *ext = strtok((char*)extensions.cstr(),",");
+	while (ext != NULL)
+	{
+		if (!mame_stricmp(ext, file_extension))
+        {
+            result = TRUE;
+            break;
+        }
+		ext = strtok (NULL, ",");
+	}
+    return result;
+}
+
+/****************************************************************************
+    IMAGE LOADING
+****************************************************************************/
+
+/*-------------------------------------------------
+    is_loaded - quick check to determine whether an
+    image is loaded
+-------------------------------------------------*/
+
+bool device_image_interface::is_loaded()
+{
+    return (m_file != NULL);
+}
+
+/*-------------------------------------------------
+    load_image_by_path - loads an image with a
+    specific path
+-------------------------------------------------*/
+
+image_error_t device_image_interface::load_image_by_path(UINT32 open_flags, const char *path)
+{
+    file_error filerr = FILERR_NOT_FOUND;
+    image_error_t err = IMAGE_ERROR_FILENOTFOUND;
+    astring revised_path;
+
+    /* attempt to read the file */
+    filerr = zippath_fopen(path, open_flags, &m_file, &revised_path);
+
+    /* did the open succeed? */
+    switch(filerr)
+    {
+        case FILERR_NONE:
+            /* success! */
+            m_readonly = (open_flags & OPEN_FLAG_WRITE) ? 0 : 1;
+            m_created = (open_flags & OPEN_FLAG_CREATE) ? 1 : 0;
+            err = IMAGE_ERROR_SUCCESS;
+            break;
+
+        case FILERR_NOT_FOUND:
+        case FILERR_ACCESS_DENIED:
+            /* file not found (or otherwise cannot open); continue */
+            err = IMAGE_ERROR_FILENOTFOUND;
+            break;
+
+        case FILERR_OUT_OF_MEMORY:
+            /* out of memory */
+            err = IMAGE_ERROR_OUTOFMEMORY;
+            break;
+
+        case FILERR_ALREADY_OPEN:
+            /* this shouldn't happen */
+            err = IMAGE_ERROR_ALREADYOPEN;
+            break;
+
+        case FILERR_FAILURE:
+        case FILERR_TOO_MANY_FILES:
+        case FILERR_INVALID_DATA:
+        default:
+            /* other errors */
+            err = IMAGE_ERROR_INTERNAL;
+            break;
+    }
+
+    /* if successful, set the file name */
+    if (filerr == FILERR_NONE)
+        set_image_filename(revised_path);
+
+    return err;
+}
+
+/*-------------------------------------------------
+    determine_open_plan - determines which open
+    flags to use, and in what order
+-------------------------------------------------*/
+
+void device_image_interface::determine_open_plan(int is_create, UINT32 *open_plan)
+{
+    int i = 0;
+
+    /* emit flags */
+    if (!is_create && is_readable() && is_writeable())
+        open_plan[i++] = OPEN_FLAG_READ | OPEN_FLAG_WRITE;
+    if (!is_create && !is_readable() && is_writeable())
+        open_plan[i++] = OPEN_FLAG_WRITE;
+    if (!is_create && is_readable())
+        open_plan[i++] = OPEN_FLAG_READ;
+    if (is_writeable() && is_creatable())
+        open_plan[i++] = OPEN_FLAG_READ | OPEN_FLAG_WRITE | OPEN_FLAG_CREATE;
+    open_plan[i] = 0;
+}
+
+/*-------------------------------------------------
+    load_software - software image loading
+-------------------------------------------------*/
+bool device_image_interface::load_software(char *swlist, char *swname, rom_entry *start)
+{
+	astring locationtag, breakstr("%");
+	const rom_entry *region;
+	astring regiontag;
+	bool retVal = FALSE;
+	for (region = start; region != NULL; region = rom_next_region(region))
+	{
+		/* loop until we hit the end of this region */
+		const rom_entry *romp = region + 1;
+		while (!ROMENTRY_ISREGIONEND(romp))
+		{
+			/* handle files */
+			if (ROMENTRY_ISFILE(romp))
+			{
+				file_error filerr = FILERR_NOT_FOUND;
+
+				UINT32 crc = 0;
+				bool has_crc = hash_collection(ROM_GETHASHDATA(romp)).crc(crc);
+
+				// attempt reading up the chain through the parents and create a locationtag astring in the format
+				// " swlist % clonename % parentname "
+				// below, we have the code to split the elements and to create paths to load from
+
+				software_list *software_list_ptr = software_list_open(device().machine().options(), swlist, FALSE, NULL);
+				if (software_list_ptr)
+				{
+					for (software_info *swinfo = software_list_find(software_list_ptr, swname, NULL); swinfo != NULL; )
+					{
+						{
+							astring tmp(swinfo->shortname);
+							locationtag.cat(tmp);
+							locationtag.cat(breakstr);
+							//printf("%s\n", locationtag.cstr());
+						}
+
+						const char *parentname = software_get_clone(device().machine().options(), swlist, swinfo->shortname);
+						if (parentname != NULL)
+							swinfo = software_list_find(software_list_ptr, parentname, NULL);
+						else
+							swinfo = NULL;
+					}
+					// strip the final '%'
+					locationtag.del(locationtag.len() - 1, 1);
+					software_list_close(software_list_ptr);
+				}
+
+				if (software_get_support(device().machine().options(), swlist, swname) == SOFTWARE_SUPPORTED_PARTIAL)
+					mame_printf_error("WARNING: support for software %s (in list %s) is only partial\n", swname, swlist);
+
+				if (software_get_support(device().machine().options(), swlist, swname) == SOFTWARE_SUPPORTED_NO)
+					mame_printf_error("WARNING: support for software %s (in list %s) is only preliminary\n", swname, swlist);
+
+				// check if locationtag actually contains two locations separated by '%'
+				// (i.e. check if we are dealing with a clone in softwarelist)
+				astring tag2, tag3, tag4(locationtag), tag5;
+				int separator = tag4.chr(0, '%');
+				if (separator != -1)
+				{
+					// we are loading a clone through softlists, split the setname from the parentname
+					tag5.cpysubstr(tag4, separator + 1, tag4.len() - separator + 1);
+					tag4.del(separator, tag4.len() - separator);
+				}
+
+				// prepare locations where we have to load from: list/parentname & list/clonename
+				astring tag1(swlist);
+				tag1.cat(PATH_SEPARATOR);
+				tag2.cpy(tag1.cat(tag4));
+				tag1.cpy(swlist);
+				tag1.cat(PATH_SEPARATOR);
+				tag3.cpy(tag1.cat(tag5));
+
+				if (tag5.chr(0, '%') != -1)
+					fatalerror("We do not support clones of clones!\n");
+
+				// try to load from the available location(s):
+				// - if we are not using lists, we have regiontag only;
+				// - if we are using lists, we have: list/clonename, list/parentname, clonename, parentname
+				// try to load from list/setname
+				if ((m_mame_file == NULL) && (tag2.cstr() != NULL))
+					filerr = common_process_file(device().machine().options(), tag2.cstr(), has_crc, crc, romp, &m_mame_file);
+				// try to load from list/parentname
+				if ((m_mame_file == NULL) && (tag3.cstr() != NULL))
+					filerr = common_process_file(device().machine().options(), tag3.cstr(), has_crc, crc, romp, &m_mame_file);
+				// try to load from setname
+				if ((m_mame_file == NULL) && (tag4.cstr() != NULL))
+					filerr = common_process_file(device().machine().options(), tag4.cstr(), has_crc, crc, romp, &m_mame_file);
+				// try to load from parentname
+				if ((m_mame_file == NULL) && (tag5.cstr() != NULL))
+					filerr = common_process_file(device().machine().options(), tag5.cstr(), has_crc, crc, romp, &m_mame_file);
+
+				if (filerr == FILERR_NONE)
+				{
+					m_file = *m_mame_file;
+					retVal = TRUE;
+				}
+
+				break; // load first item for start
+			}
+			romp++;	/* something else; skip */
+		}
+	}
+	return retVal;
+}
+
+/*-------------------------------------------------
+    load_internal - core image loading
+-------------------------------------------------*/
+
+bool device_image_interface::load_internal(const char *path, bool is_create, int create_format, option_resolution *create_args)
+{
+    UINT32 open_plan[4];
+    int i;
+	bool softload = FALSE;
+	m_from_swlist = FALSE;
+
+	// if the path contains no period, we are using softlists, so we won't create an image
+	astring pathstr(path);
+	bool filename_has_period = (pathstr.rchr(0, '.') != -1) ? TRUE : FALSE;
+
+    /* first unload the image */
+    unload();
+
+    /* clear any possible error messages */
+    clear_error();
+
+    /* we are now loading */
+    m_is_loading = TRUE;
+
+    /* record the filename */
+    m_err = set_image_filename(path);
+
+    if (m_err)
+        goto done;
+
+	/* Check if there's a software list defined for this device and use that if we're not creating an image */
+	if (!filename_has_period)
+	{
+		softload = load_software_part( this, path, &m_software_info_ptr, &m_software_part_ptr, &m_full_software_name );
+		// if we had launched from softlist with a specified part, e.g. "shortname:part"
+		// we would have recorded the wrong name, so record it again based on software_info
+		if (m_software_info_ptr && m_software_info_ptr->shortname)
+			m_err = set_image_filename(m_software_info_ptr->shortname);
+
+		m_from_swlist = TRUE;
+	}
+
+	if (is_create || filename_has_period)
+	{
+		/* determine open plan */
+		determine_open_plan(is_create, open_plan);
+
+		/* attempt to open the file in various ways */
+		for (i = 0; !m_file && open_plan[i]; i++)
+		{
+			/* open the file */
+			m_err = load_image_by_path(open_plan[i], path);
+			if (m_err && (m_err != IMAGE_ERROR_FILENOTFOUND))
+				goto done;
+		}
+	}
+
+	/* Copy some image information when we have been loaded through a software list */
+	if ( m_software_info_ptr )
+	{
+		m_longname = m_software_info_ptr->longname;
+		m_manufacturer = m_software_info_ptr->publisher;
+		m_year = m_software_info_ptr->year;
+		//m_playable = m_software_info_ptr->supported;
+	}
+
+	/* did we fail to find the file? */
+	if (!is_loaded() && !softload)
+	{
+		m_err = IMAGE_ERROR_FILENOTFOUND;
+		goto done;
+	}
+
+	/* call device load or create */
+	m_create_format = create_format;
+	m_create_args = create_args;
+
+	if (m_init_phase==FALSE) {
+		m_err = (image_error_t)finish_load();
+		if (m_err)
+			goto done;
+	}
+    /* success! */
+
+done:
+    if (m_err!=0) {
+		if (!m_init_phase)
+		{
+			if (device().machine().phase() == MACHINE_PHASE_RUNNING)
+				popmessage("Error: Unable to %s image '%s': %s\n", is_create ? "create" : "load", path, error());
+			else
+				mame_printf_error("Error: Unable to %s image '%s': %s", is_create ? "create" : "load", path, error());
+		}
+		clear();
+	}
+	else {
+		/* do we need to reset the CPU? only schedule it if load/create is successful */
+		if (device().machine().time() > attotime::zero && is_reset_on_load())
+			device().machine().schedule_hard_reset();
+		else
+		{
+			if (!m_init_phase)
+			{
+				if (device().machine().phase() == MACHINE_PHASE_RUNNING)
+					popmessage("Image '%s' was successfully %s.", path, is_create ? "created" : "loaded");
+				else
+					mame_printf_info("Image '%s' was successfully %s.\n", path, is_create ? "created" : "loaded");
+			}
+		}
+	}
+	return m_err ? IMAGE_INIT_FAIL : IMAGE_INIT_PASS;
+}
+
+
+
+/*-------------------------------------------------
+    load - load an image into MESS
+-------------------------------------------------*/
+
+bool device_image_interface::load(const char *path)
+{
+    return load_internal(path, FALSE, 0, NULL);
+}
+
+
+/*-------------------------------------------------
+    image_finish_load - special call - only use
+    from core
+-------------------------------------------------*/
+
+bool device_image_interface::finish_load()
+{
+    bool err = IMAGE_INIT_PASS;
+
+    if (m_is_loading)
+    {
+		image_checkhash();
+
+		if (m_from_swlist)
+			call_display_info();
+
+		if (has_been_created() )// && get_legacy_fct(DEVINFO_FCT_IMAGE_CREATE) != NULL)
+        {
+            err = call_create(m_create_format, m_create_args);
+            if (err)
+            {
+                if (!m_err)
+                    m_err = IMAGE_ERROR_UNSPECIFIED;
+            }
+        }
+        else
+        {
+            /* using device load */
+            err = call_load();
+            if (err)
+            {
+                if (!m_err)
+                    m_err = IMAGE_ERROR_UNSPECIFIED;
+            }
+        }
+    }
+    m_is_loading = FALSE;
+    m_create_format = 0;
+    m_create_args = NULL;
+	m_init_phase = FALSE;
+    return err;
+}
+
+/*-------------------------------------------------
+    create - create a image
+-------------------------------------------------*/
+
+bool device_image_interface::create(const char *path, const image_device_format *create_format, option_resolution *create_args)
+{
+    int format_index = (create_format != NULL) ? create_format->m_index : 0;
+    return load_internal(path, TRUE, format_index, create_args);
+}
+
+
+/*-------------------------------------------------
+    clear - clear all internal data pertaining
+    to an image
+-------------------------------------------------*/
+
+void device_image_interface::clear()
+{
+	if (m_mame_file)
+    {
+		global_free(m_mame_file);
+		m_mame_file = NULL;
+		m_file = NULL;
+	} else {
+		if (m_file)
+		{
+			core_fclose(m_file);
+			m_file = NULL;
+		}
+	}
+
+    m_image_name.reset();
+    m_readonly = false;
+    m_created = false;
+
+    m_longname.reset();
+    m_manufacturer.reset();
+    m_year.reset();
+	m_basename.reset();
+    m_basename_noext.reset();
+	m_filetype.reset();
+
+	m_full_software_name = NULL;
+	m_software_info_ptr = NULL;
+	m_software_part_ptr = NULL;
+}
+
+/*-------------------------------------------------
+    unload - main call to unload an image
+-------------------------------------------------*/
+
+void device_image_interface::unload()
+{
+	if (is_loaded()) {
+		call_unload();
+	}
+    clear();
+	clear_error();
+}
+
+/*-------------------------------------------------
+    update_names - update brief and instance names
+-------------------------------------------------*/
+
+void device_image_interface::update_names()
+{
+	const device_image_interface *image = NULL;
+	int count = 0;
+	int index = -1;
+
+	for (bool gotone = device().mconfig().devicelist().first(image); gotone; gotone = image->next(image))
+	{
+		if (this == image)
+			index = count;
+		if (image->image_type() == image_type())
+			count++;
+	}
+	if (count > 1) {
+		m_instance_name.printf("%s%d", device_typename(image_type()), index + 1);
+		m_brief_instance_name.printf("%s%d", device_brieftypename(image_type()), index + 1);
+	}
+	else
+	{
+		m_instance_name = device_typename(image_type());
+		m_brief_instance_name = device_brieftypename(image_type());
+	}
+}
