@@ -136,6 +136,25 @@ device_state_entry &device_state_entry::formatstr(const char *_format)
 }
 
 
+//-------------------------------------------------
+//  format_from_mask - make a format based on
+//  the data mask
+//-------------------------------------------------
+
+void device_state_entry::format_from_mask()
+{
+	// skip if we have a user-provided format
+	if (!m_default_format)
+		return;
+
+	// make up a format based on the mask
+	int width = 0;
+	for (UINT64 tempmask = m_datamask; tempmask != 0; tempmask >>= 4)
+		width++;
+	m_format.printf("%%0%dX", width);
+}
+
+
 //-------------------------------------------------
 //  value - return the current value as a UINT64
 //-------------------------------------------------
@@ -355,49 +374,6 @@ void device_state_entry::set_value(const char *string) const
 }
 
 
-//-------------------------------------------------
-//  format_from_mask - make a format based on
-//  the data mask
-//-------------------------------------------------
-
-void device_state_entry::format_from_mask()
-{
-	// skip if we have a user-provided format
-	if (!m_default_format)
-		return;
-
-	// make up a format based on the mask
-	int width = 0;
-	for (UINT64 tempmask = m_datamask; tempmask != 0; tempmask >>= 4)
-		width++;
-	m_format.printf("%%0%dX", width);
-}
-
-
-
-//**************************************************************************
-//  DEVICE CONFIG STATE INTERFACE
-//**************************************************************************
-
-//-------------------------------------------------
-//  device_config_state_interface - constructor
-//-------------------------------------------------
-
-device_config_state_interface::device_config_state_interface(const machine_config &mconfig, device_config &devconfig)
-	: device_config_interface(mconfig, devconfig)
-{
-}
-
-
-//-------------------------------------------------
-//  ~device_config_state_interface - destructor
-//-------------------------------------------------
-
-device_config_state_interface::~device_config_state_interface()
-{
-}
-
-
 
 //**************************************************************************
 //  DEVICE STATE INTERFACE
@@ -407,12 +383,13 @@ device_config_state_interface::~device_config_state_interface()
 //  device_state_interface - constructor
 //-------------------------------------------------
 
-device_state_interface::device_state_interface(running_machine &machine, const device_config &config, device_t &device)
-	: device_interface(machine, config, device),
-	  m_machine(machine),
-	  m_state_config(dynamic_cast<const device_config_state_interface &>(config))
+device_state_interface::device_state_interface(const machine_config &mconfig, device_t &device)
+	: device_interface(device)
 {
 	memset(m_fast_state, 0, sizeof(m_fast_state));
+
+	// configure the fast accessor
+	device.m_state = this;
 }
 
 
@@ -528,46 +505,6 @@ void device_state_interface::set_state(int index, const char *string)
 }
 
 
-//-------------------------------------------------
-//  state_import - called after new state is
-//  written to perform any post-processing
-//-------------------------------------------------
-
-void device_state_interface::state_import(const device_state_entry &entry)
-{
-}
-
-
-//-------------------------------------------------
-//  state_export - called prior to new state
-//  reading the state
-//-------------------------------------------------
-
-void device_state_interface::state_export(const device_state_entry &entry)
-{
-}
-
-
-//-------------------------------------------------
-//  state_string_import - called after new state is
-//  written to perform any post-processing
-//-------------------------------------------------
-
-void device_state_interface::state_string_import(const device_state_entry &entry, astring &string)
-{
-}
-
-
-//-------------------------------------------------
-//  state_string_export - called after new state is
-//  written to perform any post-processing
-//-------------------------------------------------
-
-void device_state_interface::state_string_export(const device_state_entry &entry, astring &string)
-{
-}
-
-
 //-------------------------------------------------
 //  state_add - return the value of the given
 //  pieces of indexed state as a UINT64
@@ -580,7 +517,7 @@ device_state_entry &device_state_interface::state_add(int index, const char *sym
 	assert(symbol != NULL);
 
 	// allocate new entry
-	device_state_entry *entry = auto_alloc(&m_machine, device_state_entry(index, symbol, data, size));
+	device_state_entry *entry = auto_alloc(device().machine(), device_state_entry(index, symbol, data, size));
 
 	// append to the end of the list
 	m_state_list.append(*entry);
@@ -593,6 +530,63 @@ device_state_entry &device_state_interface::state_add(int index, const char *sym
 }
 
 
+//-------------------------------------------------
+//  state_import - called after new state is
+//  written to perform any post-processing
+//-------------------------------------------------
+
+void device_state_interface::state_import(const device_state_entry &entry)
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  state_export - called prior to new state
+//  reading the state
+//-------------------------------------------------
+
+void device_state_interface::state_export(const device_state_entry &entry)
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  state_string_import - called after new state is
+//  written to perform any post-processing
+//-------------------------------------------------
+
+void device_state_interface::state_string_import(const device_state_entry &entry, astring &string)
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  state_string_export - called after new state is
+//  written to perform any post-processing
+//-------------------------------------------------
+
+void device_state_interface::state_string_export(const device_state_entry &entry, astring &string)
+{
+	// do nothing by default
+}
+
+
+//-------------------------------------------------
+//  interface_post_start - verify that state was
+//  properly set up
+//-------------------------------------------------
+
+void device_state_interface::interface_post_start()
+{
+	// make sure we got something during startup
+	if (m_state_list.count() == 0)
+		throw emu_fatalerror("No state registered for device '%s' that supports it!", m_device.tag());
+}
+
+
 //-------------------------------------------------
 //  state_find_entry - return a pointer to the
 //  state entry for the given index
@@ -612,16 +606,3 @@ const device_state_entry *device_state_interface::state_find_entry(int index)
 	// handle failure by returning NULL
 	return NULL;
 }
-
-
-//-------------------------------------------------
-//  interface_post_start - verify that state was
-//  properly set up
-//-------------------------------------------------
-
-void device_state_interface::interface_post_start()
-{
-	// make sure we got something during startup
-	if (m_state_list.count() == 0)
-		throw emu_fatalerror("No state registered for device '%s' that supports it!", m_device.tag());
-}
