@@ -51,6 +51,7 @@
 
 // core emulator headers -- must be first
 #include "emucore.h"
+#include "emutempl.h"
 #include "eminline.h"
 #include "profiler.h"
 
@@ -61,19 +62,28 @@
 
 // emulator-specific utilities
 #include "attotime.h"
+#include "hash.h"
 #include "fileio.h" // remove me once NVRAM is implemented as device
-#include "tokenize.h"
 #include "delegate.h"
+#include "cothread.h"
 
 // memory and address spaces
 #include "memory.h"
 #include "addrmap.h"
 
+// machine-wide utilities
+#include "romload.h"
+#include "save.h"
+
 // define machine_config_constructor here due to circular dependency
 // between devices and the machine config
 class machine_config;
-class device_config;
-typedef device_config * (*machine_config_constructor)(machine_config &config, device_config *owner);
+typedef device_t * (*machine_config_constructor)(machine_config &config, device_t *owner);
+
+// I/O
+#include "input.h"
+#include "inptport.h"
+#include "output.h"
 
 // devices and callbacks
 #include "devintrf.h"
@@ -82,17 +92,13 @@ typedef device_config * (*machine_config_constructor)(machine_config &config, de
 #include "diexec.h"
 #include "opresolv.h"
 #include "diimage.h"
+#include "dislot.h"
 #include "disound.h"
 #include "dinvram.h"
+#include "dirtc.h"
 #include "didisasm.h"
-#include "timer.h"
 #include "schedule.h"
-
-// I/O
-#include "input.h"
-#include "inputseq.h"
-#include "inptport.h"
-#include "output.h"
+#include "timer.h"
 
 // timers, CPU and scheduling
 #include "devcpu.h"
@@ -102,18 +108,11 @@ typedef device_config * (*machine_config_constructor)(machine_config &config, de
 #include "mconfig.h"
 #include "driver.h"
 
-// machine-wide utilities
-#include "romload.h"
-#include "state.h"
-
 // image-related
 #include "softlist.h"
 #include "image.h"
 
 // the running machine
-#ifdef MESS
-#include "mess.h"
-#endif /* MESS */
 #include "machine.h"
 #include "mame.h"
 
@@ -125,8 +124,8 @@ typedef device_config * (*machine_config_constructor)(machine_config &config, de
 #include "video.h"
 
 // sound-related
-#include "streams.h"
 #include "sound.h"
+#include "speaker.h"
 
 // generic helpers
 #include "devcb.h"
