@@ -41,6 +41,14 @@
 #include "coreutil.h"
 
 
+//**************************************************************************
+//  DEBUGGING
+//**************************************************************************
+
+#define LOG_ALLOCS		(0)
+
+
+
 //**************************************************************************
 //  CONSTANTS
 //**************************************************************************
@@ -79,11 +87,12 @@ public:
 	int					m_line;				// line number within that file
 	UINT64				m_id;				// unique id
 
-	static const int	k_hash_prime = 193;
+	static const int	k_hash_prime = 6151;
 
 	static UINT64		s_curid;			// current ID
 	static osd_lock *	s_lock;				// lock for managing the list
 	static bool			s_lock_alloc;		// set to true temporarily during lock allocation
+	static bool			s_tracking;			// set to true when tracking is live
 	static memory_entry *s_hash[k_hash_prime];// hash table based on pointer
 	static memory_entry *s_freehead;		// pointer to the head of the free list
 
@@ -104,15 +113,16 @@ private:
 //**************************************************************************
 
 // global resource pool to handle allocations outside of the emulator context
-resource_pool global_resource_pool;
+resource_pool global_resource_pool(6151);
 
 // dummy zeromem object
 const zeromem_t zeromem = { };
 
 // globals for memory_entry
-UINT64 memory_entry::s_curid = 0;
+UINT64 memory_entry::s_curid = 1;
 osd_lock *memory_entry::s_lock = NULL;
 bool memory_entry::s_lock_alloc = false;
+bool memory_entry::s_tracking = false;
 memory_entry *memory_entry::s_hash[memory_entry::k_hash_prime] = { NULL };
 memory_entry *memory_entry::s_freehead = NULL;
 
@@ -122,10 +132,10 @@ memory_entry *memory_entry::s_freehead = NULL;
 //  GLOBAL HELPERS
 //**************************************************************************
 
-/*-------------------------------------------------
-    malloc_file_line - allocate memory with file
-    and line number information
--------------------------------------------------*/
+//-------------------------------------------------
+//  malloc_file_line - allocate memory with file
+//  and line number information
+//-------------------------------------------------
 
 void *malloc_file_line(size_t size, const char *file, int line)
 {
@@ -146,10 +156,35 @@ void *malloc_file_line(size_t size, const char *file, int line)
 }
 
 
-/*-------------------------------------------------
-    free_file_line - free memory with file
-    and line number information
--------------------------------------------------*/
+//-------------------------------------------------
+//  malloc_array_file_line - allocate memory with
+//  file and line number information, and a hint
+//  that this object is an array
+//-------------------------------------------------
+
+void *malloc_array_file_line(size_t size, const char *file, int line)
+{
+	// allocate the memory and fail if we can't
+	void *result = osd_malloc_array(size);
+	if (result == NULL)
+		return NULL;
+
+	// add a new entry
+	memory_entry::allocate(size, result, file, line);
+
+#ifdef MAME_DEBUG
+	// randomize the memory
+	rand_memory(result, size);
+#endif
+
+	return result;
+}
+
+
+//-------------------------------------------------
+//  free_file_line - free memory with file
+//  and line number information
+//-------------------------------------------------
 
 void free_file_line(void *memory, const char *file, int line)
 {
@@ -167,23 +202,33 @@ void free_file_line(void *memory, const char *file, int line)
 #ifdef MAME_DEBUG
 	// clear memory to a bogus value
 	memset(memory, 0xfc, entry->m_size);
-
-	// free the entry and the memory
-	if (entry != NULL)
-		memory_entry::release(entry);
 #endif
 
+	// free the entry and the memory
+	memory_entry::release(entry);
 	osd_free(memory);
 }
 
 
-/*-------------------------------------------------
-    dump_unfreed_mem - called from the exit path
-    of any code that wants to check for unfreed
-    memory
--------------------------------------------------*/
+//-------------------------------------------------
+//  dump_unfreed_mem - called from the exit path
+//  of any code that wants to check for unfreed
+//  memory
+//-------------------------------------------------
 
-void dump_unfreed_mem(void)
+void track_memory(bool track)
+{
+	memory_entry::s_tracking = track;
+}
+
+
+//-------------------------------------------------
+//  dump_unfreed_mem - called from the exit path
+//  of any code that wants to check for unfreed
+//  memory
+//-------------------------------------------------
+
+void dump_unfreed_mem()
 {
 #ifdef MAME_DEBUG
 	memory_entry::report_unfreed();
@@ -196,44 +241,47 @@ void dump_unfreed_mem(void)
 //  RESOURCE POOL
 //**************************************************************************
 
-/*-------------------------------------------------
-    resource_pool - constructor for a new resource
-    pool
--------------------------------------------------*/
+//-------------------------------------------------
+//  resource_pool - constructor for a new resource
+//  pool
+//-------------------------------------------------
 
-resource_pool::resource_pool()
-	: m_listlock(osd_lock_alloc()),
+resource_pool::resource_pool(int hash_size)
+	: m_hash_size(hash_size),
+	  m_listlock(osd_lock_alloc()),
+	  m_hash(new resource_pool_item *[hash_size]),
 	  m_ordered_head(NULL),
 	  m_ordered_tail(NULL)
 {
-	memset(m_hash, 0, sizeof(m_hash));
+	memset(m_hash, 0, hash_size * sizeof(m_hash[0]));
 }
 
 
-/*-------------------------------------------------
-    ~resource_pool - destructor for a resource
-    pool; make sure all tracked objects are
-    deleted
--------------------------------------------------*/
+//-------------------------------------------------
+//  ~resource_pool - destructor for a resource
+//  pool; make sure all tracked objects are
+//  deleted
+//-------------------------------------------------
 
 resource_pool::~resource_pool()
 {
 	clear();
 	if (m_listlock != NULL)
 		osd_lock_free(m_listlock);
+	delete[] m_hash;
 }
 
 
-/*-------------------------------------------------
-    add - add a new item to the resource pool
--------------------------------------------------*/
+//-------------------------------------------------
+//  add - add a new item to the resource pool
+//-------------------------------------------------
 
 void resource_pool::add(resource_pool_item &item)
 {
 	osd_lock_acquire(m_listlock);
 
 	// insert into hash table
-	int hashval = reinterpret_cast<FPTR>(item.m_ptr) % k_hash_prime;
+	int hashval = reinterpret_cast<FPTR>(item.m_ptr) % m_hash_size;
 	item.m_next = m_hash[hashval];
 	m_hash[hashval] = &item;
 
@@ -244,6 +292,8 @@ void resource_pool::add(resource_pool_item &item)
 		entry = memory_entry::find(reinterpret_cast<UINT8 *>(item.m_ptr) - sizeof(size_t));
 	assert(entry != NULL);
 	item.m_id = entry->m_id;
+	if (LOG_ALLOCS)
+		fprintf(stderr, "#%06d, add %d bytes (%s:%d)\n", (UINT32)entry->m_id, static_cast<UINT32>(entry->m_size), entry->m_file, (int)entry->m_line);
 
 	// find the entry to insert after
 	resource_pool_item *insert_after;
@@ -277,10 +327,10 @@ void resource_pool::add(resource_pool_item &item)
 }
 
 
-/*-------------------------------------------------
-    remove - remove a specific item from the
-    resource pool
--------------------------------------------------*/
+//-------------------------------------------------
+//  remove - remove a specific item from the
+//  resource pool
+//-------------------------------------------------
 
 void resource_pool::remove(void *ptr)
 {
@@ -291,7 +341,7 @@ void resource_pool::remove(void *ptr)
 	// search for the item
 	osd_lock_acquire(m_listlock);
 
-	int hashval = reinterpret_cast<FPTR>(ptr) % k_hash_prime;
+	int hashval = reinterpret_cast<FPTR>(ptr) % m_hash_size;
 	for (resource_pool_item **scanptr = &m_hash[hashval]; *scanptr != NULL; scanptr = &(*scanptr)->m_next)
 
 		// must match the pointer
@@ -312,6 +362,8 @@ void resource_pool::remove(void *ptr)
 				m_ordered_tail = deleteme->m_ordered_prev;
 
 			// delete the object and break
+			if (LOG_ALLOCS)
+				fprintf(stderr, "#%06d, delete %d bytes\n", (UINT32)deleteme->m_id, static_cast<UINT32>(deleteme->m_size));
 			delete deleteme;
 			break;
 		}
@@ -320,17 +372,17 @@ void resource_pool::remove(void *ptr)
 }
 
 
-/*-------------------------------------------------
-    find - find a specific item in the resource
-    pool
--------------------------------------------------*/
+//-------------------------------------------------
+//  find - find a specific item in the resource
+//  pool
+//-------------------------------------------------
 
 resource_pool_item *resource_pool::find(void *ptr)
 {
 	// search for the item
 	osd_lock_acquire(m_listlock);
 
-	int hashval = reinterpret_cast<FPTR>(ptr) % k_hash_prime;
+	int hashval = reinterpret_cast<FPTR>(ptr) % m_hash_size;
 	resource_pool_item *item;
 	for (item = m_hash[hashval]; item != NULL; item = item->m_next)
 		if (item->m_ptr == ptr)
@@ -342,10 +394,10 @@ resource_pool_item *resource_pool::find(void *ptr)
 }
 
 
-/*-------------------------------------------------
-    contains - return true if given ptr is
-    contained by one of the objects in the pool
--------------------------------------------------*/
+//-------------------------------------------------
+//  contains - return true if given ptr is
+//  contained by one of the objects in the pool
+//-------------------------------------------------
 
 bool resource_pool::contains(void *_ptrstart, void *_ptrend)
 {
@@ -371,9 +423,9 @@ found:
 }
 
 
-/*-------------------------------------------------
-    clear - remove all items from a resource pool
--------------------------------------------------*/
+//-------------------------------------------------
+//  clear - remove all items from a resource pool
+//-------------------------------------------------
 
 void resource_pool::clear()
 {
@@ -393,10 +445,10 @@ void resource_pool::clear()
 //  MEMORY ENTRY
 //**************************************************************************
 
-/*-------------------------------------------------
-    acquire_lock - acquire the memory entry lock,
-    creating a new one if needed
--------------------------------------------------*/
+//-------------------------------------------------
+//  acquire_lock - acquire the memory entry lock,
+//  creating a new one if needed
+//-------------------------------------------------
 
 void memory_entry::acquire_lock()
 {
@@ -414,9 +466,9 @@ void memory_entry::acquire_lock()
 }
 
 
-/*-------------------------------------------------
-    release_lock - release the memory entry lock
--------------------------------------------------*/
+//-------------------------------------------------
+//  release_lock - release the memory entry lock
+//-------------------------------------------------
 
 void memory_entry::release_lock()
 {
@@ -424,9 +476,9 @@ void memory_entry::release_lock()
 }
 
 
-/*-------------------------------------------------
-    allocate - allocate a new memory entry
--------------------------------------------------*/
+//-------------------------------------------------
+//  allocate - allocate a new memory entry
+//-------------------------------------------------
 
 memory_entry *memory_entry::allocate(size_t size, void *base, const char *file, int line)
 {
@@ -436,7 +488,7 @@ memory_entry *memory_entry::allocate(size_t size, void *base, const char *file,
 	if (s_freehead == NULL)
 	{
 		// create a new chunk, and fail if we can't
-		memory_entry *entry = reinterpret_cast<memory_entry *>(osd_malloc(memory_block_alloc_chunk * sizeof(memory_entry)));
+		memory_entry *entry = reinterpret_cast<memory_entry *>(osd_malloc_array(memory_block_alloc_chunk * sizeof(memory_entry)));
 		if (entry == NULL)
 		{
 			release_lock();
@@ -458,9 +510,11 @@ memory_entry *memory_entry::allocate(size_t size, void *base, const char *file,
 	// populate it
 	entry->m_size = size;
 	entry->m_base = base;
-	entry->m_file = file;
-	entry->m_line = line;
+	entry->m_file = s_tracking ? file : NULL;
+	entry->m_line = s_tracking ? line : 0;
 	entry->m_id = s_curid++;
+	if (LOG_ALLOCS)
+		fprintf(stderr, "#%06d, alloc %d bytes (%s:%d)\n", (UINT32)entry->m_id, static_cast<UINT32>(entry->m_size), entry->m_file, (int)entry->m_line);
 
 	// add it to the alloc list
 	int hashval = reinterpret_cast<FPTR>(base) % k_hash_prime;
@@ -475,9 +529,9 @@ memory_entry *memory_entry::allocate(size_t size, void *base, const char *file,
 }
 
 
-/*-------------------------------------------------
-    find - find a memory entry
--------------------------------------------------*/
+//-------------------------------------------------
+//  find - find a memory entry
+//-------------------------------------------------
 
 memory_entry *memory_entry::find(void *ptr)
 {
@@ -499,9 +553,9 @@ memory_entry *memory_entry::find(void *ptr)
 }
 
 
-/*-------------------------------------------------
-    release - release a memory entry
--------------------------------------------------*/
+//-------------------------------------------------
+//  release - release a memory entry
+//-------------------------------------------------
 
 void memory_entry::release(memory_entry *entry)
 {
@@ -524,10 +578,10 @@ void memory_entry::release(memory_entry *entry)
 }
 
 
-/*-------------------------------------------------
-    report_unfreed - print a list of unfreed
-    memory to the target file
--------------------------------------------------*/
+//-------------------------------------------------
+//  report_unfreed - print a list of unfreed
+//  memory to the target file
+//-------------------------------------------------
 
 void memory_entry::report_unfreed()
 {
@@ -543,11 +597,11 @@ void memory_entry::report_unfreed()
 				if (total == 0)
 					fprintf(stderr, "--- memory leak warning ---\n");
 				total += entry->m_size;
-				fprintf(stderr, "allocation #%06d, %d bytes (%s:%d)\n", (UINT32)entry->m_id, static_cast<UINT32>(entry->m_size), entry->m_file, (int)entry->m_line);
+				fprintf(stderr, "#%06d, nofree %d bytes (%s:%d)\n", (UINT32)entry->m_id, static_cast<UINT32>(entry->m_size), entry->m_file, (int)entry->m_line);
 			}
 
 	release_lock();
 
 	if (total > 0)
-		fprintf(stderr, "a total of %d bytes were not free()'d\n", total);
+		fprintf(stderr, "a total of %d bytes were not freed\n", total);
 }
