@@ -112,40 +112,33 @@ const int DEBUG_FLAG_OSD_ENABLED	= 0x00001000;		// The OSD debugger is enabled
 
 // macros to wrap legacy callbacks
 #define MACHINE_START_NAME(name)	machine_start_##name
-#define MACHINE_START(name)			void MACHINE_START_NAME(name)(running_machine *machine)
+#define MACHINE_START(name)			void MACHINE_START_NAME(name)(running_machine &machine)
 #define MACHINE_START_CALL(name)	MACHINE_START_NAME(name)(machine)
 
 #define MACHINE_RESET_NAME(name)	machine_reset_##name
-#define MACHINE_RESET(name)			void MACHINE_RESET_NAME(name)(running_machine *machine)
+#define MACHINE_RESET(name)			void MACHINE_RESET_NAME(name)(running_machine &machine)
 #define MACHINE_RESET_CALL(name)	MACHINE_RESET_NAME(name)(machine)
 
 #define SOUND_START_NAME(name)		sound_start_##name
-#define SOUND_START(name)			void SOUND_START_NAME(name)(running_machine *machine)
+#define SOUND_START(name)			void SOUND_START_NAME(name)(running_machine &machine)
 #define SOUND_START_CALL(name)		SOUND_START_NAME(name)(machine)
 
 #define SOUND_RESET_NAME(name)		sound_reset_##name
-#define SOUND_RESET(name)			void SOUND_RESET_NAME(name)(running_machine *machine)
+#define SOUND_RESET(name)			void SOUND_RESET_NAME(name)(running_machine &machine)
 #define SOUND_RESET_CALL(name)		SOUND_RESET_NAME(name)(machine)
 
 #define VIDEO_START_NAME(name)		video_start_##name
-#define VIDEO_START(name)			void VIDEO_START_NAME(name)(running_machine *machine)
+#define VIDEO_START(name)			void VIDEO_START_NAME(name)(running_machine &machine)
 #define VIDEO_START_CALL(name)		VIDEO_START_NAME(name)(machine)
 
 #define VIDEO_RESET_NAME(name)		video_reset_##name
-#define VIDEO_RESET(name)			void VIDEO_RESET_NAME(name)(running_machine *machine)
+#define VIDEO_RESET(name)			void VIDEO_RESET_NAME(name)(running_machine &machine)
 #define VIDEO_RESET_CALL(name)		VIDEO_RESET_NAME(name)(machine)
 
 #define PALETTE_INIT_NAME(name)		palette_init_##name
-#define PALETTE_INIT(name)			void PALETTE_INIT_NAME(name)(running_machine *machine, const UINT8 *color_prom)
+#define PALETTE_INIT(name)			void PALETTE_INIT_NAME(name)(running_machine &machine, const UINT8 *color_prom)
 #define PALETTE_INIT_CALL(name)		PALETTE_INIT_NAME(name)(machine, color_prom)
 
-#define VIDEO_EOF_NAME(name)		video_eof_##name
-#define VIDEO_EOF(name)				void VIDEO_EOF_NAME(name)(running_machine *machine)
-#define VIDEO_EOF_CALL(name)		VIDEO_EOF_NAME(name)(machine)
-
-#define VIDEO_UPDATE_NAME(name)		video_update_##name
-#define VIDEO_UPDATE(name)			UINT32 VIDEO_UPDATE_NAME(name)(screen_device *screen, bitmap_t *bitmap, const rectangle *cliprect)
-#define VIDEO_UPDATE_CALL(name)		VIDEO_UPDATE_NAME(name)(screen, bitmap, cliprect)
 
 
 // NULL versions
@@ -156,17 +149,15 @@ const int DEBUG_FLAG_OSD_ENABLED	= 0x00001000;		// The OSD debugger is enabled
 #define video_start_0				NULL
 #define video_reset_0				NULL
 #define palette_init_0				NULL
-#define video_eof_0 				NULL
-#define video_update_0				NULL
 
 
 
 // global allocation helpers
-#define auto_alloc(m, t)				pool_alloc(static_cast<running_machine *>(m)->m_respool, t)
-#define auto_alloc_clear(m, t)			pool_alloc_clear(static_cast<running_machine *>(m)->m_respool, t)
-#define auto_alloc_array(m, t, c)		pool_alloc_array(static_cast<running_machine *>(m)->m_respool, t, c)
-#define auto_alloc_array_clear(m, t, c)	pool_alloc_array_clear(static_cast<running_machine *>(m)->m_respool, t, c)
-#define auto_free(m, v)					pool_free(static_cast<running_machine *>(m)->m_respool, v)
+#define auto_alloc(m, t)				pool_alloc(static_cast<running_machine &>(m).respool(), t)
+#define auto_alloc_clear(m, t)			pool_alloc_clear(static_cast<running_machine &>(m).respool(), t)
+#define auto_alloc_array(m, t, c)		pool_alloc_array(static_cast<running_machine &>(m).respool(), t, c)
+#define auto_alloc_array_clear(m, t, c)	pool_alloc_array_clear(static_cast<running_machine &>(m).respool(), t, c)
+#define auto_free(m, v)					pool_free(static_cast<running_machine &>(m).respool(), v)
 
 #define auto_bitmap_alloc(m, w, h, f)	auto_alloc(m, bitmap_t(w, h, f))
 #define auto_strdup(m, s)				strcpy(auto_alloc_array(m, char, strlen(s) + 1), s)
@@ -182,39 +173,27 @@ class gfx_element;
 class colortable_t;
 class cheat_manager;
 class render_manager;
+class sound_manager;
 class video_manager;
 class debug_view_manager;
 class osd_interface;
 
-typedef struct _mame_private mame_private;
-typedef struct _cpuexec_private cpuexec_private;
-typedef struct _timer_private timer_private;
-typedef struct _state_private state_private;
 typedef struct _memory_private memory_private;
 typedef struct _palette_private palette_private;
 typedef struct _tilemap_private tilemap_private;
-typedef struct _streams_private streams_private;
-typedef struct _devices_private devices_private;
 typedef struct _romload_private romload_private;
-typedef struct _sound_private sound_private;
 typedef struct _input_private input_private;
 typedef struct _input_port_private input_port_private;
 typedef struct _ui_input_private ui_input_private;
 typedef struct _debugcpu_private debugcpu_private;
-typedef struct _debugvw_private debugvw_private;
 typedef struct _generic_machine_private generic_machine_private;
 typedef struct _generic_video_private generic_video_private;
 typedef struct _generic_audio_private generic_audio_private;
 
 
-// template specializations
-typedef tagged_list<memory_region> region_list;
-
-
 // legacy callback functions
-typedef void   (*legacy_callback_func)(running_machine *machine);
-typedef void   (*palette_init_func)(running_machine *machine, const UINT8 *color_prom);
-typedef UINT32 (*video_update_func)(screen_device *screen, bitmap_t *bitmap, const rectangle *cliprect);
+typedef void   (*legacy_callback_func)(running_machine &machine);
+typedef void   (*palette_init_func)(running_machine &machine, const UINT8 *color_prom);
 
 
 
@@ -226,26 +205,25 @@ class memory_region
 	DISABLE_COPYING(memory_region);
 
 	friend class running_machine;
-	template<class T> friend class tagged_list;
+	friend class simple_list<memory_region>;
 	friend resource_pool_object<memory_region>::~resource_pool_object();
 
 	// construction/destruction
-	memory_region(running_machine &machine, const char *name, UINT32 length, UINT32 flags);
+	memory_region(running_machine &machine, const char *name, UINT32 length, UINT8 width, endianness_t endian);
 	~memory_region();
 
 public:
 	// getters
+	running_machine &machine() const { return m_machine; }
 	memory_region *next() const { return m_next; }
 	UINT8 *base() const { return (this != NULL) ? m_base.u8 : NULL; }
 	UINT8 *end() const { return (this != NULL) ? m_base.u8 + m_length : NULL; }
 	UINT32 bytes() const { return (this != NULL) ? m_length : 0; }
 	const char *name() const { return m_name; }
-	UINT32 flags() const { return m_flags; }
 
 	// flag expansion
-	endianness_t endianness() const { return ((m_flags & ROMREGION_ENDIANMASK) == ROMREGION_LE) ? ENDIANNESS_LITTLE : ENDIANNESS_BIG; }
-	UINT8 width() const { return 1 << ((m_flags & ROMREGION_WIDTHMASK) >> 8); }
-	bool invert() const { return ((m_flags & ROMREGION_INVERTMASK) != 0); }
+	endianness_t endianness() const { return m_endianness; }
+	UINT8 width() const { return m_width; }
 
 	// data access
 	UINT8 &u8(offs_t offset = 0) const { return m_base.u8[offset]; }
@@ -271,7 +249,8 @@ private:
 	astring					m_name;
 	generic_ptr				m_base;
 	UINT32					m_length;
-	UINT32					m_flags;
+	UINT8					m_width;
+	endianness_t			m_endianness;
 };
 
 
@@ -327,51 +306,77 @@ public:
 
 // ======================> running_machine
 
+typedef delegate<void ()> machine_notify_delegate;
+
 // description of the currently-running machine
-class running_machine : public bindable_object
+class running_machine
 {
 	DISABLE_COPYING(running_machine);
 
-	friend void debugger_init(running_machine *machine);
+	friend void debugger_init(running_machine &machine);
+	friend class sound_manager;
 
-	typedef void (*notify_callback)(running_machine &machine);
 	typedef void (*logerror_callback)(running_machine &machine, const char *string);
 
+	// must be at top of member variables
+	resource_pool			m_respool;				// pool of resources for this machine
+
 public:
 	// construction/destruction
-	running_machine(const machine_config &config, osd_interface &osd, core_options &options, bool exit_to_game_select = false);
+	running_machine(const machine_config &config, osd_interface &osd, bool exit_to_game_select = false);
 	~running_machine();
 
+	// getters
+	const machine_config &config() const { return m_config; }
+	const device_list &devicelist() const { return m_config.devicelist(); }
+	const game_driver &system() const { return m_system; }
+	osd_interface &osd() const { return m_osd; }
+	resource_pool &respool() { return m_respool; }
+	device_scheduler &scheduler() { return m_scheduler; }
+	save_manager &save() { return m_save; }
+	cheat_manager &cheat() const { assert(m_cheat != NULL); return *m_cheat; }
+	render_manager &render() const { assert(m_render != NULL); return *m_render; }
+	input_manager &input() const { assert(m_input != NULL); return *m_input; }
+	sound_manager &sound() const { assert(m_sound != NULL); return *m_sound; }
+	video_manager &video() const { assert(m_video != NULL); return *m_video; }
+	debug_view_manager &debug_view() const { assert(m_debug_view != NULL); return *m_debug_view; }
+	driver_device *driver_data() const { return m_driver_device; }
+	template<class _DriverClass> _DriverClass *driver_data() const { return downcast<_DriverClass *>(m_driver_device); }
+	machine_phase phase() const { return m_current_phase; }
+	bool paused() const { return m_paused || (m_current_phase != MACHINE_PHASE_RUNNING); }
+	bool exit_pending() const { return m_exit_pending; }
+	bool new_driver_pending() const { return (m_new_driver_pending != NULL); }
+	const char *new_driver_name() const { return m_new_driver_pending->name; }
+	bool ui_active() const { return m_ui_active; }
+	const char *basename() const { return m_basename; }
+	int sample_rate() const { return m_sample_rate; }
+	bool save_or_load_pending() const { return m_saveload_pending_file; }
+	screen_device *first_screen() const { return primary_screen; }
+
+	// additional helpers
+	emu_options &options() const { return m_config.options(); }
+	memory_region *first_region() const { return m_regionlist.first(); }
+	attotime time() const { return m_scheduler.time(); }
+	bool scheduled_event_pending() const { return m_exit_pending || m_hard_reset_pending; }
+
 	// fetch items by name
 	inline device_t *device(const char *tag);
-	template<class T> inline T *device(const char *tag) { return downcast<T *>(device(tag)); }
+	template<class _DeviceClass> inline _DeviceClass *device(const char *tag) { return downcast<_DeviceClass *>(device(tag)); }
 	inline const input_port_config *port(const char *tag);
 	inline const memory_region *region(const char *tag);
 
 	// configuration helpers
+	device_t &add_dynamic_device(device_t &owner, device_type type, const char *tag, UINT32 clock);
 	UINT32 total_colors() const { return m_config.m_total_colors; }
 
-	// getters
-	const char *basename() const { return m_basename; }
-	core_options *options() const { return &m_options; }
-	machine_phase phase() const { return m_current_phase; }
-	bool paused() const { return m_paused || (m_current_phase != MACHINE_PHASE_RUNNING); }
-	bool scheduled_event_pending() const { return m_exit_pending || m_hard_reset_pending; }
-	bool save_or_load_pending() const { return (m_saveload_pending_file); }
-	bool exit_pending() const { return m_exit_pending; }
-	bool new_driver_pending() const { return (m_new_driver_pending != NULL); }
-	const char *new_driver_name() const { return m_new_driver_pending->name; }
-	device_scheduler &scheduler() { return m_scheduler; }
-	osd_interface &osd() const { return m_osd; }
-	screen_device *first_screen() const { return primary_screen; }
-
 	// immediate operations
 	int run(bool firstrun);
 	void pause();
 	void resume();
-	void add_notifier(machine_notification event, notify_callback callback);
+	void add_notifier(machine_notification event, machine_notify_delegate callback);
 	void call_notifiers(machine_notification which);
 	void add_logerror_callback(logerror_callback callback);
+	void set_ui_active(bool active) { m_ui_active = active; }
 
 	// scheduled operations
 	void schedule_exit();
@@ -381,20 +386,14 @@ public:
 	void schedule_save(const char *filename);
 	void schedule_load(const char *filename);
 
-	// time
+	// date & time
 	void base_datetime(system_time &systime);
 	void current_datetime(system_time &systime);
 
 	// regions
-	memory_region *region_alloc(const char *name, UINT32 length, UINT32 flags);
+	memory_region *region_alloc(const char *name, UINT32 length, UINT8 width, endianness_t endian);
 	void region_free(const char *name);
 
-	// managers
-	cheat_manager &cheat() const { assert(m_cheat != NULL); return *m_cheat; }
-	render_manager &render() const { assert(m_render != NULL); return *m_render; }
-	video_manager &video() const { assert(m_video != NULL); return *m_video; }
-	debug_view_manager &debug_view() const { assert(m_debug_view != NULL); return *m_debug_view; }
-
 	// misc
 	void CLIB_DECL logerror(const char *format, ...);
 	void CLIB_DECL vlogerror(const char *format, va_list args);
@@ -402,22 +401,10 @@ public:
 	const char *describe_context();
 
 	// internals
-	resource_pool			m_respool;			// pool of resources for this machine
-	region_list				m_regionlist;		// list of memory regions
-	device_list				m_devicelist;		// list of running devices
-
-	// configuration data
-	const machine_config *	config;				// points to the constructed machine_config
-	const machine_config &	m_config;			// points to the constructed machine_config
 	ioport_list				m_portlist;			// points to a list of input port configurations
 
 	// CPU information
 	cpu_device *			firstcpu;			// first CPU (allows for quick iteration via typenext)
-	address_space *			m_nonspecific_space;// a dummy address_space used for legacy compatibility
-
-	// game-related information
-	const game_driver *		gamedrv;			// points to the definition of the game machine
-	const game_driver &		m_game;				// points to the definition of the game machine
 
 	// video-related information
 	gfx_element *			gfx[MAX_GFX_ELEMENTS];// array of pointers to graphic sets (chars, sprites)
@@ -430,29 +417,17 @@ public:
 	pen_t *					shadow_table;		// table for looking up a shadowed pen
 	bitmap_t *				priority_bitmap;	// priority bitmap
 
-	// audio-related information
-	int						sample_rate;		// the digital audio sample rate
-
 	// debugger-related information
 	UINT32					debug_flags;		// the current debug flags
 
-	// UI-related
-	bool					ui_active;			// ui active or not (useful for games / systems with keyboard inputs)
-
 	// generic pointers
 	generic_pointers		generic;			// generic pointers
 
 	// internal core information
-	mame_private *			mame_data;			// internal data from mame.c
-	timer_private *			timer_data;			// internal data from timer.c
-	state_private *			state_data;			// internal data from state.c
 	memory_private *		memory_data;		// internal data from memory.c
 	palette_private *		palette_data;		// internal data from palette.c
 	tilemap_private *		tilemap_data;		// internal data from tilemap.c
-	streams_private *		streams_data;		// internal data from streams.c
-	devices_private *		devices_data;		// internal data from devices.c
 	romload_private *		romload_data;		// internal data from romload.c
-	sound_private *			sound_data;			// internal data from sound.c
 	input_private *			input_data;			// internal data from input.c
 	input_port_private *	input_port_data;	// internal data from inptport.c
 	ui_input_private *		ui_input_data;		// internal data from uiinput.c
@@ -461,58 +436,57 @@ public:
 	generic_video_private *	generic_video_data;	// internal data from video/generic.c
 	generic_audio_private *	generic_audio_data;	// internal data from audio/generic.c
 
-	// driver-specific information
-	driver_device *driver_data() const { return m_driver_device; }
-
-	template<class T>
-	T *driver_data() const { return downcast<T *>(m_driver_device); }
-
 private:
+	// internal helpers
 	void start();
 	void set_saveload_filename(const char *filename);
 	void fill_systime(system_time &systime, time_t t);
 	void handle_saveload();
+	void soft_reset(void *ptr = NULL, INT32 param = 0);
 
-	static TIMER_CALLBACK( static_soft_reset );
-	void soft_reset();
-
+	// internal callbacks
 	static void logfile_callback(running_machine &machine, const char *buffer);
 
-	// notifier callbacks
-	struct notifier_callback_item
-	{
-		notifier_callback_item(notify_callback func);
-		notifier_callback_item *	m_next;
-		notify_callback				m_func;
-	};
-	notifier_callback_item *m_notifier_list[MACHINE_NOTIFY_COUNT];
+	// internal state
+	const machine_config &	m_config;				// reference to the constructed machine_config
+	const game_driver &		m_system;				// reference to the definition of the game machine
+	osd_interface &			m_osd;					// reference to OSD system
 
-	// logerror callbacks
-	struct logerror_callback_item
-	{
-		logerror_callback_item(logerror_callback func);
-		logerror_callback_item *	m_next;
-		logerror_callback			m_func;
-	};
-	logerror_callback_item *m_logerror_list;
+	// embedded managers and objects
+	tagged_list<memory_region> m_regionlist;		// list of memory regions
+	save_manager			m_save;					// save manager
+	device_scheduler		m_scheduler;			// scheduler object
 
-	device_scheduler		m_scheduler;		// scheduler object
-	core_options &			m_options;
-	osd_interface &			m_osd;
+	// managers
+	cheat_manager *			m_cheat;				// internal data from cheat.c
+	render_manager *		m_render;				// internal data from render.c
+	input_manager *			m_input;				// internal data from input.c
+	sound_manager *			m_sound;				// internal data from sound.c
+	video_manager *			m_video;				// internal data from video.c
+	debug_view_manager *	m_debug_view;			// internal data from debugvw.c
 
-	astring					m_context;			// context string
-	astring					m_basename;			// basename used for game-related paths
+	// driver state
+	driver_device *			m_driver_device;		// pointer to the current driver device
 
-	machine_phase			m_current_phase;
-	bool					m_paused;
-	bool					m_hard_reset_pending;
-	bool					m_exit_pending;
-	bool					m_exit_to_game_select;
-	const game_driver *		m_new_driver_pending;
-	emu_timer *				m_soft_reset_timer;
-	mame_file *				m_logfile;
+	// system state
+	machine_phase			m_current_phase;		// current execution phase
+	bool					m_paused;				// paused?
+	bool					m_hard_reset_pending;	// is a hard reset pending?
+	bool					m_exit_pending;			// is an exit pending?
+	bool					m_exit_to_game_select;	// when we exit, go we go back to the game select?
+	const game_driver *		m_new_driver_pending;	// pointer to the next pending driver
+	emu_timer *				m_soft_reset_timer;		// timer used to schedule a soft reset
 
-	// load/save
+	// misc state
+	UINT32					m_rand_seed;			// current random number seed
+	bool					m_ui_active;			// ui active or not (useful for games / systems with keyboard inputs)
+	time_t					m_base_time;			// real time at initial emulation time
+	astring					m_basename;				// basename used for game-related paths
+	astring					m_context;				// context string buffer
+	int						m_sample_rate;			// the digital audio sample rate
+	emu_file *				m_logfile;				// pointer to the active log file
+
+	// load/save management
 	enum saveload_schedule
 	{
 		SLS_NONE,
@@ -524,90 +498,36 @@ private:
 	astring					m_saveload_pending_file;
 	const char *			m_saveload_searchpath;
 
-	// random number seed
-	UINT32					m_rand_seed;
-
-	// base time
-	time_t					m_base_time;
-
-	driver_device *			m_driver_device;
-	cheat_manager *			m_cheat;			// internal data from cheat.c
-	render_manager *		m_render;			// internal data from render.c
-	video_manager *			m_video;			// internal data from video.c
-	debug_view_manager *	m_debug_view;		// internal data from debugvw.c
-};
-
-
-
-// ======================> driver_device_config_base
-
-// a base class with common functionality for the (mostly stub) driver_device_configs
-class driver_device_config_base : public device_config
-{
-	friend class driver_device;
-
-protected:
-	// construction/destruction
-	driver_device_config_base(const machine_config &mconfig, device_type type, const char *tag, const device_config *owner);
-
-public:
-	// indexes into our generic callbacks
-	enum callback_type
+	// notifier callbacks
+	struct notifier_callback_item
 	{
-		CB_MACHINE_START,
-		CB_MACHINE_RESET,
-		CB_SOUND_START,
-		CB_SOUND_RESET,
-		CB_VIDEO_START,
-		CB_VIDEO_RESET,
-		CB_VIDEO_EOF,
-		CB_COUNT
+		// construction/destruction
+		notifier_callback_item(machine_notify_delegate func);
+
+		// getters
+		notifier_callback_item *next() const { return m_next; }
+
+		// state
+		notifier_callback_item *	m_next;
+		machine_notify_delegate		m_func;
 	};
+	simple_list<notifier_callback_item> m_notifier_list[MACHINE_NOTIFY_COUNT];
 
-	// inline configuration helpers
-	static void static_set_game(device_config *device, const game_driver *game);
-	static void static_set_callback(device_config *device, callback_type type, legacy_callback_func callback);
-	static void static_set_palette_init(device_config *device, palette_init_func callback);
-	static void static_set_video_update(device_config *device, video_update_func callback);
-
-protected:
-	// optional information overrides
-	virtual const rom_entry *rom_region() const;
-
-	// internal state
-	const game_driver *		m_game;						// pointer to the game driver
-
-	legacy_callback_func	m_callbacks[CB_COUNT];		// generic legacy callbacks
-	palette_init_func		m_palette_init;				// one-time palette init callback
-	video_update_func		m_video_update;				// video update callback
-};
-
-
-
-// ======================> driver_device_config
-
-// this provides a minimal config class for driver devices, which don't
-// explicitly declare their own
-template<class _DeviceClass>
-class driver_device_config : public driver_device_config_base
-{
-	// construction/destruction
-	driver_device_config(const machine_config &mconfig, const char *tag, const device_config *owner)
-		: driver_device_config_base(mconfig, static_alloc_device_config, tag, owner) { }
-
-public:
-	// allocators
-	static device_config *static_alloc_device_config(const machine_config &mconfig, const char *tag, const device_config *owner, UINT32 clock)
+	// logerror callbacks
+	class logerror_callback_item
 	{
-		return global_alloc(driver_device_config(mconfig, tag, owner));
-	}
+	public:
+		// construction/destruction
+		logerror_callback_item(logerror_callback func);
 
-	virtual device_t *alloc_device(running_machine &machine) const
-	{
-		// we clear here for historical reasons, as many existing driver states
-		// assume everything is NULL before starting
-		return auto_alloc_clear(&machine, _DeviceClass(machine, *this));
-	}
+		// getters
+		logerror_callback_item *next() const { return m_next; }
+
+		// state
+		logerror_callback_item *	m_next;
+		logerror_callback			m_func;
+	};
+	simple_list<logerror_callback_item> m_logerror_list;
 };
 
 
@@ -619,12 +539,29 @@ class driver_device : public device_t
 {
 public:
 	// construction/destruction
-	driver_device(running_machine &machine, const driver_device_config_base &config);
+	driver_device(const machine_config &mconfig, device_type type, const char *tag);
 	virtual ~driver_device();
 
+	// indexes into our generic callbacks
+	enum callback_type
+	{
+		CB_MACHINE_START,
+		CB_MACHINE_RESET,
+		CB_SOUND_START,
+		CB_SOUND_RESET,
+		CB_VIDEO_START,
+		CB_VIDEO_RESET,
+		CB_COUNT
+	};
+
+	// inline configuration helpers
+	static void static_set_game(device_t &device, const game_driver &game);
+	static void static_set_callback(device_t &device, callback_type type, legacy_callback_func callback);
+	static void static_set_palette_init(device_t &device, palette_init_func callback);
+
 	// additional video helpers
-	virtual bool video_update(screen_device &screen, bitmap_t &bitmap, const rectangle &cliprect);
-	virtual void video_eof();
+	virtual bool screen_update(screen_device &screen, bitmap_t &bitmap, const rectangle &cliprect);
+	virtual void screen_eof();
 
 protected:
 	// helpers called at startup
@@ -640,14 +577,29 @@ protected:
 	virtual void video_reset();
 
 	// device-level overrides
+	virtual const rom_entry *device_rom_region() const;
+	virtual ioport_constructor device_input_ports() const;
 	virtual void device_start();
 	virtual void device_reset();
 
 	// internal state
-	const driver_device_config_base &m_config;
+	const game_driver *		m_system;					// pointer to the game driver
+
+	legacy_callback_func	m_callbacks[CB_COUNT];		// generic legacy callbacks
+	palette_init_func		m_palette_init;				// one-time palette init callback
 };
 
 
+// this template function creates a stub which constructs a device
+template<class _DriverClass>
+device_t *driver_device_creator(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+{
+	assert(owner == NULL);
+	assert(clock == 0);
+	return global_alloc_clear(_DriverClass(mconfig, &driver_device_creator<_DriverClass>, tag));
+}
+
+
 
 //**************************************************************************
 //  INLINE FUNCTIONS
@@ -655,7 +607,7 @@ protected:
 
 inline device_t *running_machine::device(const char *tag)
 {
-	return m_devicelist.find(tag);
+	return devicelist().find(tag);
 }
 
 inline const input_port_config *running_machine::port(const char *tag)
