@@ -45,86 +45,34 @@
 //  DEVICE CONFIGURATION
 //**************************************************************************
 
-//-------------------------------------------------
-//  mos6526_device_config - constructor
-//-------------------------------------------------
-
-mos6526_device_config::mos6526_device_config(const machine_config &mconfig, const char *tag, const device_config *owner, UINT32 clock)
-    : device_config(mconfig, static_alloc_device_config, "MOS6526", tag, owner, clock)
-{
-}
-
-
-//-------------------------------------------------
-//  static_alloc_device_config - allocate a new
-//  configuration object
-//-------------------------------------------------
-
-device_config *mos6526_device_config::static_alloc_device_config(const machine_config &mconfig, const char *tag, const device_config *owner, UINT32 clock)
-{
-    return global_alloc(mos6526_device_config(mconfig, tag, owner, clock));
-}
-
-
-//-------------------------------------------------
-//  alloc_device - allocate a new device object
-//-------------------------------------------------
-
-device_t *mos6526_device_config::alloc_device(running_machine &machine) const
-{
-    return auto_alloc(&machine, mos6526_device(machine, *this));
-}
-
-
-//-------------------------------------------------
-//  device_config_complete - perform any
-//  operations now that the configuration is
-//  complete
-//-------------------------------------------------
-
-void mos6526_device_config::device_config_complete()
-{
-	// inherit a copy of the static data
-	const mos6526_interface *intf = reinterpret_cast<const mos6526_interface *>(static_config());
-	if (intf != NULL)
-		*static_cast<mos6526_interface *>(this) = *intf;
-
-	// or initialize to defaults if none provided
-	else
-	{
-		m_tod_clock = 0;
-    	memset(&m_out_irq_func, 0, sizeof(m_out_irq_func));
-    	memset(&m_out_pc_func, 0, sizeof(m_out_pc_func));
-    	memset(&m_out_cnt_func, 0, sizeof(m_out_cnt_func));
-    	memset(&m_out_sp_func, 0, sizeof(m_out_sp_func));
-    	memset(&m_in_pa_func, 0, sizeof(m_in_pa_func));
-    	memset(&m_out_pa_func, 0, sizeof(m_out_pa_func));
-    	memset(&m_in_pb_func, 0, sizeof(m_in_pb_func));
-    	memset(&m_out_pb_func, 0, sizeof(m_out_pb_func));
-	}
-}
-
-
 
 //**************************************************************************
 //  LIVE DEVICE
 //**************************************************************************
 
-const device_type MOS6526R1 = mos6526_device_config::static_alloc_device_config;
-const device_type MOS6526R2 = mos6526_device_config::static_alloc_device_config;
-const device_type MOS8520 = mos6526_device_config::static_alloc_device_config;
+// device type definition
+const device_type MOS6526R1 = &device_creator<mos6526r1_device>;
+const device_type MOS6526R2 = &device_creator<mos6526r2_device>;
+const device_type MOS8520 = &device_creator<mos8520_device>;
 
 //-------------------------------------------------
 //  mos6526_device - constructor
 //-------------------------------------------------
 
-mos6526_device::mos6526_device(running_machine &_machine, const mos6526_device_config &config)
-    : device_t(_machine, config),
-      m_config(config)
+mos6526_device::mos6526_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock)
+    : device_t(mconfig, type, name, tag, owner, clock)
 {
-
 }
 
+mos6526r1_device::mos6526r1_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+    : mos6526_device(mconfig, MOS6526R1, "MOS6526r1", tag, owner, clock) { }
+
+mos6526r2_device::mos6526r2_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+    : mos6526_device(mconfig, MOS6526R2, "MOS6526r2", tag, owner, clock) { }
+
+mos8520_device::mos8520_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+    : mos6526_device(mconfig, MOS8520, "MOS8520", tag, owner, clock) { }
+
 
 //-------------------------------------------------
 //  device_reset - device-specific reset
@@ -172,6 +120,35 @@ void mos6526_device::device_reset()
 }
 
 
+//-------------------------------------------------
+//  device_config_complete - perform any
+//  operations now that the configuration is
+//  complete
+//-------------------------------------------------
+
+void mos6526_device::device_config_complete()
+{
+	// inherit a copy of the static data
+	const mos6526_interface *intf = reinterpret_cast<const mos6526_interface *>(static_config());
+	if (intf != NULL)
+		*static_cast<mos6526_interface *>(this) = *intf;
+
+	// or initialize to defaults if none provided
+	else
+	{
+		m_tod_clock = 0;
+    	memset(&m_out_irq_cb, 0, sizeof(m_out_irq_cb));
+    	memset(&m_out_pc_cb, 0, sizeof(m_out_pc_cb));
+    	memset(&m_out_cnt_cb, 0, sizeof(m_out_cnt_cb));
+    	memset(&m_out_sp_cb, 0, sizeof(m_out_sp_cb));
+    	memset(&m_in_pa_cb, 0, sizeof(m_in_pa_cb));
+    	memset(&m_out_pa_cb, 0, sizeof(m_out_pa_cb));
+    	memset(&m_in_pb_cb, 0, sizeof(m_in_pb_cb));
+    	memset(&m_out_pb_cb, 0, sizeof(m_out_pb_cb));
+	}
+}
+
+
 //-------------------------------------------------
 //  device_start - device-specific startup
 //-------------------------------------------------
@@ -179,17 +156,17 @@ void mos6526_device::device_reset()
 void mos6526_device::device_start()
 {
 	/* clear out CIA structure, and copy the interface */
-	devcb_resolve_write_line(&m_out_irq_func, &m_config.m_out_irq_func, this);
-	devcb_resolve_write_line(&m_out_pc_func, &m_config.m_out_pc_func, this);
-	devcb_resolve_write_line(&m_out_cnt_func, &m_config.m_out_cnt_func, this);
-	devcb_resolve_write_line(&m_out_sp_func, &m_config.m_out_sp_func, this);
+	m_out_irq_func.resolve(m_out_irq_cb, *this);
+	m_out_pc_func.resolve(m_out_pc_cb, *this);
+	m_out_cnt_func.resolve(m_out_cnt_cb, *this);
+	m_out_sp_func.resolve(m_out_sp_cb, *this);
 	m_flag = 1;
 
 	/* setup ports */
-	devcb_resolve_read8(&m_port[0].m_read, &m_config.m_in_pa_func, this);
-	devcb_resolve_write8(&m_port[0].m_write, &m_config.m_out_pa_func, this);
-	devcb_resolve_read8(&m_port[1].m_read, &m_config.m_in_pb_func, this);
-	devcb_resolve_write8(&m_port[1].m_write, &m_config.m_out_pb_func, this);
+	m_port[0].m_read.resolve(m_in_pa_cb, *this);
+	m_port[0].m_write.resolve(m_out_pa_cb, *this);
+	m_port[1].m_read.resolve(m_in_pb_cb, *this);
+	m_port[1].m_write.resolve(m_out_pb_cb, *this);
 
 	for (int p = 0; p < (sizeof(m_port) / sizeof(m_port[0])); p++)
 	{
@@ -200,51 +177,51 @@ void mos6526_device::device_start()
 	for (int t = 0; t < (sizeof(m_timer) / sizeof(m_timer[0])); t++)
 	{
 		cia_timer *timer = &m_timer[t];
-		timer->m_timer = timer_alloc(&m_machine, timer_proc, (void*)this);
+		timer->m_timer = machine().scheduler().timer_alloc(FUNC(timer_proc), (void*)this);
 		timer->m_cia = this;
 		timer->m_irq = 0x01 << t;
 	}
 
 	/* setup TOD timer, if appropriate */
-	if (m_config.m_tod_clock != 0)
+	if (m_tod_clock != 0)
 	{
-		timer_pulse(&m_machine, ATTOTIME_IN_HZ(m_config.m_tod_clock), (void *)this, 0, clock_tod_callback);
+		machine().scheduler().timer_pulse(attotime::from_hz(m_tod_clock), FUNC(clock_tod_callback), 0, (void *)this);
 	}
 
 	/* state save support */
-	state_save_register_device_item(this, 0, m_port[0].m_ddr);
-	state_save_register_device_item(this, 0, m_port[0].m_latch);
-	state_save_register_device_item(this, 0, m_port[0].m_in);
-	state_save_register_device_item(this, 0, m_port[0].m_out);
-	state_save_register_device_item(this, 0, m_port[0].m_mask_value);
-	state_save_register_device_item(this, 0, m_port[1].m_ddr);
-	state_save_register_device_item(this, 0, m_port[1].m_latch);
-	state_save_register_device_item(this, 0, m_port[1].m_in);
-	state_save_register_device_item(this, 0, m_port[1].m_out);
-	state_save_register_device_item(this, 0, m_port[1].m_mask_value);
-	state_save_register_device_item(this, 0, m_timer[0].m_latch);
-	state_save_register_device_item(this, 0, m_timer[0].m_count);
-	state_save_register_device_item(this, 0, m_timer[0].m_mode);
-	state_save_register_device_item(this, 0, m_timer[0].m_irq);
-	state_save_register_device_item(this, 0, m_timer[1].m_latch);
-	state_save_register_device_item(this, 0, m_timer[1].m_count);
-	state_save_register_device_item(this, 0, m_timer[1].m_mode);
-	state_save_register_device_item(this, 0, m_timer[1].m_irq);
-	state_save_register_device_item(this, 0, m_tod);
-	state_save_register_device_item(this, 0, m_tod_latch);
-	state_save_register_device_item(this, 0, m_tod_latched);
-	state_save_register_device_item(this, 0, m_tod_running);
-	state_save_register_device_item(this, 0, m_alarm);
-	state_save_register_device_item(this, 0, m_icr);
-	state_save_register_device_item(this, 0, m_ics);
-	state_save_register_device_item(this, 0, m_irq);
-	state_save_register_device_item(this, 0, m_flag);
-	state_save_register_device_item(this, 0, m_loaded);
-	state_save_register_device_item(this, 0, m_sdr);
-	state_save_register_device_item(this, 0, m_sp);
-	state_save_register_device_item(this, 0, m_cnt);
-	state_save_register_device_item(this, 0, m_shift);
-	state_save_register_device_item(this, 0, m_serial);
+	save_item(NAME(m_port[0].m_ddr));
+	save_item(NAME(m_port[0].m_latch));
+	save_item(NAME(m_port[0].m_in));
+	save_item(NAME(m_port[0].m_out));
+	save_item(NAME(m_port[0].m_mask_value));
+	save_item(NAME(m_port[1].m_ddr));
+	save_item(NAME(m_port[1].m_latch));
+	save_item(NAME(m_port[1].m_in));
+	save_item(NAME(m_port[1].m_out));
+	save_item(NAME(m_port[1].m_mask_value));
+	save_item(NAME(m_timer[0].m_latch));
+	save_item(NAME(m_timer[0].m_count));
+	save_item(NAME(m_timer[0].m_mode));
+	save_item(NAME(m_timer[0].m_irq));
+	save_item(NAME(m_timer[1].m_latch));
+	save_item(NAME(m_timer[1].m_count));
+	save_item(NAME(m_timer[1].m_mode));
+	save_item(NAME(m_timer[1].m_irq));
+	save_item(NAME(m_tod));
+	save_item(NAME(m_tod_latch));
+	save_item(NAME(m_tod_latched));
+	save_item(NAME(m_tod_running));
+	save_item(NAME(m_alarm));
+	save_item(NAME(m_icr));
+	save_item(NAME(m_ics));
+	save_item(NAME(m_irq));
+	save_item(NAME(m_flag));
+	save_item(NAME(m_loaded));
+	save_item(NAME(m_sdr));
+	save_item(NAME(m_sp));
+	save_item(NAME(m_cnt));
+	save_item(NAME(m_shift));
+	save_item(NAME(m_serial));
 }
 
 
@@ -264,8 +241,8 @@ void mos6526_device::set_port_mask_value(int port, int data)
 void mos6526_device::update_pc()
 {
 	/* this should really be one cycle long */
-	devcb_call_write_line(&m_out_pc_func, 0);
-	devcb_call_write_line(&m_out_pc_func, 1);
+	m_out_pc_func(0);
+	m_out_pc_func(1);
 }
 
 /*-------------------------------------------------
@@ -291,7 +268,7 @@ void mos6526_device::update_interrupts()
 	if (m_irq != new_irq)
 	{
 		m_irq = new_irq;
-		devcb_call_write_line(&m_out_irq_func, m_irq);
+		m_out_irq_func(m_irq);
 	}
 }
 
@@ -364,11 +341,11 @@ void mos6526_device::timer_underflow(int timer)
 
 					/* transmit MSB */
 					m_sp = BIT(m_serial, 7);
-					devcb_call_write_line(&m_out_sp_func, m_sp);
+					m_out_sp_func(m_sp);
 
 					/* toggle CNT */
 					m_cnt = !m_cnt;
-					devcb_call_write_line(&m_out_cnt_func, m_cnt);
+					m_out_cnt_func(m_cnt);
 
 					/* shift data */
 					m_serial <<= 1;
@@ -385,7 +362,7 @@ void mos6526_device::timer_underflow(int timer)
 				{
 					/* toggle CNT */
 					m_cnt = !m_cnt;
-					devcb_call_write_line(&m_out_cnt_func, m_cnt);
+					m_out_cnt_func(m_cnt);
 
 					if (m_shift == 8)
 					{
@@ -585,7 +562,7 @@ UINT8 mos6526_device::reg_r(UINT8 offset)
 		case CIA_PRA:
 		case CIA_PRB:
 			port = &m_port[offset & 1];
-			data = devcb_call_read8(&port->m_read, 0);
+			data = port->m_read(0);
 			data = ((data & ~port->m_ddr) | (port->m_latch & port->m_ddr)) & port->m_mask_value;
 
 			port->m_in = data;
@@ -725,7 +702,7 @@ void mos6526_device::reg_w(UINT8 offset, UINT8 data)
 			port = &m_port[offset & 1];
 			port->m_latch = data;
 			port->m_out = (data & port->m_ddr) | (port->m_in & ~port->m_ddr);
-			devcb_call_write8(&port->m_write, 0, port->m_out);
+			port->m_write(0, port->m_out);
 
 			/* pulse /PC following the write */
 			if (offset == CIA_PRB)
@@ -856,8 +833,8 @@ void mos6526_device::reg_w(UINT8 offset, UINT8 data)
 
 static int is_timer_active(emu_timer *timer)
 {
-	attotime t = timer_firetime(timer);
-	return attotime_compare(t, attotime_never) != 0;
+	attotime t = timer->expire();
+	return (t != attotime::never);
 }
 
 /*-------------------------------------------------
@@ -873,7 +850,7 @@ void mos6526_device::cia_timer::update(int which, INT32 new_count)
 	/* update the timer count, if necessary */
 	if ((new_count == -1) && is_timer_active(m_timer))
 	{
-		UINT16 current_count = attotime_to_double(attotime_mul(timer_timeelapsed(m_timer), m_clock));
+		UINT16 current_count = (m_timer->elapsed() * m_clock).as_double();
 		m_count = m_count - MIN(m_count, current_count);
 	}
 
@@ -887,13 +864,13 @@ void mos6526_device::cia_timer::update(int which, INT32 new_count)
 	if ((m_mode & 0x01) && ((m_mode & (which ? 0x60 : 0x20)) == 0x00))
 	{
 		/* timer is on and is connected to clock */
-		attotime period = attotime_mul(ATTOTIME_IN_HZ(m_clock), (m_count ? m_count : 0x10000));
-		timer_adjust_oneshot(m_timer, period, which);
+		attotime period = attotime::from_hz(m_clock) * (m_count ? m_count : 0x10000);
+		m_timer->adjust(period, which);
 	}
 	else
 	{
 		/* timer is off or not connected to clock */
-		timer_adjust_oneshot(m_timer, attotime_never, which);
+		m_timer->adjust(attotime::never, which);
 	}
 }
 
@@ -908,7 +885,7 @@ UINT16 mos6526_device::cia_timer::get_count()
 
 	if (is_timer_active(m_timer))
 	{
-		UINT16 current_count = attotime_to_double(attotime_mul(timer_timeelapsed(m_timer), m_clock));
+		UINT16 current_count = (m_timer->elapsed() * m_clock).as_double();
 		count = m_count - MIN(m_count, current_count);
 	}
 	else
