@@ -17,8 +17,8 @@
 
 DECLARE_LEGACY_DEVICE(MSM6242, msm6242);
 
-#define MDRV_MSM6242_ADD(_tag) \
-	MDRV_DEVICE_ADD(_tag, MSM6242, 0)
+#define MCFG_MSM6242_ADD(_tag) \
+	MCFG_DEVICE_ADD(_tag, MSM6242, 0)
 
 
 READ8_DEVICE_HANDLER( msm6242_r );
