@@ -35,20 +35,24 @@ struct pic8259
 {
 	devcb_resolved_write_line out_int_func;
 
+	devcb_resolved_read_line sp_en_func;
+
+	devcb_resolved_read8 read_slave_ack_func;
+
 	emu_timer *timer;
 
 	pic8259_state_t state;
 
-	UINT8 irq_lines;
-	UINT8 esr;
 	UINT8 isr;
 	UINT8 irr;
 	UINT8 prio;
 	UINT8 imr;
+	UINT8 irq_lines;
 
 	UINT8 input;
 	UINT8 ocw3;
 
+	UINT8 master;
 	/* ICW1 state */
 	UINT32 level_trig_mode : 1;
 	UINT32 vector_size : 1;
@@ -103,25 +107,25 @@ static TIMER_CALLBACK( pic8259_timerproc )
 			if (LOG_GENERAL)
 				logerror("pic8259_timerproc(): PIC triggering IRQ #%d\n", irq);
 			if (!BIT(pic8259->ocw3, 2))
-				devcb_call_write_line(&pic8259->out_int_func, 1);
+				pic8259->out_int_func(1);
 			return;
 		}
 	}
 	if (!BIT(pic8259->ocw3, 2))
-		devcb_call_write_line(&pic8259->out_int_func, 0);
+		pic8259->out_int_func(0);
 }
 
 
 INLINE void pic8259_set_timer(pic8259_t *pic8259)
 {
-	timer_adjust_oneshot(pic8259->timer, attotime_zero, 0);
+	pic8259->timer->adjust(attotime::zero);
 }
 
 
 static void pic8259_set_irq_line(device_t *device, int irq, int state)
 {
 	pic8259_t	*pic8259 = get_safe_token(device);
-	UINT8		old_irq_lines = pic8259->irq_lines;
+	UINT8 mask = (1 << irq);
 
 	if (state)
 	{
@@ -129,11 +133,9 @@ static void pic8259_set_irq_line(device_t *device, int irq, int state)
 		if (LOG_GENERAL)
 			logerror("pic8259_set_irq_line(): PIC set IRQ line #%d\n", irq);
 
-		pic8259->irq_lines |= 1 << irq;
-
-		/* Set ESR bit if we see a 0 -> 1 transition */
-		if ( ! ( old_irq_lines & ( 1 << irq ) ) )
-			pic8259->esr |= ( 1 << irq );
+		if(pic8259->level_trig_mode || (!pic8259->level_trig_mode && !(pic8259->irq_lines & mask)))
+			pic8259->irr |= mask;
+		pic8259->irq_lines |= mask;
 	}
 	else
 	{
@@ -141,10 +143,10 @@ static void pic8259_set_irq_line(device_t *device, int irq, int state)
 		if (LOG_GENERAL)
 			logerror("pic8259_set_irq_line(): PIC cleared IRQ line #%d\n", irq);
 
-		pic8259->irq_lines &= ~(1 << irq);
+		pic8259->irq_lines &= ~mask;
+		pic8259->irr &= ~mask;
 	}
 
-	pic8259->irr = ( pic8259->level_trig_mode ) ? pic8259->esr & pic8259->irq_lines : pic8259->irq_lines;
 	pic8259_set_timer(pic8259);
 }
 
@@ -172,19 +174,25 @@ int pic8259_acknowledge(device_t *device)
 		{
 			if (LOG_GENERAL)
 				logerror("pic8259_acknowledge(): PIC acknowledge IRQ #%d\n", irq);
-			pic8259->irr &= ~mask;
-			pic8259->esr &= ~mask;
-			pic8259->irq_lines &= ~mask;
+			if (!pic8259->level_trig_mode)
+				pic8259->irr &= ~mask;
 
 			if (!pic8259->auto_eoi)
 				pic8259->isr |= mask;
+
 			pic8259_set_timer(pic8259);
-			if (pic8259->is_x86) {
-				/* For x86 mode*/
-				return irq + pic8259->base;
+
+			if ((pic8259->cascade!=0) && (pic8259->master!=0) && (mask & pic8259->slave)) {
+				// it's from slave device
+				return pic8259->read_slave_ack_func(irq);
 			} else {
-				/* in case of 8080/85) */
-				return 0xcd0000 + (pic8259->vector_addr_high << 8) + pic8259->vector_addr_low + (irq << (3-pic8259->vector_size));
+				if (pic8259->is_x86) {
+					/* For x86 mode*/
+					return irq + pic8259->base;
+				} else {
+					/* in case of 8080/85) */
+					return 0xcd0000 + (pic8259->vector_addr_high << 8) + pic8259->vector_addr_low + (irq << (3-pic8259->vector_size));
+				}
 			}
 		}
 	}
@@ -262,7 +270,6 @@ WRITE8_DEVICE_HANDLER( pic8259_w )
 					logerror("pic8259_w(): ICW1; data=0x%02X\n", data);
 
 				pic8259->imr				= 0x00;
-				pic8259->esr				= 0x00;
 				pic8259->isr				= 0x00;
 				pic8259->irr				= 0x00;
 				pic8259->level_trig_mode	= (data & 0x08) ? 1 : 0;
@@ -271,7 +278,6 @@ WRITE8_DEVICE_HANDLER( pic8259_w )
 				pic8259->icw4_needed		= (data & 0x01) ? 1 : 0;
 				pic8259->vector_addr_low	= (data & 0xe0);
 				pic8259->state			= STATE_ICW2;
-				pic8259->irq_lines          = 0x00;
 			}
 			else if (pic8259->state == STATE_READY)
 			{
@@ -303,6 +309,7 @@ WRITE8_DEVICE_HANDLER( pic8259_w )
 								if (pic8259->isr & mask)
 								{
 									pic8259->isr &= ~mask;
+									pic8259->irr &= ~mask;
 									break;
 								}
 							}
@@ -403,14 +410,16 @@ WRITE8_DEVICE_HANDLER( pic8259_w )
 static DEVICE_START( pic8259 )
 {
 	pic8259_t	*pic8259 = get_safe_token(device);
-	const struct pic8259_interface *intf = (const struct pic8259_interface *)device->baseconfig().static_config();
+	const struct pic8259_interface *intf = (const struct pic8259_interface *)device->static_config();
 
 	assert(intf != NULL);
 
-	pic8259->timer = timer_alloc( device->machine, pic8259_timerproc, (void *)device );
+	pic8259->timer = device->machine().scheduler().timer_alloc( FUNC(pic8259_timerproc), (void *)device );
 
 	/* resolve callbacks */
-	devcb_resolve_write_line(&pic8259->out_int_func, &intf->out_int_func, device);
+	pic8259->out_int_func.resolve(intf->out_int_func, *device);
+	pic8259->sp_en_func.resolve(intf->sp_en_func, *device);
+	pic8259->read_slave_ack_func.resolve(intf->read_slave_ack_func, *device);
 }
 
 
@@ -418,10 +427,9 @@ static DEVICE_RESET( pic8259 ) {
 	pic8259_t	*pic8259 = get_safe_token(device);
 
 	pic8259->state = STATE_READY;
-	pic8259->irq_lines = 0;
 	pic8259->isr = 0;
-	pic8259->esr = 0;
 	pic8259->irr = 0;
+	pic8259->irq_lines = 0;
 	pic8259->prio = 0;
 	pic8259->imr = 0;
 	pic8259->input = 0;
@@ -438,6 +446,8 @@ static DEVICE_RESET( pic8259 ) {
 	pic8259->is_x86 = 0;
 	pic8259->vector_addr_low = 0;
 	pic8259->vector_addr_high = 0;
+
+	pic8259->master = pic8259->sp_en_func();
 }
 
 
