@@ -113,6 +113,13 @@
 #include "voffff20.lh"
 #include "hoffff20.lh"
 
+// LCD screen layouts
+#include "lcd.lh"
+#include "lcd_rot.lh"
+
+// generic dummy pinball layout
+#include "pinball.lh"
+
 
 
 //**************************************************************************
@@ -193,16 +200,16 @@ static int get_variable_value(running_machine &machine, const char *string, char
 	char temp[100];
 
 	// screen 0 parameters
-	for (const screen_device_config *devconfig = machine.m_config.first_screen(); devconfig != NULL; devconfig = devconfig->next_screen())
+	for (const screen_device *device = machine.first_screen(); device != NULL; device = device->next_screen())
 	{
-		int scrnum = machine.m_config.m_devicelist.index(SCREEN, devconfig->tag());
+		int scrnum = machine.devicelist().indexof(SCREEN, device->tag());
 
 		// native X aspect factor
 		sprintf(temp, "~scr%dnativexaspect~", scrnum);
 		if (!strncmp(string, temp, strlen(temp)))
 		{
-			int num = devconfig->visible_area().max_x + 1 - devconfig->visible_area().min_x;
-			int den = devconfig->visible_area().max_y + 1 - devconfig->visible_area().min_y;
+			int num = device->visible_area().max_x + 1 - device->visible_area().min_x;
+			int den = device->visible_area().max_y + 1 - device->visible_area().min_y;
 			reduce_fraction(num, den);
 			*outputptr += sprintf(*outputptr, "%d", num);
 			return strlen(temp);
@@ -212,8 +219,8 @@ static int get_variable_value(running_machine &machine, const char *string, char
 		sprintf(temp, "~scr%dnativeyaspect~", scrnum);
 		if (!strncmp(string, temp, strlen(temp)))
 		{
-			int num = devconfig->visible_area().max_x + 1 - devconfig->visible_area().min_x;
-			int den = devconfig->visible_area().max_y + 1 - devconfig->visible_area().min_y;
+			int num = device->visible_area().max_x + 1 - device->visible_area().min_x;
+			int den = device->visible_area().max_y + 1 - device->visible_area().min_y;
 			reduce_fraction(num, den);
 			*outputptr += sprintf(*outputptr, "%d", den);
 			return strlen(temp);
@@ -223,7 +230,7 @@ static int get_variable_value(running_machine &machine, const char *string, char
 		sprintf(temp, "~scr%dwidth~", scrnum);
 		if (!strncmp(string, temp, strlen(temp)))
 		{
-			*outputptr += sprintf(*outputptr, "%d", devconfig->visible_area().max_x + 1 - devconfig->visible_area().min_x);
+			*outputptr += sprintf(*outputptr, "%d", device->visible_area().max_x + 1 - device->visible_area().min_x);
 			return strlen(temp);
 		}
 
@@ -231,7 +238,7 @@ static int get_variable_value(running_machine &machine, const char *string, char
 		sprintf(temp, "~scr%dheight~", scrnum);
 		if (!strncmp(string, temp, strlen(temp)))
 		{
-			*outputptr += sprintf(*outputptr, "%d", devconfig->visible_area().max_y + 1 - devconfig->visible_area().min_y);
+			*outputptr += sprintf(*outputptr, "%d", device->visible_area().max_y + 1 - device->visible_area().min_y);
 			return strlen(temp);
 		}
 	}
@@ -431,7 +438,7 @@ static void parse_orientation(running_machine &machine, xml_data_node *orientnod
 layout_element::layout_element(running_machine &machine, xml_data_node &elemnode, const char *dirname)
 	: m_next(NULL),
 	  m_machine(machine),
-	  m_complist(machine.m_respool),
+	  m_complist(machine.respool()),
 	  m_defstate(0),
 	  m_maxstate(0),
 	  m_elemtex(NULL)
@@ -451,7 +458,7 @@ layout_element::layout_element(running_machine &machine, xml_data_node &elemnode
 	for (xml_data_node *compnode = elemnode.child; compnode != NULL; compnode = compnode->next)
 	{
 		// allocate a new component
-		component &newcomp = m_complist.append(*auto_alloc(&machine, component(machine, *compnode, dirname)));
+		component &newcomp = m_complist.append(*auto_alloc(machine, component(machine, *compnode, dirname)));
 
 		// accumulate bounds
 		if (first)
@@ -491,7 +498,7 @@ layout_element::layout_element(running_machine &machine, xml_data_node &elemnode
 	}
 
 	// allocate an array of element textures for the states
-	m_elemtex = auto_alloc_array(&machine, texture, m_maxstate + 1);
+	m_elemtex = auto_alloc_array(machine, texture, m_maxstate + 1);
 }
 
 
@@ -502,7 +509,7 @@ layout_element::layout_element(running_machine &machine, xml_data_node &elemnode
 layout_element::~layout_element()
 {
 	// loop over all states and free their textures
-	auto_free(&m_machine, m_elemtex);
+	auto_free(machine(), m_elemtex);
 }
 
 
@@ -519,7 +526,7 @@ render_texture *layout_element::state_texture(int state)
 	{
 		m_elemtex[state].m_element = this;
 		m_elemtex[state].m_state = state;
-		m_elemtex[state].m_texture = m_machine.render().texture_alloc(element_scale, &m_elemtex[state]);
+		m_elemtex[state].m_texture = machine().render().texture_alloc(element_scale, &m_elemtex[state]);
 	}
 	return m_elemtex[state].m_texture;
 }
@@ -547,7 +554,7 @@ void layout_element::element_scale(bitmap_t &dest, const bitmap_t &source, const
 			bounds.max_y = render_round_nearest(curcomp->bounds().y1 * dest.height);
 
 			// based on the component type, add to the texture
-			curcomp->draw(elemtex->m_element->m_machine, dest, bounds, elemtex->m_state);
+			curcomp->draw(elemtex->m_element->machine(), dest, bounds, elemtex->m_state);
 		}
 }
 
@@ -575,7 +582,7 @@ layout_element::texture::texture()
 layout_element::texture::~texture()
 {
 	if (m_element != NULL)
-		m_element->m_machine.render().texture_free(m_texture);
+		m_element->machine().render().texture_free(m_texture);
 }
 
 
@@ -593,6 +600,7 @@ layout_element::component::component(running_machine &machine, xml_data_node &co
 	  m_type(CTYPE_INVALID),
 	  m_state(0),
 	  m_bitmap(NULL),
+	  m_file(NULL),
 	  m_hasalpha(false)
 {
 	// fetch common data
@@ -607,6 +615,7 @@ layout_element::component::component(running_machine &machine, xml_data_node &co
 		m_dirname = dirname;
 		m_imagefile = xml_get_attribute_string_with_subst(machine, compnode, "file", "");
 		m_alphafile = xml_get_attribute_string_with_subst(machine, compnode, "alphafile", "");
+		m_file = global_alloc(emu_file(machine.options().art_path(), OPEN_FLAG_READ));
 	}
 
 	// text nodes
@@ -660,6 +669,7 @@ layout_element::component::component(running_machine &machine, xml_data_node &co
 
 layout_element::component::~component()
 {
+	global_free(m_file);
 	global_free(m_bitmap);
 }
 
@@ -895,11 +905,12 @@ void layout_element::component::draw_text(running_machine &machine, bitmap_t &de
 bitmap_t *layout_element::component::load_bitmap()
 {
 	// load the basic bitmap
-	bitmap_t *bitmap = render_load_png(OPTION_ARTPATH, m_dirname, m_imagefile, NULL, &m_hasalpha);
+	assert(m_file != NULL);
+	bitmap_t *bitmap = render_load_png(*m_file, m_dirname, m_imagefile, NULL, &m_hasalpha);
 	if (bitmap != NULL && m_alphafile)
 
 		// load the alpha bitmap if specified
-		if (render_load_png(OPTION_ARTPATH, m_dirname, m_alphafile, bitmap, &m_hasalpha) == NULL)
+		if (render_load_png(*m_file, m_dirname, m_alphafile, bitmap, &m_hasalpha) == NULL)
 		{
 			global_free(bitmap);
 			bitmap = NULL;
@@ -1658,11 +1669,13 @@ layout_view::layout_view(running_machine &machine, xml_data_node &viewnode, simp
 	: m_next(NULL),
 	  m_aspect(1.0f),
 	  m_scraspect(1.0f),
-	  m_screens(machine.m_respool),
-	  m_backdrop_list(machine.m_respool),
-	  m_screen_list(machine.m_respool),
-	  m_overlay_list(machine.m_respool),
-	  m_bezel_list(machine.m_respool)
+	  m_screens(machine.respool()),
+	  m_backdrop_list(machine.respool()),
+	  m_screen_list(machine.respool()),
+	  m_overlay_list(machine.respool()),
+	  m_bezel_list(machine.respool()),
+	  m_cpanel_list(machine.respool()),
+	  m_marquee_list(machine.respool())
 {
 	// allocate a copy of the name
 	m_name = xml_get_attribute_string_with_subst(machine, viewnode, "name", "");
@@ -1675,19 +1688,27 @@ layout_view::layout_view(running_machine &machine, xml_data_node &viewnode, simp
 
 	// load backdrop items
 	for (xml_data_node *itemnode = xml_get_sibling(viewnode.child, "backdrop"); itemnode != NULL; itemnode = xml_get_sibling(itemnode->next, "backdrop"))
-		m_backdrop_list.append(*auto_alloc(&machine, item(machine, *itemnode, elemlist)));
+		m_backdrop_list.append(*auto_alloc(machine, item(machine, *itemnode, elemlist)));
 
 	// load screen items
 	for (xml_data_node *itemnode = xml_get_sibling(viewnode.child, "screen"); itemnode != NULL; itemnode = xml_get_sibling(itemnode->next, "screen"))
-		m_screen_list.append(*auto_alloc(&machine, item(machine, *itemnode, elemlist)));
+		m_screen_list.append(*auto_alloc(machine, item(machine, *itemnode, elemlist)));
 
 	// load overlay items
 	for (xml_data_node *itemnode = xml_get_sibling(viewnode.child, "overlay"); itemnode != NULL; itemnode = xml_get_sibling(itemnode->next, "overlay"))
-		m_overlay_list.append(*auto_alloc(&machine, item(machine, *itemnode, elemlist)));
+		m_overlay_list.append(*auto_alloc(machine, item(machine, *itemnode, elemlist)));
 
 	// load bezel items
 	for (xml_data_node *itemnode = xml_get_sibling(viewnode.child, "bezel"); itemnode != NULL; itemnode = xml_get_sibling(itemnode->next, "bezel"))
-		m_bezel_list.append(*auto_alloc(&machine, item(machine, *itemnode, elemlist)));
+		m_bezel_list.append(*auto_alloc(machine, item(machine, *itemnode, elemlist)));
+
+	// load cpanel items
+	for (xml_data_node *itemnode = xml_get_sibling(viewnode.child, "cpanel"); itemnode != NULL; itemnode = xml_get_sibling(itemnode->next, "cpanel"))
+		m_cpanel_list.append(*auto_alloc(machine, item(machine, *itemnode, elemlist)));
+
+	// load marquee items
+	for (xml_data_node *itemnode = xml_get_sibling(viewnode.child, "marquee"); itemnode != NULL; itemnode = xml_get_sibling(itemnode->next, "marquee"))
+		m_marquee_list.append(*auto_alloc(machine, item(machine, *itemnode, elemlist)));
 
 	// recompute the data for the view based on a default layer config
 	recompute(render_layer_config());
@@ -1716,6 +1737,8 @@ layout_view::item *layout_view::first_item(item_layer layer) const
 		case ITEM_LAYER_SCREEN:		return m_screen_list.first();
 		case ITEM_LAYER_OVERLAY:	return m_overlay_list.first();
 		case ITEM_LAYER_BEZEL:		return m_bezel_list.first();
+		case ITEM_LAYER_CPANEL:		return m_cpanel_list.first();
+		case ITEM_LAYER_MARQUEE:	return m_marquee_list.first();
 		default:					return NULL;
 	}
 }
@@ -1744,6 +1767,8 @@ void layout_view::recompute(render_layer_config layerconfig)
 			case ITEM_LAYER_BACKDROP:	m_layenabled[layer] = layerconfig.backdrops_enabled();	break;
 			case ITEM_LAYER_OVERLAY:	m_layenabled[layer] = layerconfig.overlays_enabled();	break;
 			case ITEM_LAYER_BEZEL:		m_layenabled[layer] = layerconfig.bezels_enabled();		break;
+			case ITEM_LAYER_CPANEL:		m_layenabled[layer] = layerconfig.cpanels_enabled();	break;
+			case ITEM_LAYER_MARQUEE:	m_layenabled[layer] = layerconfig.marquees_enabled();	break;
 			default:					m_layenabled[layer] = true;								break;
 		}
 
@@ -1857,7 +1882,7 @@ layout_view::item::item(running_machine &machine, xml_data_node &itemnode, simpl
 	// fetch common data
 	int index = xml_get_attribute_int_with_subst(machine, itemnode, "index", -1);
 	if (index != -1)
-		m_screen = downcast<screen_device *>(machine.m_devicelist.find(SCREEN, index));
+		m_screen = downcast<screen_device *>(machine.devicelist().find(SCREEN, index));
 	m_input_mask = xml_get_attribute_int_with_subst(machine, itemnode, "inputmask", 0);
 	if (m_output_name[0] != 0 && m_element != NULL)
 		output_set_value(m_output_name, m_element->default_state());
@@ -1907,7 +1932,7 @@ int layout_view::item::state() const
 	{
 		const input_field_config *field = input_field_by_tag_and_mask(m_element->machine().m_portlist, m_input_tag, m_input_mask);
 		if (field != NULL)
-			state = ((input_port_read_safe(&m_element->machine(), m_input_tag, 0) ^ field->defvalue) & m_input_mask) ? 1 : 0;
+			state = ((input_port_read_safe(m_element->machine(), m_input_tag, 0) ^ field->defvalue) & m_input_mask) ? 1 : 0;
 	}
 	return state;
 }
@@ -1924,8 +1949,8 @@ int layout_view::item::state() const
 
 layout_file::layout_file(running_machine &machine, xml_data_node &rootnode, const char *dirname)
 	: m_next(NULL),
-	  m_elemlist(machine.m_respool),
-	  m_viewlist(machine.m_respool)
+	  m_elemlist(machine.respool()),
+	  m_viewlist(machine.respool())
 {
 	// find the layout node
 	xml_data_node *mamelayoutnode = xml_get_sibling(rootnode.child, "mamelayout");
@@ -1939,11 +1964,11 @@ layout_file::layout_file(running_machine &machine, xml_data_node &rootnode, cons
 
 	// parse all the elements
 	for (xml_data_node *elemnode = xml_get_sibling(mamelayoutnode->child, "element"); elemnode != NULL; elemnode = xml_get_sibling(elemnode->next, "element"))
-		m_elemlist.append(*auto_alloc(&machine, layout_element(machine, *elemnode, dirname)));
+		m_elemlist.append(*auto_alloc(machine, layout_element(machine, *elemnode, dirname)));
 
 	// parse all the views
 	for (xml_data_node *viewnode = xml_get_sibling(mamelayoutnode->child, "view"); viewnode != NULL; viewnode = xml_get_sibling(viewnode->next, "view"))
-		m_viewlist.append(*auto_alloc(&machine, layout_view(machine, *viewnode, m_elemlist)));
+		m_viewlist.append(*auto_alloc(machine, layout_view(machine, *viewnode, m_elemlist)));
 }
 
 
