@@ -32,7 +32,6 @@
 */
 
 #include "emu.h"
-#include "streams.h"
 #include "sp0256.h"
 
 #define CLOCK_DIVIDER (7*6*8)
@@ -56,7 +55,7 @@
 	if( sp->sby_line != line_state )           \
 	{                                          \
 		sp->sby_line = line_state;             \
-		devcb_call_write_line(&sp->sby, sp->sby_line);	\
+		sp->sby(sp->sby_line);	\
 	}                                          \
 }
 
@@ -774,7 +773,7 @@ static void sp0256_micro(sp0256_state *sp)
             sp->ald      = 0;
             for (i = 0; i < 16; i++)
                 sp->filt.r[i] = 0;
-            devcb_call_write_line(&sp->drq, 1);
+            sp->drq(1);
         }
 
         /* ---------------------------------------------------------------- */
@@ -1178,16 +1177,16 @@ static STREAM_UPDATE( sp0256_update )
 
 static DEVICE_START( sp0256 )
 {
-	const sp0256_interface *intf = (const sp0256_interface *)device->baseconfig().static_config();
+	const sp0256_interface *intf = (const sp0256_interface *)device->static_config();
 	sp0256_state *sp = get_safe_token(device);
 
 	sp->device = device;
-	devcb_resolve_write_line(&sp->drq, &intf->lrq_callback, device);
-	devcb_resolve_write_line(&sp->sby, &intf->sby_callback, device);
-	devcb_call_write_line(&sp->drq, 1);
-	devcb_call_write_line(&sp->sby, 1);
+	sp->drq.resolve(intf->lrq_callback, *device);
+	sp->sby.resolve(intf->sby_callback, *device);
+	sp->drq(1);
+	sp->sby(1);
 
-	sp->stream = stream_create(device, 0, 1, device->clock() / CLOCK_DIVIDER, sp, sp0256_update);
+	sp->stream = device->machine().sound().stream_alloc(*device, 0, 1, device->clock() / CLOCK_DIVIDER, sp, sp0256_update);
 
     /* -------------------------------------------------------------------- */
     /*  Configure our internal variables.                                   */
@@ -1197,7 +1196,7 @@ static DEVICE_START( sp0256 )
     /* -------------------------------------------------------------------- */
     /*  Allocate a scratch buffer for generating ~10kHz samples.             */
     /* -------------------------------------------------------------------- */
-    sp->scratch = auto_alloc_array(device->machine, INT16, SCBUF_SIZE);
+    sp->scratch = auto_alloc_array(device->machine(), INT16, SCBUF_SIZE);
     sp->sc_head = sp->sc_tail = 0;
 
     /* -------------------------------------------------------------------- */
@@ -1235,7 +1234,7 @@ static void sp0256_reset(sp0256_state *sp)
 	sp->mode     = 0;
 	sp->page     = 0x1000 << 3;
 	sp->silent   = 1;
-	devcb_call_write_line(&sp->drq, 1);
+	sp->drq(1);
 	SET_SBY(1)
 }
 
@@ -1264,12 +1263,19 @@ WRITE8_DEVICE_HANDLER( sp0256_ALD_w )
 	/* ---------------------------------------------------------------- */
 	sp->lrq = 0;
 	sp->ald = (0xFF & data) << 4;
-	devcb_call_write_line(&sp->drq, 0);
+	sp->drq(0);
 	SET_SBY(0)
 
 	return;
 }
 
+READ_LINE_DEVICE_HANDLER( sp0256_sby_r )
+{
+	sp0256_state *sp = get_safe_token(device);
+
+	return sp->sby_line;
+}
+
 READ16_DEVICE_HANDLER( spb640_r )
 {
 	sp0256_state *sp = get_safe_token(device);
