@@ -47,7 +47,7 @@ RST not only resets the chip on its rising edge but grabs a byte of mode state d
     9bit DAC is composed of 5bit Physical and 3bitPWM.
 
   todo:
-    Noise Generator circuit without 'machine->rand()' function.
+    Noise Generator circuit without 'machine.rand()' function.
 
 ----------- command format (Analytical result) ----------
 
@@ -108,7 +108,6 @@ chirp 12-..: vokume   0   : silent
 
 */
 #include "emu.h"
-#include "streams.h"
 #include "vlm5030.h"
 
 /* interpolator per frame   */
@@ -411,7 +410,7 @@ static STREAM_UPDATE( vlm5030_update_callback )
 			}
 			else if (chip->old_pitch <= 1)
 			{	/* generate unvoiced samples here */
-				current_val = (chip->device->machine->rand()&1) ? chip->current_energy : -chip->current_energy;
+				current_val = (chip->device->machine().rand()&1) ? chip->current_energy : -chip->current_energy;
 			}
 			else
 			{
@@ -488,7 +487,7 @@ phase_stop:
 /* realtime update */
 static void vlm5030_update(vlm5030_state *chip)
 {
-	stream_update(chip->channel);
+	chip->channel->update();
 }
 
 /* setup parameteroption when RST=H */
@@ -518,9 +517,8 @@ static void vlm5030_setup_parameter(vlm5030_state *chip, UINT8 param)
 }
 
 
-static STATE_POSTLOAD( vlm5030_restore_state )
+static void vlm5030_restore_state(vlm5030_state *chip)
 {
-	vlm5030_state *chip = (vlm5030_state *)param;
 	int i;
 
 	int interp_effect = FR_SIZE - (chip->interp_count%FR_SIZE);
@@ -686,7 +684,7 @@ static DEVICE_START( vlm5030 )
 	vlm5030_state *chip = get_safe_token(device);
 
 	chip->device = device;
-	chip->intf = (device->baseconfig().static_config() != NULL) ? (const vlm5030_interface *)device->baseconfig().static_config() : &defintrf;
+	chip->intf = (device->static_config() != NULL) ? (const vlm5030_interface *)device->static_config() : &defintrf;
 
 	emulation_rate = device->clock() / 440;
 
@@ -704,30 +702,30 @@ static DEVICE_START( vlm5030 )
 	else
 		chip->address_mask = chip->intf->memory_size-1;
 
-	chip->channel = stream_create(device, 0, 1, emulation_rate,chip,vlm5030_update_callback);
+	chip->channel = device->machine().sound().stream_alloc(*device, 0, 1, emulation_rate,chip,vlm5030_update_callback);
 
 	/* don't restore "UINT8 *chip->rom" when use vlm5030_set_rom() */
 
-	state_save_register_device_item(device,0,chip->address);
-	state_save_register_device_item(device,0,chip->pin_BSY);
-	state_save_register_device_item(device,0,chip->pin_ST);
-	state_save_register_device_item(device,0,chip->pin_VCU);
-	state_save_register_device_item(device,0,chip->pin_RST);
-	state_save_register_device_item(device,0,chip->latch_data);
-	state_save_register_device_item(device,0,chip->vcu_addr_h);
-	state_save_register_device_item(device,0,chip->parameter);
-	state_save_register_device_item(device,0,chip->phase);
-	state_save_register_device_item(device,0,chip->interp_count);
-	state_save_register_device_item(device,0,chip->sample_count);
-	state_save_register_device_item(device,0,chip->pitch_count);
-	state_save_register_device_item(device,0,chip->old_energy);
-	state_save_register_device_item(device,0,chip->old_pitch);
-	state_save_register_device_item_array(device,0,chip->old_k);
-	state_save_register_device_item(device,0,chip->target_energy);
-	state_save_register_device_item(device,0,chip->target_pitch);
-	state_save_register_device_item_array(device,0,chip->target_k);
-	state_save_register_device_item_array(device,0,chip->x);
-	state_save_register_postload(device->machine, vlm5030_restore_state, chip);
+	device->save_item(NAME(chip->address));
+	device->save_item(NAME(chip->pin_BSY));
+	device->save_item(NAME(chip->pin_ST));
+	device->save_item(NAME(chip->pin_VCU));
+	device->save_item(NAME(chip->pin_RST));
+	device->save_item(NAME(chip->latch_data));
+	device->save_item(NAME(chip->vcu_addr_h));
+	device->save_item(NAME(chip->parameter));
+	device->save_item(NAME(chip->phase));
+	device->save_item(NAME(chip->interp_count));
+	device->save_item(NAME(chip->sample_count));
+	device->save_item(NAME(chip->pitch_count));
+	device->save_item(NAME(chip->old_energy));
+	device->save_item(NAME(chip->old_pitch));
+	device->save_item(NAME(chip->old_k));
+	device->save_item(NAME(chip->target_energy));
+	device->save_item(NAME(chip->target_pitch));
+	device->save_item(NAME(chip->target_k));
+	device->save_item(NAME(chip->x));
+	device->machine().save().register_postload(save_prepost_delegate(FUNC(vlm5030_restore_state), chip));
 }
 
 
