@@ -13,7 +13,6 @@
 */
 
 #include "emu.h"
-#include "streams.h"
 #include "ymf271.h"
 
 #define VERBOSE		(1)
@@ -525,7 +524,7 @@ static void update_pcm(YMF271Chip *chip, int slotnum, INT32 *mixp, int length)
 	int i;
 	int final_volume;
 	INT16 sample;
-	INT64 ch0_vol, ch1_vol, ch2_vol, ch3_vol;
+	INT64 ch0_vol, ch1_vol; //, ch2_vol, ch3_vol;
 	const UINT8 *rombase;
 
 	YMF271Slot *slot = &chip->slots[slotnum];
@@ -562,8 +561,8 @@ static void update_pcm(YMF271Chip *chip, int slotnum, INT32 *mixp, int length)
 
 		ch0_vol = ((UINT64)final_volume * (UINT64)channel_attenuation[slot->ch0_level]) >> 16;
 		ch1_vol = ((UINT64)final_volume * (UINT64)channel_attenuation[slot->ch1_level]) >> 16;
-		ch2_vol = ((UINT64)final_volume * (UINT64)channel_attenuation[slot->ch2_level]) >> 16;
-		ch3_vol = ((UINT64)final_volume * (UINT64)channel_attenuation[slot->ch3_level]) >> 16;
+//      ch2_vol = ((UINT64)final_volume * (UINT64)channel_attenuation[slot->ch2_level]) >> 16;
+//      ch3_vol = ((UINT64)final_volume * (UINT64)channel_attenuation[slot->ch3_level]) >> 16;
 
 		if (ch0_vol > 65536) ch0_vol = 65536;
 		if (ch1_vol > 65536) ch1_vol = 65536;
@@ -1403,9 +1402,9 @@ static TIMER_CALLBACK( ymf271_timer_b_tick )
 
 static UINT8 ymf271_read_ext_memory(YMF271Chip *chip, UINT32 address)
 {
-	if( chip->ext_mem_read.read )
+	if( !chip->ext_mem_read.isnull() )
 	{
-		return devcb_call_read8(&chip->ext_mem_read, address);
+		return chip->ext_mem_read(address);
 	}
 	else
 	{
@@ -1417,7 +1416,7 @@ static UINT8 ymf271_read_ext_memory(YMF271Chip *chip, UINT32 address)
 
 static void ymf271_write_ext_memory(YMF271Chip *chip, UINT32 address, UINT8 data)
 {
-	devcb_call_write8(&chip->ext_mem_write, address, data);
+	chip->ext_mem_write(address, data);
 }
 
 static void ymf271_write_timer(YMF271Chip *chip, int data)
@@ -1485,9 +1484,9 @@ static void ymf271_write_timer(YMF271Chip *chip, int data)
 					if (chip->irq_callback) chip->irq_callback(chip->device, 0);
 
 					//period = (double)(256.0 - chip->timerAVal ) * ( 384.0 * 4.0 / (double)CLOCK);
-					period = attotime_mul(ATTOTIME_IN_HZ(chip->clock), 384 * (1024 - chip->timerAVal));
+					period = attotime::from_hz(chip->clock) * (384 * (1024 - chip->timerAVal));
 
-					timer_adjust_periodic(chip->timA, period, 0, period);
+					chip->timA->adjust(period, 0, period);
 				}
 				if (data & 0x20)
 				{	// timer B reset
@@ -1496,9 +1495,9 @@ static void ymf271_write_timer(YMF271Chip *chip, int data)
 
 					if (chip->irq_callback) chip->irq_callback(chip->device, 0);
 
-					period = attotime_mul(ATTOTIME_IN_HZ(chip->clock), 384 * 16 * (256 - chip->timerBVal));
+					period = attotime::from_hz(chip->clock) * (384 * 16 * (256 - chip->timerBVal));
 
-					timer_adjust_periodic(chip->timB, period, 0, period);
+					chip->timB->adjust(period, 0, period);
 				}
 
 				break;
@@ -1590,7 +1589,7 @@ READ8_DEVICE_HANDLER( ymf271_r )
 	return 0;
 }
 
-static void init_tables(running_machine *machine)
+static void init_tables(running_machine &machine)
 {
 	int i,j;
 
@@ -1682,87 +1681,87 @@ static void init_state(YMF271Chip *chip, device_t *device)
 
 	for (i = 0; i < ARRAY_LENGTH(chip->slots); i++)
 	{
-		state_save_register_device_item(device, i, chip->slots[i].extout);
-		state_save_register_device_item(device, i, chip->slots[i].lfoFreq);
-		state_save_register_device_item(device, i, chip->slots[i].pms);
-		state_save_register_device_item(device, i, chip->slots[i].ams);
-		state_save_register_device_item(device, i, chip->slots[i].detune);
-		state_save_register_device_item(device, i, chip->slots[i].multiple);
-		state_save_register_device_item(device, i, chip->slots[i].tl);
-		state_save_register_device_item(device, i, chip->slots[i].keyscale);
-		state_save_register_device_item(device, i, chip->slots[i].ar);
-		state_save_register_device_item(device, i, chip->slots[i].decay1rate);
-		state_save_register_device_item(device, i, chip->slots[i].decay2rate);
-		state_save_register_device_item(device, i, chip->slots[i].decay1lvl);
-		state_save_register_device_item(device, i, chip->slots[i].relrate);
-		state_save_register_device_item(device, i, chip->slots[i].fns);
-		state_save_register_device_item(device, i, chip->slots[i].block);
-		state_save_register_device_item(device, i, chip->slots[i].feedback);
-		state_save_register_device_item(device, i, chip->slots[i].waveform);
-		state_save_register_device_item(device, i, chip->slots[i].accon);
-		state_save_register_device_item(device, i, chip->slots[i].algorithm);
-		state_save_register_device_item(device, i, chip->slots[i].ch0_level);
-		state_save_register_device_item(device, i, chip->slots[i].ch1_level);
-		state_save_register_device_item(device, i, chip->slots[i].ch2_level);
-		state_save_register_device_item(device, i, chip->slots[i].ch3_level);
-		state_save_register_device_item(device, i, chip->slots[i].startaddr);
-		state_save_register_device_item(device, i, chip->slots[i].loopaddr);
-		state_save_register_device_item(device, i, chip->slots[i].endaddr);
-		state_save_register_device_item(device, i, chip->slots[i].fs);
-		state_save_register_device_item(device, i, chip->slots[i].srcnote);
-		state_save_register_device_item(device, i, chip->slots[i].srcb);
-		state_save_register_device_item(device, i, chip->slots[i].step);
-		state_save_register_device_item(device, i, chip->slots[i].stepptr);
-		state_save_register_device_item(device, i, chip->slots[i].active);
-		state_save_register_device_item(device, i, chip->slots[i].bits);
-		state_save_register_device_item(device, i, chip->slots[i].volume);
-		state_save_register_device_item(device, i, chip->slots[i].env_state);
-		state_save_register_device_item(device, i, chip->slots[i].env_attack_step);
-		state_save_register_device_item(device, i, chip->slots[i].env_decay1_step);
-		state_save_register_device_item(device, i, chip->slots[i].env_decay2_step);
-		state_save_register_device_item(device, i, chip->slots[i].env_release_step);
-		state_save_register_device_item(device, i, chip->slots[i].feedback_modulation0);
-		state_save_register_device_item(device, i, chip->slots[i].feedback_modulation1);
-		state_save_register_device_item(device, i, chip->slots[i].lfo_phase);
-		state_save_register_device_item(device, i, chip->slots[i].lfo_step);
-		state_save_register_device_item(device, i, chip->slots[i].lfo_amplitude);
+		device->save_item(NAME(chip->slots[i].extout), i);
+		device->save_item(NAME(chip->slots[i].lfoFreq), i);
+		device->save_item(NAME(chip->slots[i].pms), i);
+		device->save_item(NAME(chip->slots[i].ams), i);
+		device->save_item(NAME(chip->slots[i].detune), i);
+		device->save_item(NAME(chip->slots[i].multiple), i);
+		device->save_item(NAME(chip->slots[i].tl), i);
+		device->save_item(NAME(chip->slots[i].keyscale), i);
+		device->save_item(NAME(chip->slots[i].ar), i);
+		device->save_item(NAME(chip->slots[i].decay1rate), i);
+		device->save_item(NAME(chip->slots[i].decay2rate), i);
+		device->save_item(NAME(chip->slots[i].decay1lvl), i);
+		device->save_item(NAME(chip->slots[i].relrate), i);
+		device->save_item(NAME(chip->slots[i].fns), i);
+		device->save_item(NAME(chip->slots[i].block), i);
+		device->save_item(NAME(chip->slots[i].feedback), i);
+		device->save_item(NAME(chip->slots[i].waveform), i);
+		device->save_item(NAME(chip->slots[i].accon), i);
+		device->save_item(NAME(chip->slots[i].algorithm), i);
+		device->save_item(NAME(chip->slots[i].ch0_level), i);
+		device->save_item(NAME(chip->slots[i].ch1_level), i);
+		device->save_item(NAME(chip->slots[i].ch2_level), i);
+		device->save_item(NAME(chip->slots[i].ch3_level), i);
+		device->save_item(NAME(chip->slots[i].startaddr), i);
+		device->save_item(NAME(chip->slots[i].loopaddr), i);
+		device->save_item(NAME(chip->slots[i].endaddr), i);
+		device->save_item(NAME(chip->slots[i].fs), i);
+		device->save_item(NAME(chip->slots[i].srcnote), i);
+		device->save_item(NAME(chip->slots[i].srcb), i);
+		device->save_item(NAME(chip->slots[i].step), i);
+		device->save_item(NAME(chip->slots[i].stepptr), i);
+		device->save_item(NAME(chip->slots[i].active), i);
+		device->save_item(NAME(chip->slots[i].bits), i);
+		device->save_item(NAME(chip->slots[i].volume), i);
+		device->save_item(NAME(chip->slots[i].env_state), i);
+		device->save_item(NAME(chip->slots[i].env_attack_step), i);
+		device->save_item(NAME(chip->slots[i].env_decay1_step), i);
+		device->save_item(NAME(chip->slots[i].env_decay2_step), i);
+		device->save_item(NAME(chip->slots[i].env_release_step), i);
+		device->save_item(NAME(chip->slots[i].feedback_modulation0), i);
+		device->save_item(NAME(chip->slots[i].feedback_modulation1), i);
+		device->save_item(NAME(chip->slots[i].lfo_phase), i);
+		device->save_item(NAME(chip->slots[i].lfo_step), i);
+		device->save_item(NAME(chip->slots[i].lfo_amplitude), i);
 	}
 
 	for (i = 0; i < sizeof(chip->groups) / sizeof(chip->groups[0]); i++)
 	{
-		state_save_register_device_item(device, i, chip->groups[i].sync);
-		state_save_register_device_item(device, i, chip->groups[i].pfm);
+		device->save_item(NAME(chip->groups[i].sync), i);
+		device->save_item(NAME(chip->groups[i].pfm), i);
 	}
 
-	state_save_register_device_item(device, 0, chip->timerA);
-	state_save_register_device_item(device, 0, chip->timerB);
-	state_save_register_device_item(device, 0, chip->timerAVal);
-	state_save_register_device_item(device, 0, chip->timerBVal);
-	state_save_register_device_item(device, 0, chip->irqstate);
-	state_save_register_device_item(device, 0, chip->status);
-	state_save_register_device_item(device, 0, chip->enable);
-	state_save_register_device_item(device, 0, chip->reg0);
-	state_save_register_device_item(device, 0, chip->reg1);
-	state_save_register_device_item(device, 0, chip->reg2);
-	state_save_register_device_item(device, 0, chip->reg3);
-	state_save_register_device_item(device, 0, chip->pcmreg);
-	state_save_register_device_item(device, 0, chip->timerreg);
-	state_save_register_device_item(device, 0, chip->ext_address);
-	state_save_register_device_item(device, 0, chip->ext_read);
+	device->save_item(NAME(chip->timerA));
+	device->save_item(NAME(chip->timerB));
+	device->save_item(NAME(chip->timerAVal));
+	device->save_item(NAME(chip->timerBVal));
+	device->save_item(NAME(chip->irqstate));
+	device->save_item(NAME(chip->status));
+	device->save_item(NAME(chip->enable));
+	device->save_item(NAME(chip->reg0));
+	device->save_item(NAME(chip->reg1));
+	device->save_item(NAME(chip->reg2));
+	device->save_item(NAME(chip->reg3));
+	device->save_item(NAME(chip->pcmreg));
+	device->save_item(NAME(chip->timerreg));
+	device->save_item(NAME(chip->ext_address));
+	device->save_item(NAME(chip->ext_read));
 }
 
 static void ymf271_init(device_t *device, YMF271Chip *chip, UINT8 *rom, void (*cb)(device_t *,int), const devcb_read8 *ext_read, const devcb_write8 *ext_write)
 {
-	chip->timA = timer_alloc(device->machine, ymf271_timer_a_tick, chip);
-	chip->timB = timer_alloc(device->machine, ymf271_timer_b_tick, chip);
+	chip->timA = device->machine().scheduler().timer_alloc(FUNC(ymf271_timer_a_tick), chip);
+	chip->timB = device->machine().scheduler().timer_alloc(FUNC(ymf271_timer_b_tick), chip);
 
 	chip->rom = rom;
 	chip->irq_callback = cb;
 
-	devcb_resolve_read8(&chip->ext_mem_read, ext_read, device);
-	devcb_resolve_write8(&chip->ext_mem_write, ext_write, device);
+	chip->ext_mem_read.resolve(*ext_read, *device);
+	chip->ext_mem_write.resolve(*ext_write, *device);
 
-	init_tables(device->machine);
+	init_tables(device->machine());
 	init_state(chip, device);
 }
 
@@ -1776,10 +1775,10 @@ static DEVICE_START( ymf271 )
 	chip->device = device;
 	chip->clock = device->clock();
 
-	intf = (device->baseconfig().static_config() != NULL) ? (const ymf271_interface *)device->baseconfig().static_config() : &defintrf;
+	intf = (device->static_config() != NULL) ? (const ymf271_interface *)device->static_config() : &defintrf;
 
 	ymf271_init(device, chip, *device->region(), intf->irq_callback, &intf->ext_read, &intf->ext_write);
-	chip->stream = stream_create(device, 0, 2, device->clock()/384, chip, ymf271_update);
+	chip->stream = device->machine().sound().stream_alloc(*device, 0, 2, device->clock()/384, chip, ymf271_update);
 
 	for (i = 0; i < 256; i++)
 	{
