@@ -22,7 +22,6 @@
 
 
 #include "emu.h"
-#include "streams.h"
 #include "ymz280b.h"
 
 
@@ -117,16 +116,16 @@ static TIMER_CALLBACK( update_irq_state_timer_5 );
 static TIMER_CALLBACK( update_irq_state_timer_6 );
 static TIMER_CALLBACK( update_irq_state_timer_7 );
 
-static const timer_fired_func update_irq_state_cb[] =
+static const struct { timer_expired_func func; const char *name; } update_irq_state_cb[] =
 {
-	update_irq_state_timer_0,
-	update_irq_state_timer_1,
-	update_irq_state_timer_2,
-	update_irq_state_timer_3,
-	update_irq_state_timer_4,
-	update_irq_state_timer_5,
-	update_irq_state_timer_6,
-	update_irq_state_timer_7
+	{ FUNC(update_irq_state_timer_0) },
+	{ FUNC(update_irq_state_timer_1) },
+	{ FUNC(update_irq_state_timer_2) },
+	{ FUNC(update_irq_state_timer_3) },
+	{ FUNC(update_irq_state_timer_4) },
+	{ FUNC(update_irq_state_timer_5) },
+	{ FUNC(update_irq_state_timer_6) },
+	{ FUNC(update_irq_state_timer_7) }
 };
 
 
@@ -197,16 +196,15 @@ INLINE void update_volumes(struct YMZ280BVoice *voice)
 }
 
 
-static STATE_POSTLOAD( YMZ280B_state_save_update_step )
+static void YMZ280B_state_save_update_step(ymz280b_state *chip)
 {
-	ymz280b_state *chip = (ymz280b_state *)param;
 	int j;
 	for (j = 0; j < 8; j++)
 	{
 		struct YMZ280BVoice *voice = &chip->voice[j];
 		update_step(chip, voice);
 		if(voice->irq_schedule)
-			timer_set(machine, attotime_zero, chip, 0, update_irq_state_cb[j]);
+			chip->device->machine().scheduler().timer_set(attotime::zero, update_irq_state_cb[j].func, update_irq_state_cb[j].name, 0, chip);
 	}
 }
 
@@ -582,7 +580,7 @@ static STREAM_UPDATE( ymz280b_update )
 				voice->playing = 0;
 
 				/* set update_irq_state_timer. IRQ is signaled on next CPU execution. */
-				timer_set(chip->device->machine, attotime_zero, chip, 0, update_irq_state_cb[v]);
+				chip->device->machine().scheduler().timer_set(attotime::zero, update_irq_state_cb[v].func, update_irq_state_cb[v].name, 0, chip);
 				voice->irq_schedule = 1;
 			}
 		}
@@ -636,12 +634,12 @@ static STREAM_UPDATE( ymz280b_update )
 static DEVICE_START( ymz280b )
 {
 	static const ymz280b_interface defintrf = { 0 };
-	const ymz280b_interface *intf = (device->baseconfig().static_config() != NULL) ? (const ymz280b_interface *)device->baseconfig().static_config() : &defintrf;
+	const ymz280b_interface *intf = (device->static_config() != NULL) ? (const ymz280b_interface *)device->static_config() : &defintrf;
 	ymz280b_state *chip = get_safe_token(device);
 
 	chip->device = device;
-	devcb_resolve_read8(&chip->ext_ram_read, &intf->ext_read, device);
-	devcb_resolve_write8(&chip->ext_ram_write, &intf->ext_write, device);
+	chip->ext_ram_read.resolve(intf->ext_read, *device);
+	chip->ext_ram_write.resolve(intf->ext_write, *device);
 
 	/* compute ADPCM tables */
 	compute_tables();
@@ -652,50 +650,50 @@ static DEVICE_START( ymz280b )
 	chip->irq_callback = intf->irq_callback;
 
 	/* create the stream */
-	chip->stream = stream_create(device, 0, 2, INTERNAL_SAMPLE_RATE, chip, ymz280b_update);
+	chip->stream = device->machine().sound().stream_alloc(*device, 0, 2, INTERNAL_SAMPLE_RATE, chip, ymz280b_update);
 
 	/* allocate memory */
-	chip->scratch = auto_alloc_array(device->machine, INT16, MAX_SAMPLE_CHUNK);
+	chip->scratch = auto_alloc_array(device->machine(), INT16, MAX_SAMPLE_CHUNK);
 
 	/* state save */
 	{
 		int j;
-		state_save_register_device_item(device, 0, chip->current_register);
-		state_save_register_device_item(device, 0, chip->status_register);
-		state_save_register_device_item(device, 0, chip->irq_state);
-		state_save_register_device_item(device, 0, chip->irq_mask);
-		state_save_register_device_item(device, 0, chip->irq_enable);
-		state_save_register_device_item(device, 0, chip->keyon_enable);
-		state_save_register_device_item(device, 0, chip->rom_readback_addr);
+		device->save_item(NAME(chip->current_register));
+		device->save_item(NAME(chip->status_register));
+		device->save_item(NAME(chip->irq_state));
+		device->save_item(NAME(chip->irq_mask));
+		device->save_item(NAME(chip->irq_enable));
+		device->save_item(NAME(chip->keyon_enable));
+		device->save_item(NAME(chip->rom_readback_addr));
 		for (j = 0; j < 8; j++)
 		{
-			state_save_register_device_item(device, j, chip->voice[j].playing);
-			state_save_register_device_item(device, j, chip->voice[j].keyon);
-			state_save_register_device_item(device, j, chip->voice[j].looping);
-			state_save_register_device_item(device, j, chip->voice[j].mode);
-			state_save_register_device_item(device, j, chip->voice[j].fnum);
-			state_save_register_device_item(device, j, chip->voice[j].level);
-			state_save_register_device_item(device, j, chip->voice[j].pan);
-			state_save_register_device_item(device, j, chip->voice[j].start);
-			state_save_register_device_item(device, j, chip->voice[j].stop);
-			state_save_register_device_item(device, j, chip->voice[j].loop_start);
-			state_save_register_device_item(device, j, chip->voice[j].loop_end);
-			state_save_register_device_item(device, j, chip->voice[j].position);
-			state_save_register_device_item(device, j, chip->voice[j].signal);
-			state_save_register_device_item(device, j, chip->voice[j].step);
-			state_save_register_device_item(device, j, chip->voice[j].loop_signal);
-			state_save_register_device_item(device, j, chip->voice[j].loop_step);
-			state_save_register_device_item(device, j, chip->voice[j].loop_count);
-			state_save_register_device_item(device, j, chip->voice[j].output_left);
-			state_save_register_device_item(device, j, chip->voice[j].output_right);
-			state_save_register_device_item(device, j, chip->voice[j].output_pos);
-			state_save_register_device_item(device, j, chip->voice[j].last_sample);
-			state_save_register_device_item(device, j, chip->voice[j].curr_sample);
-			state_save_register_device_item(device, j, chip->voice[j].irq_schedule);
+			device->save_item(NAME(chip->voice[j].playing), j);
+			device->save_item(NAME(chip->voice[j].keyon), j);
+			device->save_item(NAME(chip->voice[j].looping), j);
+			device->save_item(NAME(chip->voice[j].mode), j);
+			device->save_item(NAME(chip->voice[j].fnum), j);
+			device->save_item(NAME(chip->voice[j].level), j);
+			device->save_item(NAME(chip->voice[j].pan), j);
+			device->save_item(NAME(chip->voice[j].start), j);
+			device->save_item(NAME(chip->voice[j].stop), j);
+			device->save_item(NAME(chip->voice[j].loop_start), j);
+			device->save_item(NAME(chip->voice[j].loop_end), j);
+			device->save_item(NAME(chip->voice[j].position), j);
+			device->save_item(NAME(chip->voice[j].signal), j);
+			device->save_item(NAME(chip->voice[j].step), j);
+			device->save_item(NAME(chip->voice[j].loop_signal), j);
+			device->save_item(NAME(chip->voice[j].loop_step), j);
+			device->save_item(NAME(chip->voice[j].loop_count), j);
+			device->save_item(NAME(chip->voice[j].output_left), j);
+			device->save_item(NAME(chip->voice[j].output_right), j);
+			device->save_item(NAME(chip->voice[j].output_pos), j);
+			device->save_item(NAME(chip->voice[j].last_sample), j);
+			device->save_item(NAME(chip->voice[j].curr_sample), j);
+			device->save_item(NAME(chip->voice[j].irq_schedule), j);
 		}
 	}
 
-	state_save_register_postload(device->machine, YMZ280B_state_save_update_step, chip);
+	device->machine().save().register_postload(save_prepost_delegate(FUNC(YMZ280B_state_save_update_step), chip));
 
 #if MAKE_WAVS
 	chip->wavresample = wav_open("resamp.wav", INTERNAL_SAMPLE_RATE, 2);
@@ -716,7 +714,7 @@ static void write_to_register(ymz280b_state *chip, int data)
 	int i;
 
 	/* force an update */
-	stream_update(chip->stream);
+	chip->stream->update();
 
 	/* lower registers follow a pattern */
 	if (chip->current_register < 0x80)
@@ -841,8 +839,8 @@ static void write_to_register(ymz280b_state *chip, int data)
 				break;
 
 			case 0x87:		/* RAM write */
-				if (chip->ext_ram_write.write)
-					devcb_call_write8(&chip->ext_ram_write, chip->rom_readback_addr, data);
+				if (!chip->ext_ram_write.isnull())
+					chip->ext_ram_write(chip->rom_readback_addr, data);
 				else
 					logerror("YMZ280B attempted RAM write to %X\n", chip->rom_readback_addr);
 				break;
@@ -903,7 +901,7 @@ static int compute_status(ymz280b_state *chip)
 	}
 
 	/* force an update */
-	stream_update(chip->stream);
+	chip->stream->update();
 
 	result = chip->status_register;
 
@@ -927,7 +925,7 @@ READ8_DEVICE_HANDLER( ymz280b_r )
 	ymz280b_state *chip = get_safe_token(device);
 
 	if ((offset & 1) == 0)
-		return devcb_call_read8(&chip->ext_ram_read, chip->rom_readback_addr++ - 1);
+		return chip->ext_ram_read(chip->rom_readback_addr++ - 1);
 	else
 		return compute_status(chip);
 }
