@@ -118,9 +118,9 @@ const gfx_layout gfx_16x16x4_planar =
     palette RAM referenced by offset
 -------------------------------------------------*/
 
-INLINE UINT16 paletteram16_le(running_machine *machine, offs_t offset)
+INLINE UINT16 paletteram16_le(running_machine &machine, offs_t offset)
 {
-	return machine->generic.paletteram.u8[offset & ~1] | (machine->generic.paletteram.u8[offset | 1] << 8);
+	return machine.generic.paletteram.u8[offset & ~1] | (machine.generic.paletteram.u8[offset | 1] << 8);
 }
 
 
@@ -130,9 +130,9 @@ INLINE UINT16 paletteram16_le(running_machine *machine, offs_t offset)
     palette RAM referenced by offset
 -------------------------------------------------*/
 
-INLINE UINT16 paletteram16_be(running_machine *machine, offs_t offset)
+INLINE UINT16 paletteram16_be(running_machine &machine, offs_t offset)
 {
-	return machine->generic.paletteram.u8[offset | 1] | (machine->generic.paletteram.u8[offset & ~1] << 8);
+	return machine.generic.paletteram.u8[offset | 1] | (machine.generic.paletteram.u8[offset & ~1] << 8);
 }
 
 
@@ -142,9 +142,9 @@ INLINE UINT16 paletteram16_be(running_machine *machine, offs_t offset)
     RAM referenced by offset
 -------------------------------------------------*/
 
-INLINE UINT16 paletteram16_split(running_machine *machine, offs_t offset)
+INLINE UINT16 paletteram16_split(running_machine &machine, offs_t offset)
 {
-	return machine->generic.paletteram.u8[offset] | (machine->generic.paletteram2.u8[offset] << 8);
+	return machine.generic.paletteram.u8[offset] | (machine.generic.paletteram2.u8[offset] << 8);
 }
 
 
@@ -154,9 +154,9 @@ INLINE UINT16 paletteram16_split(running_machine *machine, offs_t offset)
     palette RAM referenced by offset
 -------------------------------------------------*/
 
-INLINE UINT32 paletteram32_be(running_machine *machine, offs_t offset)
+INLINE UINT32 paletteram32_be(running_machine &machine, offs_t offset)
 {
-	return machine->generic.paletteram.u16[offset | 1] | (machine->generic.paletteram.u16[offset & ~1] << 16);
+	return machine.generic.paletteram.u16[offset | 1] | (machine.generic.paletteram.u16[offset & ~1] << 16);
 }
 
 
@@ -166,7 +166,7 @@ INLINE UINT32 paletteram32_be(running_machine *machine, offs_t offset)
     shift values
 -------------------------------------------------*/
 
-INLINE void set_color_444(running_machine *machine, pen_t color, int rshift, int gshift, int bshift, UINT16 data)
+INLINE void set_color_444(running_machine &machine, pen_t color, int rshift, int gshift, int bshift, UINT16 data)
 {
 	palette_set_color_rgb(machine, color, pal4bit(data >> rshift), pal4bit(data >> gshift), pal4bit(data >> bshift));
 }
@@ -178,7 +178,7 @@ INLINE void set_color_444(running_machine *machine, pen_t color, int rshift, int
     shift values
 -------------------------------------------------*/
 
-INLINE void set_color_4444(running_machine *machine, pen_t color, int ishift, int rshift, int gshift, int bshift, UINT16 data)
+INLINE void set_color_4444(running_machine &machine, pen_t color, int ishift, int rshift, int gshift, int bshift, UINT16 data)
 {
 	static const UINT8 ztable[16] =
 		{ 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0x10, 0x11 };
@@ -199,7 +199,7 @@ INLINE void set_color_4444(running_machine *machine, pen_t color, int ishift, in
     shift values
 -------------------------------------------------*/
 
-INLINE void set_color_555(running_machine *machine, pen_t color, int rshift, int gshift, int bshift, UINT16 data)
+INLINE void set_color_555(running_machine &machine, pen_t color, int rshift, int gshift, int bshift, UINT16 data)
 {
 	palette_set_color_rgb(machine, color, pal5bit(data >> rshift), pal5bit(data >> gshift), pal5bit(data >> bshift));
 }
@@ -211,7 +211,7 @@ INLINE void set_color_555(running_machine *machine, pen_t color, int rshift, int
     shift values
 -------------------------------------------------*/
 
-INLINE void set_color_888(running_machine *machine, pen_t color, int rshift, int gshift, int bshift, UINT32 data)
+INLINE void set_color_888(running_machine &machine, pen_t color, int rshift, int gshift, int bshift, UINT32 data)
 {
 	palette_set_color_rgb(machine, color, (data >> rshift) & 0xff, (data >> gshift) & 0xff, (data >> bshift) & 0xff);
 }
@@ -227,34 +227,34 @@ INLINE void set_color_888(running_machine *machine, pen_t color, int rshift, int
     register for save states
 -------------------------------------------------*/
 
-void generic_video_init(running_machine *machine)
+void generic_video_init(running_machine &machine)
 {
 	generic_video_private *state;
 
-	state = machine->generic_video_data = auto_alloc_clear(machine, generic_video_private);
+	state = machine.generic_video_data = auto_alloc_clear(machine, generic_video_private);
 
-	state_save_register_item(machine, "video", NULL, 0, state->flip_screen_x);
-	state_save_register_item(machine, "video", NULL, 0, state->flip_screen_y);
+	machine.save().save_item(NAME(state->flip_screen_x));
+	machine.save().save_item(NAME(state->flip_screen_y));
 
 	// create spriteram buffers if necessary
-	if (machine->config->m_video_attributes & VIDEO_BUFFERS_SPRITERAM)
+	if (machine.config().m_video_attributes & VIDEO_BUFFERS_SPRITERAM)
 	{
-		assert_always(machine->generic.spriteram_size != 0, "Video buffers spriteram but spriteram size is 0");
+		assert_always(machine.generic.spriteram_size != 0, "Video buffers spriteram but spriteram size is 0");
 
 		// allocate memory for the back buffer
-		machine->generic.buffered_spriteram.u8 = auto_alloc_array(machine, UINT8, machine->generic.spriteram_size);
+		machine.generic.buffered_spriteram.u8 = auto_alloc_array(machine, UINT8, machine.generic.spriteram_size);
 
 		// register for saving it
-		state_save_register_global_pointer(machine, machine->generic.buffered_spriteram.u8, machine->generic.spriteram_size);
+		state_save_register_global_pointer(machine, machine.generic.buffered_spriteram.u8, machine.generic.spriteram_size);
 
 		// do the same for the second back buffer, if present
-		if (machine->generic.spriteram2_size)
+		if (machine.generic.spriteram2_size)
 		{
 			// allocate memory
-			machine->generic.buffered_spriteram2.u8 = auto_alloc_array(machine, UINT8, machine->generic.spriteram2_size);
+			machine.generic.buffered_spriteram2.u8 = auto_alloc_array(machine, UINT8, machine.generic.spriteram2_size);
 
 			// register for saving it
-			state_save_register_global_pointer(machine, machine->generic.buffered_spriteram2.u8, machine->generic.spriteram2_size);
+			state_save_register_global_pointer(machine, machine.generic.buffered_spriteram2.u8, machine.generic.spriteram2_size);
 		}
 	}
 }
@@ -273,21 +273,21 @@ void generic_video_init(running_machine *machine)
 VIDEO_START( generic_bitmapped )
 {
 	/* allocate the temporary bitmap */
-	machine->generic.tmpbitmap = machine->primary_screen->alloc_compatible_bitmap();
+	machine.generic.tmpbitmap = machine.primary_screen->alloc_compatible_bitmap();
 
 	/* ensure the contents of the bitmap are saved */
-	state_save_register_global_bitmap(machine, machine->generic.tmpbitmap);
+	machine.save().save_item(NAME(*machine.generic.tmpbitmap));
 }
 
 
 /*-------------------------------------------------
-    VIDEO_UPDATE( generic_bitmapped ) - blast the
+    SCREEN_UPDATE( generic_bitmapped ) - blast the
     generic bitmap to the screen
 -------------------------------------------------*/
 
-VIDEO_UPDATE( generic_bitmapped )
+SCREEN_UPDATE( generic_bitmapped )
 {
-	copybitmap(bitmap, screen->machine->generic.tmpbitmap, 0, 0, 0, 0, cliprect);
+	copybitmap(bitmap, screen->machine().generic.tmpbitmap, 0, 0, 0, 0, cliprect);
 	return 0;
 }
 
@@ -348,17 +348,17 @@ more control is needed over what is buffered.
 
 WRITE8_HANDLER( buffer_spriteram_w )
 {
-	memcpy(space->machine->generic.buffered_spriteram.u8, space->machine->generic.spriteram.u8, space->machine->generic.spriteram_size);
+	memcpy(space->machine().generic.buffered_spriteram.u8, space->machine().generic.spriteram.u8, space->machine().generic.spriteram_size);
 }
 
 WRITE16_HANDLER( buffer_spriteram16_w )
 {
-	memcpy(space->machine->generic.buffered_spriteram.u16, space->machine->generic.spriteram.u16, space->machine->generic.spriteram_size);
+	memcpy(space->machine().generic.buffered_spriteram.u16, space->machine().generic.spriteram.u16, space->machine().generic.spriteram_size);
 }
 
 WRITE32_HANDLER( buffer_spriteram32_w )
 {
-	memcpy(space->machine->generic.buffered_spriteram.u32, space->machine->generic.spriteram.u32, space->machine->generic.spriteram_size);
+	memcpy(space->machine().generic.buffered_spriteram.u32, space->machine().generic.spriteram.u32, space->machine().generic.spriteram_size);
 }
 
 
@@ -369,17 +369,17 @@ WRITE32_HANDLER( buffer_spriteram32_w )
 
 WRITE8_HANDLER( buffer_spriteram_2_w )
 {
-	memcpy(space->machine->generic.buffered_spriteram2.u8, space->machine->generic.spriteram2.u8, space->machine->generic.spriteram2_size);
+	memcpy(space->machine().generic.buffered_spriteram2.u8, space->machine().generic.spriteram2.u8, space->machine().generic.spriteram2_size);
 }
 
 WRITE16_HANDLER( buffer_spriteram16_2_w )
 {
-	memcpy(space->machine->generic.buffered_spriteram2.u16, space->machine->generic.spriteram2.u16, space->machine->generic.spriteram2_size);
+	memcpy(space->machine().generic.buffered_spriteram2.u16, space->machine().generic.spriteram2.u16, space->machine().generic.spriteram2_size);
 }
 
 WRITE32_HANDLER( buffer_spriteram32_2_w )
 {
-	memcpy(space->machine->generic.buffered_spriteram2.u32, space->machine->generic.spriteram2.u32, space->machine->generic.spriteram2_size);
+	memcpy(space->machine().generic.buffered_spriteram2.u32, space->machine().generic.spriteram2.u32, space->machine().generic.spriteram2_size);
 }
 
 
@@ -388,14 +388,14 @@ WRITE32_HANDLER( buffer_spriteram32_2_w )
     spriteram
 -------------------------------------------------*/
 
-void buffer_spriteram(running_machine *machine, UINT8 *ptr, int length)
+void buffer_spriteram(running_machine &machine, UINT8 *ptr, int length)
 {
-	memcpy(machine->generic.buffered_spriteram.u8, ptr, length);
+	memcpy(machine.generic.buffered_spriteram.u8, ptr, length);
 }
 
-void buffer_spriteram_2(running_machine *machine, UINT8 *ptr, int length)
+void buffer_spriteram_2(running_machine &machine, UINT8 *ptr, int length)
 {
-	memcpy(machine->generic.buffered_spriteram2.u8, ptr, length);
+	memcpy(machine.generic.buffered_spriteram2.u8, ptr, length);
 }
 
 
@@ -408,13 +408,13 @@ void buffer_spriteram_2(running_machine *machine, UINT8 *ptr, int length)
     updateflip - handle global flipping
 -------------------------------------------------*/
 
-static void updateflip(running_machine *machine)
+static void updateflip(running_machine &machine)
 {
-	generic_video_private *state = machine->generic_video_data;
-	int width = machine->primary_screen->width();
-	int height = machine->primary_screen->height();
-	attoseconds_t period = machine->primary_screen->frame_period().attoseconds;
-	rectangle visarea = machine->primary_screen->visible_area();
+	generic_video_private *state = machine.generic_video_data;
+	int width = machine.primary_screen->width();
+	int height = machine.primary_screen->height();
+	attoseconds_t period = machine.primary_screen->frame_period().attoseconds;
+	rectangle visarea = machine.primary_screen->visible_area();
 
 	tilemap_set_flip_all(machine,(TILEMAP_FLIPX & state->flip_screen_x) | (TILEMAP_FLIPY & state->flip_screen_y));
 
@@ -435,7 +435,7 @@ static void updateflip(running_machine *machine)
 		visarea.max_y = temp;
 	}
 
-	machine->primary_screen->configure(width, height, visarea, period);
+	machine.primary_screen->configure(width, height, visarea, period);
 }
 
 
@@ -443,10 +443,16 @@ static void updateflip(running_machine *machine)
     flip_screen_set - set global flip
 -------------------------------------------------*/
 
-void flip_screen_set(running_machine *machine, int on)
+void flip_screen_set(running_machine &machine, int on)
 {
-	flip_screen_x_set(machine, on);
-	flip_screen_y_set(machine, on);
+	generic_video_private *state = machine.generic_video_data;
+	if (on) on = ~0;
+	if (state->flip_screen_x != on || state->flip_screen_y != on)
+	{
+		if (!on) updateflip(machine); // flip visarea back
+		state->flip_screen_x = state->flip_screen_y = on;
+		updateflip(machine);
+	}
 }
 
 
@@ -455,14 +461,15 @@ void flip_screen_set(running_machine *machine, int on)
        do not call update_flip.
 -------------------------------------------------*/
 
-void flip_screen_set_no_update(running_machine *machine, int on)
+void flip_screen_set_no_update(running_machine &machine, int on)
 {
 	/* flip_screen_y is not updated on purpose
      * this function is for drivers which
      * where writing to flip_screen_x to
      * bypass update_flip
      */
-	generic_video_private *state = machine->generic_video_data;
+	generic_video_private *state = machine.generic_video_data;
+	if (on) on = ~0;
 	state->flip_screen_x = on;
 }
 
@@ -471,9 +478,9 @@ void flip_screen_set_no_update(running_machine *machine, int on)
     flip_screen_x_set - set global horizontal flip
 -------------------------------------------------*/
 
-void flip_screen_x_set(running_machine *machine, int on)
+void flip_screen_x_set(running_machine &machine, int on)
 {
-	generic_video_private *state = machine->generic_video_data;
+	generic_video_private *state = machine.generic_video_data;
 	if (on) on = ~0;
 	if (state->flip_screen_x != on)
 	{
@@ -487,9 +494,9 @@ void flip_screen_x_set(running_machine *machine, int on)
     flip_screen_y_set - set global vertical flip
 -------------------------------------------------*/
 
-void flip_screen_y_set(running_machine *machine, int on)
+void flip_screen_y_set(running_machine &machine, int on)
 {
-	generic_video_private *state = machine->generic_video_data;
+	generic_video_private *state = machine.generic_video_data;
 	if (on) on = ~0;
 	if (state->flip_screen_y != on)
 	{
@@ -503,9 +510,9 @@ void flip_screen_y_set(running_machine *machine, int on)
     flip_screen_get - get global flip
 -------------------------------------------------*/
 
-int flip_screen_get(running_machine *machine)
+int flip_screen_get(running_machine &machine)
 {
-	generic_video_private *state = machine->generic_video_data;
+	generic_video_private *state = machine.generic_video_data;
 	return state->flip_screen_x;
 }
 
@@ -514,9 +521,9 @@ int flip_screen_get(running_machine *machine)
     flip_screen_x_get - get global x flip
 -------------------------------------------------*/
 
-int flip_screen_x_get(running_machine *machine)
+int flip_screen_x_get(running_machine &machine)
 {
-	generic_video_private *state = machine->generic_video_data;
+	generic_video_private *state = machine.generic_video_data;
 	return state->flip_screen_x;
 }
 
@@ -525,9 +532,9 @@ int flip_screen_x_get(running_machine *machine)
     flip_screen_get - get global y flip
 -------------------------------------------------*/
 
-int flip_screen_y_get(running_machine *machine)
+int flip_screen_y_get(running_machine &machine)
 {
-	generic_video_private *state = machine->generic_video_data;
+	generic_video_private *state = machine.generic_video_data;
 	return state->flip_screen_y;
 }
 
@@ -545,7 +552,7 @@ PALETTE_INIT( all_black )
 {
 	int i;
 
-	for (i = 0; i < machine->total_colors(); i++)
+	for (i = 0; i < machine.total_colors(); i++)
 	{
 		palette_set_color(machine,i,RGB_BLACK); /* black */
 	}
@@ -599,7 +606,7 @@ PALETTE_INIT( RRRR_GGGG_BBBB )
 {
 	int i;
 
-	for (i = 0; i < machine->total_colors(); i++)
+	for (i = 0; i < machine.total_colors(); i++)
 	{
 		int bit0,bit1,bit2,bit3,r,g,b;
 
@@ -611,17 +618,17 @@ PALETTE_INIT( RRRR_GGGG_BBBB )
 		r = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 
 		/* green component */
-		bit0 = (color_prom[i + machine->total_colors()] >> 0) & 0x01;
-		bit1 = (color_prom[i + machine->total_colors()] >> 1) & 0x01;
-		bit2 = (color_prom[i + machine->total_colors()] >> 2) & 0x01;
-		bit3 = (color_prom[i + machine->total_colors()] >> 3) & 0x01;
+		bit0 = (color_prom[i + machine.total_colors()] >> 0) & 0x01;
+		bit1 = (color_prom[i + machine.total_colors()] >> 1) & 0x01;
+		bit2 = (color_prom[i + machine.total_colors()] >> 2) & 0x01;
+		bit3 = (color_prom[i + machine.total_colors()] >> 3) & 0x01;
 		g = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 
 		/* blue component */
-		bit0 = (color_prom[i + 2*machine->total_colors()] >> 0) & 0x01;
-		bit1 = (color_prom[i + 2*machine->total_colors()] >> 1) & 0x01;
-		bit2 = (color_prom[i + 2*machine->total_colors()] >> 2) & 0x01;
-		bit3 = (color_prom[i + 2*machine->total_colors()] >> 3) & 0x01;
+		bit0 = (color_prom[i + 2*machine.total_colors()] >> 0) & 0x01;
+		bit1 = (color_prom[i + 2*machine.total_colors()] >> 1) & 0x01;
+		bit2 = (color_prom[i + 2*machine.total_colors()] >> 2) & 0x01;
+		bit3 = (color_prom[i + 2*machine.total_colors()] >> 3) & 0x01;
 		b = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 
 		palette_set_color(machine,i,MAKE_RGB(r,g,b));
@@ -681,8 +688,8 @@ PALETTE_INIT( RRRRR_GGGGGG_BBBBB )
 
 WRITE8_HANDLER( paletteram_RRRGGGBB_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	palette_set_color_rgb(space->machine, offset, pal3bit(data >> 5), pal3bit(data >> 2), pal2bit(data >> 0));
+	space->machine().generic.paletteram.u8[offset] = data;
+	palette_set_color_rgb(space->machine(), offset, pal3bit(data >> 5), pal3bit(data >> 2), pal2bit(data >> 0));
 }
 
 
@@ -692,8 +699,8 @@ WRITE8_HANDLER( paletteram_RRRGGGBB_w )
 
 WRITE8_HANDLER( paletteram_BBGGGRRR_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	palette_set_color_rgb(space->machine, offset, pal3bit(data >> 0), pal3bit(data >> 3), pal2bit(data >> 6));
+	space->machine().generic.paletteram.u8[offset] = data;
+	palette_set_color_rgb(space->machine(), offset, pal3bit(data >> 0), pal3bit(data >> 3), pal2bit(data >> 6));
 }
 
 
@@ -705,8 +712,8 @@ WRITE8_HANDLER( paletteram_BBGGRRII_w )
 {
 	int i = (data >> 0) & 3;
 
-	space->machine->generic.paletteram.u8[offset] = data;
-	palette_set_color_rgb(space->machine, offset, pal4bit(((data >> 0) & 0x0c) | i),
+	space->machine().generic.paletteram.u8[offset] = data;
+	palette_set_color_rgb(space->machine(), offset, pal4bit(((data >> 0) & 0x0c) | i),
 	                                   pal4bit(((data >> 2) & 0x0c) | i),
 	                                   pal4bit(((data >> 4) & 0x0c) | i));
 }
@@ -719,8 +726,8 @@ WRITE8_HANDLER( paletteram_IIBBGGRR_w )
 {
 	int i = (data >> 6) & 3;
 
-	space->machine->generic.paletteram.u8[offset] = data;
-	palette_set_color_rgb(space->machine, offset, pal4bit(((data << 2) & 0x0c) | i),
+	space->machine().generic.paletteram.u8[offset] = data;
+	palette_set_color_rgb(space->machine(), offset, pal4bit(((data << 2) & 0x0c) | i),
 	                                   pal4bit(((data >> 0) & 0x0c) | i),
 	                                   pal4bit(((data >> 2) & 0x0c) | i));
 }
@@ -737,32 +744,32 @@ WRITE8_HANDLER( paletteram_IIBBGGRR_w )
 
 WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_le_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_444(space->machine, offset / 2, 0, 4, 8, paletteram16_le(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_444(space->machine(), offset / 2, 0, 4, 8, paletteram16_le(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_be_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_444(space->machine, offset / 2, 0, 4, 8, paletteram16_be(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_444(space->machine(), offset / 2, 0, 4, 8, paletteram16_be(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_split1_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_444(space->machine, offset, 0, 4, 8, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_444(space->machine(), offset, 0, 4, 8, paletteram16_split(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_split2_w )
 {
-	space->machine->generic.paletteram2.u8[offset] = data;
-	set_color_444(space->machine, offset, 0, 4, 8, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram2.u8[offset] = data;
+	set_color_444(space->machine(), offset, 0, 4, 8, paletteram16_split(space->machine(), offset));
 }
 
 WRITE16_HANDLER( paletteram16_xxxxBBBBGGGGRRRR_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_444(space->machine, offset, 0, 4, 8, space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_444(space->machine(), offset, 0, 4, 8, space->machine().generic.paletteram.u16[offset]);
 }
 
 
@@ -772,32 +779,32 @@ WRITE16_HANDLER( paletteram16_xxxxBBBBGGGGRRRR_word_w )
 
 WRITE8_HANDLER( paletteram_xxxxBBBBRRRRGGGG_le_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_444(space->machine, offset / 2, 4, 0, 8, paletteram16_le(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_444(space->machine(), offset / 2, 4, 0, 8, paletteram16_le(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxBBBBRRRRGGGG_be_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_444(space->machine, offset / 2, 4, 0, 8, paletteram16_be(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_444(space->machine(), offset / 2, 4, 0, 8, paletteram16_be(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxBBBBRRRRGGGG_split1_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_444(space->machine, offset, 4, 0, 8, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_444(space->machine(), offset, 4, 0, 8, paletteram16_split(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxBBBBRRRRGGGG_split2_w )
 {
-	space->machine->generic.paletteram2.u8[offset] = data;
-	set_color_444(space->machine, offset, 4, 0, 8, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram2.u8[offset] = data;
+	set_color_444(space->machine(), offset, 4, 0, 8, paletteram16_split(space->machine(), offset));
 }
 
 WRITE16_HANDLER( paletteram16_xxxxBBBBRRRRGGGG_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_444(space->machine, offset, 4, 0, 8, space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_444(space->machine(), offset, 4, 0, 8, space->machine().generic.paletteram.u16[offset]);
 }
 
 
@@ -807,14 +814,14 @@ WRITE16_HANDLER( paletteram16_xxxxBBBBRRRRGGGG_word_w )
 
 WRITE8_HANDLER( paletteram_xxxxRRRRBBBBGGGG_split1_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_444(space->machine, offset, 8, 0, 4, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_444(space->machine(), offset, 8, 0, 4, paletteram16_split(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxRRRRBBBBGGGG_split2_w )
 {
-	space->machine->generic.paletteram2.u8[offset] = data;
-	set_color_444(space->machine, offset, 8, 0, 4, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram2.u8[offset] = data;
+	set_color_444(space->machine(), offset, 8, 0, 4, paletteram16_split(space->machine(), offset));
 }
 
 
@@ -824,32 +831,32 @@ WRITE8_HANDLER( paletteram_xxxxRRRRBBBBGGGG_split2_w )
 
 WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_le_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_444(space->machine, offset / 2, 8, 4, 0, paletteram16_le(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_444(space->machine(), offset / 2, 8, 4, 0, paletteram16_le(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_be_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_444(space->machine, offset / 2, 8, 4, 0, paletteram16_be(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_444(space->machine(), offset / 2, 8, 4, 0, paletteram16_be(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_split1_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_444(space->machine, offset, 8, 4, 0, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_444(space->machine(), offset, 8, 4, 0, paletteram16_split(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_split2_w )
 {
-	space->machine->generic.paletteram2.u8[offset] = data;
-	set_color_444(space->machine, offset, 8, 4, 0, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram2.u8[offset] = data;
+	set_color_444(space->machine(), offset, 8, 4, 0, paletteram16_split(space->machine(), offset));
 }
 
 WRITE16_HANDLER( paletteram16_xxxxRRRRGGGGBBBB_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_444(space->machine, offset, 8, 4, 0, space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_444(space->machine(), offset, 8, 4, 0, space->machine().generic.paletteram.u16[offset]);
 }
 
 
@@ -859,26 +866,26 @@ WRITE16_HANDLER( paletteram16_xxxxRRRRGGGGBBBB_word_w )
 
 WRITE8_HANDLER( paletteram_RRRRGGGGBBBBxxxx_be_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_444(space->machine, offset / 2, 12, 8, 4, paletteram16_be(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_444(space->machine(), offset / 2, 12, 8, 4, paletteram16_be(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_RRRRGGGGBBBBxxxx_split1_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_444(space->machine, offset, 12, 8, 4, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_444(space->machine(), offset, 12, 8, 4, paletteram16_split(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_RRRRGGGGBBBBxxxx_split2_w )
 {
-	space->machine->generic.paletteram2.u8[offset] = data;
-	set_color_444(space->machine, offset, 12, 8, 4, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram2.u8[offset] = data;
+	set_color_444(space->machine(), offset, 12, 8, 4, paletteram16_split(space->machine(), offset));
 }
 
 WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBxxxx_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_444(space->machine, offset, 12, 8, 4, space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_444(space->machine(), offset, 12, 8, 4, space->machine().generic.paletteram.u16[offset]);
 }
 
 
@@ -893,32 +900,32 @@ WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBxxxx_word_w )
 
 WRITE8_HANDLER( paletteram_xBBBBBGGGGGRRRRR_le_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_555(space->machine, offset / 2, 0, 5, 10, paletteram16_le(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_555(space->machine(), offset / 2, 0, 5, 10, paletteram16_le(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xBBBBBGGGGGRRRRR_be_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_555(space->machine, offset / 2, 0, 5, 10, paletteram16_be(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_555(space->machine(), offset / 2, 0, 5, 10, paletteram16_be(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xBBBBBGGGGGRRRRR_split1_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_555(space->machine, offset, 0, 5, 10, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_555(space->machine(), offset, 0, 5, 10, paletteram16_split(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xBBBBBGGGGGRRRRR_split2_w )
 {
-	space->machine->generic.paletteram2.u8[offset] = data;
-	set_color_555(space->machine, offset, 0, 5, 10, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram2.u8[offset] = data;
+	set_color_555(space->machine(), offset, 0, 5, 10, paletteram16_split(space->machine(), offset));
 }
 
 WRITE16_HANDLER( paletteram16_xBBBBBGGGGGRRRRR_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_555(space->machine, offset, 0, 5, 10, space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_555(space->machine(), offset, 0, 5, 10, space->machine().generic.paletteram.u16[offset]);
 }
 
 
@@ -928,14 +935,14 @@ WRITE16_HANDLER( paletteram16_xBBBBBGGGGGRRRRR_word_w )
 
 WRITE8_HANDLER( paletteram_xBBBBBRRRRRGGGGG_split1_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_555(space->machine, offset, 5, 0, 10, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_555(space->machine(), offset, 5, 0, 10, paletteram16_split(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xBBBBBRRRRRGGGGG_split2_w )
 {
-	space->machine->generic.paletteram2.u8[offset] = data;
-	set_color_555(space->machine, offset, 5, 0, 10, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram2.u8[offset] = data;
+	set_color_555(space->machine(), offset, 5, 0, 10, paletteram16_split(space->machine(), offset));
 }
 
 
@@ -945,32 +952,32 @@ WRITE8_HANDLER( paletteram_xBBBBBRRRRRGGGGG_split2_w )
 
 WRITE8_HANDLER( paletteram_xRRRRRGGGGGBBBBB_le_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_555(space->machine, offset / 2, 10, 5, 0, paletteram16_le(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_555(space->machine(), offset / 2, 10, 5, 0, paletteram16_le(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xRRRRRGGGGGBBBBB_be_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_555(space->machine, offset / 2, 10, 5, 0, paletteram16_be(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_555(space->machine(), offset / 2, 10, 5, 0, paletteram16_be(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xRRRRRGGGGGBBBBB_split1_w )
 {
-	space->machine->generic.paletteram.u8[offset] = data;
-	set_color_555(space->machine, offset, 10, 5, 0, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram.u8[offset] = data;
+	set_color_555(space->machine(), offset, 10, 5, 0, paletteram16_split(space->machine(), offset));
 }
 
 WRITE8_HANDLER( paletteram_xRRRRRGGGGGBBBBB_split2_w )
 {
-	space->machine->generic.paletteram2.u8[offset] = data;
-	set_color_555(space->machine, offset, 10, 5, 0, paletteram16_split(space->machine, offset));
+	space->machine().generic.paletteram2.u8[offset] = data;
+	set_color_555(space->machine(), offset, 10, 5, 0, paletteram16_split(space->machine(), offset));
 }
 
 WRITE16_HANDLER( paletteram16_xRRRRRGGGGGBBBBB_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_555(space->machine, offset, 10, 5, 0, space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_555(space->machine(), offset, 10, 5, 0, space->machine().generic.paletteram.u16[offset]);
 }
 
 
@@ -980,8 +987,8 @@ WRITE16_HANDLER( paletteram16_xRRRRRGGGGGBBBBB_word_w )
 
 WRITE16_HANDLER( paletteram16_xGGGGGRRRRRBBBBB_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_555(space->machine, offset, 5, 10, 0, space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_555(space->machine(), offset, 5, 10, 0, space->machine().generic.paletteram.u16[offset]);
 }
 
 
@@ -991,8 +998,8 @@ WRITE16_HANDLER( paletteram16_xGGGGGRRRRRBBBBB_word_w )
 
 WRITE16_HANDLER( paletteram16_xGGGGGBBBBBRRRRR_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_555(space->machine, offset, 0, 10, 5, space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_555(space->machine(), offset, 0, 10, 5, space->machine().generic.paletteram.u16[offset]);
 }
 
 
@@ -1002,8 +1009,8 @@ WRITE16_HANDLER( paletteram16_xGGGGGBBBBBRRRRR_word_w )
 
 WRITE16_HANDLER( paletteram16_GGGGGRRRRRBBBBBx_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_555(space->machine, offset, 6, 11, 1, space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_555(space->machine(), offset, 6, 11, 1, space->machine().generic.paletteram.u16[offset]);
 }
 
 /*-------------------------------------------------
@@ -1012,8 +1019,8 @@ WRITE16_HANDLER( paletteram16_GGGGGRRRRRBBBBBx_word_w )
 
 WRITE16_HANDLER( paletteram16_RRRRRGGGGGBBBBBx_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_555(space->machine, offset, 11, 6, 1, space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_555(space->machine(), offset, 11, 6, 1, space->machine().generic.paletteram.u16[offset]);
 }
 
 
@@ -1023,9 +1030,9 @@ WRITE16_HANDLER( paletteram16_RRRRRGGGGGBBBBBx_word_w )
 
 WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBRGBx_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	data = space->machine->generic.paletteram.u16[offset];
-	palette_set_color_rgb(space->machine, offset, pal5bit(((data >> 11) & 0x1e) | ((data >> 3) & 0x01)),
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	data = space->machine().generic.paletteram.u16[offset];
+	palette_set_color_rgb(space->machine(), offset, pal5bit(((data >> 11) & 0x1e) | ((data >> 3) & 0x01)),
 	                                       pal5bit(((data >>  7) & 0x1e) | ((data >> 2) & 0x01)),
 	                                       pal5bit(((data >>  3) & 0x1e) | ((data >> 1) & 0x01)));
 }
@@ -1042,8 +1049,8 @@ WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBRGBx_word_w )
 
 WRITE16_HANDLER( paletteram16_IIIIRRRRGGGGBBBB_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_4444(space->machine, offset, 12, 8, 4, 0, space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_4444(space->machine(), offset, 12, 8, 4, 0, space->machine().generic.paletteram.u16[offset]);
 }
 
 
@@ -1053,8 +1060,8 @@ WRITE16_HANDLER( paletteram16_IIIIRRRRGGGGBBBB_word_w )
 
 WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBIIII_word_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_4444(space->machine, offset, 0, 12, 8, 4, space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_4444(space->machine(), offset, 0, 12, 8, 4, space->machine().generic.paletteram.u16[offset]);
 }
 
 
@@ -1069,8 +1076,8 @@ WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBIIII_word_w )
 
 WRITE16_HANDLER( paletteram16_xrgb_word_be_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_888(space->machine, offset / 2, 16, 8, 0, paletteram32_be(space->machine, offset));
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_888(space->machine(), offset / 2, 16, 8, 0, paletteram32_be(space->machine(), offset));
 }
 
 
@@ -1080,6 +1087,6 @@ WRITE16_HANDLER( paletteram16_xrgb_word_be_w )
 
 WRITE16_HANDLER( paletteram16_xbgr_word_be_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
-	set_color_888(space->machine, offset / 2, 0, 8, 16, paletteram32_be(space->machine, offset));
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
+	set_color_888(space->machine(), offset / 2, 0, 8, 16, paletteram32_be(space->machine(), offset));
 }
