@@ -52,7 +52,7 @@ struct _tms9927_state
 };
 
 
-static STATE_POSTLOAD( tms9927_state_save_postload );
+static void tms9927_state_save_postload(tms9927_state *state);
 static void recompute_parameters(tms9927_state *tms, int postload);
 
 
@@ -68,9 +68,9 @@ INLINE tms9927_state *get_safe_token(device_t *device)
 }
 
 
-static STATE_POSTLOAD( tms9927_state_save_postload )
+static void tms9927_state_save_postload(tms9927_state *state)
 {
-	recompute_parameters((tms9927_state *)param, TRUE);
+	recompute_parameters(state, TRUE);
 }
 
 
@@ -259,7 +259,7 @@ static DEVICE_START( tms9927 )
 	/* validate arguments */
 	assert(device != NULL);
 
-	tms->intf = (const tms9927_interface *)device->baseconfig().static_config();
+	tms->intf = (const tms9927_interface *)device->static_config();
 
 	if (tms->intf != NULL)
 	{
@@ -271,25 +271,25 @@ static DEVICE_START( tms9927 )
 		tms->hpixels_per_column = tms->intf->hpixels_per_column;
 
 		/* get the screen device */
-		tms->screen = downcast<screen_device *>(device->machine->device(tms->intf->screen_tag));
+		tms->screen = downcast<screen_device *>(device->machine().device(tms->intf->screen_tag));
 		assert(tms->screen != NULL);
 
 		/* get the self-load PROM */
 		if (tms->intf->selfload_region != NULL)
 		{
-			tms->selfload = device->machine->region(tms->intf->selfload_region)->base();
+			tms->selfload = device->machine().region(tms->intf->selfload_region)->base();
 			assert(tms->selfload != NULL);
 		}
 	}
 
 	/* register for state saving */
-	state_save_register_postload(device->machine, tms9927_state_save_postload, tms);
+	device->machine().save().register_postload(save_prepost_delegate(FUNC(tms9927_state_save_postload), tms));
 
-	state_save_register_device_item(device, 0, tms->clock);
-	state_save_register_device_item_array(device, 0, tms->reg);
-	state_save_register_device_item(device, 0, tms->start_datarow);
-	state_save_register_device_item(device, 0, tms->reset);
-	state_save_register_device_item(device, 0, tms->hpixels_per_column);
+	device->save_item(NAME(tms->clock));
+	device->save_item(NAME(tms->reg));
+	device->save_item(NAME(tms->start_datarow));
+	device->save_item(NAME(tms->reset));
+	device->save_item(NAME(tms->hpixels_per_column));
 }
 
 
