@@ -106,82 +106,77 @@ const char *const gorf_sample_names[] =
  "galaxy.wav","got.wav","power.wav","try.wav","supreme.wav","all.wav",
  "hail.wav","emperor.wav",
  0
-} ;
+};
 
 
-/* Total word to join the phonemes together - Global to make it easier to use */
-static char totalword[256], *totalword_ptr;
-static char oldword[256];
-static int plural = 0;
-
 READ8_HANDLER( gorf_speech_r )
 {
-	device_t *samples = space->machine->device("samples");
-    int Phoneme,Intonation;
-    int i = 0;
-
+	astrocde_state *state = space->machine().driver_data<astrocde_state>();
+	device_t *samples = space->machine().device("samples");
+	int Phoneme, Intonation;
+	int i = 0;
 	UINT8 data = offset >> 8;
 	offset &= 0xff;
 
-    totalword_ptr = totalword;
+	state->m_totalword_ptr = state->m_totalword;
 
-    Phoneme = data & 0x3F;
-    Intonation = data >> 6;
+	Phoneme = data & 0x3F;
+	Intonation = data >> 6;
 
-    logerror("Date : %d Speech : %s at intonation %d\n",Phoneme, PhonemeTable[Phoneme],Intonation);
+	logerror("Date : %d Speech : %s at intonation %d\n",Phoneme, PhonemeTable[Phoneme],Intonation);
 
-	 if(Phoneme==63) {
+	if(Phoneme==63) {
 		sample_stop(samples, 0);
-                if (strlen(totalword)>2) logerror("Clearing sample %s\n",totalword);
-                totalword[0] = 0;				   /* Clear the total word stack */
-					 return data;
-    }
+		if (strlen(state->m_totalword)>2) logerror("Clearing sample %s\n",state->m_totalword);
+		state->m_totalword[0] = 0;				   /* Clear the total word stack */
+		return data;
+	}
 
-/* Phoneme to word translation */
+	/* Phoneme to word translation */
 
-	 if (strlen(totalword) == 0) {
-		 strcpy(totalword,PhonemeTable[Phoneme]);	                   /* Copy over the first phoneme */
-		 if (plural != 0) {
-			 logerror("found a possible plural at %d\n",plural-1);
-			 if (!strcmp("S",totalword)) {		   /* Plural check */
-				 sample_start(samples, 0, num_samples-2, 0);	   /* play the sample at position of word */
-				 sample_set_freq(samples, 0, 11025);    /* play at correct rate */
-				 totalword[0] = 0;				   /* Clear the total word stack */
-				 oldword[0] = 0;				   /* Clear the total word stack */
-				 return data;
-			 } else {
-				 plural=0;
-			 }
-		 }
-	 } else
-		 strcat(totalword,PhonemeTable[Phoneme]);	                   /* Copy over the first phoneme */
+	if (strlen(state->m_totalword) == 0) {
+		strcpy(state->m_totalword,PhonemeTable[Phoneme]);	                   /* Copy over the first phoneme */
+		if (state->m_plural != 0) {
+			logerror("found a possible plural at %d\n",state->m_plural-1);
+			if (!strcmp("S",state->m_totalword)) {		   /* Plural check */
+				sample_start(samples, 0, num_samples-2, 0);	   /* play the sample at position of word */
+				sample_set_freq(samples, 0, 11025);    /* play at correct rate */
+				state->m_totalword[0] = 0;				   /* Clear the total word stack */
+				state->m_oldword[0] = 0;				   /* Clear the total word stack */
+				return data;
+			} else {
+				state->m_plural=0;
+			}
+		}
+	} else
+		strcat(state->m_totalword,PhonemeTable[Phoneme]);	                   /* Copy over the first phoneme */
 
-	 logerror("Total word = %s\n",totalword);
+	logerror("Total word = %s\n",state->m_totalword);
 
-	 for (i=0; GorfWordTable[i]; i++) {
-		 if (!strcmp(GorfWordTable[i],totalword)) {		   /* Scan the word (sample) table for the complete word */
-			 if ((!strcmp("GDTO1RFYA2N",totalword)) || (!strcmp("RO1U1BAH1T",totalword)) || (!strcmp("KO1UH3I3E1N",totalword)) || (!strcmp("WORAYY1EH3R",totalword)) || (!strcmp("IN",totalword)) ) {              /* May be plural */
-				 plural=i+1;
-				 strcpy(oldword,totalword);
-		  logerror("Storing sample position %d and copying string %s\n",plural,oldword);
-			 } else {
-             plural=0;
-          }
-          sample_start(samples, 0, i, 0);	                   /* play the sample at position of word */
-          sample_set_freq(samples, 0, 11025);       /* play at correct rate */
-          logerror("Playing sample %d",i);
-          totalword[0] = 0;				   /* Clear the total word stack */
-          return data;
-       }
-    }
+	for (i=0; GorfWordTable[i]; i++) {
+		if (!strcmp(GorfWordTable[i],state->m_totalword)) {		   /* Scan the word (sample) table for the complete word */
+			if ((!strcmp("GDTO1RFYA2N",state->m_totalword)) || (!strcmp("RO1U1BAH1T",state->m_totalword)) || (!strcmp("KO1UH3I3E1N",state->m_totalword)) || (!strcmp("WORAYY1EH3R",state->m_totalword)) || (!strcmp("IN",state->m_totalword)) ) {              /* May be state->m_plural */
+				state->m_plural=i+1;
+				strcpy(state->m_oldword,state->m_totalword);
+				logerror("Storing sample position %d and copying string %s\n",state->m_plural,state->m_oldword);
+			} else {
+				state->m_plural=0;
+			}
+			sample_start(samples, 0, i, 0);	                   /* play the sample at position of word */
+			sample_set_freq(samples, 0, 11025);       /* play at correct rate */
+			logerror("Playing sample %d",i);
+			state->m_totalword[0] = 0;				   /* Clear the total word stack */
+			return data;
+		}
+	}
 
-    /* Note : We should really also use volume in this as well as frequency */
-	 return data;				                   /* Return nicely */
+	/* Note : We should really also use volume in this as well as frequency */
+	return data;				                   /* Return nicely */
 }
 
 
 CUSTOM_INPUT( gorf_speech_status_r )
 {
-	device_t *samples = field->port->machine->device("samples");
+	device_t *samples = field.machine().device("samples");
 	return !sample_playing(samples, 0);
 }
