@@ -33,7 +33,6 @@
 ***************************************************************************/
 
 #include "emu.h"
-#include "streams.h"
 #include "audio/seibu.h"
 #include "sound/3812intf.h"
 #include "sound/2151intf.h"
@@ -102,11 +101,11 @@ static UINT8 decrypt_opcode(int a,int src)
 	return src;
 }
 
-void seibu_sound_decrypt(running_machine *machine,const char *cpu,int length)
+void seibu_sound_decrypt(running_machine &machine,const char *cpu,int length)
 {
-	address_space *space = cputag_get_address_space(machine, cpu, ADDRESS_SPACE_PROGRAM);
+	address_space *space = machine.device(cpu)->memory().space(AS_PROGRAM);
 	UINT8 *decrypt = auto_alloc_array(machine, UINT8, length);
-	UINT8 *rom = machine->region(cpu)->base();
+	UINT8 *rom = machine.region(cpu)->base();
 	int i;
 
 	space->set_decrypted_region(0x0000, (length < 0x10000) ? (length - 1) : 0x1fff, decrypt);
@@ -130,16 +129,27 @@ void seibu_sound_decrypt(running_machine *machine,const char *cpu,int length)
     Handlers for early Seibu/Tad games with dual channel ADPCM
 */
 
+const seibu_adpcm_interface seibu_adpcm1_intf =
+{
+	"adpcm1"
+};
+
+const seibu_adpcm_interface seibu_adpcm2_intf =
+{
+	"adpcm2"
+};
+
 typedef struct _seibu_adpcm_state seibu_adpcm_state;
 struct _seibu_adpcm_state
 {
-	adpcm_state adpcm;
-	sound_stream *stream;
-	UINT32 current, end;
-	UINT8 nibble;
-	UINT8 playing;
-	UINT8 allocated;
-	UINT8 *base;
+	adpcm_state m_adpcm;
+	sound_stream *m_stream;
+	UINT32 m_current;
+	UINT32 m_end;
+	UINT8 m_nibble;
+	UINT8 m_playing;
+	UINT8 m_allocated;
+	UINT8 *m_base;
 };
 
 static STREAM_UPDATE( seibu_adpcm_callback )
@@ -147,19 +157,19 @@ static STREAM_UPDATE( seibu_adpcm_callback )
 	seibu_adpcm_state *state = (seibu_adpcm_state *)param;
 	stream_sample_t *dest = outputs[0];
 
-	while (state->playing && samples > 0)
+	while (state->m_playing && samples > 0)
 	{
-		int val = (state->base[state->current] >> state->nibble) & 15;
+		int val = (state->m_base[state->m_current] >> state->m_nibble) & 15;
 
-		state->nibble ^= 4;
-		if (state->nibble == 4)
+		state->m_nibble ^= 4;
+		if (state->m_nibble == 4)
 		{
-			state->current++;
-			if (state->current >= state->end)
-				state->playing = 0;
+			state->m_current++;
+			if (state->m_current >= state->m_end)
+				state->m_playing = 0;
 		}
 
-		*dest++ = state->adpcm.clock(val) << 4;
+		*dest++ = state->m_adpcm.clock(val) << 4;
 		samples--;
 	}
 	while (samples > 0)
@@ -171,13 +181,21 @@ static STREAM_UPDATE( seibu_adpcm_callback )
 
 static DEVICE_START( seibu_adpcm )
 {
-	running_machine *machine = device->machine;
+	running_machine &machine = device->machine();
 	seibu_adpcm_state *state = (seibu_adpcm_state *)downcast<legacy_device_base *>(device)->token();
+	const seibu_adpcm_interface *intf;
 
-	state->playing = 0;
-	state->stream = stream_create(device, 0, 1, device->clock(), state, seibu_adpcm_callback);
-	state->base = machine->region("adpcm")->base();
-	state->adpcm.reset();
+	intf = (const seibu_adpcm_interface *)device->static_config();
+
+	state->m_playing = 0;
+	state->m_stream = device->machine().sound().stream_alloc(*device, 0, 1, device->clock(), state, seibu_adpcm_callback);
+	state->m_base = machine.region(intf->rom_region)->base();
+
+	// because legacy device tokens are just allocated as a blob, the constructor for adpcm_state
+	// is not called, so use placement new to force it to set up; when this is converted to a
+	// modern device, we can remove this grossness
+	new(&state->m_adpcm) adpcm_state;
+	state->m_adpcm.reset();
 }
 
 DEVICE_GET_INFO( seibu_adpcm )
@@ -201,10 +219,10 @@ DEVICE_GET_INFO( seibu_adpcm )
 // simplify PCB layout/routing rather than intentional protection, but it
 // still fits, especially since the Z80s for all these games are truly encrypted.
 
-void seibu_adpcm_decrypt(running_machine *machine, const char *region)
+void seibu_adpcm_decrypt(running_machine &machine, const char *region)
 {
-	UINT8 *ROM = machine->region(region)->base();
-	int len = machine->region(region)->bytes();
+	UINT8 *ROM = machine.region(region)->base();
+	int len = machine.region(region)->bytes();
 	int i;
 
 	for (i = 0; i < len; i++)
@@ -217,16 +235,16 @@ WRITE8_DEVICE_HANDLER( seibu_adpcm_adr_w )
 {
 	seibu_adpcm_state *state = (seibu_adpcm_state *)downcast<legacy_device_base *>(device)->token();
 
-	if (state->stream)
-		stream_update(state->stream);
+	if (state->m_stream)
+		state->m_stream->update();
 	if (offset)
 	{
-		state->end = data<<8;
+		state->m_end = data<<8;
 	}
 	else
 	{
-		state->current = data<<8;
-		state->nibble = 4;
+		state->m_current = data<<8;
+		state->m_nibble = 4;
 	}
 }
 
@@ -235,17 +253,17 @@ WRITE8_DEVICE_HANDLER( seibu_adpcm_ctl_w )
 	seibu_adpcm_state *state = (seibu_adpcm_state *)downcast<legacy_device_base *>(device)->token();
 
 	// sequence is 00 02 01 each time.
-	if (state->stream)
-		stream_update(state->stream);
+	if (state->m_stream)
+		state->m_stream->update();
 	switch (data)
 	{
 		case 0:
-			state->playing = 0;
+			state->m_playing = 0;
 			break;
 		case 2:
 			break;
 		case 1:
-			state->playing = 1;
+			state->m_playing = 1;
 			break;
 
 	}
@@ -264,7 +282,7 @@ enum
 	RST18_CLEAR
 };
 
-static void update_irq_lines(running_machine *machine, int param)
+static void update_irq_lines(running_machine &machine, int param)
 {
 	static int irq1,irq2;
 
@@ -292,15 +310,15 @@ static void update_irq_lines(running_machine *machine, int param)
 	}
 
 	if ((irq1 & irq2) == 0xff)	/* no IRQs pending */
-		cpu_set_input_line(sound_cpu,0,CLEAR_LINE);
+		device_set_input_line(sound_cpu,0,CLEAR_LINE);
 	else	/* IRQ pending */
-		cpu_set_input_line_and_vector(sound_cpu,0,ASSERT_LINE,irq1 & irq2);
+		device_set_input_line_and_vector(sound_cpu,0,ASSERT_LINE,irq1 & irq2);
 }
 
 WRITE8_HANDLER( seibu_irq_clear_w )
 {
 	/* Denjin Makai and SD Gundam doesn't like this, it's tied to the rst18 ack ONLY so it could be related to it. */
-	//update_irq_lines(space->machine, VECTOR_INIT);
+	//update_irq_lines(space->machine(), VECTOR_INIT);
 }
 
 WRITE8_HANDLER( seibu_rst10_ack_w )
@@ -310,32 +328,32 @@ WRITE8_HANDLER( seibu_rst10_ack_w )
 
 WRITE8_HANDLER( seibu_rst18_ack_w )
 {
-	update_irq_lines(space->machine, RST18_CLEAR);
+	update_irq_lines(space->machine(), RST18_CLEAR);
 }
 
 void seibu_ym3812_irqhandler(device_t *device, int linestate)
 {
-	update_irq_lines(device->machine, linestate ? RST10_ASSERT : RST10_CLEAR);
+	update_irq_lines(device->machine(), linestate ? RST10_ASSERT : RST10_CLEAR);
 }
 
 void seibu_ym2151_irqhandler(device_t *device, int linestate)
 {
-	update_irq_lines(device->machine, linestate ? RST10_ASSERT : RST10_CLEAR);
+	update_irq_lines(device->machine(), linestate ? RST10_ASSERT : RST10_CLEAR);
 }
 
 void seibu_ym2203_irqhandler(device_t *device, int linestate)
 {
-	update_irq_lines(device->machine, linestate ? RST10_ASSERT : RST10_CLEAR);
+	update_irq_lines(device->machine(), linestate ? RST10_ASSERT : RST10_CLEAR);
 }
 
 /***************************************************************************/
 
 MACHINE_RESET( seibu_sound )
 {
-	int romlength = machine->region("audiocpu")->bytes();
-	UINT8 *rom = machine->region("audiocpu")->base();
+	int romlength = machine.region("audiocpu")->bytes();
+	UINT8 *rom = machine.region("audiocpu")->base();
 
-	sound_cpu = machine->device("audiocpu");
+	sound_cpu = machine.device("audiocpu");
 	update_irq_lines(machine, VECTOR_INIT);
 	if (romlength > 0x10000)
 	{
@@ -353,13 +371,13 @@ static int main2sub_pending,sub2main_pending;
 
 WRITE8_HANDLER( seibu_bank_w )
 {
-	memory_set_bank(space->machine, "bank1", data & 1);
+	memory_set_bank(space->machine(), "bank1", data & 1);
 }
 
 WRITE8_HANDLER( seibu_coin_w )
 {
-	coin_counter_w(space->machine, 0,data & 1);
-	coin_counter_w(space->machine, 1,data & 2);
+	coin_counter_w(space->machine(), 0,data & 1);
+	coin_counter_w(space->machine(), 1,data & 2);
 }
 
 READ8_HANDLER( seibu_soundlatch_r )
@@ -386,7 +404,7 @@ static WRITE8_HANDLER( seibu_pending_w )
 
 READ16_HANDLER( seibu_main_word_r )
 {
-	//logerror("%06x: seibu_main_word_r(%x)\n",cpu_get_pc(space->cpu),offset);
+	//logerror("%06x: seibu_main_word_r(%x)\n",cpu_get_pc(&space->device()),offset);
 	switch (offset)
 	{
 		case 2:
@@ -395,14 +413,14 @@ READ16_HANDLER( seibu_main_word_r )
 		case 5:
 			return main2sub_pending ? 1 : 0;
 		default:
-			//logerror("%06x: seibu_main_word_r(%x)\n",cpu_get_pc(space->cpu),offset);
+			//logerror("%06x: seibu_main_word_r(%x)\n",cpu_get_pc(&space->device()),offset);
 			return 0xffff;
 	}
 }
 
 WRITE16_HANDLER( seibu_main_word_w )
 {
-	//printf("%06x: seibu_main_word_w(%x,%02x)\n",cpu_get_pc(space->cpu),offset,data);
+	//printf("%06x: seibu_main_word_w(%x,%02x)\n",cpu_get_pc(&space->device()),offset,data);
 	if (ACCESSING_BITS_0_7)
 	{
 		switch (offset)
@@ -412,7 +430,7 @@ WRITE16_HANDLER( seibu_main_word_w )
 				main2sub[offset] = data;
 				break;
 			case 4:
-				update_irq_lines(space->machine, RST18_ASSERT);
+				update_irq_lines(space->machine(), RST18_ASSERT);
 				break;
 			case 2: //Sengoku Mahjong writes here
 			case 6:
@@ -421,7 +439,7 @@ WRITE16_HANDLER( seibu_main_word_w )
 				main2sub_pending = 1;
 				break;
 			default:
-				//logerror("%06x: seibu_main_word_w(%x,%02x)\n",cpu_get_pc(space->cpu),offset,data);
+				//logerror("%06x: seibu_main_word_w(%x,%02x)\n",cpu_get_pc(&space->device()),offset,data);
 				break;
 		}
 	}
@@ -444,7 +462,7 @@ WRITE16_HANDLER( seibu_main_mustb_w )
 
 //  logerror("seibu_main_mustb_w: %x -> %x %x\n", data, main2sub[0], main2sub[1]);
 
-	update_irq_lines(space->machine, RST18_ASSERT);
+	update_irq_lines(space->machine(), RST18_ASSERT);
 }
 
 /***************************************************************************/
@@ -471,7 +489,7 @@ const ym2203_interface seibu_ym2203_interface =
 
 /***************************************************************************/
 
-ADDRESS_MAP_START( seibu_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+ADDRESS_MAP_START( seibu_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x27ff) AM_RAM
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(seibu_pending_w)
@@ -489,8 +507,25 @@ ADDRESS_MAP_START( seibu_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8000, 0xffff) AM_ROMBANK("bank1")
 ADDRESS_MAP_END
 
+ADDRESS_MAP_START( seibu2_airraid_sound_map, AS_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1fff) AM_ROM
+	AM_RANGE(0x2000, 0x27ff) AM_RAM
+	AM_RANGE(0x4000, 0x4000) AM_WRITE(seibu_pending_w)
+	AM_RANGE(0x4001, 0x4001) AM_WRITE(seibu_irq_clear_w)
+	AM_RANGE(0x4002, 0x4002) AM_WRITE(seibu_rst10_ack_w)
+	AM_RANGE(0x4003, 0x4003) AM_WRITE(seibu_rst18_ack_w)
+	AM_RANGE(0x4007, 0x4007) AM_WRITENOP // bank, always 0
+	AM_RANGE(0x4008, 0x4009) AM_DEVREADWRITE("ymsnd", ym2151_r, ym2151_w)
+	AM_RANGE(0x4010, 0x4011) AM_READ(seibu_soundlatch_r)
+	AM_RANGE(0x4012, 0x4012) AM_READ(seibu_main_data_pending_r)
+	AM_RANGE(0x4013, 0x4013) AM_READ_PORT("COIN")
+	AM_RANGE(0x4018, 0x4019) AM_WRITE(seibu_main_data_w)
+	AM_RANGE(0x401b, 0x401b) AM_WRITE(seibu_coin_w)
+//  AM_RANGE(0x6000, 0x6000) AM_DEVREADWRITE_MODERN("oki", okim6295_device, read, write)
+	AM_RANGE(0x8000, 0xffff) AM_ROM
+ADDRESS_MAP_END
 
-ADDRESS_MAP_START( seibu2_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+ADDRESS_MAP_START( seibu2_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x27ff) AM_RAM
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(seibu_pending_w)
@@ -508,7 +543,7 @@ ADDRESS_MAP_START( seibu2_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8000, 0xffff) AM_ROMBANK("bank1")
 ADDRESS_MAP_END
 
-ADDRESS_MAP_START( seibu2_raiden2_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+ADDRESS_MAP_START( seibu2_raiden2_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x27ff) AM_RAM
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(seibu_pending_w)
@@ -529,7 +564,7 @@ ADDRESS_MAP_START( seibu2_raiden2_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x401a, 0x401a) AM_NOP
 ADDRESS_MAP_END
 
-ADDRESS_MAP_START( seibu_newzeroteam_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+ADDRESS_MAP_START( seibu_newzeroteam_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x27ff) AM_RAM
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(seibu_pending_w)
@@ -547,7 +582,7 @@ ADDRESS_MAP_START( seibu_newzeroteam_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8000, 0xffff) AM_ROMBANK("bank1")
 ADDRESS_MAP_END
 
-ADDRESS_MAP_START( seibu3_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+ADDRESS_MAP_START( seibu3_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x27ff) AM_RAM
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(seibu_pending_w)
@@ -565,7 +600,7 @@ ADDRESS_MAP_START( seibu3_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8000, 0xffff) AM_ROMBANK("bank1")
 ADDRESS_MAP_END
 
-ADDRESS_MAP_START( seibu3_adpcm_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+ADDRESS_MAP_START( seibu3_adpcm_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x27ff) AM_RAM
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(seibu_pending_w)
