@@ -132,21 +132,21 @@ MACHINE_CONFIG_END
 
 static TIMER_CALLBACK( frogs_croak_callback )
 {
-	device_t *samples = machine->device("samples");
+	device_t *samples = machine.device("samples");
 	sample_stop(samples, 2);
 }
 
 
 MACHINE_START( frogs_audio )
 {
-	frogs_croak_timer = timer_alloc(machine, frogs_croak_callback, NULL);
+	frogs_croak_timer = machine.scheduler().timer_alloc(FUNC(frogs_croak_callback));
 }
 
 
 WRITE8_HANDLER( frogs_audio_w )
 {
-	device_t *samples = space->machine->device("samples");
-	device_t *discrete = space->machine->device("discrete");
+	device_t *samples = space->machine().device("samples");
+	device_t *discrete = space->machine().device("discrete");
 	static int last_croak = 0;
 	static int last_buzzz = 0;
 	int new_croak = data & 0x08;
@@ -170,7 +170,7 @@ WRITE8_HANDLER( frogs_audio_w )
 		if (last_croak)
 		{
 			/* The croak will keep playing until .429s after being disabled */
-			timer_adjust_oneshot(frogs_croak_timer, double_to_attotime(1.1 * RES_K(390) * CAP_U(1)), 0);
+			frogs_croak_timer->adjust(attotime::from_double(1.1 * RES_K(390) * CAP_U(1)));
 		}
 	}
 	if (new_buzzz)
@@ -245,16 +245,16 @@ static const discrete_mixer_desc headon_crash_mixer =
 	0, 1
 };
 
-static const discrete_inverter_osc_desc headon_inverter_osc_1 =
+static const discrete_dss_inverter_osc_node::description headon_inverter_osc_1 =
 {
 	DEFAULT_CD40XX_VALUES(12),
-	DISC_OSC_INVERTER_IS_TYPE4
+	discrete_dss_inverter_osc_node::IS_TYPE4
 };
 
-static const discrete_inverter_osc_desc headon_inverter_osc_2 =
+static const discrete_dss_inverter_osc_node::description headon_inverter_osc_2 =
 {
 	DEFAULT_CD40XX_VALUES(12),
-	DISC_OSC_INVERTER_IS_TYPE5 | DISC_OSC_INVERTER_OUT_IS_LOGIC
+	discrete_dss_inverter_osc_node::IS_TYPE5 | discrete_dss_inverter_osc_node::OUT_IS_LOGIC
 };
 
 static const discrete_555_desc headon_555_bonus =
@@ -462,7 +462,7 @@ MACHINE_CONFIG_END
 
 WRITE8_HANDLER( headon_audio_w )
 {
-	device_t *discrete = space->machine->device("discrete");
+	device_t *discrete = space->machine().device("discrete");
 	if (discrete == NULL)
 		return;
 	discrete_sound_w(discrete, HEADON_HISPEED_PC_EN, data & 0x01);
@@ -477,7 +477,7 @@ WRITE8_HANDLER( headon_audio_w )
 
 WRITE8_HANDLER( invho2_audio_w )
 {
-	device_t *discrete = space->machine->device("discrete");
+	device_t *discrete = space->machine().device("discrete");
 	if (discrete == NULL)
 		return;
 	discrete_sound_w(discrete, HEADON_HISPEED_PC_EN, data & 0x10);
