@@ -450,37 +450,51 @@
 #include "sound/ay8910.h"
 #include "sound/okim6295.h"
 
-static UINT8 main_latch_d800;
-static UINT8 snd_latch_0800;
-static UINT8 snd_latch_0a02;
-static UINT8 ay8910_addr;
-static device_t *ay8910;
+
+class _5clown_state : public driver_device
+{
+public:
+	_5clown_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 m_main_latch_d800;
+	UINT8 m_snd_latch_0800;
+	UINT8 m_snd_latch_0a02;
+	UINT8 m_ay8910_addr;
+	device_t *m_ay8910;
+	UINT8 *m_videoram;
+	UINT8 *m_colorram;
+	tilemap_t *m_bg_tilemap;
+	int m_mux_data;
+};
+
+
 
 
 /*************************
 *     Video Hardware     *
 *************************/
 
-static UINT8 *videoram;
-static UINT8 *colorram;
-static tilemap_t *bg_tilemap;
 
 
 static WRITE8_HANDLER( fclown_videoram_w )
 {
-	videoram[offset] = data;
-	tilemap_mark_tile_dirty(bg_tilemap, offset);
+	_5clown_state *state = space->machine().driver_data<_5clown_state>();
+	state->m_videoram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
 }
 
 static WRITE8_HANDLER( fclown_colorram_w )
 {
-	colorram[offset] = data;
-	tilemap_mark_tile_dirty(bg_tilemap, offset);
+	_5clown_state *state = space->machine().driver_data<_5clown_state>();
+	state->m_colorram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
 }
 
 
 static TILE_GET_INFO( get_fclown_tile_info )
 {
+	_5clown_state *state = machine.driver_data<_5clown_state>();
 
 /*  - bits -
     7654 3210
@@ -491,8 +505,8 @@ static TILE_GET_INFO( get_fclown_tile_info )
     x--- ----   Extra color for 7's.
 */
 
-	int attr = colorram[tile_index];
-	int code = ((attr & 0x01) << 8) | ((attr & 0x40) << 2) | videoram[tile_index];	/* bit 8 for extended char set */
+	int attr = state->m_colorram[tile_index];
+	int code = ((attr & 0x01) << 8) | ((attr & 0x40) << 2) | state->m_videoram[tile_index];	/* bit 8 for extended char set */
 	int bank = (attr & 0x02) >> 1;													/* bit 1 switch the gfx banks */
 	int color = (attr & 0x3c) >> 2 | ((attr & 0x80) >> 3);							/* bits 2-3-4-5-7 for color */
 
@@ -502,13 +516,15 @@ static TILE_GET_INFO( get_fclown_tile_info )
 
 static VIDEO_START(fclown)
 {
-	bg_tilemap = tilemap_create(machine, get_fclown_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
+	_5clown_state *state = machine.driver_data<_5clown_state>();
+	state->m_bg_tilemap = tilemap_create(machine, get_fclown_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
 }
 
 
-static VIDEO_UPDATE( fclown )
+static SCREEN_UPDATE( fclown )
 {
-	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
+	_5clown_state *state = screen->machine().driver_data<_5clown_state>();
+	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
 	return 0;
 }
 
@@ -528,7 +544,7 @@ static PALETTE_INIT( fclown )
 
 	if (color_prom == 0) return;
 
-	for (i = 0;i < machine->total_colors();i++)
+	for (i = 0;i < machine.total_colors();i++)
 	{
 		int bit0, bit1, bit2, bit3, r, g, b, bk;
 
@@ -557,7 +573,6 @@ static PALETTE_INIT( fclown )
 *         R/W Handlers        *
 ******************************/
 
-static int mux_data = 0;
 
 /* Inputs (buttons) are multiplexed.
    There are 4 sets of 5 bits each and are connected to PIA0, portA.
@@ -565,12 +580,13 @@ static int mux_data = 0;
 */
 static READ8_DEVICE_HANDLER( mux_port_r )
 {
-	switch( mux_data & 0xf0 )		/* bits 4-7 */
+	_5clown_state *state = device->machine().driver_data<_5clown_state>();
+	switch( state->m_mux_data & 0xf0 )		/* bits 4-7 */
 	{
-		case 0x10: return input_port_read(device->machine, "IN0-0");
-		case 0x20: return input_port_read(device->machine, "IN0-1");
-		case 0x40: return input_port_read(device->machine, "IN0-2");
-		case 0x80: return input_port_read(device->machine, "IN0-3");
+		case 0x10: return input_port_read(device->machine(), "IN0-0");
+		case 0x20: return input_port_read(device->machine(), "IN0-1");
+		case 0x40: return input_port_read(device->machine(), "IN0-2");
+		case 0x80: return input_port_read(device->machine(), "IN0-3");
 	}
 
 	return 0xff;
@@ -579,7 +595,8 @@ static READ8_DEVICE_HANDLER( mux_port_r )
 
 static WRITE8_DEVICE_HANDLER( mux_w )
 {
-	mux_data = data ^ 0xff;	/* Inverted */
+	_5clown_state *state = device->machine().driver_data<_5clown_state>();
+	state->m_mux_data = data ^ 0xff;	/* Inverted */
 }
 
 
@@ -594,10 +611,10 @@ static WRITE8_DEVICE_HANDLER( counters_w )
     -x-- ----   Unknown (increments at start).
     x--- ----   Unknown (increments at start).
 */
-	coin_counter_w(device->machine, 0, data & 0x10);	/* Key In */
-	coin_counter_w(device->machine, 1, data & 0x20);	/* Payout */
-	coin_counter_w(device->machine, 2, data & 0x40);	/* unknown */
-	coin_counter_w(device->machine, 3, data & 0x80);	/* unknown */
+	coin_counter_w(device->machine(), 0, data & 0x10);	/* Key In */
+	coin_counter_w(device->machine(), 1, data & 0x20);	/* Payout */
+	coin_counter_w(device->machine(), 2, data & 0x40);	/* unknown */
+	coin_counter_w(device->machine(), 3, data & 0x80);	/* unknown */
 
 }
 
@@ -610,12 +627,12 @@ static WRITE8_DEVICE_HANDLER( trigsnd_w )
 
 	if ( (data & 0x0f) == 0x07 )
 	{
-		cputag_set_input_line(device->machine, "audiocpu", INPUT_LINE_NMI, ASSERT_LINE );
+		cputag_set_input_line(device->machine(), "audiocpu", INPUT_LINE_NMI, ASSERT_LINE );
 	}
 
 	else
 	{
-		cputag_set_input_line(device->machine, "audiocpu", INPUT_LINE_NMI, CLEAR_LINE );
+		cputag_set_input_line(device->machine(), "audiocpu", INPUT_LINE_NMI, CLEAR_LINE );
 	}
 
 }
@@ -643,8 +660,9 @@ static WRITE8_HANDLER( cpu_c048_w)
 
 static WRITE8_HANDLER( cpu_d800_w )
 {
+	_5clown_state *state = space->machine().driver_data<_5clown_state>();
 	logerror("Main: Write to $D800: %02x\n", data);
-	main_latch_d800 = data;
+	state->m_main_latch_d800 = data;
 }
 
 
@@ -665,29 +683,32 @@ static WRITE8_DEVICE_HANDLER( fclown_ay8910_w )
 
 static READ8_HANDLER( snd_e06_r )
 {
+	_5clown_state *state = space->machine().driver_data<_5clown_state>();
 	logerror("Sound: Read from $0E06 \n");
-	return main_latch_d800;
+	return state->m_main_latch_d800;
 }
 
 static WRITE8_HANDLER( snd_800_w )
 {
-	snd_latch_0800 = data;
+	_5clown_state *state = space->machine().driver_data<_5clown_state>();
+	state->m_snd_latch_0800 = data;
 
-	if (snd_latch_0a02 == 0xc0)
+	if (state->m_snd_latch_0a02 == 0xc0)
 	{
-		ay8910_addr = snd_latch_0800;
+		state->m_ay8910_addr = state->m_snd_latch_0800;
 	}
 
-	if (snd_latch_0a02 == 0x00)
+	if (state->m_snd_latch_0a02 == 0x00)
 	{
-		fclown_ay8910_w( ay8910, ay8910_addr, snd_latch_0800);
+		fclown_ay8910_w( state->m_ay8910, state->m_ay8910_addr, state->m_snd_latch_0800);
 	}
 }
 
 static WRITE8_HANDLER( snd_a02_w )
 {
-	snd_latch_0a02 = data & 0xff;
-	logerror("Sound: Write to $0A02: %02x\n", snd_latch_0a02);
+	_5clown_state *state = space->machine().driver_data<_5clown_state>();
+	state->m_snd_latch_0a02 = data & 0xff;
+	logerror("Sound: Write to $0A02: %02x\n", state->m_snd_latch_0a02);
 }
 
 
@@ -695,14 +716,14 @@ static WRITE8_HANDLER( snd_a02_w )
 * Memory map information *
 *************************/
 
-static ADDRESS_MAP_START( fclown_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( fclown_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_SHARE("nvram")
-	AM_RANGE(0x0800, 0x0800) AM_DEVWRITE("crtc", mc6845_address_w)
-	AM_RANGE(0x0801, 0x0801) AM_DEVREADWRITE("crtc", mc6845_register_r, mc6845_register_w)
-	AM_RANGE(0x0844, 0x0847) AM_DEVREADWRITE("pia0", pia6821_r, pia6821_w)
-	AM_RANGE(0x0848, 0x084b) AM_DEVREADWRITE("pia1", pia6821_r, pia6821_w)
-	AM_RANGE(0x1000, 0x13ff) AM_RAM_WRITE(fclown_videoram_w) AM_BASE(&videoram)	/* Init'ed at $2042 */
-	AM_RANGE(0x1800, 0x1bff) AM_RAM_WRITE(fclown_colorram_w) AM_BASE(&colorram)	/* Init'ed at $2054 */
+	AM_RANGE(0x0800, 0x0800) AM_DEVWRITE_MODERN("crtc", mc6845_device, address_w)
+	AM_RANGE(0x0801, 0x0801) AM_DEVREADWRITE_MODERN("crtc", mc6845_device, register_r, register_w)
+	AM_RANGE(0x0844, 0x0847) AM_DEVREADWRITE_MODERN("pia0", pia6821_device, read, write)
+	AM_RANGE(0x0848, 0x084b) AM_DEVREADWRITE_MODERN("pia1", pia6821_device, read, write)
+	AM_RANGE(0x1000, 0x13ff) AM_RAM_WRITE(fclown_videoram_w) AM_BASE_MEMBER(_5clown_state, m_videoram)	/* Init'ed at $2042 */
+	AM_RANGE(0x1800, 0x1bff) AM_RAM_WRITE(fclown_colorram_w) AM_BASE_MEMBER(_5clown_state, m_colorram)	/* Init'ed at $2054 */
 	AM_RANGE(0x2000, 0x7fff) AM_ROM					/* ROM space */
 
 	AM_RANGE(0xc048, 0xc048) AM_WRITE(cpu_c048_w )
@@ -770,7 +791,7 @@ ADDRESS_MAP_END
 
 */
 
-static ADDRESS_MAP_START( fcaudio_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( fcaudio_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_RAM
 	AM_RANGE(0x0800, 0x0800) AM_WRITE(snd_800_w)
 	AM_RANGE(0x0a02, 0x0a02) AM_WRITE(snd_a02_w)
@@ -1028,7 +1049,7 @@ static const ay8910_interface ay8910_config =
 *    Machine Drivers     *
 *************************/
 
-static MACHINE_CONFIG_START( fclown, driver_device )
+static MACHINE_CONFIG_START( fclown, _5clown_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M6502, MASTER_CLOCK/8)	/* guess, seems ok */
@@ -1050,13 +1071,13 @@ static MACHINE_CONFIG_START( fclown, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE((39+1)*8, (31+1)*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 32*8-1)
+	MCFG_SCREEN_UPDATE(fclown)
 
 	MCFG_GFXDECODE(fclown)
 	MCFG_PALETTE_LENGTH(256)
 	MCFG_PALETTE_INIT(fclown)
 
 	MCFG_VIDEO_START(fclown)
-	MCFG_VIDEO_UPDATE(fclown)
 
 	MCFG_MC6845_ADD("crtc", MC6845, MASTER_CLOCK/16, mc6845_intf) /* guess */
 
@@ -1177,10 +1198,11 @@ ROM_END
 
 static DRIVER_INIT( fclown )
 {
+	_5clown_state *state = machine.driver_data<_5clown_state>();
     /* Decrypting main program */
 
 	int x;
-	UINT8 *src = machine->region( "maincpu" )->base();
+	UINT8 *src = machine.region( "maincpu" )->base();
 
 	for (x = 0x0000; x < 0x10000; x++)
 	{
@@ -1190,8 +1212,8 @@ static DRIVER_INIT( fclown )
 
     /* Decrypting GFX by segments */
 
-	UINT8 *gfx1_src = machine->region( "gfx1" )->base();
-	UINT8 *gfx2_src = machine->region( "gfx2" )->base();
+	UINT8 *gfx1_src = machine.region( "gfx1" )->base();
+	UINT8 *gfx2_src = machine.region( "gfx2" )->base();
 
 	for (x = 0x2000; x < 0x3000; x++)
 	{
@@ -1211,7 +1233,7 @@ static DRIVER_INIT( fclown )
 
     /* Decrypting sound samples */
 
-	UINT8 *samples_src = machine->region( "oki6295" )->base();
+	UINT8 *samples_src = machine.region( "oki6295" )->base();
 
 	for (x = 0x0000; x < 0x10000; x++)
 	{
@@ -1229,7 +1251,7 @@ static DRIVER_INIT( fclown )
 
 	/* Assigning AY-3-8910 sound device */
 
-	ay8910 = machine->device("ay8910");
+	state->m_ay8910 = machine.device("ay8910");
 }
 
 
