@@ -23,13 +23,13 @@
 
     I/O Ports:
 
-    00-01       R/W AY8910 #0 (Port A = Input Port #0)
-    80-81       R/W AY8910 #1 (Port A = Input Port #1)
+    00-01       R/W AY8912 #0 (Port A = Input Port #0)
+    80-81       R/W AY8912 #1 (Port A = Input Port #1)
 
 
     TODO:
 
-    - Verify Z80 and AY8910 clock speeds
+    - Verify actual Z80 and AY8912 clock speeds from PCB (XTAL confirmed)
 
 ***************************************************************************/
 
@@ -47,13 +47,13 @@
 
 static WRITE8_HANDLER( ambush_coin_counter_w )
 {
-	coin_counter_w(space->machine, 0, data & 0x01);
-	coin_counter_w(space->machine, 1, data & 0x02);
+	coin_counter_w(space->machine(), 0, data & 0x01);
+	coin_counter_w(space->machine(), 1, data & 0x02);
 }
 
 static WRITE8_HANDLER( flip_screen_w )
 {
-	flip_screen_set(space->machine, data);
+	flip_screen_set(space->machine(), data);
 }
 
 
@@ -63,23 +63,23 @@ static WRITE8_HANDLER( flip_screen_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0x87ff) AM_RAM
 	AM_RANGE(0xa000, 0xa000) AM_READ(watchdog_reset_r)
 	AM_RANGE(0xc000, 0xc7ff) AM_RAM
-	AM_RANGE(0xc080, 0xc09f) AM_BASE_MEMBER(ambush_state, scrollram)
-	AM_RANGE(0xc100, 0xc1ff) AM_BASE_MEMBER(ambush_state, colorram)
-	AM_RANGE(0xc200, 0xc3ff) AM_BASE_SIZE_MEMBER(ambush_state, spriteram, spriteram_size)
-	AM_RANGE(0xc400, 0xc7ff) AM_BASE_SIZE_MEMBER(ambush_state, videoram, videoram_size)
+	AM_RANGE(0xc080, 0xc09f) AM_BASE_MEMBER(ambush_state, m_scrollram)
+	AM_RANGE(0xc100, 0xc1ff) AM_BASE_MEMBER(ambush_state, m_colorram)
+	AM_RANGE(0xc200, 0xc3ff) AM_BASE_SIZE_MEMBER(ambush_state, m_spriteram, m_spriteram_size)
+	AM_RANGE(0xc400, 0xc7ff) AM_BASE_SIZE_MEMBER(ambush_state, m_videoram, m_videoram_size)
 	AM_RANGE(0xc800, 0xc800) AM_READ_PORT("DSW1")
 	AM_RANGE(0xcc00, 0xcc03) AM_WRITENOP
 	AM_RANGE(0xcc04, 0xcc04) AM_WRITE(flip_screen_w)
-	AM_RANGE(0xcc05, 0xcc05) AM_WRITEONLY AM_BASE_MEMBER(ambush_state, colorbank)
+	AM_RANGE(0xcc05, 0xcc05) AM_WRITEONLY AM_BASE_MEMBER(ambush_state, m_colorbank)
 	AM_RANGE(0xcc07, 0xcc07) AM_WRITE(ambush_coin_counter_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( main_portmap, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( main_portmap, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_DEVREADWRITE("ay1", ay8910_r, ay8910_address_w)
 	AM_RANGE(0x01, 0x01) AM_DEVWRITE("ay1", ay8910_data_w)
@@ -199,7 +199,7 @@ GFXDECODE_END
  *
  *************************************/
 
-static const ay8910_interface ay8910_interface_1 =
+static const ay8910_interface ay8912_interface_1 =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
@@ -209,7 +209,7 @@ static const ay8910_interface ay8910_interface_1 =
 	DEVCB_NULL
 };
 
-static const ay8910_interface ay8910_interface_2 =
+static const ay8910_interface ay8912_interface_2 =
 {
 	AY8910_LEGACY_OUTPUT,
 	AY8910_DEFAULT_LOADS,
@@ -229,7 +229,7 @@ static const ay8910_interface ay8910_interface_2 =
 static MACHINE_CONFIG_START( ambush, ambush_state )
 
 	/* basic machine hardware */
-	MCFG_CPU_ADD("maincpu", Z80, 4000000)        /* 4.00 MHz??? */
+	MCFG_CPU_ADD("maincpu", Z80, XTAL_18_432MHz/6)		/* XTAL confirmed, divisor guessed */
 	MCFG_CPU_PROGRAM_MAP(main_map)
 	MCFG_CPU_IO_MAP(main_portmap)
 	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
@@ -241,22 +241,23 @@ static MACHINE_CONFIG_START( ambush, ambush_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-3)  /* The -3 makes the cocktail mode perfect */
+	MCFG_SCREEN_UPDATE(ambush)
+
 	MCFG_GFXDECODE(ambush)
 	MCFG_PALETTE_LENGTH(256)
 
 	MCFG_PALETTE_INIT(ambush)
-	MCFG_VIDEO_UPDATE(ambush)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MCFG_SOUND_ADD("ay1", AY8910, 1500000)
-	MCFG_SOUND_CONFIG(ay8910_interface_1)
-	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SOUND_ADD("ay1", AY8912, XTAL_18_432MHz/6/2)	/* XTAL confirmed, divisor guessed */
+	MCFG_SOUND_CONFIG(ay8912_interface_1)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.33)
 
-	MCFG_SOUND_ADD("ay2", AY8910, 1500000)
-	MCFG_SOUND_CONFIG(ay8910_interface_2)
-	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SOUND_ADD("ay2", AY8912, XTAL_18_432MHz/6/2)	/* XTAL confirmed, divisor guessed */
+	MCFG_SOUND_CONFIG(ay8912_interface_2)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.33)
 MACHINE_CONFIG_END
 
 
