@@ -104,6 +104,7 @@
     DIP locations verified for:
     - seawolf2 (manual)
     - wow (manual)
+    - spacezap (manual)
     - gorf (manual)
     - robby (manual)
     - profpac (manual)
@@ -119,20 +120,11 @@
 #include "sound/samples.h"
 #include "sound/astrocde.h"
 #include "sound/ay8910.h"
+
 #include "tenpindx.lh"
 #include "gorf.lh"
 
 
-static UINT8 *protected_ram;
-
-static UINT8 port_1_last;
-static UINT8 port_2_last;
-static UINT8 ram_write_enable;
-static UINT8 input_select;
-static UINT8 profpac_bank;
-
-
-
 /*************************************
  *
  *  Machine setup
@@ -141,13 +133,14 @@ static UINT8 profpac_bank;
 
 static MACHINE_START( astrocde )
 {
-	state_save_register_global(machine, port_1_last);
-	state_save_register_global(machine, port_2_last);
-	state_save_register_global(machine, ram_write_enable);
-	state_save_register_global(machine, input_select);
-	state_save_register_global(machine, profpac_bank);
+	astrocde_state *state = machine.driver_data<astrocde_state>();
+	state_save_register_global(machine, state->m_port_1_last);
+	state_save_register_global(machine, state->m_port_2_last);
+	state_save_register_global(machine, state->m_ram_write_enable);
+	state_save_register_global(machine, state->m_input_select);
+	state_save_register_global(machine, state->m_profpac_bank);
 
-	port_1_last = port_2_last = 0xff;
+	state->m_port_1_last = state->m_port_2_last = 0xff;
 }
 
 
@@ -160,22 +153,25 @@ static MACHINE_START( astrocde )
 
 static WRITE8_HANDLER( protected_ram_enable_w )
 {
-	ram_write_enable = TRUE;
+	astrocde_state *state = space->machine().driver_data<astrocde_state>();
+	state->m_ram_write_enable = TRUE;
 }
 
 
 static READ8_HANDLER( protected_ram_r )
 {
-	ram_write_enable = FALSE;
-	return protected_ram[offset];
+	astrocde_state *state = space->machine().driver_data<astrocde_state>();
+	state->m_ram_write_enable = FALSE;
+	return state->m_protected_ram[offset];
 }
 
 
 static WRITE8_HANDLER( protected_ram_w )
 {
-	if (ram_write_enable)
-		protected_ram[offset] = data;
-	ram_write_enable = FALSE;
+	astrocde_state *state = space->machine().driver_data<astrocde_state>();
+	if (state->m_ram_write_enable)
+		state->m_protected_ram[offset] = data;
+	state->m_ram_write_enable = FALSE;
 }
 
 
@@ -208,9 +204,10 @@ static WRITE8_HANDLER( seawolf2_lamps_w )
 
 static WRITE8_HANDLER( seawolf2_sound_1_w )  // Port 40
 {
-	device_t *samples = space->machine->device("samples");
-	UINT8 rising_bits = data & ~port_1_last;
-	port_1_last = data;
+	astrocde_state *state = space->machine().driver_data<astrocde_state>();
+	device_t *samples = space->machine().device("samples");
+	UINT8 rising_bits = data & ~state->m_port_1_last;
+	state->m_port_1_last = data;
 
 	if (rising_bits & 0x01) sample_start(samples, 1, 1, 0);  /* Left Torpedo */
 	if (rising_bits & 0x02) sample_start(samples, 0, 0, 0);  /* Left Ship Hit */
@@ -223,9 +220,10 @@ static WRITE8_HANDLER( seawolf2_sound_1_w )  // Port 40
 
 static WRITE8_HANDLER( seawolf2_sound_2_w )  // Port 41
 {
-	device_t *samples = space->machine->device("samples");
-	UINT8 rising_bits = data & ~port_2_last;
-	port_2_last = data;
+	astrocde_state *state = space->machine().driver_data<astrocde_state>();
+	device_t *samples = space->machine().device("samples");
+	UINT8 rising_bits = data & ~state->m_port_2_last;
+	state->m_port_2_last = data;
 
 	sample_set_volume(samples, 0, (data & 0x80) ? 1.0 : 0.0);
 	sample_set_volume(samples, 1, (data & 0x80) ? 1.0 : 0.0);
@@ -248,7 +246,7 @@ static WRITE8_HANDLER( seawolf2_sound_2_w )  // Port 41
 	if (rising_bits & 0x10) sample_start(samples, 8, 3, 0);  /* Right Sonar */
 	if (rising_bits & 0x20) sample_start(samples, 3, 3, 0);  /* Left Sonar */
 
-	coin_counter_w(space->machine, 0, data & 0x40);    /* Coin Counter */
+	coin_counter_w(space->machine(), 0, data & 0x40);    /* Coin Counter */
 }
 
 
@@ -261,20 +259,22 @@ static WRITE8_HANDLER( seawolf2_sound_2_w )  // Port 41
 
 static CUSTOM_INPUT( ebases_trackball_r )
 {
+	astrocde_state *state = field.machine().driver_data<astrocde_state>();
 	static const char *const names[] = { "TRACKX2", "TRACKY2", "TRACKX1", "TRACKY1" };
-	return input_port_read(field->port->machine, names[input_select]);
+	return input_port_read(field.machine(), names[state->m_input_select]);
 }
 
 
 static WRITE8_HANDLER( ebases_trackball_select_w )
 {
-	input_select = data & 3;
+	astrocde_state *state = space->machine().driver_data<astrocde_state>();
+	state->m_input_select = data & 3;
 }
 
 
 static WRITE8_HANDLER( ebases_coin_w )
 {
-	coin_counter_w(space->machine, 0, data & 1);
+	coin_counter_w(space->machine(), 0, data & 1);
 }
 
 
@@ -287,9 +287,9 @@ static WRITE8_HANDLER( ebases_coin_w )
 
 static READ8_HANDLER( spacezap_io_r )
 {
-	coin_counter_w(space->machine, 0, (offset >> 8) & 1);
-	coin_counter_w(space->machine, 1, (offset >> 9) & 1);
-	return input_port_read_safe(space->machine, "P3HANDLE", 0xff);
+	coin_counter_w(space->machine(), 0, (offset >> 8) & 1);
+	coin_counter_w(space->machine(), 1, (offset >> 9) & 1);
+	return input_port_read_safe(space->machine(), "P3HANDLE", 0xff);
 }
 
 
@@ -302,17 +302,18 @@ static READ8_HANDLER( spacezap_io_r )
 
 static READ8_HANDLER( wow_io_r )
 {
+	astrocde_state *state = space->machine().driver_data<astrocde_state>();
 	UINT8 data = (offset >> 8) & 1;
 
 	switch ((offset >> 9) & 7)
 	{
-		case 0: coin_counter_w(space->machine, 0, data);		break;
-		case 1: coin_counter_w(space->machine, 1, data);		break;
-		case 2: astrocade_sparkle[0] = data;	break;
-		case 3: astrocade_sparkle[1] = data;	break;
-		case 4: astrocade_sparkle[2] = data;	break;
-		case 5: astrocade_sparkle[3] = data;	break;
-		case 7: coin_counter_w(space->machine, 2, data);		break;
+		case 0: coin_counter_w(space->machine(), 0, data);		break;
+		case 1: coin_counter_w(space->machine(), 1, data);		break;
+		case 2: state->m_sparkle[0] = data;	break;
+		case 3: state->m_sparkle[1] = data;	break;
+		case 4: state->m_sparkle[2] = data;	break;
+		case 5: state->m_sparkle[3] = data;	break;
+		case 7: coin_counter_w(space->machine(), 2, data);		break;
 	}
 	return 0xff;
 }
@@ -327,19 +328,20 @@ static READ8_HANDLER( wow_io_r )
 
 static READ8_HANDLER( gorf_io_1_r )
 {
+	astrocde_state *state = space->machine().driver_data<astrocde_state>();
 	UINT8 data = (offset >> 8) & 1;
 
 	switch ((offset >> 9) & 7)
 	{
-		case 0: coin_counter_w(space->machine, 0, data);		break;
-		case 1: coin_counter_w(space->machine, 1, data);		break;
-		case 2: astrocade_sparkle[0] = data;	break;
-		case 3: astrocade_sparkle[1] = data;	break;
-		case 4: astrocade_sparkle[2] = data;	break;
-		case 5: astrocade_sparkle[3] = data;	break;
+		case 0: coin_counter_w(space->machine(), 0, data);		break;
+		case 1: coin_counter_w(space->machine(), 1, data);		break;
+		case 2: state->m_sparkle[0] = data;	break;
+		case 3: state->m_sparkle[1] = data;	break;
+		case 4: state->m_sparkle[2] = data;	break;
+		case 5: state->m_sparkle[3] = data;	break;
 		case 6:
-			sound_set_output_gain(space->machine->device("astrocade1"), 0, data ? 0.0 : 1.0);
-			sound_set_output_gain(space->machine->device("samples"), 0, data ? 1.0 : 0.0);
+			space->machine().device<astrocade_device>("astrocade1")->set_output_gain(0, data ? 0.0 : 1.0);
+			space->machine().device<samples_device>("samples")->set_output_gain(0, data ? 1.0 : 0.0);
 			break;
 		case 7:	mame_printf_debug("io_1:%d\n", data); break;
 	}
@@ -379,11 +381,11 @@ static READ8_HANDLER( robby_io_r )
 
 	switch ((offset >> 9) & 7)
 	{
-		case 0: coin_counter_w(space->machine, 0, data);	break;
-		case 1: coin_counter_w(space->machine, 1, data);	break;
-		case 2: coin_counter_w(space->machine, 2, data);	break;
-		case 6: set_led_status(space->machine, 0, data);	break;
-		case 7: set_led_status(space->machine, 1, data);	break;
+		case 0: coin_counter_w(space->machine(), 0, data);	break;
+		case 1: coin_counter_w(space->machine(), 1, data);	break;
+		case 2: coin_counter_w(space->machine(), 2, data);	break;
+		case 6: set_led_status(space->machine(), 0, data);	break;
+		case 7: set_led_status(space->machine(), 1, data);	break;
 	}
 	return 0xff;
 }
@@ -398,10 +400,10 @@ static READ8_HANDLER( robby_io_r )
 
 static READ8_HANDLER( profpac_io_1_r )
 {
-	coin_counter_w(space->machine, 0, (offset >> 8) & 1);
-	coin_counter_w(space->machine, 1, (offset >> 9) & 1);
-	set_led_status(space->machine, 0, (offset >> 10) & 1);
-	set_led_status(space->machine, 1, (offset >> 11) & 1);
+	coin_counter_w(space->machine(), 0, (offset >> 8) & 1);
+	coin_counter_w(space->machine(), 1, (offset >> 9) & 1);
+	set_led_status(space->machine(), 0, (offset >> 10) & 1);
+	set_led_status(space->machine(), 1, (offset >> 11) & 1);
 	return 0xff;
 }
 
@@ -420,24 +422,25 @@ static READ8_HANDLER( profpac_io_2_r )
 
 static WRITE8_HANDLER( profpac_banksw_w )
 {
+	astrocde_state *state = space->machine().driver_data<astrocde_state>();
 	int bank = (data >> 5) & 3;
 
 	/* this is accessed from I/O space but modifies program space, so we normalize here */
-	space = cpu_get_address_space(space->cpu, ADDRESS_SPACE_PROGRAM);
+	space = space->device().memory().space(AS_PROGRAM);
 
 	/* remember the banking bits for save state support */
-	profpac_bank = data;
+	state->m_profpac_bank = data;
 
 	/* set the main banking */
-	memory_install_read_bank(space, 0x4000, 0xbfff, 0, 0, "bank1");
-	memory_set_bankptr(space->machine, "bank1", space->machine->region("user1")->base() + 0x8000 * bank);
+	space->install_read_bank(0x4000, 0xbfff, "bank1");
+	memory_set_bankptr(space->machine(), "bank1", space->machine().region("user1")->base() + 0x8000 * bank);
 
 	/* bank 0 reads video RAM in the 4000-7FFF range */
 	if (bank == 0)
-		memory_install_read8_handler(space, 0x4000, 0x7fff, 0, 0, profpac_videoram_r);
+		space->install_legacy_read_handler(0x4000, 0x7fff, FUNC(profpac_videoram_r));
 
 	/* if we have a 640k EPROM board, map that on top of the 4000-7FFF range if specified */
-	if ((data & 0x80) && space->machine->region("user2")->base() != NULL)
+	if ((data & 0x80) && space->machine().region("user2")->base() != NULL)
 	{
 		/* Note: There is a jumper which could change the base offset to 0xa8 instead */
 		bank = data - 0x80;
@@ -445,20 +448,21 @@ static WRITE8_HANDLER( profpac_banksw_w )
 		/* if the bank is in range, map the appropriate bank */
 		if (bank < 0x28)
 		{
-			memory_install_read_bank(space, 0x4000, 0x7fff, 0, 0, "bank2");
-			memory_set_bankptr(space->machine, "bank2", space->machine->region("user2")->base() + 0x4000 * bank);
+			space->install_read_bank(0x4000, 0x7fff, "bank2");
+			memory_set_bankptr(space->machine(), "bank2", space->machine().region("user2")->base() + 0x4000 * bank);
 		}
 		else
-			memory_unmap_read(space, 0x4000, 0x7fff, 0, 0);
+			space->unmap_read(0x4000, 0x7fff);
 	}
 }
 
 
-static STATE_POSTLOAD( profbank_banksw_restore )
+static void profbank_banksw_restore(running_machine &machine)
 {
-	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	astrocde_state *state = machine.driver_data<astrocde_state>();
+	address_space *space = machine.device("maincpu")->memory().space(AS_IO);
 
-	profpac_banksw_w(space, 0, profpac_bank);
+	profpac_banksw_w(space, 0, state->m_profpac_bank);
 }
 
 
@@ -471,19 +475,21 @@ static STATE_POSTLOAD( profbank_banksw_restore )
 
 static READ8_HANDLER( demndrgn_io_r )
 {
-	coin_counter_w(space->machine, 0, (offset >> 8) & 1);
-	coin_counter_w(space->machine, 1, (offset >> 9) & 1);
-	set_led_status(space->machine, 0, (offset >> 10) & 1);
-	set_led_status(space->machine, 1, (offset >> 11) & 1);
-	input_select = (offset >> 12) & 1;
+	astrocde_state *state = space->machine().driver_data<astrocde_state>();
+	coin_counter_w(space->machine(), 0, (offset >> 8) & 1);
+	coin_counter_w(space->machine(), 1, (offset >> 9) & 1);
+	set_led_status(space->machine(), 0, (offset >> 10) & 1);
+	set_led_status(space->machine(), 1, (offset >> 11) & 1);
+	state->m_input_select = (offset >> 12) & 1;
 	return 0xff;
 }
 
 
 static CUSTOM_INPUT( demndragn_joystick_r )
 {
+	astrocde_state *state = field.machine().driver_data<astrocde_state>();
 	static const char *const names[] = { "MOVEX", "MOVEY" };
-	return input_port_read(field->port->machine, names[input_select]);
+	return input_port_read(field.machine(), names[state->m_input_select]);
 }
 
 
@@ -524,7 +530,7 @@ static const ay8910_interface ay8912_interface =
 static WRITE8_HANDLER( tenpindx_sound_w )
 {
 	soundlatch_w(space, offset, data);
-	cputag_set_input_line(space->machine, "sub", INPUT_LINE_NMI, PULSE_LINE);
+	cputag_set_input_line(space->machine(), "sub", INPUT_LINE_NMI, PULSE_LINE);
 }
 
 
@@ -552,7 +558,7 @@ static WRITE8_HANDLER( tenpindx_lamp_w )
 
 static WRITE8_HANDLER( tenpindx_counter_w )
 {
-	coin_counter_w(space->machine, 0, (data >> 0) & 1);
+	coin_counter_w(space->machine(), 0, (data >> 0) & 1);
 	if (data & 0xfc) mame_printf_debug("tenpindx_counter_w = %02X\n", data);
 }
 
@@ -581,64 +587,64 @@ static WRITE8_HANDLER( tenpindx_lights_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( seawolf2_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( seawolf2_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(astrocade_funcgen_w)
-	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, videoram)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, m_videoram)
 	AM_RANGE(0xc000, 0xc3ff) AM_RAM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( ebases_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( ebases_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(astrocade_funcgen_w)
-	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, videoram)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, m_videoram)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( spacezap_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( spacezap_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(astrocade_funcgen_w)
-	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, videoram)
-	AM_RANGE(0xd000, 0xd03f) AM_READWRITE(protected_ram_r, protected_ram_w) AM_BASE(&protected_ram)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, m_videoram)
+	AM_RANGE(0xd000, 0xd03f) AM_READWRITE(protected_ram_r, protected_ram_w) AM_BASE_MEMBER(astrocde_state, m_protected_ram)
 	AM_RANGE(0xd040, 0xd7ff) AM_RAM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( wow_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( wow_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(astrocade_funcgen_w)
-	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, videoram)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, m_videoram)
 	AM_RANGE(0x8000, 0xcfff) AM_ROM
-	AM_RANGE(0xd000, 0xd03f) AM_READWRITE(protected_ram_r, protected_ram_w) AM_BASE(&protected_ram)
+	AM_RANGE(0xd000, 0xd03f) AM_READWRITE(protected_ram_r, protected_ram_w) AM_BASE_MEMBER(astrocde_state, m_protected_ram)
 	AM_RANGE(0xd040, 0xdfff) AM_RAM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( robby_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( robby_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(astrocade_funcgen_w)
-	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, videoram)
+	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE_MEMBER(astrocde_state, m_videoram)
 	AM_RANGE(0x8000, 0xdfff) AM_ROM
-	AM_RANGE(0xe000, 0xe1ff) AM_READWRITE(protected_ram_r, protected_ram_w) AM_BASE(&protected_ram)
+	AM_RANGE(0xe000, 0xe1ff) AM_READWRITE(protected_ram_r, protected_ram_w) AM_BASE_MEMBER(astrocde_state, m_protected_ram)
 	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0xe800, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( profpac_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( profpac_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(astrocade_funcgen_w)
 	AM_RANGE(0x4000, 0x7fff) AM_READWRITE(profpac_videoram_r, profpac_videoram_w)
 	AM_RANGE(0x4000, 0xbfff) AM_ROMBANK("bank1")
 	AM_RANGE(0xc000, 0xdfff) AM_ROM
-	AM_RANGE(0xe000, 0xe1ff) AM_READWRITE(protected_ram_r, protected_ram_w) AM_BASE(&protected_ram)
+	AM_RANGE(0xe000, 0xe1ff) AM_READWRITE(protected_ram_r, protected_ram_w) AM_BASE_MEMBER(astrocde_state, m_protected_ram)
 	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0xe800, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( demndrgn_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( demndrgn_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x0000, 0x3fff) AM_WRITE(astrocade_funcgen_w)
 	AM_RANGE(0x4000, 0x7fff) AM_READWRITE(profpac_videoram_r, profpac_videoram_w)
@@ -649,7 +655,7 @@ static ADDRESS_MAP_START( demndrgn_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( tenpin_sub_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( tenpin_sub_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x8000, 0x87ff) AM_RAM
 	AM_RANGE(0xc000, 0xc7ff) AM_RAM
@@ -663,19 +669,19 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( port_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( port_map, AS_IO, 8 )
 	AM_RANGE(0x0000, 0x0019) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_READWRITE(astrocade_data_chip_register_r, astrocade_data_chip_register_w)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( port_map_mono_pattern, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( port_map_mono_pattern, AS_IO, 8 )
 	AM_RANGE(0x0000, 0x0019) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_READWRITE(astrocade_data_chip_register_r, astrocade_data_chip_register_w)
 	AM_RANGE(0x0078, 0x007e) AM_MIRROR(0xff00) AM_WRITE(astrocade_pattern_board_w)
 	AM_RANGE(0xa55b, 0xa55b) AM_WRITE(protected_ram_enable_w)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( port_map_stereo_pattern, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( port_map_stereo_pattern, AS_IO, 8 )
 	AM_RANGE(0x0000, 0x0019) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_READWRITE(astrocade_data_chip_register_r, astrocade_data_chip_register_w)
 	AM_RANGE(0x0050, 0x0058) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_DEVWRITE("astrocade2", astrocade_sound_w)
 	AM_RANGE(0x0078, 0x007e) AM_MIRROR(0xff00) AM_WRITE(astrocade_pattern_board_w)
@@ -683,7 +689,7 @@ static ADDRESS_MAP_START( port_map_stereo_pattern, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( port_map_16col_pattern, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( port_map_16col_pattern, AS_IO, 8 )
 	AM_RANGE(0x0000, 0x0019) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_READWRITE(astrocade_data_chip_register_r, astrocade_data_chip_register_w)
 	AM_RANGE(0x0050, 0x0058) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_DEVWRITE("astrocade2", astrocade_sound_w)
 	AM_RANGE(0x0078, 0x007e) AM_MIRROR(0xff00) AM_WRITE(astrocade_pattern_board_w)
@@ -695,7 +701,7 @@ static ADDRESS_MAP_START( port_map_16col_pattern, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( port_map_16col_pattern_nosound, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( port_map_16col_pattern_nosound, AS_IO, 8 )
 	AM_RANGE(0x0000, 0x0019) AM_MIRROR(0xff00) AM_MASK(0xffff) AM_READWRITE(astrocade_data_chip_register_r, astrocade_data_chip_register_w)
 	AM_RANGE(0x0078, 0x007e) AM_MIRROR(0xff00) AM_WRITE(astrocade_pattern_board_w)
 	AM_RANGE(0x00bf, 0x00bf) AM_MIRROR(0xff00) AM_WRITE(profpac_page_select_w)
@@ -706,7 +712,7 @@ static ADDRESS_MAP_START( port_map_16col_pattern_nosound, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( tenpin_sub_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( tenpin_sub_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x90, 0x93) AM_DEVREADWRITE("ctc", z80ctc_r, z80ctc_w)
 	AM_RANGE(0x97, 0x97) AM_READ(soundlatch_r)
@@ -833,9 +839,18 @@ static INPUT_PORTS_START( ebases )
 INPUT_PORTS_END
 
 
+static INPUT_CHANGED( spacezap_monitor )
+{
+	astrocde_state *state = field.machine().driver_data<astrocde_state>();
+	if (newval)
+		state->m_video_config &= ~AC_MONITOR_BW;
+	else
+		state->m_video_config |= AC_MONITOR_BW;
+}
+
 static INPUT_PORTS_START( spacezap )
 	PORT_START("P1HANDLE")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )	// manual says this dip is unused on cocktail cabs
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_TILT )
 	PORT_SERVICE( 0x08, IP_ACTIVE_LOW )
@@ -844,19 +859,19 @@ static INPUT_PORTS_START( spacezap )
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
 
 	PORT_START("P2HANDLE")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_4WAY PORT_COCKTAIL
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_4WAY PORT_COCKTAIL
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_4WAY PORT_COCKTAIL
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_4WAY PORT_COCKTAIL
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL PORT_NAME("P2 Aim Up")
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_COCKTAIL PORT_NAME("P2 Aim Down")
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_COCKTAIL PORT_NAME("P2 Aim Left")
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_BUTTON5 ) PORT_COCKTAIL PORT_NAME("P2 Aim Right")
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
 	PORT_DIPUNUSED_DIPLOC( 0x20, 0x20, "JU:1" )
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
 
 	PORT_START("P3HANDLE")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_4WAY
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_4WAY
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_4WAY
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_4WAY
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_NAME("P1 Aim Up") PORT_CODE(KEYCODE_UP)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_NAME("P1 Aim Down") PORT_CODE(KEYCODE_DOWN)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_NAME("P1 Aim Left") PORT_CODE(KEYCODE_LEFT)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_BUTTON5 ) PORT_NAME("P1 Aim Right") PORT_CODE(KEYCODE_RIGHT)
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Cabinet ) )	PORT_DIPLOCATION("JU:2")
 	PORT_DIPSETTING(    0x20, DEF_STR( Upright ) )
@@ -877,6 +892,13 @@ static INPUT_PORTS_START( spacezap )
 	PORT_DIPUNUSED_DIPLOC( 0x20, 0x00, "S1:6" )
 	PORT_DIPUNUSED_DIPLOC( 0x40, 0x00, "S1:7" )
 	PORT_DIPUNUSED_DIPLOC( 0x80, 0x00, "S1:8" )
+
+	PORT_START("FAKE")
+	/* Dedicated cabinets had a B/W monitor and color overlay,
+       some (unofficial/repaired?) cabinets had a color monitor. */
+	PORT_CONFNAME( 0x01, 0x00, "Monitor" ) PORT_CHANGED(spacezap_monitor, 0)
+	PORT_CONFSETTING(    0x00, "B/W" )
+	PORT_CONFSETTING(    0x01, "Color" )
 INPUT_PORTS_END
 
 
@@ -1286,10 +1308,10 @@ static MACHINE_CONFIG_START( astrocade_base, astrocde_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_RAW_PARAMS(ASTROCADE_CLOCK, 455, 0, 352, 262, 0, 240)
 	MCFG_SCREEN_DEFAULT_POSITION(1.1, 0.0, 1.18, -0.018)	/* clip out borders */
+	MCFG_SCREEN_UPDATE(astrocde)
 
 	MCFG_PALETTE_INIT(astrocde)
 	MCFG_VIDEO_START(astrocde)
-	MCFG_VIDEO_UPDATE(astrocde)
 MACHINE_CONFIG_END
 
 
@@ -1303,7 +1325,9 @@ static MACHINE_CONFIG_DERIVED( astrocade_16color_base, astrocade_base )
 
 	MCFG_PALETTE_INIT(profpac)
 	MCFG_VIDEO_START(profpac)
-	MCFG_VIDEO_UPDATE(profpac)
+
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_UPDATE(profpac)
 MACHINE_CONFIG_END
 
 
@@ -1709,100 +1733,109 @@ ROM_END
 
 static DRIVER_INIT( seawolf2 )
 {
-	astrocade_video_config = 0x00;
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x40, 0x40, 0, 0xff18, seawolf2_sound_1_w);
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x41, 0x41, 0, 0xff18, seawolf2_sound_2_w);
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x42, 0x43, 0, 0xff18, seawolf2_lamps_w);
+	astrocde_state *state = machine.driver_data<astrocde_state>();
+	state->m_video_config = 0x00;
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_write_handler(0x40, 0x40, 0, 0xff18, FUNC(seawolf2_sound_1_w));
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_write_handler(0x41, 0x41, 0, 0xff18, FUNC(seawolf2_sound_2_w));
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_write_handler(0x42, 0x43, 0, 0xff18, FUNC(seawolf2_lamps_w));
 }
 
 
 static DRIVER_INIT( ebases )
 {
-	astrocade_video_config = AC_SOUND_PRESENT;
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x20, 0x20, 0, 0xff07, ebases_coin_w);
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x28, 0x28, 0, 0xff07, ebases_trackball_select_w);
+	astrocde_state *state = machine.driver_data<astrocde_state>();
+	state->m_video_config = AC_SOUND_PRESENT;
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_write_handler(0x20, 0x20, 0, 0xff07, FUNC(ebases_coin_w));
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_write_handler(0x28, 0x28, 0, 0xff07, FUNC(ebases_trackball_select_w));
 }
 
 
 static DRIVER_INIT( spacezap )
 {
-	astrocade_video_config = AC_SOUND_PRESENT;
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x13, 0x13, 0x03ff, 0xff00, spacezap_io_r);
+	astrocde_state *state = machine.driver_data<astrocde_state>();
+	state->m_video_config = AC_SOUND_PRESENT | AC_MONITOR_BW;
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x13, 0x13, 0x03ff, 0xff00, FUNC(spacezap_io_r));
 }
 
 
 static DRIVER_INIT( wow )
 {
-	astrocade_video_config = AC_SOUND_PRESENT | AC_LIGHTPEN_INTS | AC_STARS;
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x15, 0x15, 0x0fff, 0xff00, wow_io_r);
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x17, 0x17, 0xffff, 0xff00, wow_speech_r);
+	astrocde_state *state = machine.driver_data<astrocde_state>();
+	state->m_video_config = AC_SOUND_PRESENT | AC_LIGHTPEN_INTS | AC_STARS;
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x15, 0x15, 0x0fff, 0xff00, FUNC(wow_io_r));
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x17, 0x17, 0xffff, 0xff00, FUNC(wow_speech_r));
 }
 
 
 static DRIVER_INIT( gorf )
 {
-	astrocade_video_config = AC_SOUND_PRESENT | AC_LIGHTPEN_INTS | AC_STARS;
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x15, 0x15, 0x0fff, 0xff00, gorf_io_1_r);
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x16, 0x16, 0x0fff, 0xff00, gorf_io_2_r);
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x17, 0x17, 0xffff, 0xff00, gorf_speech_r);
+	astrocde_state *state = machine.driver_data<astrocde_state>();
+	state->m_video_config = AC_SOUND_PRESENT | AC_LIGHTPEN_INTS | AC_STARS;
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x15, 0x15, 0x0fff, 0xff00, FUNC(gorf_io_1_r));
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x16, 0x16, 0x0fff, 0xff00, FUNC(gorf_io_2_r));
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x17, 0x17, 0xffff, 0xff00, FUNC(gorf_speech_r));
 }
 
 
 static DRIVER_INIT( robby )
 {
-	astrocade_video_config = AC_SOUND_PRESENT;
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x15, 0x15, 0x0fff, 0xff00, robby_io_r);
+	astrocde_state *state = machine.driver_data<astrocde_state>();
+	state->m_video_config = AC_SOUND_PRESENT;
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x15, 0x15, 0x0fff, 0xff00, FUNC(robby_io_r));
 }
 
 
 static DRIVER_INIT( profpac )
 {
-	address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	astrocde_state *state = machine.driver_data<astrocde_state>();
+	address_space *iospace = machine.device("maincpu")->memory().space(AS_IO);
 
-	astrocade_video_config = AC_SOUND_PRESENT;
-	memory_install_read8_handler(iospace, 0x14, 0x14, 0x0fff, 0xff00, profpac_io_1_r);
-	memory_install_read8_handler(iospace, 0x15, 0x15, 0x77ff, 0xff00, profpac_io_2_r);
+	state->m_video_config = AC_SOUND_PRESENT;
+	iospace->install_legacy_read_handler(0x14, 0x14, 0x0fff, 0xff00, FUNC(profpac_io_1_r));
+	iospace->install_legacy_read_handler(0x15, 0x15, 0x77ff, 0xff00, FUNC(profpac_io_2_r));
 
 	/* reset banking */
 	profpac_banksw_w(iospace, 0, 0);
-	state_save_register_postload(machine, profbank_banksw_restore, NULL);
+	machine.save().register_postload(save_prepost_delegate(FUNC(profbank_banksw_restore), &machine));
 }
 
 
 static DRIVER_INIT( demndrgn )
 {
-	address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	astrocde_state *state = machine.driver_data<astrocde_state>();
+	address_space *iospace = machine.device("maincpu")->memory().space(AS_IO);
 
-	astrocade_video_config = 0x00;
-	memory_install_read8_handler(iospace, 0x14, 0x14, 0x1fff, 0xff00, demndrgn_io_r);
-	memory_install_read_port(iospace, 0x1c, 0x1c, 0x0000, 0xff00, "FIREX");
-	memory_install_read_port(iospace, 0x1d, 0x1d, 0x0000, 0xff00, "FIREY");
-	memory_install_write8_handler(iospace, 0x97, 0x97, 0x0000, 0xff00, demndrgn_sound_w);
+	state->m_video_config = 0x00;
+	iospace->install_legacy_read_handler(0x14, 0x14, 0x1fff, 0xff00, FUNC(demndrgn_io_r));
+	iospace->install_read_port(0x1c, 0x1c, 0x0000, 0xff00, "FIREX");
+	iospace->install_read_port(0x1d, 0x1d, 0x0000, 0xff00, "FIREY");
+	iospace->install_legacy_write_handler(0x97, 0x97, 0x0000, 0xff00, FUNC(demndrgn_sound_w));
 
 	/* reset banking */
 	profpac_banksw_w(iospace, 0, 0);
-	state_save_register_postload(machine, profbank_banksw_restore, NULL);
+	machine.save().register_postload(save_prepost_delegate(FUNC(profbank_banksw_restore), &machine));
 }
 
 
 static DRIVER_INIT( tenpindx )
 {
-	address_space *iospace = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO);
+	astrocde_state *state = machine.driver_data<astrocde_state>();
+	address_space *iospace = machine.device("maincpu")->memory().space(AS_IO);
 
-	astrocade_video_config = 0x00;
-	memory_install_read_port(iospace, 0x60, 0x60, 0x0000, 0xff00, "P60");
-	memory_install_read_port(iospace, 0x61, 0x61, 0x0000, 0xff00, "P61");
-	memory_install_read_port(iospace, 0x62, 0x62, 0x0000, 0xff00, "P62");
-	memory_install_read_port(iospace, 0x63, 0x63, 0x0000, 0xff00, "P63");
-	memory_install_read_port(iospace, 0x64, 0x64, 0x0000, 0xff00, "P64");
-	memory_install_write8_handler(iospace, 0x65, 0x66, 0x0000, 0xff00, tenpindx_lamp_w);
-	memory_install_write8_handler(iospace, 0x67, 0x67, 0x0000, 0xff00, tenpindx_counter_w);
-	memory_install_write8_handler(iospace, 0x68, 0x68, 0x0000, 0xff00, tenpindx_lights_w);
-	memory_install_write8_handler(iospace, 0x97, 0x97, 0x0000, 0xff00, tenpindx_sound_w);
+	state->m_video_config = 0x00;
+	iospace->install_read_port(0x60, 0x60, 0x0000, 0xff00, "P60");
+	iospace->install_read_port(0x61, 0x61, 0x0000, 0xff00, "P61");
+	iospace->install_read_port(0x62, 0x62, 0x0000, 0xff00, "P62");
+	iospace->install_read_port(0x63, 0x63, 0x0000, 0xff00, "P63");
+	iospace->install_read_port(0x64, 0x64, 0x0000, 0xff00, "P64");
+	iospace->install_legacy_write_handler(0x65, 0x66, 0x0000, 0xff00, FUNC(tenpindx_lamp_w));
+	iospace->install_legacy_write_handler(0x67, 0x67, 0x0000, 0xff00, FUNC(tenpindx_counter_w));
+	iospace->install_legacy_write_handler(0x68, 0x68, 0x0000, 0xff00, FUNC(tenpindx_lights_w));
+	iospace->install_legacy_write_handler(0x97, 0x97, 0x0000, 0xff00, FUNC(tenpindx_sound_w));
 
 	/* reset banking */
 	profpac_banksw_w(iospace, 0, 0);
-	state_save_register_postload(machine, profbank_banksw_restore, NULL);
+	machine.save().register_postload(save_prepost_delegate(FUNC(profbank_banksw_restore), &machine));
 }
 
 
@@ -1839,4 +1872,4 @@ GAME( 1983, profpac,  0,    profpac,  profpac,  profpac,  ROT0,   "Bally Midway"
 
 /* 91465 CPU board + 91699 game board + 91466 RAM board + 91488 pattern board + 91467 memory board */
 GAME( 1982, demndrgn, 0,    demndrgn, demndrgn, demndrgn, ROT0,   "Bally Midway", "Demons & Dragons (prototype)", GAME_NO_SOUND | GAME_SUPPORTS_SAVE )
-GAMEL(1983, tenpindx, 0,    tenpindx, tenpindx, tenpindx, ROT0,   "Bally Midway", "Ten Pin Deluxe", GAME_NOT_WORKING | GAME_SUPPORTS_SAVE, layout_tenpindx )
+GAMEL(1983, tenpindx, 0,    tenpindx, tenpindx, tenpindx, ROT0,   "Bally Midway", "Ten Pin Deluxe", GAME_NOT_WORKING | GAME_SUPPORTS_SAVE | GAME_MECHANICAL, layout_tenpindx )
