@@ -5,7 +5,7 @@
                                        driver by   Luca Elia (l.elia@tin.it)
 
 CPU:    68000
-GFX:    ASTRO V0x (x = 1,2,5 or 6)
+GFX:    ASTRO V0x (x = 1,2,5,6 or 7)
 SOUND:  OKI M6295 (AD-65)
 OTHER:  EEPROM, Battery
 
@@ -20,6 +20,7 @@ Year + Game          PCB ID         CPU                Video      Chips
 03  Speed Drop       None           JX-1689HP          ASTRO V05  pLSI1016-60LJ
 05? Zoo              M1.1           ASTRO V102PX-005?  ASTRO V06  ASTRO F02 2005-02-18                    Encrypted
 05? Win Win Bingo    M1.2           ASTRO V102PX-006?  ASTRO V06  ASTRO F02 2005-09-17                    Encrypted
+07? Western Venture  CS350P032      ASTRO V102?        ASTRO V07  ASTRO F01 2007-06-03                    Encrypted
 -------------------------------------------------------------------------------------------------------------------
 
 To do:
@@ -39,18 +40,18 @@ To do:
 class astrocorp_state : public driver_device
 {
 public:
-	astrocorp_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	astrocorp_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT16 *   spriteram;
-	UINT16 *   paletteram;
-	size_t     spriteram_size;
+	UINT16 *   m_spriteram;
+	UINT16 *   m_paletteram;
+	size_t     m_spriteram_size;
 
 	/* video-related */
-	bitmap_t * bitmap;
-	UINT16     screen_enable;
-	UINT16     draw_sprites;
+	bitmap_t * m_bitmap;
+	UINT16     m_screen_enable;
+	UINT16     m_draw_sprites;
 };
 
 /***************************************************************************
@@ -59,13 +60,13 @@ public:
 
 static VIDEO_START( astrocorp )
 {
-	astrocorp_state *state = machine->driver_data<astrocorp_state>();
+	astrocorp_state *state = machine.driver_data<astrocorp_state>();
 
-	state->bitmap = machine->primary_screen->alloc_compatible_bitmap();
+	state->m_bitmap = machine.primary_screen->alloc_compatible_bitmap();
 
-	state_save_register_global_bitmap(machine, state->bitmap);
-	state_save_register_global       (machine, state->screen_enable);
-	state_save_register_global       (machine, state->draw_sprites);
+	state->save_item(NAME(*state->m_bitmap));
+	state->save_item       (NAME(state->m_screen_enable));
+	state->save_item       (NAME(state->m_draw_sprites));
 }
 
 /***************************************************************************
@@ -90,11 +91,11 @@ static VIDEO_START( astrocorp )
 
 ***************************************************************************/
 
-static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect )
+static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect )
 {
-	astrocorp_state *state = machine->driver_data<astrocorp_state>();
-	UINT16 *source = state->spriteram;
-	UINT16 *finish = state->spriteram + state->spriteram_size / 2;
+	astrocorp_state *state = machine.driver_data<astrocorp_state>();
+	UINT16 *source = state->m_spriteram;
+	UINT16 *finish = state->m_spriteram + state->m_spriteram_size / 2;
 
 	for ( ; source < finish; source += 8 / 2 )
 	{
@@ -126,7 +127,7 @@ static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rect
 				{
 					for (xwrap = 0 ; xwrap <= 0x200 ; xwrap += 0x200)
 					{
-						drawgfx_transpen(bitmap,cliprect, machine->gfx[0],
+						drawgfx_transpen(bitmap,cliprect, machine.gfx[0],
 								code, 0,
 								0, 0,
 								sx + x * 16 - xwrap, sy + y * 16 - ywrap, 0xff);
@@ -138,14 +139,14 @@ static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rect
 	}
 }
 
-static VIDEO_UPDATE(astrocorp)
+static SCREEN_UPDATE(astrocorp)
 {
-	astrocorp_state *state = screen->machine->driver_data<astrocorp_state>();
+	astrocorp_state *state = screen->machine().driver_data<astrocorp_state>();
 
-	if (state->screen_enable & 1)
-		copybitmap(bitmap, state->bitmap, 0,0,0,0, cliprect);
+	if (state->m_screen_enable & 1)
+		copybitmap(bitmap, state->m_bitmap, 0,0,0,0, cliprect);
 	else
-		bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+		bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine()));
 
 	return 0;
 }
@@ -157,20 +158,20 @@ static VIDEO_UPDATE(astrocorp)
 
 static WRITE16_HANDLER( astrocorp_draw_sprites_w )
 {
-	astrocorp_state *state = space->machine->driver_data<astrocorp_state>();
+	astrocorp_state *state = space->machine().driver_data<astrocorp_state>();
 
-	UINT16 old = state->draw_sprites;
-	UINT16 now = COMBINE_DATA(&state->draw_sprites);
+	UINT16 old = state->m_draw_sprites;
+	UINT16 now = COMBINE_DATA(&state->m_draw_sprites);
 
 	if (!old && now)
-		draw_sprites(space->machine, state->bitmap, &space->machine->primary_screen->visible_area());
+		draw_sprites(space->machine(), state->m_bitmap, &space->machine().primary_screen->visible_area());
 }
 
 static WRITE16_HANDLER( astrocorp_eeprom_w )
 {
 	if (ACCESSING_BITS_0_7)
 	{
-		input_port_write(space->machine, "EEPROMOUT", data, 0xff);
+		input_port_write(space->machine(), "EEPROMOUT", data, 0xff);
 	}
 }
 
@@ -180,7 +181,7 @@ static WRITE16_DEVICE_HANDLER( astrocorp_sound_bank_w )
 	{
 		okim6295_device *oki = downcast<okim6295_device *>(device);
 		oki->set_bank_base(0x40000 * ((data >> 8) & 1));
-//      logerror("CPU #0 PC %06X: OKI bank %08X\n", cpu_get_pc(space->cpu), data);
+//      logerror("CPU #0 PC %06X: OKI bank %08X\n", cpu_get_pc(&space->device()), data);
 	}
 }
 
@@ -190,7 +191,7 @@ static WRITE16_DEVICE_HANDLER( skilldrp_sound_bank_w )
 	{
 		okim6295_device *oki = downcast<okim6295_device *>(device);
 		oki->set_bank_base(0x40000 * (data & 1));
-//      logerror("CPU #0 PC %06X: OKI bank %08X\n", cpu_get_pc(space->cpu), data);
+//      logerror("CPU #0 PC %06X: OKI bank %08X\n", cpu_get_pc(&space->device()), data);
 	}
 }
 
@@ -198,18 +199,18 @@ static WRITE16_HANDLER( showhand_outputs_w )
 {
 	if (ACCESSING_BITS_0_7)
 	{
-		coin_counter_w(space->machine, 0,	(data & 0x0004));	// coin counter
-		set_led_status(space->machine, 0,	(data & 0x0008));	// you win
-		if ((data & 0x0010)) increment_dispensed_tickets(space->machine, 1); // coin out
-		set_led_status(space->machine, 1,	(data & 0x0020));	// coin/hopper jam
+		coin_counter_w(space->machine(), 0,	(data & 0x0004));	// coin counter
+		set_led_status(space->machine(), 0,	(data & 0x0008));	// you win
+		if ((data & 0x0010)) increment_dispensed_tickets(space->machine(), 1); // coin out
+		set_led_status(space->machine(), 1,	(data & 0x0020));	// coin/hopper jam
 	}
 	if (ACCESSING_BITS_8_15)
 	{
-		set_led_status(space->machine, 2,	(data & 0x0100));	// bet
-		set_led_status(space->machine, 3,	(data & 0x0800));	// start
-		set_led_status(space->machine, 4,	(data & 0x1000));	// ? select/choose
-		set_led_status(space->machine, 5,	(data & 0x2000));	// ? select/choose
-		set_led_status(space->machine, 6,	(data & 0x4000));	// look
+		set_led_status(space->machine(), 2,	(data & 0x0100));	// bet
+		set_led_status(space->machine(), 3,	(data & 0x0800));	// start
+		set_led_status(space->machine(), 4,	(data & 0x1000));	// ? select/choose
+		set_led_status(space->machine(), 5,	(data & 0x2000));	// ? select/choose
+		set_led_status(space->machine(), 6,	(data & 0x4000));	// look
 	}
 //  popmessage("%04X",data);
 }
@@ -234,23 +235,23 @@ static WRITE16_HANDLER( skilldrp_outputs_w )
 
 	if (ACCESSING_BITS_0_7)
 	{
-		coin_counter_w(space->machine, 0,	(data & 0x0001));	// key in  |
-		coin_counter_w(space->machine, 0,	(data & 0x0002));	// coin in |- manual shows 1 in- and 1 out- counter
-		coin_counter_w(space->machine, 1,	(data & 0x0004));	// key out |
-		ticket_dispenser_w(space->machine->device("hopper"), 0, (data & 0x0008)<<4);	// hopper motor?
+		coin_counter_w(space->machine(), 0,	(data & 0x0001));	// key in  |
+		coin_counter_w(space->machine(), 0,	(data & 0x0002));	// coin in |- manual shows 1 in- and 1 out- counter
+		coin_counter_w(space->machine(), 1,	(data & 0x0004));	// key out |
+		ticket_dispenser_w(space->machine().device("hopper"), 0, (data & 0x0008)<<4);	// hopper motor?
 		//                                  (data & 0x0010)     // hopper?
-		set_led_status(space->machine, 0,	(data & 0x0020));	// error lamp (coin/hopper jam: "call attendant")
-		ticket_dispenser_w(space->machine->device("ticket"), 0, data & 0x0080);	// ticket motor?
+		set_led_status(space->machine(), 0,	(data & 0x0020));	// error lamp (coin/hopper jam: "call attendant")
+		ticket_dispenser_w(space->machine().device("ticket"), 0, data & 0x0080);	// ticket motor?
 	}
 	if (ACCESSING_BITS_8_15)
 	{
 		// lamps:
-		set_led_status(space->machine, 1,	(data & 0x0100));	// select
-		set_led_status(space->machine, 2,	(data & 0x0400));	// take
-		set_led_status(space->machine, 3,	(data & 0x0800));	// bet
-		set_led_status(space->machine, 4,	(data & 0x1000));	// start
-		set_led_status(space->machine, 5,	(data & 0x4000));	// win / test
-		set_led_status(space->machine, 6,	(data & 0x8000));	// ticket?
+		set_led_status(space->machine(), 1,	(data & 0x0100));	// select
+		set_led_status(space->machine(), 2,	(data & 0x0400));	// take
+		set_led_status(space->machine(), 3,	(data & 0x0800));	// bet
+		set_led_status(space->machine(), 4,	(data & 0x1000));	// start
+		set_led_status(space->machine(), 5,	(data & 0x4000));	// win / test
+		set_led_status(space->machine(), 6,	(data & 0x8000));	// ticket?
 	}
 
 //  popmessage("%04X",data);
@@ -258,11 +259,11 @@ static WRITE16_HANDLER( skilldrp_outputs_w )
 
 static WRITE16_HANDLER( astrocorp_screen_enable_w )
 {
-	astrocorp_state *state = space->machine->driver_data<astrocorp_state>();
-	COMBINE_DATA(&state->screen_enable);
+	astrocorp_state *state = space->machine().driver_data<astrocorp_state>();
+	COMBINE_DATA(&state->m_screen_enable);
 //  popmessage("%04X",data);
-	if (state->screen_enable & (~1))
-		logerror("CPU #0 PC %06X: screen enable = %04X\n", cpu_get_pc(space->cpu), state->screen_enable);
+	if (state->m_screen_enable & (~1))
+		logerror("CPU #0 PC %06X: screen enable = %04X\n", cpu_get_pc(&space->device()), state->m_screen_enable);
 }
 
 static READ16_HANDLER( astrocorp_unk_r )
@@ -273,35 +274,35 @@ static READ16_HANDLER( astrocorp_unk_r )
 // 5-6-5 Palette: BBBBB-GGGGGG-RRRRR
 static WRITE16_HANDLER( astrocorp_palette_w )
 {
-	astrocorp_state *state = space->machine->driver_data<astrocorp_state>();
-	COMBINE_DATA(&state->paletteram[offset]);
-	palette_set_color_rgb(space->machine, offset,
-		pal5bit((state->paletteram[offset] >>  0) & 0x1f),
-		pal6bit((state->paletteram[offset] >>  5) & 0x3f),
-		pal5bit((state->paletteram[offset] >> 11) & 0x1f)
+	astrocorp_state *state = space->machine().driver_data<astrocorp_state>();
+	COMBINE_DATA(&state->m_paletteram[offset]);
+	palette_set_color_rgb(space->machine(), offset,
+		pal5bit((state->m_paletteram[offset] >>  0) & 0x1f),
+		pal6bit((state->m_paletteram[offset] >>  5) & 0x3f),
+		pal5bit((state->m_paletteram[offset] >> 11) & 0x1f)
 	);
 }
 
-static ADDRESS_MAP_START( showhand_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( showhand_map, AS_PROGRAM, 16 )
 	AM_RANGE( 0x000000, 0x01ffff ) AM_ROM
-	AM_RANGE( 0x050000, 0x050fff ) AM_RAM AM_BASE_SIZE_MEMBER(astrocorp_state, spriteram, spriteram_size)
+	AM_RANGE( 0x050000, 0x050fff ) AM_RAM AM_BASE_SIZE_MEMBER(astrocorp_state, m_spriteram, m_spriteram_size)
 	AM_RANGE( 0x052000, 0x052001 ) AM_WRITE(astrocorp_draw_sprites_w)
 	AM_RANGE( 0x054000, 0x054001 ) AM_READ_PORT("INPUTS")
 	AM_RANGE( 0x058000, 0x058001 ) AM_WRITE(astrocorp_eeprom_w)
 	AM_RANGE( 0x05a000, 0x05a001 ) AM_WRITE(showhand_outputs_w)
 	AM_RANGE( 0x05e000, 0x05e001 ) AM_READ_PORT("EEPROMIN")
-	AM_RANGE( 0x060000, 0x0601ff ) AM_RAM_WRITE(astrocorp_palette_w) AM_BASE_MEMBER(astrocorp_state, paletteram)
+	AM_RANGE( 0x060000, 0x0601ff ) AM_RAM_WRITE(astrocorp_palette_w) AM_BASE_MEMBER(astrocorp_state, m_paletteram)
 	AM_RANGE( 0x070000, 0x073fff ) AM_RAM AM_SHARE("nvram")	// battery
 	AM_RANGE( 0x080000, 0x080001 ) AM_DEVWRITE("oki", astrocorp_sound_bank_w)
 	AM_RANGE( 0x0a0000, 0x0a0001 ) AM_WRITE(astrocorp_screen_enable_w)
 	AM_RANGE( 0x0d0000, 0x0d0001 ) AM_READ(astrocorp_unk_r) AM_DEVWRITE8_MODERN("oki", okim6295_device, write, 0xff00)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( showhanc_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( showhanc_map, AS_PROGRAM, 16 )
 	AM_RANGE( 0x000000, 0x01ffff ) AM_ROM
-	AM_RANGE( 0x060000, 0x0601ff ) AM_RAM_WRITE(astrocorp_palette_w) AM_BASE_MEMBER(astrocorp_state, paletteram)
+	AM_RANGE( 0x060000, 0x0601ff ) AM_RAM_WRITE(astrocorp_palette_w) AM_BASE_MEMBER(astrocorp_state, m_paletteram)
 	AM_RANGE( 0x070000, 0x070001 ) AM_DEVWRITE("oki", astrocorp_sound_bank_w)
-	AM_RANGE( 0x080000, 0x080fff ) AM_RAM AM_BASE_SIZE_MEMBER(astrocorp_state, spriteram, spriteram_size)
+	AM_RANGE( 0x080000, 0x080fff ) AM_RAM AM_BASE_SIZE_MEMBER(astrocorp_state, m_spriteram, m_spriteram_size)
 	AM_RANGE( 0x082000, 0x082001 ) AM_WRITE(astrocorp_draw_sprites_w)
 	AM_RANGE( 0x084000, 0x084001 ) AM_READ_PORT("INPUTS")
 	AM_RANGE( 0x088000, 0x088001 ) AM_WRITE(astrocorp_eeprom_w)
@@ -312,31 +313,31 @@ static ADDRESS_MAP_START( showhanc_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE( 0x0e0000, 0x0e0001 ) AM_READ(astrocorp_unk_r) AM_DEVWRITE8_MODERN("oki", okim6295_device, write, 0xff00)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( skilldrp_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( skilldrp_map, AS_PROGRAM, 16 )
 	AM_RANGE( 0x000000, 0x03ffff ) AM_ROM
-	AM_RANGE( 0x200000, 0x200fff ) AM_RAM AM_BASE_SIZE_MEMBER(astrocorp_state, spriteram, spriteram_size)
+	AM_RANGE( 0x200000, 0x200fff ) AM_RAM AM_BASE_SIZE_MEMBER(astrocorp_state, m_spriteram, m_spriteram_size)
 	AM_RANGE( 0x202000, 0x202001 ) AM_WRITE(astrocorp_draw_sprites_w)
 	AM_RANGE( 0x204000, 0x204001 ) AM_READ_PORT("INPUTS")
 	AM_RANGE( 0x208000, 0x208001 ) AM_WRITE(astrocorp_eeprom_w)
 	AM_RANGE( 0x20a000, 0x20a001 ) AM_WRITE(skilldrp_outputs_w)
 	AM_RANGE( 0x20e000, 0x20e001 ) AM_READ_PORT("EEPROMIN")
-	AM_RANGE( 0x380000, 0x3801ff ) AM_RAM_WRITE(astrocorp_palette_w) AM_BASE_MEMBER(astrocorp_state, paletteram)
+	AM_RANGE( 0x380000, 0x3801ff ) AM_RAM_WRITE(astrocorp_palette_w) AM_BASE_MEMBER(astrocorp_state, m_paletteram)
 	AM_RANGE( 0x400000, 0x400001 ) AM_WRITE(astrocorp_screen_enable_w)
 	AM_RANGE( 0x500000, 0x507fff ) AM_RAM AM_SHARE("nvram")	// battery
 	AM_RANGE( 0x580000, 0x580001 ) AM_DEVWRITE("oki", skilldrp_sound_bank_w)
 	AM_RANGE( 0x600000, 0x600001 ) AM_DEVREADWRITE8_MODERN("oki", okim6295_device, read, write, 0x00ff)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( speeddrp_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( speeddrp_map, AS_PROGRAM, 16 )
 	AM_RANGE( 0x000000, 0x01ffff ) AM_ROM
 	AM_RANGE( 0x280000, 0x283fff ) AM_RAM AM_SHARE("nvram")	// battery
-	AM_RANGE( 0x380000, 0x380fff ) AM_RAM AM_BASE_SIZE_MEMBER(astrocorp_state, spriteram, spriteram_size)
+	AM_RANGE( 0x380000, 0x380fff ) AM_RAM AM_BASE_SIZE_MEMBER(astrocorp_state, m_spriteram, m_spriteram_size)
 	AM_RANGE( 0x382000, 0x382001 ) AM_WRITE(astrocorp_draw_sprites_w)
 	AM_RANGE( 0x384000, 0x384001 ) AM_READ_PORT("INPUTS")
 	AM_RANGE( 0x388000, 0x388001 ) AM_WRITE(astrocorp_eeprom_w)
 	AM_RANGE( 0x38a000, 0x38a001 ) AM_WRITE(skilldrp_outputs_w)
 	AM_RANGE( 0x38e000, 0x38e001 ) AM_READ_PORT("EEPROMIN")
-	AM_RANGE( 0x480000, 0x4801ff ) AM_RAM_WRITE(astrocorp_palette_w) AM_BASE_MEMBER(astrocorp_state, paletteram)
+	AM_RANGE( 0x480000, 0x4801ff ) AM_RAM_WRITE(astrocorp_palette_w) AM_BASE_MEMBER(astrocorp_state, m_paletteram)
 	AM_RANGE( 0x500000, 0x500001 ) AM_WRITE(astrocorp_screen_enable_w)
 	AM_RANGE( 0x580000, 0x580001 ) AM_DEVWRITE("oki", skilldrp_sound_bank_w)
 	AM_RANGE( 0x600000, 0x600001 ) AM_DEVREADWRITE8_MODERN("oki", okim6295_device, read, write, 0x00ff)
@@ -367,12 +368,12 @@ static INPUT_PORTS_START( showhand )
 
 	PORT_START( "EEPROMIN" )
 	PORT_BIT( 0xfff7, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_READ_LINE_DEVICE("eeprom", eeprom_read_bit)
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_READ_LINE_DEVICE_MEMBER("eeprom", eeprom_device, read_bit)
 
 	PORT_START( "EEPROMOUT" )
-	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_write_bit)
-	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_set_clock_line)
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW,  IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_set_cs_line)
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, write_bit)
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, set_clock_line)
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW,  IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, set_cs_line)
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( showhanc )
@@ -396,12 +397,12 @@ static INPUT_PORTS_START( showhanc )
 
 	PORT_START( "EEPROMIN" )
 	PORT_BIT( 0xfff7, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_READ_LINE_DEVICE("eeprom", eeprom_read_bit)
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_READ_LINE_DEVICE_MEMBER("eeprom", eeprom_device, read_bit)
 
 	PORT_START( "EEPROMOUT" )
-	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_write_bit)
-	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_set_clock_line)
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW,  IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_set_cs_line)
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, write_bit)
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, set_clock_line)
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW,  IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, set_cs_line)
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( skilldrp )
@@ -425,12 +426,12 @@ static INPUT_PORTS_START( skilldrp )
 
 	PORT_START( "EEPROMIN" )
 	PORT_BIT( 0xfff7, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_READ_LINE_DEVICE("eeprom", eeprom_read_bit)
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_READ_LINE_DEVICE_MEMBER("eeprom", eeprom_device, read_bit)
 
 	PORT_START( "EEPROMOUT" )
-	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_write_bit)
-	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_set_clock_line)
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW,  IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_set_cs_line)
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, write_bit)
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, set_clock_line)
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW,  IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, set_cs_line)
 INPUT_PORTS_END
 
 /***************************************************************************
@@ -477,12 +478,12 @@ static MACHINE_CONFIG_START( showhand, astrocorp_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(320, 240)
 	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, 0, 240-1)
+	MCFG_SCREEN_UPDATE(astrocorp)
 
 	MCFG_GFXDECODE(astrocorp)
 	MCFG_PALETTE_LENGTH(0x100)
 
 	MCFG_VIDEO_START(astrocorp)
-	MCFG_VIDEO_UPDATE(astrocorp)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -502,8 +503,8 @@ static INTERRUPT_GEN( skilldrp_irq )
 {
 	switch (cpu_getiloops(device))
 	{
-		case 0:	cpu_set_input_line(device, 4, HOLD_LINE);	break;	// sprites, sound, i/o
-		case 1:	cpu_set_input_line(device, 2, HOLD_LINE);	break;	// palette
+		case 0:	device_set_input_line(device, 4, HOLD_LINE);	break;	// sprites, sound, i/o
+		case 1:	device_set_input_line(device, 2, HOLD_LINE);	break;	// palette
 	}
 }
 
@@ -527,12 +528,12 @@ static MACHINE_CONFIG_START( skilldrp, astrocorp_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(0x200, 0x100)
 	MCFG_SCREEN_VISIBLE_AREA(0, 0x200-1, 0, 0xf0-1)
+	MCFG_SCREEN_UPDATE(astrocorp)
 
 	MCFG_GFXDECODE(astrocorp)
 	MCFG_PALETTE_LENGTH(0x100)
 
 	MCFG_VIDEO_START(astrocorp)
-	MCFG_VIDEO_UPDATE(astrocorp)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -791,6 +792,46 @@ ROM_END
 
 /***************************************************************************
 
+Western Venture
+(c) ASTRO
+
+ASTRO V07 0709
+ASTRO F01 2007-06-03
+ASTRO ??? (V102?)
+AD-65?
+93C46 EEPROM
+
+XTAL 24 MHz (near F01)
+XTAL 18.432 MHz (near empty 44 pin PLCC socket and RS232?)
+
+Push Button
+
+ROM types:
+
+EV29001TSC-70R
+MX29F1610MC-10
+
+***************************************************************************/
+
+ROM_START( westvent )
+	ROM_REGION( 0x40000, "maincpu", 0 )
+	ROM_LOAD16_BYTE( "1_w.v.aa.02.d.bin", 0x00000, 0x20000, CRC(5e208192) SHA1(5a35a419fe95513b68423d4eb6c77fdd375667f3) )	// good?
+	ROM_LOAD16_BYTE( "2_w.v.aa.02.d.bin", 0x00001, 0x20000, BAD_DUMP CRC(f56d3ead) SHA1(2cf8960eab221cfce1c7ac6a20d002c4b05d8cc6) )	// FIXED BITS (xxxxxx0xxxxxxxxx)
+
+	ROM_REGION( 0x600000, "sprites", 0 )
+	ROM_LOAD( "top.bin",    0x000000, 0x200000, CRC(75bbaae0) SHA1(ef35775dd481ff343df1ee071ccd52b024d084b7) )
+	ROM_LOAD( "bottom.bin", 0x200000, 0x200000, CRC(e2dd58d5) SHA1(9ab881cfb2ee6cbc48aa28ba28529adb00803e44) )
+	ROM_LOAD( "middle.bin", 0x400000, 0x200000, CRC(7348fd37) SHA1(b5ec0994afb5bceae5627c37f1b35c7abcfd2f0a) )
+
+	ROM_REGION( 0x80000, "oki", 0 )
+	ROM_LOAD( "5.bin", 0x00000, 0x80000, CRC(92dc09d1) SHA1(6b448b3372e78047d054c5e42fcfcff7f75ff9b9) )
+
+	ROM_REGION16_BE( 0x80, "eeprom", 0 )
+	ROM_LOAD( "at93c46.bin", 0x00, 0x80, CRC(fd961d46) SHA1(e238da65e8769575f17b4464fb00f5c4813bafab) )
+ROM_END
+
+/***************************************************************************
+
 Win Win Bingo
 
 ASTRO M1.2 PCB:
@@ -963,7 +1004,7 @@ ROM_END
 static DRIVER_INIT( showhand )
 {
 #if 0
-	UINT16 *rom = (UINT16*)machine->region("maincpu")->base();
+	UINT16 *rom = (UINT16*)machine.region("maincpu")->base();
 
 	rom[0x0a1a/2] = 0x6000;	// hopper jam
 
@@ -979,7 +1020,7 @@ static DRIVER_INIT( showhand )
 static DRIVER_INIT( showhanc )
 {
 #if 0
-	UINT16 *rom = (UINT16*)machine->region("maincpu")->base();
+	UINT16 *rom = (UINT16*)machine.region("maincpu")->base();
 
 	rom[0x14d4/2] = 0x4e71;	// enable full test mode
 	rom[0x14d6/2] = 0x4e71;	// ""
@@ -989,10 +1030,11 @@ static DRIVER_INIT( showhanc )
 #endif
 }
 
-GAME( 2000,  showhand,  0,        showhand, showhand, showhand, ROT0, "Astro Corp.", "Show Hand (Italy)",     GAME_SUPPORTS_SAVE )
-GAME( 2000,  showhanc,  showhand, showhanc, showhanc, showhanc, ROT0, "Astro Corp.", "Wang Pai Dui Jue",      GAME_SUPPORTS_SAVE )
-GAME( 2002,  skilldrp,  0,        skilldrp, skilldrp, 0,        ROT0, "Astro Corp.", "Skill Drop Georgia",    GAME_SUPPORTS_SAVE )
-GAME( 2003,  speeddrp,  0,        speeddrp, skilldrp, 0,        ROT0, "Astro Corp.", "Speed Drop",            GAME_SUPPORTS_SAVE )
-GAME( 2005?, winbingo,  0,        showhand, showhand, 0,        ROT0, "Astro Corp.", "Win Win Bingo (set 1)", GAME_NOT_WORKING )
-GAME( 2005?, winbingoa, winbingo, showhand, showhand, 0,        ROT0, "Astro Corp.", "Win Win Bingo (set 2)", GAME_NOT_WORKING )
-GAME( 2005?, zoo,       0,        showhand, showhand, 0,        ROT0, "Astro Corp.", "Zoo",                   GAME_NOT_WORKING )
+GAME( 2000,  showhand,  0,        showhand, showhand, showhand, ROT0, "Astro Corp.", "Show Hand (Italy)",               GAME_SUPPORTS_SAVE )
+GAME( 2000,  showhanc,  showhand, showhanc, showhanc, showhanc, ROT0, "Astro Corp.", "Wang Pai Dui Jue (China)",        GAME_SUPPORTS_SAVE )
+GAME( 2002,  skilldrp,  0,        skilldrp, skilldrp, 0,        ROT0, "Astro Corp.", "Skill Drop Georgia (Ver. G1.0S)", GAME_SUPPORTS_SAVE )
+GAME( 2003,  speeddrp,  0,        speeddrp, skilldrp, 0,        ROT0, "Astro Corp.", "Speed Drop (Ver. 1.06)",          GAME_SUPPORTS_SAVE )
+GAME( 2005?, winbingo,  0,        showhand, showhand, 0,        ROT0, "Astro Corp.", "Win Win Bingo (set 1)",           GAME_NOT_WORKING )
+GAME( 2005?, winbingoa, winbingo, showhand, showhand, 0,        ROT0, "Astro Corp.", "Win Win Bingo (set 2)",           GAME_NOT_WORKING )
+GAME( 2005?, zoo,       0,        showhand, showhand, 0,        ROT0, "Astro Corp.", "Zoo (Ver. ZO.02.D)",              GAME_NOT_WORKING )
+GAME( 2007?, westvent,  0,        showhand, showhand, 0,        ROT0, "Astro Corp.", "Western Venture (Ver. AA.02.D)",  GAME_NOT_WORKING )
