@@ -19,34 +19,39 @@
 #include "cpu/arm/arm.h"
 #include "video/deco16ic.h"
 #include "rendlay.h"
+#include "video/decospr.h"
 
 class backfire_state : public driver_device
 {
 public:
-	backfire_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	backfire_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT16 *  pf1_rowscroll;
-	UINT16 *  pf2_rowscroll;
-	UINT16 *  pf3_rowscroll;
-	UINT16 *  pf4_rowscroll;
-	UINT32 *  spriteram_1;
-	UINT32 *  spriteram_2;
-	UINT32 *  mainram;
-	UINT32 *  left_priority;
-	UINT32 *  right_priority;
+	UINT16 *  m_spriteram_1;
+	UINT16 *  m_spriteram_2;
+	UINT32 *  m_mainram;
+	UINT32 *  m_left_priority;
+	UINT32 *  m_right_priority;
 
 	/* video related */
-	bitmap_t  *left;
-	bitmap_t  *right;
+	bitmap_t  *m_left;
+	bitmap_t  *m_right;
 
 	/* devices */
-	device_t *maincpu;
-	device_t *deco16ic;
-	device_t *lscreen;
-	device_t *rscreen;
-	device_t *eeprom;
+	device_t *m_maincpu;
+	device_t *m_deco_tilegen1;
+	device_t *m_deco_tilegen2;
+
+	device_t *m_lscreen;
+	device_t *m_rscreen;
+	eeprom_device *m_eeprom;
+
+	/* memory */
+	UINT16    m_pf1_rowscroll[0x0800/2];
+	UINT16    m_pf2_rowscroll[0x0800/2];
+	UINT16    m_pf3_rowscroll[0x0800/2];
+	UINT16    m_pf4_rowscroll[0x0800/2];
 };
 
 //UINT32 *backfire_180010, *backfire_188010;
@@ -54,158 +59,81 @@ public:
 /* I'm using the functions in deco16ic.c ... same chips, why duplicate code? */
 static VIDEO_START( backfire )
 {
-	backfire_state *state = machine->driver_data<backfire_state>();
+	backfire_state *state = machine.driver_data<backfire_state>();
 
-	/* allocate the ram as 16-bit (we do it here because the CPU is 32-bit) */
-	state->pf1_rowscroll = auto_alloc_array(machine, UINT16, 0x0800/2);
-	state->pf2_rowscroll = auto_alloc_array(machine, UINT16, 0x0800/2);
-	state->pf3_rowscroll = auto_alloc_array(machine, UINT16, 0x0800/2);
-	state->pf4_rowscroll = auto_alloc_array(machine, UINT16, 0x0800/2);
+	state->m_spriteram_1 = auto_alloc_array(machine, UINT16, 0x2000/2);
+	state->m_spriteram_2 = auto_alloc_array(machine, UINT16, 0x2000/2);
 
 	/* and register the allocated ram so that save states still work */
-	state_save_register_global_pointer(machine, state->pf1_rowscroll, 0x800/2);
-	state_save_register_global_pointer(machine, state->pf2_rowscroll, 0x800/2);
-	state_save_register_global_pointer(machine, state->pf3_rowscroll, 0x800/2);
-	state_save_register_global_pointer(machine, state->pf4_rowscroll, 0x800/2);
+	state->save_item(NAME(state->m_pf1_rowscroll));
+	state->save_item(NAME(state->m_pf2_rowscroll));
+	state->save_item(NAME(state->m_pf3_rowscroll));
+	state->save_item(NAME(state->m_pf4_rowscroll));
 
-	state->left =  auto_bitmap_alloc(machine, 80*8, 32*8, BITMAP_FORMAT_INDEXED16);
-	state->right = auto_bitmap_alloc(machine, 80*8, 32*8, BITMAP_FORMAT_INDEXED16);
+	state->m_left =  auto_bitmap_alloc(machine, 80*8, 32*8, BITMAP_FORMAT_INDEXED16);
+	state->m_right = auto_bitmap_alloc(machine, 80*8, 32*8, BITMAP_FORMAT_INDEXED16);
 
-	state_save_register_global_bitmap(machine, state->left);
-	state_save_register_global_bitmap(machine, state->right);
-}
+	state->save_pointer(NAME(state->m_spriteram_1), 0x2000/2);
+	state->save_pointer(NAME(state->m_spriteram_2), 0x2000/2);
 
-static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, UINT32 *spriteram, int region )
-{
-	int offs;
-
-	flip_screen_set_no_update(machine, 1);
-
-	for (offs = (0x1400 / 4) - 4; offs >= 0; offs -= 4) // 0x1400 for charlien
-	{
-		int x, y, sprite, colour, multi, fx, fy, inc, flash, mult, pri;
-
-		sprite = spriteram[offs + 1] & 0xffff;
-
-		y = spriteram[offs] & 0xffff;
-		flash = y & 0x1000;
-		if (flash && (machine->primary_screen->frame_number() & 1))
-			continue;
-
-		x = spriteram[offs + 2] & 0xffff;
-		colour = (x >> 9) & 0x1f;
-
-		pri = (x & 0xc000); // 2 bits or 1?
-
-		switch (pri & 0xc000)
-		{
-			case 0x0000: pri = 0;   break; // numbers, people, cars when in the air, status display..
-			case 0x4000: pri = 0xf0;break; // cars most of the time
-			case 0x8000: pri = 0;   break; // car wheels during jump?
-			case 0xc000: pri = 0xf0;break; /* car wheels in race? */
-		}
-
-		// pri 0 = ontop of everything//
-
-		// pri = 0;
-
-		fx = y & 0x2000;
-		fy = y & 0x4000;
-		multi = (1 << ((y & 0x0600) >> 9)) - 1;	/* 1x, 2x, 4x, 8x height */
-
-		x = x & 0x01ff;
-		y = y & 0x01ff;
-		if (x >= 320) x -= 512;
-		if (y >= 256) y -= 512;
-		y = 240 - y;
-		x = 304 - x;
-
-		if (x > 320) continue;
-
-		sprite &= ~multi;
-		if (fy)
-			inc = -1;
-		else
-		{
-			sprite += multi;
-			inc = 1;
-		}
-
-		if (flip_screen_x_get(machine))
-		{
-			y = 240 - y;
-			x = 304 - x;
-			if (fx) fx = 0; else fx = 1;
-			if (fy) fy = 0; else fy = 1;
-			mult = 16;
-		}
-		else mult = -16;
-
-		while (multi >= 0)
-		{
-			pdrawgfx_transpen(bitmap,cliprect,machine->gfx[region],
-					sprite - multi * inc,
-					colour,
-					fx,fy,
-					x,y + mult * multi,
-					machine->priority_bitmap,pri,0);
-
-			multi--;
-		}
-	}
+	state->save_item(NAME(*state->m_left));
+	state->save_item(NAME(*state->m_right));
 }
 
 
 
-static VIDEO_UPDATE( backfire )
+static SCREEN_UPDATE( backfire )
 {
-	backfire_state *state = screen->machine->driver_data<backfire_state>();
+	backfire_state *state = screen->machine().driver_data<backfire_state>();
+
+	//FIXME: flip_screen_x should not be written!
+	flip_screen_set_no_update(screen->machine(), 1);
 
 	/* screen 1 uses pf1 as the forground and pf3 as the background */
 	/* screen 2 uses pf2 as the foreground and pf4 as the background */
-	deco16ic_pf12_update(state->deco16ic, state->pf1_rowscroll, state->pf2_rowscroll);
-	deco16ic_pf34_update(state->deco16ic, state->pf3_rowscroll, state->pf4_rowscroll);
+	deco16ic_pf_update(state->m_deco_tilegen1, state->m_pf1_rowscroll, state->m_pf2_rowscroll);
+	deco16ic_pf_update(state->m_deco_tilegen2, state->m_pf3_rowscroll, state->m_pf4_rowscroll);
 
-	if (screen == state->lscreen)
+	if (screen == state->m_lscreen)
 	{
 
-		bitmap_fill(screen->machine->priority_bitmap, NULL, 0);
+		bitmap_fill(screen->machine().priority_bitmap, NULL, 0);
 		bitmap_fill(bitmap, cliprect, 0x100);
 
-		if (state->left_priority[0] == 0)
+		if (state->m_left_priority[0] == 0)
 		{
-			deco16ic_tilemap_3_draw(state->deco16ic, bitmap, cliprect, 0, 1);
-			deco16ic_tilemap_1_draw(state->deco16ic, bitmap, cliprect, 0, 2);
-			draw_sprites(screen->machine, bitmap, cliprect, state->spriteram_1, 3);
+			deco16ic_tilemap_1_draw(state->m_deco_tilegen2, bitmap, cliprect, 0, 1);
+			deco16ic_tilemap_1_draw(state->m_deco_tilegen1, bitmap, cliprect, 0, 2);
+			screen->machine().device<decospr_device>("spritegen")->draw_sprites(screen->machine(), bitmap, cliprect, state->m_spriteram_1, 0x800);
 		}
-		else if (state->left_priority[0] == 2)
+		else if (state->m_left_priority[0] == 2)
 		{
-			deco16ic_tilemap_1_draw(state->deco16ic, bitmap, cliprect, 0, 2);
-			deco16ic_tilemap_3_draw(state->deco16ic, bitmap, cliprect, 0, 4);
-			draw_sprites(screen->machine, bitmap, cliprect, state->spriteram_1, 3);
+			deco16ic_tilemap_1_draw(state->m_deco_tilegen1, bitmap, cliprect, 0, 2);
+			deco16ic_tilemap_1_draw(state->m_deco_tilegen2, bitmap, cliprect, 0, 4);
+			screen->machine().device<decospr_device>("spritegen")->draw_sprites(screen->machine(), bitmap, cliprect, state->m_spriteram_1, 0x800);
 		}
 		else
-			popmessage( "unknown left priority %08x", state->left_priority[0]);
+			popmessage( "unknown left priority %08x", state->m_left_priority[0]);
 	}
-	else if (screen == state->rscreen)
+	else if (screen == state->m_rscreen)
 	{
-		bitmap_fill(screen->machine->priority_bitmap, NULL, 0);
+		bitmap_fill(screen->machine().priority_bitmap, NULL, 0);
 		bitmap_fill(bitmap, cliprect, 0x500);
 
-		if (state->right_priority[0] == 0)
+		if (state->m_right_priority[0] == 0)
 		{
-			deco16ic_tilemap_4_draw(state->deco16ic, bitmap, cliprect, 0, 1);
-			deco16ic_tilemap_2_draw(state->deco16ic, bitmap, cliprect, 0, 2);
-			draw_sprites(screen->machine, bitmap, cliprect, state->spriteram_2, 4);
+			deco16ic_tilemap_2_draw(state->m_deco_tilegen2, bitmap, cliprect, 0, 1);
+			deco16ic_tilemap_2_draw(state->m_deco_tilegen1, bitmap, cliprect, 0, 2);
+			screen->machine().device<decospr_device>("spritegen2")->draw_sprites(screen->machine(), bitmap, cliprect, state->m_spriteram_2, 0x800);
 		}
-		else if (state->right_priority[0] == 2)
+		else if (state->m_right_priority[0] == 2)
 		{
-			deco16ic_tilemap_2_draw(state->deco16ic, bitmap, cliprect, 0, 2);
-			deco16ic_tilemap_4_draw(state->deco16ic, bitmap, cliprect, 0, 4);
-			draw_sprites(screen->machine, bitmap, cliprect, state->spriteram_2, 4);
+			deco16ic_tilemap_2_draw(state->m_deco_tilegen1, bitmap, cliprect, 0, 2);
+			deco16ic_tilemap_2_draw(state->m_deco_tilegen2, bitmap, cliprect, 0, 4);
+			screen->machine().device<decospr_device>("spritegen2")->draw_sprites(screen->machine(), bitmap, cliprect, state->m_spriteram_2, 0x800);
 		}
 		else
-			popmessage( "unknown right priority %08x", state->right_priority[0]);
+			popmessage( "unknown right priority %08x", state->m_right_priority[0]);
 	}
 	return 0;
 }
@@ -215,105 +143,139 @@ static VIDEO_UPDATE( backfire )
 static READ32_DEVICE_HANDLER( backfire_eeprom_r )
 {
 	/* some kind of screen indicator?  checked by backfirea set before it will boot */
-	int backfire_screen = device->machine->rand() & 1;
-	return ((eeprom_read_bit(device) << 24) | input_port_read(device->machine, "IN0")
-			| ((input_port_read(device->machine, "IN2") & 0xbf) << 16)
-			| ((input_port_read(device->machine, "IN3") & 0x40) << 16)) ^ (backfire_screen << 26) ;
+	int backfire_screen = device->machine().rand() & 1;
+	eeprom_device *eeprom = downcast<eeprom_device *>(device);
+	return ((eeprom->read_bit() << 24) | input_port_read(device->machine(), "IN0")
+			| ((input_port_read(device->machine(), "IN2") & 0xbf) << 16)
+			| ((input_port_read(device->machine(), "IN3") & 0x40) << 16)) ^ (backfire_screen << 26) ;
 }
 
 static READ32_HANDLER( backfire_control2_r )
 {
-	backfire_state *state = space->machine->driver_data<backfire_state>();
+	backfire_state *state = space->machine().driver_data<backfire_state>();
 
-//  logerror("%08x:Read eprom %08x (%08x)\n", cpu_get_pc(space->cpu), offset << 1, mem_mask);
-	return (eeprom_read_bit(state->eeprom) << 24) | input_port_read(space->machine, "IN1") | (input_port_read(space->machine, "IN1") << 16);
+//  logerror("%08x:Read eprom %08x (%08x)\n", cpu_get_pc(&space->device()), offset << 1, mem_mask);
+	return (state->m_eeprom->read_bit() << 24) | input_port_read(space->machine(), "IN1") | (input_port_read(space->machine(), "IN1") << 16);
 }
 
 #ifdef UNUSED_FUNCTION
 static READ32_HANDLER(backfire_control3_r)
 {
-	backfire_state *state = space->machine->driver_data<backfire_state>();
+	backfire_state *state = space->machine().driver_data<backfire_state>();
 
-//  logerror("%08x:Read eprom %08x (%08x)\n", cpu_get_pc(space->cpu), offset << 1, mem_mask);
-	return (eeprom_read_bit(state->eeprom) << 24) | input_port_read(space->machine, "IN2") | (input_port_read(space->machine, "IN2") << 16);
+//  logerror("%08x:Read eprom %08x (%08x)\n", cpu_get_pc(&space->device()), offset << 1, mem_mask);
+	return (state->m_eeprom->read_bit() << 24) | input_port_read(space->machine(), "IN2") | (input_port_read(space->machine(), "IN2") << 16);
 }
 #endif
 
 
 static WRITE32_DEVICE_HANDLER(backfire_eeprom_w)
 {
-	logerror("%s:write eprom %08x (%08x) %08x\n",cpuexec_describe_context(device->machine),offset<<1,mem_mask,data);
+	logerror("%s:write eprom %08x (%08x) %08x\n",device->machine().describe_context(),offset<<1,mem_mask,data);
 	if (ACCESSING_BITS_0_7)
 	{
-		eeprom_set_clock_line(device, BIT(data, 1) ? ASSERT_LINE : CLEAR_LINE);
-		eeprom_write_bit(device, BIT(data, 0));
-		eeprom_set_cs_line(device, BIT(data, 2) ? CLEAR_LINE : ASSERT_LINE);
+		eeprom_device *eeprom = downcast<eeprom_device *>(device);
+		eeprom->set_clock_line(BIT(data, 1) ? ASSERT_LINE : CLEAR_LINE);
+		eeprom->write_bit(BIT(data, 0));
+		eeprom->set_cs_line(BIT(data, 2) ? CLEAR_LINE : ASSERT_LINE);
 	}
 }
 
 
 static WRITE32_HANDLER(backfire_nonbuffered_palette_w)
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u32[offset]);
-	palette_set_color_rgb(space->machine,offset,pal5bit(space->machine->generic.paletteram.u32[offset] >> 0),pal5bit(space->machine->generic.paletteram.u32[offset] >> 5),pal5bit(space->machine->generic.paletteram.u32[offset] >> 10));
+	COMBINE_DATA(&space->machine().generic.paletteram.u32[offset]);
+	palette_set_color_rgb(space->machine(),offset,pal5bit(space->machine().generic.paletteram.u32[offset] >> 0),pal5bit(space->machine().generic.paletteram.u32[offset] >> 5),pal5bit(space->machine().generic.paletteram.u32[offset] >> 10));
 }
 
 /* map 32-bit writes to 16-bit */
 
-static READ32_HANDLER( backfire_pf1_rowscroll_r ) { backfire_state *state = space->machine->driver_data<backfire_state>(); return state->pf1_rowscroll[offset] ^ 0xffff0000; }
-static READ32_HANDLER( backfire_pf2_rowscroll_r ) { backfire_state *state = space->machine->driver_data<backfire_state>(); return state->pf2_rowscroll[offset] ^ 0xffff0000; }
-static READ32_HANDLER( backfire_pf3_rowscroll_r ) { backfire_state *state = space->machine->driver_data<backfire_state>(); return state->pf3_rowscroll[offset] ^ 0xffff0000; }
-static READ32_HANDLER( backfire_pf4_rowscroll_r ) { backfire_state *state = space->machine->driver_data<backfire_state>(); return state->pf4_rowscroll[offset] ^ 0xffff0000; }
-static WRITE32_HANDLER( backfire_pf1_rowscroll_w ) { backfire_state *state = space->machine->driver_data<backfire_state>(); data &= 0x0000ffff; mem_mask &= 0x0000ffff; COMBINE_DATA(&state->pf1_rowscroll[offset]); }
-static WRITE32_HANDLER( backfire_pf2_rowscroll_w ) { backfire_state *state = space->machine->driver_data<backfire_state>(); data &= 0x0000ffff; mem_mask &= 0x0000ffff; COMBINE_DATA(&state->pf2_rowscroll[offset]); }
-static WRITE32_HANDLER( backfire_pf3_rowscroll_w ) { backfire_state *state = space->machine->driver_data<backfire_state>(); data &= 0x0000ffff; mem_mask &= 0x0000ffff; COMBINE_DATA(&state->pf3_rowscroll[offset]); }
-static WRITE32_HANDLER( backfire_pf4_rowscroll_w ) { backfire_state *state = space->machine->driver_data<backfire_state>(); data &= 0x0000ffff; mem_mask &= 0x0000ffff; COMBINE_DATA(&state->pf4_rowscroll[offset]); }
+static READ32_HANDLER( backfire_pf1_rowscroll_r ) { backfire_state *state = space->machine().driver_data<backfire_state>(); return state->m_pf1_rowscroll[offset] ^ 0xffff0000; }
+static READ32_HANDLER( backfire_pf2_rowscroll_r ) { backfire_state *state = space->machine().driver_data<backfire_state>(); return state->m_pf2_rowscroll[offset] ^ 0xffff0000; }
+static READ32_HANDLER( backfire_pf3_rowscroll_r ) { backfire_state *state = space->machine().driver_data<backfire_state>(); return state->m_pf3_rowscroll[offset] ^ 0xffff0000; }
+static READ32_HANDLER( backfire_pf4_rowscroll_r ) { backfire_state *state = space->machine().driver_data<backfire_state>(); return state->m_pf4_rowscroll[offset] ^ 0xffff0000; }
+static WRITE32_HANDLER( backfire_pf1_rowscroll_w ) { backfire_state *state = space->machine().driver_data<backfire_state>(); data &= 0x0000ffff; mem_mask &= 0x0000ffff; COMBINE_DATA(&state->m_pf1_rowscroll[offset]); }
+static WRITE32_HANDLER( backfire_pf2_rowscroll_w ) { backfire_state *state = space->machine().driver_data<backfire_state>(); data &= 0x0000ffff; mem_mask &= 0x0000ffff; COMBINE_DATA(&state->m_pf2_rowscroll[offset]); }
+static WRITE32_HANDLER( backfire_pf3_rowscroll_w ) { backfire_state *state = space->machine().driver_data<backfire_state>(); data &= 0x0000ffff; mem_mask &= 0x0000ffff; COMBINE_DATA(&state->m_pf3_rowscroll[offset]); }
+static WRITE32_HANDLER( backfire_pf4_rowscroll_w ) { backfire_state *state = space->machine().driver_data<backfire_state>(); data &= 0x0000ffff; mem_mask &= 0x0000ffff; COMBINE_DATA(&state->m_pf4_rowscroll[offset]); }
 
 
 #ifdef UNUSED_FUNCTION
 READ32_HANDLER( backfire_unknown_wheel_r )
 {
-	return input_port_read(space->machine, "PADDLE0");
+	return input_port_read(space->machine(), "PADDLE0");
 }
 
 READ32_HANDLER( backfire_wheel1_r )
 {
-	return space->machine->rand();
+	return space->machine().rand();
 }
 
 READ32_HANDLER( backfire_wheel2_r )
 {
-	return space->machine->rand();
+	return space->machine().rand();
 }
 #endif
 
 
-static ADDRESS_MAP_START( backfire_map, ADDRESS_SPACE_PROGRAM, 32 )
+static READ32_HANDLER( backfire_spriteram1_r )
+{
+	backfire_state *state = space->machine().driver_data<backfire_state>();
+	return state->m_spriteram_1[offset] ^ 0xffff0000;
+}
+
+static WRITE32_HANDLER( backfire_spriteram1_w )
+{
+	backfire_state *state = space->machine().driver_data<backfire_state>();
+	data &= 0x0000ffff;
+	mem_mask &= 0x0000ffff;
+
+	COMBINE_DATA(&state->m_spriteram_1[offset]);
+}
+
+static READ32_HANDLER( backfire_spriteram2_r )
+{
+	backfire_state *state = space->machine().driver_data<backfire_state>();
+	return state->m_spriteram_2[offset] ^ 0xffff0000;
+}
+
+static WRITE32_HANDLER( backfire_spriteram2_w )
+{
+	backfire_state *state = space->machine().driver_data<backfire_state>();
+	data &= 0x0000ffff;
+	mem_mask &= 0x0000ffff;
+
+	COMBINE_DATA(&state->m_spriteram_2[offset]);
+}
+
+
+
+static ADDRESS_MAP_START( backfire_map, AS_PROGRAM, 32 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
-	AM_RANGE(0x100000, 0x10001f) AM_DEVREADWRITE("deco_custom", deco16ic_pf12_control_dword_r, deco16ic_pf12_control_dword_w)
-	AM_RANGE(0x110000, 0x111fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
-	AM_RANGE(0x114000, 0x115fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
+	AM_RANGE(0x100000, 0x10001f) AM_DEVREADWRITE("tilegen1", deco16ic_pf_control_dword_r, deco16ic_pf_control_dword_w)
+	AM_RANGE(0x110000, 0x111fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
+	AM_RANGE(0x114000, 0x115fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
 	AM_RANGE(0x120000, 0x120fff) AM_READWRITE(backfire_pf1_rowscroll_r, backfire_pf1_rowscroll_w)
 	AM_RANGE(0x124000, 0x124fff) AM_READWRITE(backfire_pf2_rowscroll_r, backfire_pf2_rowscroll_w)
-	AM_RANGE(0x130000, 0x13001f) AM_DEVREADWRITE("deco_custom", deco16ic_pf34_control_dword_r, deco16ic_pf34_control_dword_w)
-	AM_RANGE(0x140000, 0x141fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf3_data_dword_r, deco16ic_pf3_data_dword_w)
-	AM_RANGE(0x144000, 0x145fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf4_data_dword_r, deco16ic_pf4_data_dword_w)
+	AM_RANGE(0x130000, 0x13001f) AM_DEVREADWRITE("tilegen2", deco16ic_pf_control_dword_r, deco16ic_pf_control_dword_w)
+	AM_RANGE(0x140000, 0x141fff) AM_DEVREADWRITE("tilegen2", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
+	AM_RANGE(0x144000, 0x145fff) AM_DEVREADWRITE("tilegen2", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
 	AM_RANGE(0x150000, 0x150fff) AM_READWRITE(backfire_pf3_rowscroll_r, backfire_pf3_rowscroll_w)
 	AM_RANGE(0x154000, 0x154fff) AM_READWRITE(backfire_pf4_rowscroll_r, backfire_pf4_rowscroll_w)
 	AM_RANGE(0x160000, 0x161fff) AM_WRITE(backfire_nonbuffered_palette_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0x170000, 0x177fff) AM_RAM AM_BASE_MEMBER(backfire_state, mainram)// main ram
+	AM_RANGE(0x170000, 0x177fff) AM_RAM AM_BASE_MEMBER(backfire_state, m_mainram)// main ram
 
 //  AM_RANGE(0x180010, 0x180013) AM_RAM AM_BASE(&backfire_180010) // always 180010 ?
 //  AM_RANGE(0x188010, 0x188013) AM_RAM AM_BASE(&backfire_188010) // always 188010 ?
 
-	AM_RANGE(0x184000, 0x185fff) AM_RAM AM_BASE_MEMBER(backfire_state, spriteram_1)
-	AM_RANGE(0x18c000, 0x18dfff) AM_RAM AM_BASE_MEMBER(backfire_state, spriteram_2)
+	AM_RANGE(0x184000, 0x185fff) AM_READWRITE(backfire_spriteram1_r, backfire_spriteram1_w)
+	AM_RANGE(0x18c000, 0x18dfff) AM_READWRITE(backfire_spriteram2_r, backfire_spriteram2_w)
 	AM_RANGE(0x190000, 0x190003) AM_DEVREAD("eeprom", backfire_eeprom_r)
 	AM_RANGE(0x194000, 0x194003) AM_READ(backfire_control2_r)
 	AM_RANGE(0x1a4000, 0x1a4003) AM_DEVWRITE("eeprom", backfire_eeprom_w)
 
-	AM_RANGE(0x1a8000, 0x1a8003) AM_RAM AM_BASE_MEMBER(backfire_state, left_priority)
-	AM_RANGE(0x1ac000, 0x1ac003) AM_RAM AM_BASE_MEMBER(backfire_state, right_priority)
+	AM_RANGE(0x1a8000, 0x1a8003) AM_RAM AM_BASE_MEMBER(backfire_state, m_left_priority)
+	AM_RANGE(0x1ac000, 0x1ac003) AM_RAM AM_BASE_MEMBER(backfire_state, m_right_priority)
 //  AM_RANGE(0x1b0000, 0x1b0003) AM_WRITENOP // always 1b0000
 
 	/* when set to pentometer in test mode */
@@ -421,6 +383,7 @@ static const gfx_layout tilelayout =
 static GFXDECODE_START( backfire )
 	GFXDECODE_ENTRY( "gfx1", 0, charlayout,      0, 128 )	/* Characters 8x8 */
 	GFXDECODE_ENTRY( "gfx1", 0, tilelayout,      0, 128 )	/* Tiles 16x16 */
+	GFXDECODE_ENTRY( "gfx2", 0, charlayout,      0, 128 )	/* Characters 8x8 */
 	GFXDECODE_ENTRY( "gfx2", 0, tilelayout,      0, 128 )	/* Tiles 16x16 */
 	GFXDECODE_ENTRY( "gfx3", 0, spritelayout,    0x200, 32 )	/* Sprites 16x16 (screen 1) */
 	GFXDECODE_ENTRY( "gfx4", 0, spritelayout,    0x600, 32 )	/* Sprites 16x16 (screen 2) */
@@ -439,7 +402,7 @@ static const ymz280b_interface ymz280b_intf =
 
 static INTERRUPT_GEN( deco32_vbl_interrupt )
 {
-	cpu_set_input_line(device, ARM_IRQ_LINE, HOLD_LINE);
+	device_set_input_line(device, ARM_IRQ_LINE, HOLD_LINE);
 }
 
 
@@ -453,28 +416,52 @@ static int backfire_bank_callback( int bank )
 	return bank * 0x1000;
 }
 
-static const deco16ic_interface backfire_deco16ic_intf =
+static const deco16ic_interface backfire_deco16ic_tilegen1_intf =
 {
 	"lscreen",
-	0, 0, 1,
-	0x0f, 0x0f, 0x0f, 0x0f,	/* trans masks (default values) */
-	0x00, 0x40, 0x10, 0x50, /* color base */
-	0x0f, 0x0f, 0x0f, 0x0f,	/* color masks (default values) */
+	0, 1,
+	0x0f, 0x0f,	/* trans masks (default values) */
+	0x00, 0x40, /* color base */
+	0x0f, 0x0f,	/* color masks (default values) */
 	backfire_bank_callback,
 	backfire_bank_callback,
+	0,1
+};
+
+static const deco16ic_interface backfire_deco16ic_tilegen2_intf =
+{
+	"lscreen",
+	0, 1,
+	0x0f, 0x0f,	/* trans masks (default values) */
+	0x10, 0x50, /* color base */
+	0x0f, 0x0f,	/* color masks (default values) */
 	backfire_bank_callback,
-	backfire_bank_callback
+	backfire_bank_callback,
+	2,3
 };
 
 static MACHINE_START( backfire )
 {
-	backfire_state *state = machine->driver_data<backfire_state>();
+	backfire_state *state = machine.driver_data<backfire_state>();
 
-	state->maincpu = machine->device("maincpu");
-	state->deco16ic = machine->device("deco_custom");
-	state->lscreen = machine->device("lscreen");
-	state->rscreen = machine->device("rscreen");
-	state->eeprom = machine->device("eeprom");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_deco_tilegen1 = machine.device("tilegen1");
+	state->m_deco_tilegen2 = machine.device("tilegen2");
+	state->m_lscreen = machine.device("lscreen");
+	state->m_rscreen = machine.device("rscreen");
+	state->m_eeprom = machine.device<eeprom_device>("eeprom");
+}
+
+UINT16 backfire_pri_callback(UINT16 x)
+{
+	switch (x & 0xc000)
+	{
+		case 0x0000: return 0;   break; // numbers, people, cars when in the air, status display..
+		case 0x4000: return 0xf0;break; // cars most of the time
+		case 0x8000: return 0;   break; // car wheels during jump?
+		case 0xc000: return 0xf0;break; /* car wheels in race? */
+	}
+	return 0;
 }
 
 static MACHINE_CONFIG_START( backfire, backfire_state )
@@ -499,6 +486,7 @@ static MACHINE_CONFIG_START( backfire, backfire_state )
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_UPDATE(backfire)
 
 	MCFG_SCREEN_ADD("rscreen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -506,11 +494,21 @@ static MACHINE_CONFIG_START( backfire, backfire_state )
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_UPDATE(backfire)
 
 	MCFG_VIDEO_START(backfire)
-	MCFG_VIDEO_UPDATE(backfire)
 
-	MCFG_DECO16IC_ADD("deco_custom", backfire_deco16ic_intf)
+	MCFG_DECO16IC_ADD("tilegen1", backfire_deco16ic_tilegen1_intf)
+	MCFG_DECO16IC_ADD("tilegen2", backfire_deco16ic_tilegen2_intf)
+
+	MCFG_DEVICE_ADD("spritegen", DECO_SPRITE, 0)
+	decospr_device::set_gfx_region(*device, 4);
+	decospr_device::set_pri_callback(*device, backfire_pri_callback);
+
+	MCFG_DEVICE_ADD("spritegen2", DECO_SPRITE, 0)
+	decospr_device::set_gfx_region(*device, 5);
+	decospr_device::set_pri_callback(*device, backfire_pri_callback);
+
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
@@ -643,9 +641,9 @@ ROM_START( backfirea )
 	ROM_LOAD( "mbz-06.19l",    0x200000, 0x080000,  CRC(4a38c635) SHA1(7f0fb6a7a4aa6774c04fa38e53ceff8744fe1e9f) )
 ROM_END
 
-static void descramble_sound( running_machine *machine )
+static void descramble_sound( running_machine &machine )
 {
-	UINT8 *rom = machine->region("ymz")->base();
+	UINT8 *rom = machine.region("ymz")->base();
 	int length = 0x200000; // only the first rom is swapped on backfire!
 	UINT8 *buf1 = auto_alloc_array(machine, UINT8, length);
 	UINT32 x;
@@ -671,14 +669,14 @@ static void descramble_sound( running_machine *machine )
 
 static READ32_HANDLER( backfire_speedup_r )
 {
-	backfire_state *state = space->machine->driver_data<backfire_state>();
+	backfire_state *state = space->machine().driver_data<backfire_state>();
 
-	//mame_printf_debug( "%08x\n",cpu_get_pc(space->cpu));
+	//mame_printf_debug( "%08x\n",cpu_get_pc(&space->device()));
 
-	if (cpu_get_pc(space->cpu )== 0xce44)  cpu_spinuntil_time(space->cpu, ATTOTIME_IN_USEC(400)); // backfire
-	if (cpu_get_pc(space->cpu) == 0xcee4)  cpu_spinuntil_time(space->cpu, ATTOTIME_IN_USEC(400)); // backfirea
+	if (cpu_get_pc(&space->device() )== 0xce44)  device_spin_until_time(&space->device(), attotime::from_usec(400)); // backfire
+	if (cpu_get_pc(&space->device()) == 0xcee4)  device_spin_until_time(&space->device(), attotime::from_usec(400)); // backfirea
 
-	return state->mainram[0x18/4];
+	return state->m_mainram[0x18/4];
 }
 
 
@@ -687,9 +685,9 @@ static DRIVER_INIT( backfire )
 	deco56_decrypt_gfx(machine, "gfx1"); /* 141 */
 	deco56_decrypt_gfx(machine, "gfx2"); /* 141 */
 	deco156_decrypt(machine);
-	machine->device("maincpu")->set_clock_scale(4.0f); /* core timings aren't accurate */
+	machine.device("maincpu")->set_clock_scale(4.0f); /* core timings aren't accurate */
 	descramble_sound(machine);
-	memory_install_read32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x0170018, 0x017001b, 0, 0, backfire_speedup_r );
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x0170018, 0x017001b, FUNC(backfire_speedup_r) );
 }
 
 GAME( 1995, backfire,  0,        backfire,   backfire, backfire, ROT0, "Data East Corporation", "Backfire! (set 1)", GAME_SUPPORTS_SAVE )
