@@ -81,6 +81,7 @@
 #include "sound/ay8910.h"
 #include "machine/nvram.h"
 
+
 /*
     Defines
 */
@@ -88,54 +89,12 @@
 #define M6809_XTAL	1000000
 
 
-/*
-    Globals
-*/
-static UINT8 bank_data[4];
-static UINT8 *work_ram;
-static UINT8 *video_ram;
-static UINT8 h_scroll;
-static UINT8 v_scroll;
-static UINT8 flip_8;
-static UINT8 flip_22;
-static UINT8 videomode;
-
-/* UART source/sinks */
-static UINT8 z80_m6809_line;
-static UINT8 m6809_z80_line;
-static UINT8 data_r;
-static UINT8 data_t;
-
-static int irq_state;
-static int acia_irq;
-static int vblank_irq;
-static int blitter_irq;
-
-static UINT8 z80_int;
-static UINT8 z80_inten;
-
-/* EM and lamps stuff */
-static UINT32 meter_latch;
-static UINT32 mux_input;
-static UINT32 mux_outputlatch;
-
 /*
     Function prototypes
 */
-INLINE void z80_bank(running_machine *machine, int num, int data);
+INLINE void z80_bank(running_machine &machine, int num, int data);
 
 
-static void update_irqs(running_machine *machine)
-{
-	int newstate = blitter_irq || vblank_irq || acia_irq;
-
-	if (newstate != irq_state)
-	{
-		irq_state = newstate;
-		cputag_set_input_line(machine, "maincpu", 0, irq_state ? ASSERT_LINE : CLEAR_LINE);
-	}
-}
-
 /***************************************************************************
 
     Split into video\cobra.c !
@@ -190,7 +149,7 @@ typedef union
 /*
     Blitter state
 */
-static struct
+struct blitter_t
 {
 	ADDR_REG	program;
 
@@ -207,14 +166,14 @@ static struct
 	UINT8		innercnt;
 	UINT8		step;
 	UINT8		pattern;
-} blitter;
+};
 
 #define LOOPTYPE ( ( blitter.command&0x60 ) >> 5 )
 
 /*
     MUSIC Semiconductor TR9C1710 RAMDAC or equivalent
 */
-static struct
+struct ramdac_t
 {
 	UINT8	addr_w;
 	UINT8	addr_r;
@@ -228,7 +187,32 @@ static struct
 	/* Access counts */
 	UINT8	count_r;
 	UINT8	count_w;
-} ramdac;
+};
+
+
+struct fdc_t
+{
+	UINT8	MSR;
+
+	int		side;
+	int		track;
+	int		sector;
+	int		number;
+	int		stop_track;
+	int		setup_read;
+
+	int		byte_pos;
+	int		offset;
+
+	int		phase;
+	int		next_phase;
+	int		cmd_len;
+	int		cmd_cnt;
+	int		res_len;
+	int		res_cnt;
+	UINT8	cmd[10];
+	UINT8	results[8];
+};
 
 
 #define BLUE_0 0
@@ -252,6 +236,44 @@ static struct
 #define RED_6 ( 6 << 5 )
 #define RED_7 ( 7 << 5 )
 
+class bfcobra_state : public driver_device
+{
+public:
+	bfcobra_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 m_bank_data[4];
+	UINT8 *m_work_ram;
+	UINT8 *m_video_ram;
+	UINT8 m_h_scroll;
+	UINT8 m_v_scroll;
+	UINT8 m_flip_8;
+	UINT8 m_flip_22;
+	UINT8 m_videomode;
+	UINT8 m_z80_m6809_line;
+	UINT8 m_m6809_z80_line;
+	UINT8 m_data_r;
+	UINT8 m_data_t;
+	int m_irq_state;
+	int m_acia_irq;
+	int m_vblank_irq;
+	int m_blitter_irq;
+	UINT8 m_z80_int;
+	UINT8 m_z80_inten;
+	UINT32 m_meter_latch;
+	UINT32 m_mux_input;
+	UINT32 m_mux_outputlatch;
+	UINT8 m_col4bit[16];
+	UINT8 m_col3bit[16];
+	UINT8 m_col8bit[256];
+	UINT8 m_col7bit[256];
+	UINT8 m_col6bit[256];
+	struct blitter_t m_blitter;
+	struct ramdac_t m_ramdac;
+	struct fdc_t m_fdc;
+};
+
+
 static const UINT8 col4bit_default[16]=
 {
 	BLUE_0 | GREEN_0 | RED_0,
@@ -292,37 +314,34 @@ static const UINT8 col3bit_default[16]=
 	RED_7 | GREEN_7 | BLUE_3
 };
 
-static UINT8 col4bit[16];
-static UINT8 col3bit[16];
-static UINT8 col8bit[256];
-static UINT8 col7bit[256];
-static UINT8 col6bit[256];
 static const UINT8 col76index[] = {0, 2, 4, 7};
 
 
 static VIDEO_START( bfcobra )
 {
+	bfcobra_state *state = machine.driver_data<bfcobra_state>();
 	int i;
 
-	memcpy(col4bit, col4bit_default, sizeof(col4bit));
-	memcpy(col3bit, col3bit_default, sizeof(col3bit));
+	memcpy(state->m_col4bit, col4bit_default, sizeof(state->m_col4bit));
+	memcpy(state->m_col3bit, col3bit_default, sizeof(state->m_col3bit));
 	for (i = 0; i < 256; ++i)
 	{
 		UINT8 col;
 
-		col8bit[i] = i;
+		state->m_col8bit[i] = i;
 		col = i & 0x7f;
 		col = (col & 0x1f) | (col76index[ ( (col & 0x60) >> 5 ) & 3] << 5);
-		col7bit[i] = col;
+		state->m_col7bit[i] = col;
 
 		col = (col & 3) | (col76index[( (col & 0x0c) >> 2) & 3] << 2 ) |
 			  (col76index[( (col & 0x30) >> 4) & 3] << 5 );
-		col6bit[i] = col;
+		state->m_col6bit[i] = col;
 	}
 }
 
-static VIDEO_UPDATE( bfcobra )
+static SCREEN_UPDATE( bfcobra )
 {
+	bfcobra_state *state = screen->machine().driver_data<bfcobra_state>();
 	int x, y;
 	UINT8  *src;
 	UINT32 *dest;
@@ -332,47 +351,47 @@ static VIDEO_UPDATE( bfcobra )
 
 	/* Select screen has to be programmed into two registers */
 	/* No idea what happens if the registers are different */
-	if (flip_8 & 0x40 && flip_22 & 0x40)
+	if (state->m_flip_8 & 0x40 && state->m_flip_22 & 0x40)
 		offset = 0x10000;
 	else
 		offset = 0;
 
-	if(videomode & 0x20)
+	if(state->m_videomode & 0x20)
 	{
-		hirescol = col3bit;
-		lorescol = col7bit;
+		hirescol = state->m_col3bit;
+		lorescol = state->m_col7bit;
 	}
-	else if(videomode & 0x40)
+	else if(state->m_videomode & 0x40)
 	{
-		hirescol = col4bit;
-		lorescol = col6bit;
+		hirescol = state->m_col4bit;
+		lorescol = state->m_col6bit;
 	}
 	else
 	{
-		hirescol = col4bit;
-		lorescol = col8bit;
+		hirescol = state->m_col4bit;
+		lorescol = state->m_col8bit;
 	}
 
 	for (y = cliprect->min_y; y <= cliprect->max_y; ++y)
 	{
-		UINT16 y_offset = (y + v_scroll) * 256;
-		src = &video_ram[offset + y_offset];
+		UINT16 y_offset = (y + state->m_v_scroll) * 256;
+		src = &state->m_video_ram[offset + y_offset];
 		dest = BITMAP_ADDR32(bitmap, y, 0);
 
 		for (x = cliprect->min_x; x <= cliprect->max_x / 2; ++x)
 		{
-			UINT8 x_offset = x + h_scroll;
+			UINT8 x_offset = x + state->m_h_scroll;
 			UINT8 pen = *(src + x_offset);
 
-			if ( ( videomode & 0x81 ) == 1 || (videomode & 0x80 && pen & 0x80) )
+			if ( ( state->m_videomode & 0x81 ) == 1 || (state->m_videomode & 0x80 && pen & 0x80) )
 			{
-				*dest++ = screen->machine->pens[hirescol[pen & 0x0f]];
-				*dest++ = screen->machine->pens[hirescol[(pen >> 4) & 0x0f]];
+				*dest++ = screen->machine().pens[hirescol[pen & 0x0f]];
+				*dest++ = screen->machine().pens[hirescol[(pen >> 4) & 0x0f]];
 			}
 			else
 			{
-				*dest++ = screen->machine->pens[lorescol[pen]];
-				*dest++ = screen->machine->pens[lorescol[pen]];
+				*dest++ = screen->machine().pens[lorescol[pen]];
+				*dest++ = screen->machine().pens[lorescol[pen]];
 			}
 		}
 	}
@@ -380,27 +399,28 @@ static VIDEO_UPDATE( bfcobra )
 	return 0;
 }
 
-INLINE UINT8* blitter_get_addr(running_machine *machine, UINT32 addr)
+INLINE UINT8* blitter_get_addr(running_machine &machine, UINT32 addr)
 {
+	bfcobra_state *state = machine.driver_data<bfcobra_state>();
 	if (addr < 0x10000)
 	{
 		/* Is this region fixed? */
-		return (UINT8*)(machine->region("user1")->base() + addr);
+		return (UINT8*)(machine.region("user1")->base() + addr);
 	}
 	else if(addr < 0x20000)
 	{
 		addr &= 0xffff;
-		addr += (bank_data[0] & 1) ? 0x10000 : 0;
+		addr += (state->m_bank_data[0] & 1) ? 0x10000 : 0;
 
-		return (UINT8*)(machine->region("user1")->base() + addr + ((bank_data[0] >> 1) * 0x20000));
+		return (UINT8*)(machine.region("user1")->base() + addr + ((state->m_bank_data[0] >> 1) * 0x20000));
 	}
 	else if (addr >= 0x20000 && addr < 0x40000)
 	{
-		return (UINT8*)&video_ram[addr - 0x20000];
+		return (UINT8*)&state->m_video_ram[addr - 0x20000];
 	}
 	else
 	{
-		return (UINT8*)&work_ram[addr - 0x40000];
+		return (UINT8*)&state->m_work_ram[addr - 0x40000];
 	}
 }
 
@@ -412,8 +432,10 @@ INLINE UINT8* blitter_get_addr(running_machine *machine, UINT32 addr)
 */
 static void RunBlit(address_space *space)
 {
-#define BLITPRG_READ(x)		blitter.x = *(blitter_get_addr(space->machine, blitter.program.addr++))
+#define BLITPRG_READ(x)		blitter.x = *(blitter_get_addr(space->machine(), blitter.program.addr++))
 
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
+	struct blitter_t &blitter = state->m_blitter;
 	int cycles_used = 0;
 
 
@@ -440,7 +462,7 @@ static void RunBlit(address_space *space)
 		/* This debug is now wrong ! */
 		if (DEBUG_BLITTER)
 		{
-			mame_printf_debug("\n%s:Blitter: Running command from 0x%.5x\n\n", cpuexec_describe_context(device->machine), blitter.program.addr - 12);
+			mame_printf_debug("\n%s:Blitter: Running command from 0x%.5x\n\n", device->machine().describe_context(), blitter.program.addr - 12);
 			mame_printf_debug("Command Reg         %.2x",	blitter.command);
 			mame_printf_debug("		%s %s %s %s %s %s %s\n",
 				blitter.command & CMD_RUN ? "RUN" : "     ",
@@ -522,7 +544,7 @@ static void RunBlit(address_space *space)
 						blitter.source.addr0 -=blitter.step;
 					}
 
-					*blitter_get_addr(space->machine, blitter.dest.addr) = blitter.pattern;
+					*blitter_get_addr(space->machine(), blitter.dest.addr) = blitter.pattern;
 					cycles_used++;
 
 				} while (--innercnt);
@@ -536,7 +558,7 @@ static void RunBlit(address_space *space)
 
 				if (LOOPTYPE == 3 && innercnt == blitter.innercnt)
 				{
-					srcdata = *(blitter_get_addr(space->machine, blitter.source.addr & 0xfffff));
+					srcdata = *(blitter_get_addr(space->machine(), blitter.source.addr & 0xfffff));
 					blitter.source.loword++;
 					cycles_used++;
 				}
@@ -546,7 +568,7 @@ static void RunBlit(address_space *space)
 				{
 					if (LOOPTYPE == 0 || LOOPTYPE == 1)
 					{
-						srcdata = *(blitter_get_addr(space->machine, blitter.source.addr & 0xfffff));
+						srcdata = *(blitter_get_addr(space->machine(), blitter.source.addr & 0xfffff));
 						cycles_used++;
 
 						if (blitter.modectl & MODE_SSIGN)
@@ -561,7 +583,7 @@ static void RunBlit(address_space *space)
 				/* Read destination pixel? */
 				if (LOOPTYPE == 0)
 				{
-					dstdata = *blitter_get_addr(space->machine, blitter.dest.addr & 0xfffff);
+					dstdata = *blitter_get_addr(space->machine(), blitter.dest.addr & 0xfffff);
 					cycles_used++;
 				}
 
@@ -630,10 +652,10 @@ static void RunBlit(address_space *space)
                             The existing destination pixel is used as a lookup
                             into the table and the colours is replaced.
                         */
-						UINT8 dest = *blitter_get_addr(space->machine, blitter.dest.addr);
-						UINT8 newcol = *(blitter_get_addr(space->machine, (blitter.source.addr + dest) & 0xfffff));
+						UINT8 dest = *blitter_get_addr(space->machine(), blitter.dest.addr);
+						UINT8 newcol = *(blitter_get_addr(space->machine(), (blitter.source.addr + dest) & 0xfffff));
 
-						*blitter_get_addr(space->machine, blitter.dest.addr) = newcol;
+						*blitter_get_addr(space->machine(), blitter.dest.addr) = newcol;
 						cycles_used += 3;
 					}
 					else
@@ -652,7 +674,7 @@ static void RunBlit(address_space *space)
 						if (blitter.compfunc & CMPFUNC_LOG0)
 							final_result |= ~result & ~dstdata;
 
-						*blitter_get_addr(space->machine, blitter.dest.addr) = final_result;
+						*blitter_get_addr(space->machine(), blitter.dest.addr) = final_result;
 						cycles_used++;
 					}
 				}
@@ -692,12 +714,14 @@ static void RunBlit(address_space *space)
 	} while (blitter.command  & CMD_RUN);
 
 	/* Burn Z80 cycles while blitter is in operation */
-	cpu_spinuntil_time(space->cpu,  ATTOTIME_IN_NSEC( (1000000000 / Z80_XTAL)*cycles_used * 2 ) );
+	device_spin_until_time(&space->device(),  attotime::from_nsec( (1000000000 / Z80_XTAL)*cycles_used * 2 ) );
 }
 
 
 static READ8_HANDLER( ramdac_r )
 {
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
+	struct ramdac_t &ramdac = state->m_ramdac;
 	UINT8 val = 0xff;
 
 	switch (offset & 3)
@@ -709,7 +733,7 @@ static READ8_HANDLER( ramdac_r )
 			if (*count == 0)
 			{
 				rgb_t color;
-				color = palette_get_color(space->machine, ramdac.addr_r);
+				color = palette_get_color(space->machine(), ramdac.addr_r);
 
 				ramdac.color_r[0] = RGB_RED(color);
 				ramdac.color_r[1] = RGB_GREEN(color);
@@ -730,7 +754,7 @@ static READ8_HANDLER( ramdac_r )
 		}
 		default:
 		{
-			mame_printf_debug("Unhandled RAMDAC read (PC:%.4x)\n", cpu_get_previouspc(space->cpu));
+			mame_printf_debug("Unhandled RAMDAC read (PC:%.4x)\n", cpu_get_previouspc(&space->device()));
 		}
 	}
 
@@ -739,6 +763,8 @@ static READ8_HANDLER( ramdac_r )
 
 static WRITE8_HANDLER( ramdac_w )
 {
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
+	struct ramdac_t &ramdac = state->m_ramdac;
 
 	switch (offset & 3)
 	{
@@ -753,7 +779,7 @@ static WRITE8_HANDLER( ramdac_w )
 			ramdac.color_w[ramdac.count_w] = pal6bit(data);
 			if (++ramdac.count_w == 3)
 			{
-				palette_set_color_rgb(space->machine, ramdac.addr_w, ramdac.color_w[0], ramdac.color_w[1], ramdac.color_w[2]);
+				palette_set_color_rgb(space->machine(), ramdac.addr_w, ramdac.color_w[0], ramdac.color_w[1], ramdac.color_w[2]);
 				ramdac.count_w = 0;
 				ramdac.addr_w++;
 			}
@@ -821,8 +847,21 @@ static WRITE8_HANDLER( ramdac_w )
 
 ***************************************************************************/
 
+static void update_irqs(running_machine &machine)
+{
+	bfcobra_state *state = machine.driver_data<bfcobra_state>();
+	int newstate = state->m_blitter_irq || state->m_vblank_irq || state->m_acia_irq;
+
+	if (newstate != state->m_irq_state)
+	{
+		state->m_irq_state = newstate;
+		cputag_set_input_line(machine, "maincpu", 0, state->m_irq_state ? ASSERT_LINE : CLEAR_LINE);
+	}
+}
+
 static READ8_HANDLER( chipset_r )
 {
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
 	UINT8 val = 0xff;
 
 	switch(offset)
@@ -831,22 +870,22 @@ static READ8_HANDLER( chipset_r )
 		case 2:
 		case 3:
 		{
-			val = bank_data[offset];
+			val = state->m_bank_data[offset];
 			break;
 		}
 		case 6:
 		{
 			/* TODO */
-			val = vblank_irq << 4;
+			val = state->m_vblank_irq << 4;
 			break;
 		}
 		case 7:
 		{
-			vblank_irq = 0;
+			state->m_vblank_irq = 0;
 			val = 0x1;
 
 			/* TODO */
-			update_irqs(space->machine);
+			update_irqs(space->machine());
 			break;
 		}
 		case 0x1C:
@@ -858,17 +897,17 @@ static READ8_HANDLER( chipset_r )
 		case 0x20:
 		{
 			/* Seems correct - used during RLE pic decoding */
-			val = blitter.dest.addr0;
+			val = state->m_blitter.dest.addr0;
 			break;
 		}
 		case 0x22:
 		{
-			val = 0x40 | input_port_read(space->machine, "JOYSTICK");
+			val = 0x40 | input_port_read(space->machine(), "JOYSTICK");
 			break;
 		}
 		default:
 		{
-			mame_printf_debug("Flare One unknown read: 0x%.2x (PC:0x%.4x)\n", offset, cpu_get_previouspc(space->cpu));
+			mame_printf_debug("Flare One unknown read: 0x%.2x (PC:0x%.4x)\n", offset, cpu_get_previouspc(&space->device()));
 		}
 	}
 
@@ -877,6 +916,7 @@ static READ8_HANDLER( chipset_r )
 
 static WRITE8_HANDLER( chipset_w )
 {
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
 	switch (offset)
 	{
 		case 0x01:
@@ -884,65 +924,65 @@ static WRITE8_HANDLER( chipset_w )
 		case 0x03:
 		{
 			if (data > 0x3f)
-				popmessage("%x: Unusual bank access (%x)\n", cpu_get_previouspc(space->cpu), data);
+				popmessage("%x: Unusual bank access (%x)\n", cpu_get_previouspc(&space->device()), data);
 
 			data &= 0x3f;
-			bank_data[offset] = data;
-			z80_bank(space->machine, offset, data);
+			state->m_bank_data[offset] = data;
+			z80_bank(space->machine(), offset, data);
 			break;
 		}
 
 		case 0x08:
 		{
-			flip_8 = data;
+			state->m_flip_8 = data;
 			break;
 		}
 		case 9:
-			videomode = data;
+			state->m_videomode = data;
 			break;
 
 		case 0x0B:
 		{
-			h_scroll = data;
+			state->m_h_scroll = data;
 			break;
 		}
 		case 0x0C:
 		{
-			v_scroll = data;
+			state->m_v_scroll = data;
 			break;
 		}
 		case 0x0E:
 		{
-			col4bit[5] = data;
-			col3bit[5] = data;
-			col3bit[5 + 8] = data;
+			state->m_col4bit[5] = data;
+			state->m_col3bit[5] = data;
+			state->m_col3bit[5 + 8] = data;
 			break;
 		}
 		case 0x0f:
 		{
-			col4bit[6] = data;
-			col3bit[6] = data;
-			col3bit[6 + 8] = data;
+			state->m_col4bit[6] = data;
+			state->m_col3bit[6] = data;
+			state->m_col3bit[6 + 8] = data;
 			break;
 		}
 		case 0x18:
 		{
-			blitter.program.addr0 = data;
+			state->m_blitter.program.addr0 = data;
 			break;
 		}
 		case 0x19:
 		{
-			blitter.program.addr1 = data;
+			state->m_blitter.program.addr1 = data;
 			break;
 		}
 		case 0x1A:
 		{
-			blitter.program.addr2 = data;
+			state->m_blitter.program.addr2 = data;
 			break;
 		}
 		case 0x20:
 		{
-			blitter.command = data;
+			state->m_blitter.command = data;
 
 			if (data & CMD_RUN)
 				RunBlit(space);
@@ -953,42 +993,44 @@ static WRITE8_HANDLER( chipset_w )
 		}
 		case 0x22:
 		{
-			flip_22 = data;
+			state->m_flip_22 = data;
 			break;
 		}
 		default:
 		{
-			mame_printf_debug("Flare One unknown write: 0x%.2x with 0x%.2x (PC:0x%.4x)\n", offset, data, cpu_get_previouspc(space->cpu));
+			mame_printf_debug("Flare One unknown write: 0x%.2x with 0x%.2x (PC:0x%.4x)\n", offset, data, cpu_get_previouspc(&space->device()));
 		}
 	}
 }
 
-INLINE void z80_bank(running_machine *machine, int num, int data)
+INLINE void z80_bank(running_machine &machine, int num, int data)
 {
+	bfcobra_state *state = machine.driver_data<bfcobra_state>();
 	static const char * const bank_names[] = { "bank1", "bank2", "bank3" };
 
 	if (data < 0x08)
 	{
-		UINT32 offset = ((bank_data[0] >> 1) * 0x20000) + ((0x4000 * data) ^ ((bank_data[0] & 1) ? 0 : 0x10000));
+		UINT32 offset = ((state->m_bank_data[0] >> 1) * 0x20000) + ((0x4000 * data) ^ ((state->m_bank_data[0] & 1) ? 0 : 0x10000));
 
-		memory_set_bankptr(machine, bank_names[num - 1], machine->region("user1")->base() + offset);
+		memory_set_bankptr(machine, bank_names[num - 1], machine.region("user1")->base() + offset);
 	}
 	else if (data < 0x10)
 	{
-		memory_set_bankptr(machine, bank_names[num - 1], &video_ram[(data - 0x08) * 0x4000]);
+		memory_set_bankptr(machine, bank_names[num - 1], &state->m_video_ram[(data - 0x08) * 0x4000]);
 	}
 	else
 	{
-		memory_set_bankptr(machine, bank_names[num - 1], &work_ram[(data - 0x10) * 0x4000]);
+		memory_set_bankptr(machine, bank_names[num - 1], &state->m_work_ram[(data - 0x10) * 0x4000]);
 	}
 }
 
 static WRITE8_HANDLER( rombank_w )
 {
-	bank_data[0] = data;
-	z80_bank(space->machine, 1, bank_data[1]);
-	z80_bank(space->machine, 2, bank_data[2]);
-	z80_bank(space->machine, 3, bank_data[3]);
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
+	state->m_bank_data[0] = data;
+	z80_bank(space->machine(), 1, state->m_bank_data[1]);
+	z80_bank(space->machine(), 2, state->m_bank_data[2]);
+	z80_bank(space->machine(), 3, state->m_bank_data[3]);
 }
 
 
@@ -1002,7 +1044,7 @@ static WRITE8_HANDLER( rombank_w )
 
 ***************************************************************************/
 
-static void command_phase(UINT8 data);
+static void command_phase(struct fdc_t &fdc, UINT8 data);
 static void exec_w_phase(UINT8 data);
 //UINT8 exec_r_phase(void);
 
@@ -1037,50 +1079,29 @@ enum command
 	SCAN_HIGH_OR_EQUAL = 29
 };
 
-static struct
+static void reset_fdc(running_machine &machine)
 {
-	UINT8	MSR;
+	bfcobra_state *state = machine.driver_data<bfcobra_state>();
+	memset(&state->m_fdc, 0, sizeof(state->m_fdc));
 
-	int		side;
-	int		track;
-	int		sector;
-	int		number;
-	int		stop_track;
-	int		setup_read;
-
-	int		byte_pos;
-	int		offset;
-
-	int		phase;
-	int		next_phase;
-	int		cmd_len;
-	int		cmd_cnt;
-	int		res_len;
-	int		res_cnt;
-	UINT8	cmd[10];
-	UINT8	results[8];
-} fdc;
-
-
-static void reset_fdc(void)
-{
-	memset(&fdc, 0, sizeof(fdc));
-
-	fdc.MSR = 0x80;
-	fdc.phase = COMMAND;
+	state->m_fdc.MSR = 0x80;
+	state->m_fdc.phase = COMMAND;
 }
 
 static READ8_HANDLER( fdctrl_r )
 {
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
 	UINT8 val = 0;
 
-	val = fdc.MSR;
+	val = state->m_fdc.MSR;
 
 	return val;
 }
 
 static READ8_HANDLER( fddata_r )
 {
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
+	struct fdc_t &fdc = state->m_fdc;
 	#define	BPS		1024
 	#define SPT		10
 	#define BPT		1024*10
@@ -1109,7 +1130,7 @@ static READ8_HANDLER( fddata_r )
 				}
 
 				fdc.offset = (BPT * fdc.track*2) + (fdc.side ? BPT : 0) + (BPS * (fdc.sector-1)) + fdc.byte_pos++;
-				val = *(space->machine->region("user2")->base() + fdc.offset);
+				val = *(space->machine().region("user2")->base() + fdc.offset);
 
 				/* Move on to next sector? */
 				if (fdc.byte_pos == 1024)
@@ -1153,11 +1174,13 @@ static READ8_HANDLER( fddata_r )
 
 static WRITE8_HANDLER( fdctrl_w )
 {
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
+	struct fdc_t &fdc = state->m_fdc;
 	switch (fdc.phase)
 	{
 		case COMMAND:
 		{
-			command_phase(data);
+			command_phase(fdc, data);
 			break;
 		}
 		case EXECUTION_W:
@@ -1172,7 +1195,7 @@ static WRITE8_HANDLER( fdctrl_w )
 	}
 }
 
-static void command_phase(UINT8 data)
+static void command_phase(struct fdc_t &fdc, UINT8 data)
 {
 	if (fdc.cmd_cnt == 0)
 	{
@@ -1281,6 +1304,7 @@ WRITE8_HANDLER( fd_ctrl_w )
 
 static MACHINE_RESET( bfcobra )
 {
+	bfcobra_state *state = machine.driver_data<bfcobra_state>();
 	unsigned int pal;
 
 	for (pal = 0; pal < 256; ++pal)
@@ -1288,11 +1312,11 @@ static MACHINE_RESET( bfcobra )
 		palette_set_color_rgb(machine, pal, pal3bit((pal>>5)&7), pal3bit((pal>>2)&7), pal2bit(pal&3));
 	}
 
-	bank_data[0] = 1;
-	memset(&ramdac, 0, sizeof(ramdac));
-	reset_fdc();
+	state->m_bank_data[0] = 1;
+	memset(&state->m_ramdac, 0, sizeof(state->m_ramdac));
+	reset_fdc(machine);
 
-	irq_state = blitter_irq = vblank_irq = acia_irq = 0;
+	state->m_irq_state = state->m_blitter_irq = state->m_vblank_irq = state->m_acia_irq = 0;
 }
 
 /***************************************************************************
@@ -1301,20 +1325,20 @@ static MACHINE_RESET( bfcobra )
 
 ***************************************************************************/
 
-static ADDRESS_MAP_START( z80_prog_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( z80_prog_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROMBANK("bank4")
 	AM_RANGE(0x4000, 0x7fff) AM_RAMBANK("bank1")
 	AM_RANGE(0x8000, 0xbfff) AM_RAMBANK("bank2")
 	AM_RANGE(0xc000, 0xffff) AM_RAMBANK("bank3")
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( z80_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( z80_io_map, AS_IO, 8 )
 ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x23) AM_READWRITE(chipset_r, chipset_w)
-	AM_RANGE(0x24, 0x24) AM_DEVWRITE("acia6850_0", acia6850_ctrl_w)
-	AM_RANGE(0x25, 0x25) AM_DEVWRITE("acia6850_0", acia6850_data_w)
-	AM_RANGE(0x26, 0x26) AM_DEVREAD("acia6850_0", acia6850_stat_r)
-	AM_RANGE(0x27, 0x27) AM_DEVREAD("acia6850_0", acia6850_data_r)
+	AM_RANGE(0x24, 0x24) AM_DEVWRITE_MODERN("acia6850_0", acia6850_device, control_write)
+	AM_RANGE(0x25, 0x25) AM_DEVWRITE_MODERN("acia6850_0", acia6850_device, data_write)
+	AM_RANGE(0x26, 0x26) AM_DEVREAD_MODERN("acia6850_0", acia6850_device, status_read)
+	AM_RANGE(0x27, 0x27) AM_DEVREAD_MODERN("acia6850_0", acia6850_device, data_read)
 	AM_RANGE(0x30, 0x30) AM_READ(fdctrl_r)
 	AM_RANGE(0x31, 0x31) AM_READWRITE(fddata_r, fdctrl_w)
 	AM_RANGE(0x40, 0x40) AM_WRITE(rombank_w)
@@ -1352,17 +1376,18 @@ static READ8_HANDLER( int_latch_r )
 /* TODO */
 static READ8_HANDLER( meter_r )
 {
-	return meter_latch;
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
+	return state->m_meter_latch;
 }
 
 /* TODO: This is borrowed from Scorpion 1 */
 static WRITE8_HANDLER( meter_w )
 {
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
 	int i;
-	int  changed = meter_latch ^ data;
-	UINT64 cycles = downcast<cpu_device *>(space->cpu)->total_cycles();
+	int  changed = state->m_meter_latch ^ data;
 
-	meter_latch = data;
+	state->m_meter_latch = data;
 
 	/*
         When a meter is triggered, the current drawn is sensed. If a meter
@@ -1372,8 +1397,8 @@ static WRITE8_HANDLER( meter_w )
 	{
 		if (changed & (1 << i))
 		{
-			Mechmtr_update(i, cycles, data & (1 << i) );
-			generic_pulse_irq_line(space->cpu, M6809_FIRQ_LINE);
+			MechMtr_update(i, data & (1 << i) );
+			generic_pulse_irq_line(&space->device(), M6809_FIRQ_LINE);
 		}
 	}
 }
@@ -1381,20 +1406,22 @@ static WRITE8_HANDLER( meter_w )
 /* TODO */
 static READ8_HANDLER( latch_r )
 {
-	return mux_input;
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
+	return state->m_mux_input;
 }
 
 static WRITE8_HANDLER( latch_w )
 {
+	bfcobra_state *state = space->machine().driver_data<bfcobra_state>();
 	/* TODO: This is borrowed from Scorpion 1 */
 	switch(offset)
 	{
 		case 0:
 		{
-			int changed = mux_outputlatch ^ data;
+			int changed = state->m_mux_outputlatch ^ data;
 			static const char *const port[] = { "STROBE0", "STROBE1", "STROBE2", "STROBE3", "STROBE4", "STROBE5", "STROBE6", "STROBE7" };
 
-			mux_outputlatch = data;
+			state->m_mux_outputlatch = data;
 
 			/* Clock has changed */
 			if (changed & 0x08)
@@ -1403,7 +1430,7 @@ static WRITE8_HANDLER( latch_w )
 
 				/* Clock is low */
 				if (!(data & 0x08))
-					mux_input = input_port_read(space->machine, port[input_strobe]);
+					state->m_mux_input = input_port_read(space->machine(), port[input_strobe]);
 			}
 			break;
 		}
@@ -1432,7 +1459,7 @@ static WRITE8_DEVICE_HANDLER( upd_w )
 	upd7759_start_w(device, data & 0x40 ? 0 : 1);
 }
 
-static ADDRESS_MAP_START( m6809_prog_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( m6809_prog_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_RAM	AM_SHARE("nvram")
 	AM_RANGE(0x2000, 0x2000) AM_RAM		// W 'B', 6F
 	AM_RANGE(0x2200, 0x2200) AM_RAM		// W 'F'
@@ -1442,10 +1469,10 @@ static ADDRESS_MAP_START( m6809_prog_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x2E00, 0x2E00) AM_READ(int_latch_r)
 	AM_RANGE(0x3001, 0x3001) AM_DEVWRITE("aysnd", ay8910_data_w)
 	AM_RANGE(0x3201, 0x3201) AM_DEVWRITE("aysnd", ay8910_address_w)
-	AM_RANGE(0x3404, 0x3404) AM_DEVREADWRITE("acia6850_1", acia6850_stat_r, acia6850_ctrl_w)
-	AM_RANGE(0x3405, 0x3405) AM_DEVREADWRITE("acia6850_1", acia6850_data_r, acia6850_data_w)
-	AM_RANGE(0x3406, 0x3406) AM_DEVREADWRITE("acia6850_2", acia6850_stat_r, acia6850_ctrl_w)
-	AM_RANGE(0x3407, 0x3407) AM_DEVREADWRITE("acia6850_2", acia6850_data_r, acia6850_data_w)
+	AM_RANGE(0x3404, 0x3404) AM_DEVREADWRITE_MODERN("acia6850_1", acia6850_device, status_read, control_write)
+	AM_RANGE(0x3405, 0x3405) AM_DEVREADWRITE_MODERN("acia6850_1", acia6850_device, data_read, data_write)
+	AM_RANGE(0x3406, 0x3406) AM_DEVREADWRITE_MODERN("acia6850_2", acia6850_device, status_read, control_write)
+	AM_RANGE(0x3407, 0x3407) AM_DEVREADWRITE_MODERN("acia6850_2", acia6850_device, data_read, data_write)
 //  AM_RANGE(0x3408, 0x3408) AM_NOP
 //  AM_RANGE(0x340A, 0x340A) AM_NOP
 //  AM_RANGE(0x3600, 0x3600) AM_NOP
@@ -1560,13 +1587,14 @@ INPUT_PORTS_END
 /*
     Allocate work RAM and video RAM shared by the Z80 and chipset.
 */
-static void init_ram(running_machine *machine)
+static void init_ram(running_machine &machine)
 {
+	bfcobra_state *state = machine.driver_data<bfcobra_state>();
 	/* 768kB work RAM */
-	work_ram = auto_alloc_array_clear(machine, UINT8, 0xC0000);
+	state->m_work_ram = auto_alloc_array_clear(machine, UINT8, 0xC0000);
 
 	/* 128kB video RAM */
-	video_ram = auto_alloc_array_clear(machine, UINT8, 0x20000);
+	state->m_video_ram = auto_alloc_array_clear(machine, UINT8, 0x20000);
 }
 
 /*
@@ -1575,18 +1603,21 @@ static void init_ram(running_machine *machine)
 
 static READ_LINE_DEVICE_HANDLER( z80_acia_rx_r )
 {
-	return m6809_z80_line;
+	bfcobra_state *state = device->machine().driver_data<bfcobra_state>();
+	return state->m_m6809_z80_line;
 }
 
 static WRITE_LINE_DEVICE_HANDLER( z80_acia_tx_w )
 {
-	z80_m6809_line = state;
+	bfcobra_state *drvstate = device->machine().driver_data<bfcobra_state>();
+	drvstate->m_z80_m6809_line = state;
 }
 
 static WRITE_LINE_DEVICE_HANDLER( z80_acia_irq )
 {
-	acia_irq = state ? CLEAR_LINE : ASSERT_LINE;
-	update_irqs(device->machine);
+	bfcobra_state *drvstate = device->machine().driver_data<bfcobra_state>();
+	drvstate->m_acia_irq = state ? CLEAR_LINE : ASSERT_LINE;
+	update_irqs(device->machine());
 }
 
 static ACIA6850_INTERFACE( z80_acia_if )
@@ -1603,17 +1634,19 @@ static ACIA6850_INTERFACE( z80_acia_if )
 
 static READ_LINE_DEVICE_HANDLER( m6809_acia_rx_r )
 {
-	return z80_m6809_line;
+	bfcobra_state *state = device->machine().driver_data<bfcobra_state>();
+	return state->m_z80_m6809_line;
 }
 
 static WRITE_LINE_DEVICE_HANDLER( m6809_acia_tx_w )
 {
-	m6809_z80_line = state;
+	bfcobra_state *drvstate = device->machine().driver_data<bfcobra_state>();
+	drvstate->m_m6809_z80_line = state;
 }
 
 static WRITE_LINE_DEVICE_HANDLER( m6809_data_irq )
 {
-	cputag_set_input_line(device->machine, "audiocpu", M6809_IRQ_LINE, state ? CLEAR_LINE : ASSERT_LINE);
+	cputag_set_input_line(device->machine(), "audiocpu", M6809_IRQ_LINE, state ? CLEAR_LINE : ASSERT_LINE);
 }
 
 static ACIA6850_INTERFACE( m6809_acia_if )
@@ -1630,12 +1663,14 @@ static ACIA6850_INTERFACE( m6809_acia_if )
 
 static READ_LINE_DEVICE_HANDLER( data_acia_rx_r )
 {
-	return data_r;
+	bfcobra_state *state = device->machine().driver_data<bfcobra_state>();
+	return state->m_data_r;
 }
 
 static WRITE_LINE_DEVICE_HANDLER( data_acia_tx_w )
 {
-	 data_t = state;
+	bfcobra_state *drvstate = device->machine().driver_data<bfcobra_state>();
+	 drvstate->m_data_t = state;
 }
 
 
@@ -1655,6 +1690,7 @@ static ACIA6850_INTERFACE( data_acia_if )
 /* TODO: Driver vs Machine Init */
 static DRIVER_INIT( bfcobra )
 {
+	bfcobra_state *state = machine.driver_data<bfcobra_state>();
 	/*
         6809 ROM address and data lines are scrambled.
         This is the same scrambling as Scorpion 2.
@@ -1667,7 +1703,7 @@ static DRIVER_INIT( bfcobra )
 	UINT8 *tmp;
 
 	tmp = auto_alloc_array(machine, UINT8, 0x8000);
-	rom = machine->region("audiocpu")->base() + 0x8000;
+	rom = machine.region("audiocpu")->base() + 0x8000;
 	memcpy(tmp, rom, 0x8000);
 
 	for (i = 0; i < 0x8000; i++)
@@ -1690,31 +1726,31 @@ static DRIVER_INIT( bfcobra )
 
 	init_ram(machine);
 
-	bank_data[0] = 1;
-	bank_data[1] = 0;
-	bank_data[2] = 0;
-	bank_data[3] = 0;
+	state->m_bank_data[0] = 1;
+	state->m_bank_data[1] = 0;
+	state->m_bank_data[2] = 0;
+	state->m_bank_data[3] = 0;
 
 	/* Fixed 16kB ROM region */
-	memory_set_bankptr(machine, "bank4", machine->region("user1")->base());
+	memory_set_bankptr(machine, "bank4", machine.region("user1")->base());
 
 	/* TODO: Properly sort out the data ACIA */
-	data_r = 1;
+	state->m_data_r = 1;
 
 	/* Finish this */
-	state_save_register_global(machine, z80_m6809_line);
-	state_save_register_global(machine, m6809_z80_line);
-	state_save_register_global(machine, data_r);
-	state_save_register_global(machine, data_t);
-	state_save_register_global(machine, h_scroll);
-	state_save_register_global(machine, v_scroll);
-	state_save_register_global(machine, flip_8);
-	state_save_register_global(machine, flip_22);
-	state_save_register_global(machine, z80_int);
-	state_save_register_global(machine, z80_inten);
-	state_save_register_global_array(machine, bank_data);
-	state_save_register_global_pointer(machine, work_ram, 0xc0000);
-	state_save_register_global_pointer(machine, video_ram, 0x20000);
+	state_save_register_global(machine, state->m_z80_m6809_line);
+	state_save_register_global(machine, state->m_m6809_z80_line);
+	state_save_register_global(machine, state->m_data_r);
+	state_save_register_global(machine, state->m_data_t);
+	state_save_register_global(machine, state->m_h_scroll);
+	state_save_register_global(machine, state->m_v_scroll);
+	state_save_register_global(machine, state->m_flip_8);
+	state_save_register_global(machine, state->m_flip_22);
+	state_save_register_global(machine, state->m_z80_int);
+	state_save_register_global(machine, state->m_z80_inten);
+	state_save_register_global_array(machine, state->m_bank_data);
+	state_save_register_global_pointer(machine, state->m_work_ram, 0xc0000);
+	state_save_register_global_pointer(machine, state->m_video_ram, 0x20000);
 }
 
 /* TODO */
@@ -1726,11 +1762,12 @@ static INTERRUPT_GEN( timer_irq )
 /* TODO */
 static INTERRUPT_GEN( vblank_gen )
 {
-	vblank_irq = 1;
-	update_irqs(device->machine);
+	bfcobra_state *state = device->machine().driver_data<bfcobra_state>();
+	state->m_vblank_irq = 1;
+	update_irqs(device->machine());
 }
 
-static MACHINE_CONFIG_START( bfcobra, driver_device )
+static MACHINE_CONFIG_START( bfcobra, bfcobra_state )
 	MCFG_CPU_ADD("maincpu", Z80, Z80_XTAL)
 	MCFG_CPU_PROGRAM_MAP(z80_prog_map)
 	MCFG_CPU_IO_MAP(z80_io_map)
@@ -1751,6 +1788,8 @@ static MACHINE_CONFIG_START( bfcobra, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(512, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 512 - 1, 0, 256 - 1)
+	MCFG_SCREEN_UPDATE(bfcobra)
+
 	MCFG_PALETTE_LENGTH(256)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -1762,7 +1801,6 @@ static MACHINE_CONFIG_START( bfcobra, driver_device )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
 	MCFG_VIDEO_START(bfcobra)
-	MCFG_VIDEO_UPDATE(bfcobra)
 
 	/* ACIAs */
 	MCFG_ACIA6850_ADD("acia6850_0", z80_acia_if)
@@ -1882,10 +1920,10 @@ ROM_START( qosb )
 	ROM_LOAD( "95740599.bin", 0x08000, 0x8000, CRC(bf1e321f) SHA1(51f18620f22ba2a1b110954284ddf00614d51a0e) )
 
 	ROM_REGION( 0x200000, "user1", 0 )
-	ROM_LOAD( "0306.bin", 0x000000, 0x80000, CRC(c26c8f83) SHA1(6949027e1fe241cbb2e1cbbce18e47bcb0d84550) )
-	ROM_LOAD( "1307.bin", 0x080000, 0x80000, CRC(94611c03) SHA1(81f545ff96ff3d44285315400da94d870c89f896) )
-	ROM_LOAD( "2308.bin", 0x100000, 0x80000, CRC(f5572726) SHA1(e109265c5571d21213a6f405a13459e7bc6699bc) )
-	ROM_LOAD( "3309.bin", 0x180000, 0x80000, CRC(1b5edfa8) SHA1(348488debd4aa52f064e351ed0c082274da1db2b) )
+	ROM_LOAD( "rom0_306.bin", 0x000000, 0x80000, CRC(c26c8f83) SHA1(6949027e1fe241cbb2e1cbbce18e47bcb0d84550) )
+	ROM_LOAD( "rom1_307.bin", 0x080000, 0x80000, CRC(94611c03) SHA1(81f545ff96ff3d44285315400da94d870c89f896) )
+	ROM_LOAD( "rom2_308.bin", 0x100000, 0x80000, CRC(f5572726) SHA1(e109265c5571d21213a6f405a13459e7bc6699bc) )
+	ROM_LOAD( "rom3_309.bin", 0x180000, 0x80000, CRC(1b5edfa8) SHA1(348488debd4aa52f064e351ed0c082274da1db2b) )
 
 	ROM_REGION( 0x20000, "upd", 0 )
 	ROM_LOAD( "snd1_218.ic7", 0x00000, 0x10000, CRC(061f496d) SHA1(653d16454d909c034191813b37d14010da7258c6) )
