@@ -63,6 +63,17 @@
 #include "machine/nvram.h"
 #include "deprecat.h"
 
+
+class big10_state : public driver_device
+{
+public:
+	big10_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 m_mux_data;
+};
+
+
 #define VDP_MEM             0x40000
 
 
@@ -70,21 +81,21 @@
 *      Interrupt handling & Video      *
 ***************************************/
 
-static void big10_vdp_interrupt(running_machine *machine, int i)
+static void big10_vdp_interrupt(running_machine &machine, int i)
 {
 	cputag_set_input_line (machine, "maincpu", 0, (i ? ASSERT_LINE : CLEAR_LINE));
 }
 
 static INTERRUPT_GEN( big10_interrupt )
 {
-	v9938_interrupt(device->machine, 0);
+	v9938_interrupt(device->machine(), 0);
 }
 
 
 static VIDEO_START( big10 )
 {
 	VIDEO_START_CALL(generic_bitmapped);
-	v9938_init (machine, 0, *machine->primary_screen, machine->generic.tmpbitmap, MODEL_V9938, VDP_MEM, big10_vdp_interrupt);
+	v9938_init (machine, 0, *machine.primary_screen, machine.generic.tmpbitmap, MODEL_V9938, VDP_MEM, big10_vdp_interrupt);
 	v9938_reset(0);
 }
 
@@ -103,23 +114,24 @@ static MACHINE_RESET(big10)
 *  Input Ports Demux & Common Routines  *
 ****************************************/
 
-static UINT8 mux_data;
 
 static WRITE8_DEVICE_HANDLER( mux_w )
 {
-	mux_data = ~data;
+	big10_state *state = device->machine().driver_data<big10_state>();
+	state->m_mux_data = ~data;
 }
 
 static READ8_HANDLER( mux_r )
 {
-	switch(mux_data)
+	big10_state *state = space->machine().driver_data<big10_state>();
+	switch(state->m_mux_data)
 	{
-		case 1: return input_port_read(space->machine, "IN1");
-		case 2: return input_port_read(space->machine, "IN2");
-		case 4: return input_port_read(space->machine, "IN3");
+		case 1: return input_port_read(space->machine(), "IN1");
+		case 2: return input_port_read(space->machine(), "IN2");
+		case 4: return input_port_read(space->machine(), "IN3");
 	}
 
-	return mux_data;
+	return state->m_mux_data;
 }
 
 
@@ -127,13 +139,13 @@ static READ8_HANDLER( mux_r )
 *             Memory Map              *
 **************************************/
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xdfff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0xf000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( main_io, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( main_io, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(mux_r)			/* present in test mode */
 	AM_RANGE(0x02, 0x02) AM_READ_PORT("SYSTEM")	/* coins and service */
@@ -238,7 +250,7 @@ static const ay8910_interface ay8910_config =
 *           Machine Driver            *
 **************************************/
 
-static MACHINE_CONFIG_START( big10, driver_device )
+static MACHINE_CONFIG_START( big10, big10_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80, MASTER_CLOCK/6)	/* guess */
@@ -255,14 +267,13 @@ static MACHINE_CONFIG_START( big10, driver_device )
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-
 	MCFG_SCREEN_SIZE(512 + 32, (212 + 28) * 2)
 	MCFG_SCREEN_VISIBLE_AREA(0, 512 + 32 - 1, 0, (212 + 28) * 2 - 1)
+	MCFG_SCREEN_UPDATE(generic_bitmapped)
 
 	MCFG_PALETTE_LENGTH(512)
 	MCFG_PALETTE_INIT(v9938)
 	MCFG_VIDEO_START(big10)
-	MCFG_VIDEO_UPDATE(generic_bitmapped)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
