@@ -292,30 +292,43 @@
 #include "sound/discrete.h"
 
 
+class blitz_state : public driver_device
+{
+public:
+	blitz_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 *m_videoram;
+	UINT8 *m_colorram;
+	tilemap_t *m_bg_tilemap;
+	int m_mux_data;
+};
+
+
+
 /*********************************************
 *               Video Hardware               *
 *********************************************/
 
-static UINT8 *videoram;
-static UINT8 *colorram;
-static tilemap_t *bg_tilemap;
-
 
 static WRITE8_HANDLER( megadpkr_videoram_w )
 {
-	videoram[offset] = data;
-	tilemap_mark_tile_dirty(bg_tilemap, offset);
+	blitz_state *state = space->machine().driver_data<blitz_state>();
+	state->m_videoram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
 }
 
 static WRITE8_HANDLER( megadpkr_colorram_w )
 {
-	colorram[offset] = data;
-	tilemap_mark_tile_dirty(bg_tilemap, offset);
+	blitz_state *state = space->machine().driver_data<blitz_state>();
+	state->m_colorram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
 }
 
 
 static TILE_GET_INFO( get_bg_tile_info )
 {
+	blitz_state *state = machine.driver_data<blitz_state>();
 /*  - bits -
     7654 3210
     --xx xx--   tiles color.
@@ -324,8 +337,8 @@ static TILE_GET_INFO( get_bg_tile_info )
     xx-- ----   unused.
 */
 
-	int attr = colorram[tile_index];
-	int code = ((attr & 1) << 8) | videoram[tile_index];
+	int attr = state->m_colorram[tile_index];
+	int code = ((attr & 1) << 8) | state->m_videoram[tile_index];
 	int bank = (attr & 0x02) >> 1;	/* bit 1 switch the gfx banks */
 	int color = (attr & 0x3c) >> 2;	/* bits 2-3-4-5 for color */
 
@@ -335,12 +348,14 @@ static TILE_GET_INFO( get_bg_tile_info )
 
 static VIDEO_START( megadpkr )
 {
-	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
+	blitz_state *state = machine.driver_data<blitz_state>();
+	state->m_bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows, 8, 8, 32, 32);
 }
 
-static VIDEO_UPDATE( megadpkr )
+static SCREEN_UPDATE( megadpkr )
 {
-	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
+	blitz_state *state = screen->machine().driver_data<blitz_state>();
+	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
 	return 0;
 }
 
@@ -365,7 +380,7 @@ static PALETTE_INIT( megadpkr )
 
 	if (color_prom == 0) return;
 
-	for (i = 0;i < machine->total_colors();i++)
+	for (i = 0;i < machine.total_colors();i++)
 	{
 		int bit0, bit1, bit2, bit3, r, g, b, bk;
 
@@ -394,7 +409,6 @@ static PALETTE_INIT( megadpkr )
 *               R/W Handlers               *
 *******************************************/
 
-static int mux_data = 0;
 
 /* Inputs (buttons) are multiplexed.
    There are 4 sets of 5 bits each and are connected to PIA0, portA.
@@ -402,12 +416,13 @@ static int mux_data = 0;
 */
 static READ8_DEVICE_HANDLER( megadpkr_mux_port_r )
 {
-	switch( mux_data & 0xf0 )		/* bits 4-7 */
+	blitz_state *state = device->machine().driver_data<blitz_state>();
+	switch( state->m_mux_data & 0xf0 )		/* bits 4-7 */
 	{
-		case 0x10: return input_port_read(device->machine, "IN0-0");
-		case 0x20: return input_port_read(device->machine, "IN0-1");
-		case 0x40: return input_port_read(device->machine, "IN0-2");
-		case 0x80: return input_port_read(device->machine, "IN0-3");
+		case 0x10: return input_port_read(device->machine(), "IN0-0");
+		case 0x20: return input_port_read(device->machine(), "IN0-1");
+		case 0x40: return input_port_read(device->machine(), "IN0-2");
+		case 0x80: return input_port_read(device->machine(), "IN0-3");
 	}
 	return 0xff;
 }
@@ -415,7 +430,8 @@ static READ8_DEVICE_HANDLER( megadpkr_mux_port_r )
 
 static WRITE8_DEVICE_HANDLER( mux_w )
 {
-	mux_data = data ^ 0xff;	/* inverted */
+	blitz_state *state = device->machine().driver_data<blitz_state>();
+	state->m_mux_data = data ^ 0xff;	/* inverted */
 }
 
 
@@ -433,9 +449,9 @@ static WRITE8_DEVICE_HANDLER( lamps_a_w )
 //  output_set_lamp_value(4, 1 - ((data >> 4) & 1));    /* Lamp 4 */
 
 //  popmessage("written : %02X", data);
-//  coin_counter_w(device->machine, 0, data & 0x40);    /* counter1 */
-//  coin_counter_w(device->machine, 1, data & 0x80);    /* counter2 */
-//  coin_counter_w(device->machine, 2, data & 0x20);    /* counter3 */
+//  coin_counter_w(device->machine(), 0, data & 0x40);    /* counter1 */
+//  coin_counter_w(device->machine(), 1, data & 0x80);    /* counter2 */
+//  coin_counter_w(device->machine(), 2, data & 0x20);    /* counter3 */
 
 /*  Counters:
 
@@ -453,24 +469,24 @@ static WRITE8_DEVICE_HANDLER( sound_w )
 *           Memory Map Information           *
 *********************************************/
 
-static ADDRESS_MAP_START( megadpkr_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( megadpkr_map, AS_PROGRAM, 8 )
 //  ADDRESS_MAP_GLOBAL_MASK(0x7fff) // seems that hardware is playing with A14 & A15 CPU lines...
 
 	AM_RANGE(0x0000, 0x07ff) AM_RAM //AM_SHARE("nvram")   /* battery backed RAM */
 //  AM_RANGE(0x0800, 0x0800) AM_DEVWRITE("crtc", mc6845_address_w)
 //  AM_RANGE(0x0801, 0x0801) AM_DEVREADWRITE("crtc", mc6845_register_r, mc6845_register_w)
-	AM_RANGE(0x0844, 0x0847) AM_DEVREADWRITE("pia0", pia6821_r, pia6821_w)
-	AM_RANGE(0x0848, 0x084b) AM_DEVREADWRITE("pia1", pia6821_r, pia6821_w)
+	AM_RANGE(0x0844, 0x0847) AM_DEVREADWRITE_MODERN("pia0", pia6821_device, read, write)
+	AM_RANGE(0x0848, 0x084b) AM_DEVREADWRITE_MODERN("pia1", pia6821_device, read, write)
 
 /*  There is another set of PIAs controlled by the code.
     Maybe they are just mirrors...
 
-    AM_RANGE(0x10f4, 0x10f7) AM_DEVREADWRITE("pia0", pia6821_r, pia6821_w)
-    AM_RANGE(0x10f8, 0x10fb) AM_DEVREADWRITE("pia1", pia6821_r, pia6821_w)
+    AM_RANGE(0x10f4, 0x10f7) AM_DEVREADWRITE_MODERN("pia0", pia6821_device, read, write)
+    AM_RANGE(0x10f8, 0x10fb) AM_DEVREADWRITE_MODERN("pia1", pia6821_device, read, write)
 */
 
-	AM_RANGE(0x1000, 0x13ff) AM_RAM_WRITE(megadpkr_videoram_w) AM_BASE(&videoram)
-	AM_RANGE(0x1800, 0x1bff) AM_RAM_WRITE(megadpkr_colorram_w) AM_BASE(&colorram)
+	AM_RANGE(0x1000, 0x13ff) AM_RAM_WRITE(megadpkr_videoram_w) AM_BASE_MEMBER(blitz_state, m_videoram)
+	AM_RANGE(0x1800, 0x1bff) AM_RAM_WRITE(megadpkr_colorram_w) AM_BASE_MEMBER(blitz_state, m_colorram)
 
 	AM_RANGE(0xc000, 0xffff) AM_ROM
 ADDRESS_MAP_END
@@ -574,7 +590,7 @@ ADDRESS_MAP_END
 
 
 /*
-static ADDRESS_MAP_START( mcu_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( mcu_map, AS_PROGRAM, 8 )
     ADDRESS_MAP_GLOBAL_MASK(0x7ff)
     AM_RANGE(0x0080, 0x07ff) AM_ROM
 ADDRESS_MAP_END
@@ -767,7 +783,7 @@ static const mc6845_interface mc6845_intf =
 *              Machine Drivers               *
 *********************************************/
 
-static MACHINE_CONFIG_START( megadpkr, driver_device )
+static MACHINE_CONFIG_START( megadpkr, blitz_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M6502, CPU_CLOCK)
@@ -789,6 +805,7 @@ static MACHINE_CONFIG_START( megadpkr, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE((32)*8, (32)*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 32*8-1)
+	MCFG_SCREEN_UPDATE(megadpkr)
 
 	MCFG_MC6845_ADD("crtc", MC6845, CPU_CLOCK, mc6845_intf)
 
@@ -796,7 +813,6 @@ static MACHINE_CONFIG_START( megadpkr, driver_device )
 	MCFG_PALETTE_INIT(megadpkr)
 	MCFG_PALETTE_LENGTH(256)
 	MCFG_VIDEO_START(megadpkr)
-	MCFG_VIDEO_UPDATE(megadpkr)
 
 MACHINE_CONFIG_END
 
