@@ -34,7 +34,7 @@ TODO:
 
  - scroll (writes to $91800 and VIA port A - not used in game (only in test mode))
  - music - writes  ($20-$30 bytes) to $93000-$93003 range
- - VIA 6522(interrupt gen , ports)
+ - VIA 6522(ports)
  - Crt
  - interrupts
  - missing gfx elements
@@ -101,20 +101,29 @@ Main board:
 */
 
 #include "emu.h"
-#include "deprecat.h"
 #include "cpu/m68000/m68000.h"
 #include "machine/6522via.h"
 #include "sound/ay8910.h"
 #include "sound/okim6295.h"
 
-static UINT16 *bmcbowl_vid1;
-static UINT16 *bmcbowl_vid2;
-static UINT8 *bmc_colorram;
 
-static UINT8 *stats_ram;
-static size_t	stats_ram_size;
-static int clr_offset=0;
-static int bmc_input=0;
+class bmcbowl_state : public driver_device
+{
+public:
+	bmcbowl_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT16 *m_vid1;
+	UINT16 *m_vid2;
+	UINT8 *m_bmc_colorram;
+	UINT8 *m_stats_ram;
+	size_t m_stats_ram_size;
+	int m_clr_offset;
+	int m_bmc_input;
+};
+
+
+
 
 #define NVRAM_HACK
 
@@ -122,43 +131,44 @@ static VIDEO_START( bmcbowl )
 {
 }
 
-static VIDEO_UPDATE( bmcbowl )
+static SCREEN_UPDATE( bmcbowl )
 {
+	bmcbowl_state *state = screen->machine().driver_data<bmcbowl_state>();
 /*
       280x230,4 bitmap layers, 8bpp,
         missing scroll and priorities   (maybe fixed ones)
 */
 
 	int x,y,z,pixdat;
-	bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
+	bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine()));
 
 	z=0;
 	for (y=0;y<230;y++)
 	{
 		for (x=0;x<280;x+=2)
 		{
-			pixdat = bmcbowl_vid2[0x8000+z];
+			pixdat = state->m_vid2[0x8000+z];
 
 			if(pixdat&0xff)
 				*BITMAP_ADDR16(bitmap, y, x+1) = (pixdat&0xff);
 			if(pixdat>>8)
 				*BITMAP_ADDR16(bitmap, y, x) = (pixdat>>8);
 
-			pixdat = bmcbowl_vid2[z];
+			pixdat = state->m_vid2[z];
 
 			if(pixdat&0xff)
 				*BITMAP_ADDR16(bitmap, y, x+1) = (pixdat&0xff);
 			if(pixdat>>8)
 				*BITMAP_ADDR16(bitmap, y, x) = (pixdat>>8);
 
-			pixdat = bmcbowl_vid1[0x8000+z];
+			pixdat = state->m_vid1[0x8000+z];
 
 			if(pixdat&0xff)
 				*BITMAP_ADDR16(bitmap, y, x+1) = (pixdat&0xff);
 			if(pixdat>>8)
 				*BITMAP_ADDR16(bitmap, y, x) = (pixdat>>8);
 
-			pixdat = bmcbowl_vid1[z];
+			pixdat = state->m_vid1[z];
 
 			if(pixdat&0xff)
 				*BITMAP_ADDR16(bitmap, y, x+1) = (pixdat&0xff);
@@ -173,15 +183,15 @@ static VIDEO_UPDATE( bmcbowl )
 
 static READ16_HANDLER( bmc_random_read )
 {
-	return space->machine->rand();
+	return space->machine().rand();
 }
 
 static READ16_HANDLER( bmc_protection_r )
 {
-	switch(cpu_get_previouspc(space->cpu))
+	switch(cpu_get_previouspc(&space->device()))
 	{
 		case 0xca68:
-			switch(cpu_get_reg(space->cpu, M68K_D2))
+			switch(cpu_get_reg(&space->device(), M68K_D2))
 			{
 				case 0: 		 return 0x37<<8;
 				case 0x1013: return 0;
@@ -189,20 +199,22 @@ static READ16_HANDLER( bmc_protection_r )
 			}
 			break;
 	}
-	logerror("Protection read @ %X\n",cpu_get_previouspc(space->cpu));
-	return space->machine->rand();
+	logerror("Protection read @ %X\n",cpu_get_previouspc(&space->device()));
+	return space->machine().rand();
 }
 
 static WRITE16_HANDLER( bmc_RAMDAC_offset_w )
 {
-	clr_offset=data*3;
+	bmcbowl_state *state = space->machine().driver_data<bmcbowl_state>();
+	state->m_clr_offset=data*3;
 }
 
 static WRITE16_HANDLER( bmc_RAMDAC_color_w )
 {
-	bmc_colorram[clr_offset]=data;
-	palette_set_color_rgb(space->machine,clr_offset/3,pal6bit(bmc_colorram[(clr_offset/3)*3]),pal6bit(bmc_colorram[(clr_offset/3)*3+1]),pal6bit(bmc_colorram[(clr_offset/3)*3+2]));
-	clr_offset=(clr_offset+1)%768;
+	bmcbowl_state *state = space->machine().driver_data<bmcbowl_state>();
+	state->m_bmc_colorram[state->m_clr_offset]=data;
+	palette_set_color_rgb(space->machine(),state->m_clr_offset/3,pal6bit(state->m_bmc_colorram[(state->m_clr_offset/3)*3]),pal6bit(state->m_bmc_colorram[(state->m_clr_offset/3)*3+1]),pal6bit(state->m_bmc_colorram[(state->m_clr_offset/3)*3+2]));
+	state->m_clr_offset=(state->m_clr_offset+1)%768;
 }
 
 static WRITE16_HANDLER( scroll_w )
@@ -213,7 +225,7 @@ static WRITE16_HANDLER( scroll_w )
 
 static READ8_DEVICE_HANDLER(via_b_in)
 {
-	return input_port_read(device->machine, "IN3");
+	return input_port_read(device->machine(), "IN3");
 }
 
 
@@ -233,9 +245,9 @@ static WRITE8_DEVICE_HANDLER(via_ca2_out)
 }
 
 
-static void via_irq(device_t *device, int state)
+static WRITE8_DEVICE_HANDLER(via_irq)
 {
-	//used
+       cputag_set_input_line(device->machine(), "maincpu", 4, data ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -276,41 +288,42 @@ static const UINT8 bmc_nv3[]=
 };
 
 
-static void init_stats(const UINT8 *table, int table_len, int address)
+static void init_stats(bmcbowl_state *state, const UINT8 *table, int table_len, int address)
 {
 	int i;
 	for (i=0; i<table_len; i++)
-		stats_ram[address+2*i]=table[i];
+		state->m_stats_ram[address+2*i]=table[i];
 }
 #endif
 
 static NVRAM_HANDLER( bmcbowl )
 {
+	bmcbowl_state *state = machine.driver_data<bmcbowl_state>();
 	int i;
 
 	if (read_or_write)
-		mame_fwrite(file, stats_ram, stats_ram_size);
+		file->write(state->m_stats_ram, state->m_stats_ram_size);
 	else
 
 #ifdef NVRAM_HACK
-	for (i = 0; i < stats_ram_size; i++)
-		stats_ram[i] = 0xff;
+	for (i = 0; i < state->m_stats_ram_size; i++)
+		state->m_stats_ram[i] = 0xff;
 
-	init_stats(bmc_nv1,ARRAY_LENGTH(bmc_nv1),0);
-	init_stats(bmc_nv2,ARRAY_LENGTH(bmc_nv2),0x3b0);
-	init_stats(bmc_nv3,ARRAY_LENGTH(bmc_nv3),0xfe2);
+	init_stats(state,bmc_nv1,ARRAY_LENGTH(bmc_nv1),0);
+	init_stats(state,bmc_nv2,ARRAY_LENGTH(bmc_nv2),0x3b0);
+	init_stats(state,bmc_nv3,ARRAY_LENGTH(bmc_nv3),0xfe2);
 #else
 	if (file)
-		mame_fread(file, stats_ram, stats_ram_size);
+		file->read(state->m_stats_ram, state->m_stats_ram_size);
 	else
 
-		for (i = 0; i < stats_ram_size; i++)
-			stats_ram[i] = 0xff;
+		for (i = 0; i < state->m_stats_ram_size; i++)
+			state->m_stats_ram[i] = 0xff;
 #endif
 
 }
 
-static ADDRESS_MAP_START( bmcbowl_mem, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( bmcbowl_mem, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x01ffff) AM_ROM
 
 	AM_RANGE(0x090000, 0x090001) AM_WRITE(bmc_RAMDAC_offset_w)
@@ -327,12 +340,12 @@ static ADDRESS_MAP_START( bmcbowl_mem, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x092800, 0x092803) AM_DEVWRITE8("aysnd", ay8910_data_address_w, 0xff00)
 	AM_RANGE(0x092802, 0x092803) AM_DEVREAD8("aysnd", ay8910_r, 0xff00)
 	AM_RANGE(0x093802, 0x093803) AM_READ_PORT("IN0")
-	AM_RANGE(0x095000, 0x095fff) AM_RAM AM_BASE((UINT16 **)&stats_ram) AM_SIZE(&stats_ram_size) /* 8 bit */
+	AM_RANGE(0x095000, 0x095fff) AM_RAM AM_BASE_MEMBER(bmcbowl_state, m_stats_ram) AM_SIZE_MEMBER(bmcbowl_state, m_stats_ram_size) /* 8 bit */
 	AM_RANGE(0x097000, 0x097001) AM_READNOP
 	AM_RANGE(0x140000, 0x1bffff) AM_ROM
-	AM_RANGE(0x1c0000, 0x1effff) AM_RAM AM_BASE(&bmcbowl_vid1)
+	AM_RANGE(0x1c0000, 0x1effff) AM_RAM AM_BASE_MEMBER(bmcbowl_state, m_vid1)
 	AM_RANGE(0x1f0000, 0x1fffff) AM_RAM
-	AM_RANGE(0x200000, 0x21ffff) AM_RAM AM_BASE(&bmcbowl_vid2)
+	AM_RANGE(0x200000, 0x21ffff) AM_RAM AM_BASE_MEMBER(bmcbowl_state, m_vid2)
 
 	AM_RANGE(0x28c000, 0x28c001) AM_DEVREADWRITE8_MODERN("oki", okim6295_device, read, write, 0xff00)
 
@@ -432,19 +445,21 @@ INPUT_PORTS_END
 
 static READ8_DEVICE_HANDLER(dips1_r)
 {
-	switch(bmc_input)
+	bmcbowl_state *state = device->machine().driver_data<bmcbowl_state>();
+	switch(state->m_bmc_input)
 	{
-			case 0x00:	return  input_port_read(device->machine, "IN1");
-			case 0x40:	return  input_port_read(device->machine, "IN2");
+			case 0x00:	return  input_port_read(device->machine(), "IN1");
+			case 0x40:	return  input_port_read(device->machine(), "IN2");
 	}
-	logerror("%s:unknown input - %X\n",cpuexec_describe_context(device->machine),bmc_input);
+	logerror("%s:unknown input - %X\n",device->machine().describe_context(),state->m_bmc_input);
 	return 0xff;
 }
 
 
 static WRITE8_DEVICE_HANDLER(input_mux_w)
 {
-	bmc_input=data;
+	bmcbowl_state *state = device->machine().driver_data<bmcbowl_state>();
+	state->m_bmc_input=data;
 }
 
 
@@ -465,26 +480,17 @@ static const via6522_interface via_interface =
 	/*inputs : CA/B1,CA/B2 */ DEVCB_NULL, DEVCB_NULL, DEVCB_NULL, DEVCB_NULL,
 	/*outputs: A/B         */ DEVCB_HANDLER(via_a_out), DEVCB_HANDLER(via_b_out),
 	/*outputs: CA/B1,CA/B2 */ DEVCB_NULL, DEVCB_NULL, DEVCB_HANDLER(via_ca2_out), DEVCB_NULL,
-	/*irq                  */ DEVCB_LINE(via_irq)
+	/*irq                  */ DEVCB_HANDLER(via_irq)
 };
 
 static MACHINE_RESET( bmcbowl )
 {
 }
 
-static INTERRUPT_GEN( bmc_interrupt )
-{
-	if (cpu_getiloops(device))
-		cpu_set_input_line(device, 4, HOLD_LINE);
-	else
-		cpu_set_input_line(device, 2, HOLD_LINE);
-}
-
-static MACHINE_CONFIG_START( bmcbowl, driver_device )
+static MACHINE_CONFIG_START( bmcbowl, bmcbowl_state )
 	MCFG_CPU_ADD("maincpu", M68000, 21477270/2 )
 	MCFG_CPU_PROGRAM_MAP(bmcbowl_mem)
-	MCFG_CPU_VBLANK_INT_HACK(bmc_interrupt,2)
-
+	MCFG_CPU_VBLANK_INT("screen",irq2_line_hold)
 
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
@@ -492,11 +498,11 @@ static MACHINE_CONFIG_START( bmcbowl, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(35*8, 30*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 35*8-1, 0*8, 29*8-1)
+	MCFG_SCREEN_UPDATE(bmcbowl)
 
 	MCFG_PALETTE_LENGTH(256)
 
 	MCFG_VIDEO_START(bmcbowl)
-	MCFG_VIDEO_UPDATE(bmcbowl)
 
 	MCFG_NVRAM_HANDLER(bmcbowl)
 	MCFG_MACHINE_RESET(bmcbowl)
@@ -536,7 +542,8 @@ ROM_END
 
 static DRIVER_INIT(bmcbowl)
 {
-	bmc_colorram = auto_alloc_array(machine, UINT8, 768);
+	bmcbowl_state *state = machine.driver_data<bmcbowl_state>();
+	state->m_bmc_colorram = auto_alloc_array(machine, UINT8, 768);
 }
 
-GAME( 1994, bmcbowl,    0, bmcbowl,    bmcbowl,    bmcbowl, ROT0,  "BMC", "BMC Bowling", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS )
+GAME( 1994, bmcbowl,    0, bmcbowl,    bmcbowl,    bmcbowl, ROT0,  "BMC", "Konkyuu no Hoshi", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS )
