@@ -54,8 +54,8 @@ Dip locations verified with Fabtek manual for the trackball version
 
 static MACHINE_RESET( cabalbl )
 {
-	cabal_state *state = machine->driver_data<cabal_state>();
-	state->sound_command1 = state->sound_command2 = 0xff;
+	cabal_state *state = machine.driver_data<cabal_state>();
+	state->m_sound_command1 = state->m_sound_command2 = 0xff;
 }
 
 
@@ -63,16 +63,16 @@ static MACHINE_RESET( cabalbl )
 
 static WRITE16_HANDLER( cabalbl_sndcmd_w )
 {
-	cabal_state *state = space->machine->driver_data<cabal_state>();
+	cabal_state *state = space->machine().driver_data<cabal_state>();
 
 	switch (offset)
 	{
 		case 0x0:
-			state->sound_command1 = data;
+			state->m_sound_command1 = data;
 			break;
 
 		case 0x1: /* ?? */
-			state->sound_command2 = data & 0xff;
+			state->m_sound_command2 = data & 0xff;
 			break;
 	}
 }
@@ -81,25 +81,25 @@ static WRITE16_HANDLER( cabalbl_sndcmd_w )
 
 static WRITE16_HANDLER( track_reset_w )
 {
-	cabal_state *state = space->machine->driver_data<cabal_state>();
+	cabal_state *state = space->machine().driver_data<cabal_state>();
 	int i;
 	static const char *const track_names[] = { "IN0", "IN1", "IN2", "IN3" };
 
 	for (i = 0; i < 4; i++)
-		state->last[i] = input_port_read(space->machine, track_names[i]);
+		state->m_last[i] = input_port_read(space->machine(), track_names[i]);
 }
 
 static READ16_HANDLER( track_r )
 {
-	cabal_state *state = space->machine->driver_data<cabal_state>();
+	cabal_state *state = space->machine().driver_data<cabal_state>();
 
 	switch (offset)
 	{
 		default:
-		case 0:	return (( input_port_read(space->machine, "IN0") - state->last[0]) & 0x00ff)		 | (((input_port_read(space->machine, "IN2") - state->last[2]) & 0x00ff) << 8);	/* X lo */
-		case 1:	return (((input_port_read(space->machine, "IN0") - state->last[0]) & 0xff00) >> 8) | (( input_port_read(space->machine, "IN2") - state->last[2]) & 0xff00);			/* X hi */
-		case 2:	return (( input_port_read(space->machine, "IN1") - state->last[1]) & 0x00ff)		 | (((input_port_read(space->machine, "IN3") - state->last[3]) & 0x00ff) << 8);	/* Y lo */
-		case 3:	return (((input_port_read(space->machine, "IN1") - state->last[1]) & 0xff00) >> 8) | (( input_port_read(space->machine, "IN3") - state->last[3]) & 0xff00);			/* Y hi */
+		case 0:	return (( input_port_read(space->machine(), "IN0") - state->m_last[0]) & 0x00ff)		 | (((input_port_read(space->machine(), "IN2") - state->m_last[2]) & 0x00ff) << 8);	/* X lo */
+		case 1:	return (((input_port_read(space->machine(), "IN0") - state->m_last[0]) & 0xff00) >> 8) | (( input_port_read(space->machine(), "IN2") - state->m_last[2]) & 0xff00);			/* X hi */
+		case 2:	return (( input_port_read(space->machine(), "IN1") - state->m_last[1]) & 0x00ff)		 | (((input_port_read(space->machine(), "IN3") - state->m_last[3]) & 0x00ff) << 8);	/* Y lo */
+		case 3:	return (((input_port_read(space->machine(), "IN1") - state->m_last[1]) & 0xff00) >> 8) | (( input_port_read(space->machine(), "IN3") - state->m_last[3]) & 0xff00);			/* Y hi */
 	}
 }
 
@@ -109,23 +109,23 @@ static WRITE16_HANDLER( cabal_sound_irq_trigger_word_w )
 	seibu_main_word_w(space,4,data,mem_mask);
 
 	/* spin for a while to let the Z80 read the command, otherwise coins "stick" */
-	cpu_spinuntil_time(space->cpu, ATTOTIME_IN_USEC(50));
+	device_spin_until_time(&space->device(), attotime::from_usec(50));
 }
 
 static WRITE16_HANDLER( cabalbl_sound_irq_trigger_word_w )
 {
-	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE );
+	cputag_set_input_line(space->machine(), "audiocpu", INPUT_LINE_NMI, PULSE_LINE );
 }
 
 
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x00000, 0x3ffff) AM_ROM
 	AM_RANGE(0x40000, 0x437ff) AM_RAM
-	AM_RANGE(0x43800, 0x43fff) AM_RAM AM_BASE_SIZE_MEMBER(cabal_state, spriteram, spriteram_size)
+	AM_RANGE(0x43800, 0x43fff) AM_RAM AM_BASE_SIZE_MEMBER(cabal_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x44000, 0x4ffff) AM_RAM
-	AM_RANGE(0x60000, 0x607ff) AM_RAM_WRITE(cabal_text_videoram16_w) AM_BASE_MEMBER(cabal_state, colorram)
-	AM_RANGE(0x80000, 0x801ff) AM_RAM_WRITE(cabal_background_videoram16_w) AM_BASE_MEMBER(cabal_state, videoram)
+	AM_RANGE(0x60000, 0x607ff) AM_RAM_WRITE(cabal_text_videoram16_w) AM_BASE_MEMBER(cabal_state, m_colorram)
+	AM_RANGE(0x80000, 0x801ff) AM_RAM_WRITE(cabal_background_videoram16_w) AM_BASE_MEMBER(cabal_state, m_videoram)
 	AM_RANGE(0x80200, 0x803ff) AM_RAM
 	AM_RANGE(0xa0000, 0xa0001) AM_READ_PORT("DSW")
 	AM_RANGE(0xa0008, 0xa000f) AM_READ(track_r)
@@ -138,13 +138,13 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xe8000, 0xe800d) AM_READWRITE(seibu_main_word_r, seibu_main_word_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( cabalbl_main_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( cabalbl_main_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x00000, 0x3ffff) AM_ROM
 	AM_RANGE(0x40000, 0x437ff) AM_RAM
-	AM_RANGE(0x43800, 0x43fff) AM_RAM AM_BASE_SIZE_MEMBER(cabal_state, spriteram, spriteram_size)
+	AM_RANGE(0x43800, 0x43fff) AM_RAM AM_BASE_SIZE_MEMBER(cabal_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x44000, 0x4ffff) AM_RAM
-	AM_RANGE(0x60000, 0x607ff) AM_RAM_WRITE(cabal_text_videoram16_w) AM_BASE_MEMBER(cabal_state, colorram)
-	AM_RANGE(0x80000, 0x801ff) AM_RAM_WRITE(cabal_background_videoram16_w) AM_BASE_MEMBER(cabal_state, videoram)
+	AM_RANGE(0x60000, 0x607ff) AM_RAM_WRITE(cabal_text_videoram16_w) AM_BASE_MEMBER(cabal_state, m_colorram)
+	AM_RANGE(0x80000, 0x801ff) AM_RAM_WRITE(cabal_background_videoram16_w) AM_BASE_MEMBER(cabal_state, m_videoram)
 	AM_RANGE(0x80200, 0x803ff) AM_RAM
 	AM_RANGE(0xa0000, 0xa0001) AM_READ_PORT("DSW")
 	AM_RANGE(0xa0008, 0xa0009) AM_READ_PORT("JOY")
@@ -162,27 +162,27 @@ ADDRESS_MAP_END
 
 static READ8_HANDLER( cabalbl_snd2_r )
 {
-	cabal_state *state = space->machine->driver_data<cabal_state>();
+	cabal_state *state = space->machine().driver_data<cabal_state>();
 
-	return BITSWAP8(state->sound_command2, 7,2,4,5,3,6,1,0);
+	return BITSWAP8(state->m_sound_command2, 7,2,4,5,3,6,1,0);
 }
 
 static READ8_HANDLER( cabalbl_snd1_r )
 {
-	cabal_state *state = space->machine->driver_data<cabal_state>();
+	cabal_state *state = space->machine().driver_data<cabal_state>();
 
-	return BITSWAP8(state->sound_command1, 7,2,4,5,3,6,1,0);
+	return BITSWAP8(state->m_sound_command1, 7,2,4,5,3,6,1,0);
 }
 
 static WRITE8_HANDLER( cabalbl_coin_w )
 {
-	coin_counter_w(space->machine, 0, data & 1);
-	coin_counter_w(space->machine, 1, data & 2);
+	coin_counter_w(space->machine(), 0, data & 1);
+	coin_counter_w(space->machine(), 1, data & 2);
 
 	//data & 0x40? video enable?
 }
 
-static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x27ff) AM_RAM
 	AM_RANGE(0x4001, 0x4001) AM_WRITE(seibu_irq_clear_w)
@@ -201,7 +201,7 @@ static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( cabalbl_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( cabalbl_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x2fff) AM_RAM
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(soundlatch3_w)
@@ -227,21 +227,21 @@ static WRITE8_DEVICE_HANDLER( cabalbl_adpcm_w )
 	msm5205_vclk_w(device,0);
 }
 
-static ADDRESS_MAP_START( cabalbl_talk1_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( cabalbl_talk1_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xffff) AM_ROM AM_WRITENOP
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( cabalbl_talk1_portmap, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( cabalbl_talk1_portmap, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(soundlatch3_r)
 	AM_RANGE(0x01, 0x01) AM_DEVWRITE("msm1", cabalbl_adpcm_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( cabalbl_talk2_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( cabalbl_talk2_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xffff) AM_ROM AM_WRITENOP
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( cabalbl_talk2_portmap, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( cabalbl_talk2_portmap, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(soundlatch4_r)
 	AM_RANGE(0x01, 0x01) AM_DEVWRITE("msm2", cabalbl_adpcm_w)
@@ -464,7 +464,7 @@ GFXDECODE_END
 
 static void irqhandler(device_t *device, int irq)
 {
-	cputag_set_input_line(device->machine, "audiocpu", 0, irq ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine(), "audiocpu", 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static const ym2151_interface cabalbl_ym2151_interface =
@@ -503,12 +503,12 @@ static MACHINE_CONFIG_START( cabal, cabal_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(cabal)
 
 	MCFG_GFXDECODE(cabal)
 	MCFG_PALETTE_LENGTH(1024)
 
 	MCFG_VIDEO_START(cabal)
-	MCFG_VIDEO_UPDATE(cabal)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -518,9 +518,11 @@ static MACHINE_CONFIG_START( cabal, cabal_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS,"mono", 0.80)
 
 	MCFG_SOUND_ADD("adpcm1", SEIBU_ADPCM, 8000) /* it should use the msm5205 */
+	MCFG_SOUND_CONFIG(seibu_adpcm1_intf)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS,"mono", 0.40)
 
 	MCFG_SOUND_ADD("adpcm2", SEIBU_ADPCM, 8000) /* it should use the msm5205 */
+	MCFG_SOUND_CONFIG(seibu_adpcm2_intf)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS,"mono", 0.40)
 MACHINE_CONFIG_END
 
@@ -547,7 +549,7 @@ static MACHINE_CONFIG_START( cabalbl, cabal_state )
 	MCFG_CPU_IO_MAP(cabalbl_talk2_portmap)
 	MCFG_CPU_PERIODIC_INT(irq0_line_hold,8000)
 
-	MCFG_QUANTUM_TIME(HZ(600))
+	MCFG_QUANTUM_TIME(attotime::from_hz(600))
 
 	MCFG_MACHINE_RESET(cabalbl)
 
@@ -558,12 +560,12 @@ static MACHINE_CONFIG_START( cabalbl, cabal_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(cabal)
 
 	MCFG_GFXDECODE(cabal)
 	MCFG_PALETTE_LENGTH(1024)
 
 	MCFG_VIDEO_START(cabal)
-	MCFG_VIDEO_UPDATE(cabal)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -617,9 +619,11 @@ ROM_START( cabal )
 	ROM_LOAD16_BYTE( "sp_rom7.bin",   0x60000, 0x10000, CRC(55c44764) SHA1(7fad1f2084664b5b4d1384c8081371b0c79c4f5e) )
 	ROM_LOAD16_BYTE( "sp_rom8.bin",   0x60001, 0x10000, CRC(702735c9) SHA1(e4ac799dc85ff5b7c8e578611605989c78f9e8b3) )
 
-	ROM_REGION( 0x20000, "adpcm", 0 )	/* Samples */
+	ROM_REGION( 0x10000, "adpcm1", 0 )	/* Samples */
 	ROM_LOAD( "2-1s",           0x00000, 0x10000, CRC(850406b4) SHA1(23ac1650c6d6f35607a5264b3aa89868401a645a) )
-	ROM_LOAD( "1-1u",           0x10000, 0x10000, CRC(8b3e0789) SHA1(b1450db1b1bada237c90930623e4def321099f13) )
+
+	ROM_REGION( 0x10000, "adpcm2", 0 )	/* Samples */
+	ROM_LOAD( "1-1u",           0x00000, 0x10000, CRC(8b3e0789) SHA1(b1450db1b1bada237c90930623e4def321099f13) )
 ROM_END
 
 ROM_START( cabala )
@@ -644,9 +648,11 @@ ROM_START( cabala )
 	ROM_REGION( 0x80000, "gfx3", 0 )
 	ROM_LOAD( "tad-1.5e",       0x00000, 0x80000, CRC(8324a7fe) SHA1(aed4470df35ec18e65e35bddc9c217a5019fdcbf) ) /* sprites */
 
-	ROM_REGION( 0x20000, "adpcm", 0 )	/* Samples */
+	ROM_REGION( 0x10000, "adpcm1", 0 )	/* Samples */
 	ROM_LOAD( "epr-a-2.1s",           0x00000, 0x10000, CRC(850406b4) SHA1(23ac1650c6d6f35607a5264b3aa89868401a645a) )
-	ROM_LOAD( "epr-a-1.1u",           0x10000, 0x10000, CRC(8b3e0789) SHA1(b1450db1b1bada237c90930623e4def321099f13) )
+
+	ROM_REGION( 0x10000, "adpcm2", 0 )	/* Samples */
+	ROM_LOAD( "epr-a-1.1u",           0x00000, 0x10000, CRC(8b3e0789) SHA1(b1450db1b1bada237c90930623e4def321099f13) )
 ROM_END
 
 ROM_START( cabalus )
@@ -669,9 +675,11 @@ ROM_START( cabalus )
 	ROM_REGION( 0x80000, "gfx3", 0 )
 	ROM_LOAD( "tad-1.5e",       0x00000, 0x80000, CRC(8324a7fe) SHA1(aed4470df35ec18e65e35bddc9c217a5019fdcbf) ) /* sprites */
 
-	ROM_REGION( 0x20000, "adpcm", 0 )	/* Samples? */
+	ROM_REGION( 0x10000, "adpcm1", 0 )	/* Samples? */
 	ROM_LOAD( "2-1s",           0x00000, 0x10000, CRC(850406b4) SHA1(23ac1650c6d6f35607a5264b3aa89868401a645a) )
-	ROM_LOAD( "1-1u",           0x10000, 0x10000, CRC(8b3e0789) SHA1(b1450db1b1bada237c90930623e4def321099f13) )
+
+	ROM_REGION( 0x10000, "adpcm2", 0 )	/* Samples */
+	ROM_LOAD( "1-1u",           0x00000, 0x10000, CRC(8b3e0789) SHA1(b1450db1b1bada237c90930623e4def321099f13) )
 
 	ROM_REGION( 0x0200, "proms", 0 )	/* unknown */
 	ROM_LOAD( "prom05.8e",      0x0000, 0x0100, CRC(a94b18c2) SHA1(e7db4c1efc9e313e36eef3f53ae5b2e573a38920) )
@@ -698,9 +706,11 @@ ROM_START( cabalus2 )
 	ROM_REGION( 0x80000, "gfx3", 0 )
 	ROM_LOAD( "tad-1.5e",       0x00000, 0x80000, CRC(8324a7fe) SHA1(aed4470df35ec18e65e35bddc9c217a5019fdcbf) ) /* sprites */
 
-	ROM_REGION( 0x20000, "adpcm", 0 )	/* Samples? */
+	ROM_REGION( 0x10000, "adpcm1", 0 )	/* Samples */
 	ROM_LOAD( "2-1s",           0x00000, 0x10000, CRC(850406b4) SHA1(23ac1650c6d6f35607a5264b3aa89868401a645a) )
-	ROM_LOAD( "1-1u",           0x10000, 0x10000, CRC(8b3e0789) SHA1(b1450db1b1bada237c90930623e4def321099f13) )
+
+	ROM_REGION( 0x10000, "adpcm2", 0 )	/* Samples */
+	ROM_LOAD( "1-1u",           0x00000, 0x10000, CRC(8b3e0789) SHA1(b1450db1b1bada237c90930623e4def321099f13) )
 
 	ROM_REGION( 0x0200, "proms", 0 )	/* unknown */
 	ROM_LOAD( "prom05.8e",      0x0000, 0x0100, CRC(a94b18c2) SHA1(e7db4c1efc9e313e36eef3f53ae5b2e573a38920) )
@@ -828,18 +838,20 @@ ROM_START( cabalbl2 )
 	ROM_LOAD16_BYTE( "c21.bin",   0x60000, 0x10000, CRC(55c44764) SHA1(7fad1f2084664b5b4d1384c8081371b0c79c4f5e) )
 	ROM_LOAD16_BYTE( "c25.bin",   0x60001, 0x10000, CRC(702735c9) SHA1(e4ac799dc85ff5b7c8e578611605989c78f9e8b3) )
 
-	ROM_REGION( 0x20000, "adpcm", 0 )	/* Samples */
+	ROM_REGION( 0x10000, "adpcm1", 0 )	/* Samples */
 	ROM_LOAD( "c2.bin",           0x00000, 0x10000, CRC(850406b4) SHA1(23ac1650c6d6f35607a5264b3aa89868401a645a) )
-	ROM_LOAD( "c1.bin",           0x10000, 0x10000, CRC(8b3e0789) SHA1(b1450db1b1bada237c90930623e4def321099f13) )
+
+	ROM_REGION( 0x10000, "adpcm2", 0 )	/* Samples */
+	ROM_LOAD( "c1.bin",           0x00000, 0x10000, CRC(8b3e0789) SHA1(b1450db1b1bada237c90930623e4def321099f13) )
 ROM_END
 
 
 
-static void seibu_sound_bootleg(running_machine *machine,const char *cpu,int length)
+static void seibu_sound_bootleg(running_machine &machine,const char *cpu,int length)
 {
-	address_space *space = cputag_get_address_space(machine, cpu, ADDRESS_SPACE_PROGRAM);
+	address_space *space = machine.device(cpu)->memory().space(AS_PROGRAM);
 	UINT8 *decrypt = auto_alloc_array(machine, UINT8, length);
-	UINT8 *rom = machine->region(cpu)->base();
+	UINT8 *rom = machine.region(cpu)->base();
 
 	space->set_decrypted_region(0x0000, (length < 0x10000) ? (length - 1) : 0x1fff, decrypt);
 
@@ -854,13 +866,15 @@ static void seibu_sound_bootleg(running_machine *machine,const char *cpu,int len
 static DRIVER_INIT( cabal )
 {
 	seibu_sound_decrypt(machine,"audiocpu",0x2000);
-	seibu_adpcm_decrypt(machine,"adpcm");
+	seibu_adpcm_decrypt(machine,"adpcm1");
+	seibu_adpcm_decrypt(machine,"adpcm2");
 }
 
 static DRIVER_INIT( cabalbl2 )
 {
 	seibu_sound_bootleg(machine,"audiocpu",0x2000);
-	seibu_adpcm_decrypt(machine,"adpcm");
+	seibu_adpcm_decrypt(machine,"adpcm1");
+	seibu_adpcm_decrypt(machine,"adpcm2");
 }
 
 
