@@ -26,71 +26,92 @@ are the same of IGS.  AMT may be previous IGS name.
 #include "sound/2413intf.h"
 
 
+class cabaret_state : public driver_device
+{
+public:
+	cabaret_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 *m_bg_tile_ram;
+	tilemap_t *m_bg_tilemap;
+	UINT8 *m_bg_scroll;
+	UINT8 *m_fg_tile_ram;
+	UINT8 *m_fg_color_ram;
+	tilemap_t *m_fg_tilemap;
+	int m_nmi_enable;
+	UINT8 m_out[3];
+};
+
+
+
 /***************************************************************************
                                 Video Hardware
 ***************************************************************************/
 
 
-static UINT8   *bg_tile_ram;
-static tilemap_t *bg_tilemap;
-static UINT8   *bg_scroll;
 
-static UINT8   *fg_tile_ram, *fg_color_ram;
-static tilemap_t *fg_tilemap;
 
 static WRITE8_HANDLER( bg_scroll_w )
 {
-	bg_scroll[offset] = data;
-	tilemap_set_scrolly(bg_tilemap,offset,data);
+	cabaret_state *state = space->machine().driver_data<cabaret_state>();
+	state->m_bg_scroll[offset] = data;
+	tilemap_set_scrolly(state->m_bg_tilemap,offset,data);
 }
 
 static WRITE8_HANDLER( bg_tile_w )
 {
-	bg_tile_ram[offset] = data;
-	tilemap_mark_tile_dirty(bg_tilemap,offset);
+	cabaret_state *state = space->machine().driver_data<cabaret_state>();
+	state->m_bg_tile_ram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_bg_tilemap,offset);
 }
 
 static TILE_GET_INFO( get_bg_tile_info )
 {
-	int code = bg_tile_ram[tile_index];
+	cabaret_state *state = machine.driver_data<cabaret_state>();
+	int code = state->m_bg_tile_ram[tile_index];
 	SET_TILE_INFO(1, code & 0xff, 0, 0);
 }
 
 static TILE_GET_INFO( get_fg_tile_info )
 {
-	int code = fg_tile_ram[tile_index] | (fg_color_ram[tile_index] << 8);
+	cabaret_state *state = machine.driver_data<cabaret_state>();
+	int code = state->m_fg_tile_ram[tile_index] | (state->m_fg_color_ram[tile_index] << 8);
 	int tile = code & 0x1fff;
 	SET_TILE_INFO(0, code, tile != 0x1fff ? ((code >> 12) & 0xe) + 1 : 0, 0);
 }
 
 static WRITE8_HANDLER( fg_tile_w )
 {
-	fg_tile_ram[offset] = data;
-	tilemap_mark_tile_dirty(fg_tilemap,offset);
+	cabaret_state *state = space->machine().driver_data<cabaret_state>();
+	state->m_fg_tile_ram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_fg_tilemap,offset);
 }
 
 static WRITE8_HANDLER( fg_color_w )
 {
-	fg_color_ram[offset] = data;
-	tilemap_mark_tile_dirty(fg_tilemap,offset);
+	cabaret_state *state = space->machine().driver_data<cabaret_state>();
+	state->m_fg_color_ram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_fg_tilemap,offset);
 }
 
 static VIDEO_START(cabaret)
 {
-	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows,	8,  32,	64, 8);
-	fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_rows,	8,  8,	64, 32);
-	tilemap_set_transparent_pen(fg_tilemap, 0);
-	tilemap_set_scroll_cols(bg_tilemap, 64);
+	cabaret_state *state = machine.driver_data<cabaret_state>();
+	state->m_bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows,	8,  32,	64, 8);
+	state->m_fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_rows,	8,  8,	64, 32);
+	tilemap_set_transparent_pen(state->m_fg_tilemap, 0);
+	tilemap_set_scroll_cols(state->m_bg_tilemap, 64);
 }
 
 
-static VIDEO_UPDATE(cabaret)
+static SCREEN_UPDATE(cabaret)
 {
-	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+	cabaret_state *state = screen->machine().driver_data<cabaret_state>();
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine()));
 
-	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
+	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
 
-	tilemap_draw(bitmap, cliprect, fg_tilemap, 0, 0);
+	tilemap_draw(bitmap, cliprect, state->m_fg_tilemap, 0, 0);
 
 	return 0;
 }
@@ -99,46 +120,45 @@ static VIDEO_UPDATE(cabaret)
                                 Memory Maps
 ***************************************************************************/
 
-static int nmi_enable;
 
-static UINT8 out[3];
 
-static void show_out(void)
+static void show_out(cabaret_state *state)
 {
 #ifdef MAME_DEBUG
-	popmessage("%02x %02x %02x", out[0], out[1], out[2]);
+	popmessage("%02x %02x %02x", state->m_out[0], state->m_out[1], state->m_out[2]);
 #endif
 }
 
 static WRITE8_HANDLER( cabaret_nmi_and_coins_w )
 {
-	if ((nmi_enable ^ data) & (~0xdd))
+	cabaret_state *state = space->machine().driver_data<cabaret_state>();
+	if ((state->m_nmi_enable ^ data) & (~0xdd))
 	{
-		logerror("PC %06X: nmi_and_coins = %02x\n",cpu_get_pc(space->cpu),data);
+		logerror("PC %06X: nmi_and_coins = %02x\n",cpu_get_pc(&space->device()),data);
 //      popmessage("%02x",data);
 	}
 
-	coin_counter_w(space->machine, 0,		data & 0x01);	// coin_a
-	coin_counter_w(space->machine, 1,		data & 0x04);	// coin_c
-	coin_counter_w(space->machine, 2,		data & 0x08);	// key in
-	coin_counter_w(space->machine, 3,		data & 0x10);	// coin out mech
+	coin_counter_w(space->machine(), 0,		data & 0x01);	// coin_a
+	coin_counter_w(space->machine(), 1,		data & 0x04);	// coin_c
+	coin_counter_w(space->machine(), 2,		data & 0x08);	// key in
+	coin_counter_w(space->machine(), 3,		data & 0x10);	// coin state->m_out mech
 
-	set_led_status(space->machine, 6,		data & 0x40);	// led for coin out / hopper active
+	set_led_status(space->machine(), 6,		data & 0x40);	// led for coin state->m_out / hopper active
 
-	nmi_enable = data;	//  data & 0x80     // nmi enable?
+	state->m_nmi_enable = data;	//  data & 0x80     // nmi enable?
 
-	out[0] = data;
-	show_out();
+	state->m_out[0] = data;
+	show_out(state);
 }
 
 
 
-static ADDRESS_MAP_START( cabaret_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( cabaret_map, AS_PROGRAM, 8 )
 	AM_RANGE( 0x00000, 0x0efff ) AM_ROM
 	AM_RANGE( 0x0f000, 0x0ffff ) AM_RAM AM_REGION("maincpu", 0xf000)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( cabaret_portmap, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( cabaret_portmap, AS_IO, 8 )
 	AM_RANGE( 0x0000, 0x003f ) AM_RAM // Z180 internal regs
 
 	AM_RANGE( 0x0080, 0x0080 ) AM_READ_PORT( "BUTTONS2" )
@@ -153,15 +173,15 @@ static ADDRESS_MAP_START( cabaret_portmap, ADDRESS_SPACE_IO, 8 )
 
 	AM_RANGE( 0x00e0, 0x00e1 ) AM_DEVWRITE( "ymsnd", ym2413_w )
 
-	AM_RANGE( 0x2000, 0x27ff ) AM_RAM_WRITE( fg_tile_w )  AM_BASE( &fg_tile_ram )
-	AM_RANGE( 0x2800, 0x2fff ) AM_RAM_WRITE( fg_color_w ) AM_BASE( &fg_color_ram )
+	AM_RANGE( 0x2000, 0x27ff ) AM_RAM_WRITE( fg_tile_w )  AM_BASE_MEMBER(cabaret_state, m_fg_tile_ram )
+	AM_RANGE( 0x2800, 0x2fff ) AM_RAM_WRITE( fg_color_w ) AM_BASE_MEMBER(cabaret_state, m_fg_color_ram )
 
 	AM_RANGE( 0x3000, 0x37ff ) AM_RAM_WRITE( paletteram_xBBBBBGGGGGRRRRR_split1_w ) AM_BASE_GENERIC( paletteram )
 	AM_RANGE( 0x3800, 0x3fff ) AM_RAM_WRITE( paletteram_xBBBBBGGGGGRRRRR_split2_w ) AM_BASE_GENERIC( paletteram2 )
 
-	AM_RANGE( 0x1000, 0x103f ) AM_RAM_WRITE( bg_scroll_w ) AM_BASE( &bg_scroll )
+	AM_RANGE( 0x1000, 0x103f ) AM_RAM_WRITE( bg_scroll_w ) AM_BASE_MEMBER(cabaret_state, m_bg_scroll )
 
-	AM_RANGE( 0x1800, 0x19ff ) AM_RAM_WRITE( bg_tile_w )  AM_BASE( &bg_tile_ram )
+	AM_RANGE( 0x1800, 0x19ff ) AM_RAM_WRITE( bg_tile_w )  AM_BASE_MEMBER(cabaret_state, m_bg_tile_ram )
 	AM_RANGE( 0x8000, 0xffff ) AM_ROM AM_REGION("gfx3", 0)
 ADDRESS_MAP_END
 
@@ -294,16 +314,18 @@ GFXDECODE_END
 
 static MACHINE_RESET( cabaret )
 {
-	nmi_enable		=	0;
+	cabaret_state *state = machine.driver_data<cabaret_state>();
+	state->m_nmi_enable		=	0;
 }
 
 static INTERRUPT_GEN( cabaret_interrupt )
 {
-	 if (nmi_enable & 0x80)
-		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
+	cabaret_state *state = device->machine().driver_data<cabaret_state>();
+	 if (state->m_nmi_enable & 0x80)
+		device_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 }
 
-static MACHINE_CONFIG_START( cabaret, driver_device )
+static MACHINE_CONFIG_START( cabaret, cabaret_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z180, XTAL_12MHz / 2)
 	MCFG_CPU_PROGRAM_MAP(cabaret_map)
@@ -319,12 +341,12 @@ static MACHINE_CONFIG_START( cabaret, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(512, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 512-1, 0, 256-1)
+	MCFG_SCREEN_UPDATE(cabaret)
 
 	MCFG_GFXDECODE(cabaret)
 	MCFG_PALETTE_LENGTH(0x800)
 
 	MCFG_VIDEO_START(cabaret)
-	MCFG_VIDEO_UPDATE(cabaret)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -335,7 +357,7 @@ MACHINE_CONFIG_END
 
 static DRIVER_INIT( cabaret )
 {
-	UINT8 *rom = machine->region("maincpu")->base();
+	UINT8 *rom = machine.region("maincpu")->base();
 	int i;
 
 	/* decrypt the program ROM */
