@@ -67,10 +67,10 @@ static READ8_HANDLER( canyon_switches_r )
 {
 	UINT8 val = 0;
 
-	if ((input_port_read(space->machine, "IN2") >> (offset & 7)) & 1)
+	if ((input_port_read(space->machine(), "IN2") >> (offset & 7)) & 1)
 		val |= 0x80;
 
-	if ((input_port_read(space->machine, "IN1") >> (offset & 3)) & 1)
+	if ((input_port_read(space->machine(), "IN1") >> (offset & 3)) & 1)
 		val |= 0x01;
 
 	return val;
@@ -79,7 +79,7 @@ static READ8_HANDLER( canyon_switches_r )
 
 static READ8_HANDLER( canyon_options_r )
 {
-	return (input_port_read(space->machine, "DSW") >> (2 * (~offset & 3))) & 3;
+	return (input_port_read(space->machine(), "DSW") >> (2 * (~offset & 3))) & 3;
 }
 
 
@@ -93,7 +93,7 @@ static READ8_HANDLER( canyon_options_r )
 
 static WRITE8_HANDLER( canyon_led_w )
 {
-	set_led_status(space->machine, offset & 0x01, offset & 0x02);
+	set_led_status(space->machine(), offset & 0x01, offset & 0x02);
 }
 
 
@@ -105,7 +105,7 @@ static WRITE8_HANDLER( canyon_led_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0x3fff)
 	AM_RANGE(0x0000, 0x00ff) AM_MIRROR(0x100) AM_RAM
 	AM_RANGE(0x0400, 0x0401) AM_DEVWRITE("discrete", canyon_motor_w)
@@ -114,7 +114,7 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0600, 0x0603) AM_DEVWRITE("discrete", canyon_whistle_w)
 	AM_RANGE(0x0680, 0x0683) AM_WRITE(canyon_led_w)
 	AM_RANGE(0x0700, 0x0703) AM_DEVWRITE("discrete", canyon_attract_w)
-	AM_RANGE(0x0800, 0x0bff) AM_RAM_WRITE(canyon_videoram_w) AM_BASE_MEMBER(canyon_state, videoram)
+	AM_RANGE(0x0800, 0x0bff) AM_RAM_WRITE(canyon_videoram_w) AM_BASE_MEMBER(canyon_state, m_videoram)
 	AM_RANGE(0x1000, 0x17ff) AM_READ(canyon_switches_r) AM_WRITENOP  /* sloppy code writes here */
 	AM_RANGE(0x1800, 0x1fff) AM_READ(canyon_options_r)
 	AM_RANGE(0x2000, 0x3fff) AM_ROM
@@ -249,13 +249,13 @@ static MACHINE_CONFIG_START( canyon, canyon_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 240)
 	MCFG_SCREEN_VISIBLE_AREA(0, 255, 0, 239)
+	MCFG_SCREEN_UPDATE(canyon)
 
 	MCFG_GFXDECODE(canyon)
 	MCFG_PALETTE_LENGTH(4)
 
 	MCFG_PALETTE_INIT(canyon)
 	MCFG_VIDEO_START(canyon)
-	MCFG_VIDEO_UPDATE(canyon)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
