@@ -3,9 +3,9 @@
     Chequered Flag / Checkered Flag (GX717) (c) Konami 1988
 
     Notes:
-    - Position counter doesn't behave correctly because of the K051733
-      protection.
     - 007232 volume & panning control is almost certainly wrong.
+    - Needs HW tests or side-by-side tests to determine if the protection
+      is 100% ok now;
 
     2008-07
     Dip locations and recommended settings verified with manual
@@ -13,7 +13,6 @@
 ***************************************************************************/
 
 #include "emu.h"
-#include "deprecat.h"
 #include "cpu/z80/z80.h"
 #include "cpu/konami/konami.h"
 #include "video/konicdev.h"
@@ -26,48 +25,43 @@
 
 static WRITE8_DEVICE_HANDLER( k007232_extvolume_w );
 
-static INTERRUPT_GEN( chqflag_interrupt )
+static TIMER_DEVICE_CALLBACK( chqflag_scanline )
 {
-	chqflag_state *state = device->machine->driver_data<chqflag_state>();
+	chqflag_state *state = timer.machine().driver_data<chqflag_state>();
+	int scanline = param;
 
-	if (cpu_getiloops(device) == 0)
-	{
-		if (k051960_is_irq_enabled(state->k051960))
-			cpu_set_input_line(device, KONAMI_IRQ_LINE, HOLD_LINE);
-	}
-	else if (cpu_getiloops(device) % 2)
-	{
-		if (k051960_is_nmi_enabled(state->k051960))
-			cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
-	}
+	if(scanline == 240 && k051960_is_irq_enabled(state->m_k051960)) // vblank irq
+		cputag_set_input_line(timer.machine(), "maincpu", KONAMI_IRQ_LINE, HOLD_LINE);
+	else if(((scanline % 32) == 0) && (k051960_is_nmi_enabled(state->m_k051960))) // timer irq
+		cputag_set_input_line(timer.machine(), "maincpu", INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static WRITE8_HANDLER( chqflag_bankswitch_w )
 {
-	chqflag_state *state = space->machine->driver_data<chqflag_state>();
+	chqflag_state *state = space->machine().driver_data<chqflag_state>();
 	int bankaddress;
-	UINT8 *RAM = space->machine->region("maincpu")->base();
+	UINT8 *RAM = space->machine().region("maincpu")->base();
 
 	/* bits 0-4 = ROM bank # (0x00-0x11) */
 	bankaddress = 0x10000 + (data & 0x1f) * 0x4000;
-	memory_set_bankptr(space->machine, "bank4", &RAM[bankaddress]);
+	memory_set_bankptr(space->machine(), "bank4", &RAM[bankaddress]);
 
 	/* bit 5 = memory bank select */
 	if (data & 0x20)
 	{
-		memory_install_read_bank(space, 0x1800, 0x1fff, 0, 0, "bank5");
-		memory_install_write8_handler(space, 0x1800, 0x1fff, 0, 0, paletteram_xBBBBBGGGGGRRRRR_be_w);
-		memory_set_bankptr(space->machine, "bank5", space->machine->generic.paletteram.v);
+		space->install_read_bank(0x1800, 0x1fff, "bank5");
+		space->install_legacy_write_handler(0x1800, 0x1fff, FUNC(paletteram_xBBBBBGGGGGRRRRR_be_w));
+		memory_set_bankptr(space->machine(), "bank5", space->machine().generic.paletteram.v);
 
-		if (state->k051316_readroms)
-			memory_install_readwrite8_device_handler(space, state->k051316_1, 0x1000, 0x17ff, 0, 0, k051316_rom_r, k051316_w);	/* 051316 #1 (ROM test) */
+		if (state->m_k051316_readroms)
+			space->install_legacy_readwrite_handler(*state->m_k051316_1, 0x1000, 0x17ff, FUNC(k051316_rom_r), FUNC(k051316_w));	/* 051316 #1 (ROM test) */
 		else
-			memory_install_readwrite8_device_handler(space, state->k051316_1, 0x1000, 0x17ff, 0, 0, k051316_r, k051316_w);		/* 051316 #1 */
+			space->install_legacy_readwrite_handler(*state->m_k051316_1, 0x1000, 0x17ff, FUNC(k051316_r), FUNC(k051316_w));		/* 051316 #1 */
 	}
 	else
 	{
-		memory_install_readwrite_bank(space, 0x1000, 0x17ff, 0, 0, "bank1");				/* RAM */
-		memory_install_readwrite_bank(space, 0x1800, 0x1fff, 0, 0, "bank2");				/* RAM */
+		space->install_readwrite_bank(0x1000, 0x17ff, "bank1");				/* RAM */
+		space->install_readwrite_bank(0x1800, 0x1fff, "bank2");				/* RAM */
 	}
 
 	/* other bits unknown/unused */
@@ -75,19 +69,19 @@ static WRITE8_HANDLER( chqflag_bankswitch_w )
 
 static WRITE8_HANDLER( chqflag_vreg_w )
 {
-	chqflag_state *state = space->machine->driver_data<chqflag_state>();
+	chqflag_state *state = space->machine().driver_data<chqflag_state>();
 
 	/* bits 0 & 1 = coin counters */
-	coin_counter_w(space->machine, 1, data & 0x01);
-	coin_counter_w(space->machine, 0, data & 0x02);
+	coin_counter_w(space->machine(), 1, data & 0x01);
+	coin_counter_w(space->machine(), 0, data & 0x02);
 
 	/* bit 4 = enable rom reading thru K051316 #1 & #2 */
-	state->k051316_readroms = (data & 0x10);
+	state->m_k051316_readroms = (data & 0x10);
 
-	if (state->k051316_readroms)
-		memory_install_read8_device_handler(space, state->k051316_2, 0x2800, 0x2fff, 0, 0, k051316_rom_r);	/* 051316 (ROM test) */
+	if (state->m_k051316_readroms)
+		space->install_legacy_read_handler(*state->m_k051316_2, 0x2800, 0x2fff, FUNC(k051316_rom_r));	/* 051316 (ROM test) */
 	else
-		memory_install_read8_device_handler(space, state->k051316_2, 0x2800, 0x2fff, 0, 0, k051316_r);		/* 051316 */
+		space->install_legacy_read_handler(*state->m_k051316_2, 0x2800, 0x2fff, FUNC(k051316_r));		/* 051316 */
 
 	/* Bits 3-7 probably control palette dimming in a similar way to TMNT2/Sunset Riders, */
 	/* however I don't have enough evidence to determine the exact behaviour. */
@@ -95,20 +89,20 @@ static WRITE8_HANDLER( chqflag_vreg_w )
 	/* the headlight (which have the shadow bit set) become highlights */
 	/* Maybe one of the bits inverts the SHAD line while the other darkens the background. */
 	if (data & 0x08)
-		palette_set_shadow_factor(space->machine, 1 / PALETTE_DEFAULT_SHADOW_FACTOR);
+		palette_set_shadow_factor(space->machine(), 1 / PALETTE_DEFAULT_SHADOW_FACTOR);
 	else
-		palette_set_shadow_factor(space->machine, PALETTE_DEFAULT_SHADOW_FACTOR);
+		palette_set_shadow_factor(space->machine(), PALETTE_DEFAULT_SHADOW_FACTOR);
 
-	if ((data & 0x80) != state->last_vreg)
+	if ((data & 0x80) != state->m_last_vreg)
 	{
 		double brt = (data & 0x80) ? PALETTE_DEFAULT_SHADOW_FACTOR : 1.0;
 		int i;
 
-		state->last_vreg = data & 0x80;
+		state->m_last_vreg = data & 0x80;
 
 		/* only affect the background */
 		for (i = 512; i < 1024; i++)
-			palette_set_pen_contrast(space->machine, i, brt);
+			palette_set_pen_contrast(space->machine(), i, brt);
 	}
 
 //if ((data & 0xf8) && (data & 0xf8) != 0x88)
@@ -120,19 +114,19 @@ static WRITE8_HANDLER( chqflag_vreg_w )
 
 static WRITE8_HANDLER( select_analog_ctrl_w )
 {
-	chqflag_state *state = space->machine->driver_data<chqflag_state>();
-	state->analog_ctrl = data;
+	chqflag_state *state = space->machine().driver_data<chqflag_state>();
+	state->m_analog_ctrl = data;
 }
 
 static READ8_HANDLER( analog_read_r )
 {
-	chqflag_state *state = space->machine->driver_data<chqflag_state>();
-	switch (state->analog_ctrl & 0x03)
+	chqflag_state *state = space->machine().driver_data<chqflag_state>();
+	switch (state->m_analog_ctrl & 0x03)
 	{
-		case 0x00: return (state->accel = input_port_read(space->machine, "IN3"));	/* accelerator */
-		case 0x01: return (state->wheel = input_port_read(space->machine, "IN4"));	/* steering */
-		case 0x02: return state->accel;						/* accelerator (previous?) */
-		case 0x03: return state->wheel;						/* steering (previous?) */
+		case 0x00: return (state->m_accel = input_port_read(space->machine(), "IN3"));	/* accelerator */
+		case 0x01: return (state->m_wheel = input_port_read(space->machine(), "IN4"));	/* steering */
+		case 0x02: return state->m_accel;						/* accelerator (previous?) */
+		case 0x03: return state->m_wheel;						/* steering (previous?) */
 	}
 
 	return 0xff;
@@ -140,15 +134,15 @@ static READ8_HANDLER( analog_read_r )
 
 static WRITE8_HANDLER( chqflag_sh_irqtrigger_w )
 {
-	chqflag_state *state = space->machine->driver_data<chqflag_state>();
+	chqflag_state *state = space->machine().driver_data<chqflag_state>();
 	soundlatch2_w(space, 0, data);
-	cpu_set_input_line(state->audiocpu, 0, HOLD_LINE);
+	device_set_input_line(state->m_audiocpu, 0, HOLD_LINE);
 }
 
 
 /****************************************************************************/
 
-static ADDRESS_MAP_START( chqflag_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( chqflag_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_RAM												/* RAM */
 	AM_RANGE(0x1000, 0x17ff) AM_RAMBANK("bank1")								/* banked RAM (RAM/051316 (chip 1)) */
 	AM_RANGE(0x1800, 0x1fff) AM_RAMBANK("bank2")								/* palette + RAM */
@@ -176,21 +170,21 @@ ADDRESS_MAP_END
 
 static WRITE8_HANDLER( k007232_bankswitch_w )
 {
-	chqflag_state *state = space->machine->driver_data<chqflag_state>();
+	chqflag_state *state = space->machine().driver_data<chqflag_state>();
 	int bank_A, bank_B;
 
 	/* banks # for the 007232 (chip 1) */
 	bank_A = ((data >> 4) & 0x03);
 	bank_B = ((data >> 6) & 0x03);
-	k007232_set_bank(state->k007232_1, bank_A, bank_B);
+	k007232_set_bank(state->m_k007232_1, bank_A, bank_B);
 
 	/* banks # for the 007232 (chip 2) */
 	bank_A = ((data >> 0) & 0x03);
 	bank_B = ((data >> 2) & 0x03);
-	k007232_set_bank(state->k007232_2, bank_A, bank_B);
+	k007232_set_bank(state->m_k007232_2, bank_A, bank_B);
 }
 
-static ADDRESS_MAP_START( chqflag_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( chqflag_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM /* ROM */
 	AM_RANGE(0x8000, 0x87ff) AM_RAM /* RAM */
 	AM_RANGE(0x9000, 0x9000) AM_WRITE(k007232_bankswitch_w)	/* 007232 bankswitch */
@@ -292,8 +286,8 @@ INPUT_PORTS_END
 
 static void chqflag_ym2151_irq_w( device_t *device, int data )
 {
-	chqflag_state *state = device->machine->driver_data<chqflag_state>();
-	cpu_set_input_line(state->audiocpu, INPUT_LINE_NMI, data ? ASSERT_LINE : CLEAR_LINE);
+	chqflag_state *state = device->machine().driver_data<chqflag_state>();
+	device_set_input_line(state->m_audiocpu, INPUT_LINE_NMI, data ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -354,35 +348,35 @@ static const k051316_interface chqflag_k051316_intf_2 =
 
 static MACHINE_START( chqflag )
 {
-	chqflag_state *state = machine->driver_data<chqflag_state>();
-	UINT8 *ROM = machine->region("maincpu")->base();
+	chqflag_state *state = machine.driver_data<chqflag_state>();
+	UINT8 *ROM = machine.region("maincpu")->base();
 
 	memory_configure_bank(machine, "bank1", 0, 4, &ROM[0x10000], 0x2000);
 
-	state->maincpu = machine->device("maincpu");
-	state->audiocpu = machine->device("audiocpu");
-	state->k051316_1 = machine->device("k051316_1");
-	state->k051316_2 = machine->device("k051316_2");
-	state->k051960 = machine->device("k051960");
-	state->k007232_1 = machine->device("k007232_1");
-	state->k007232_2 = machine->device("k007232_2");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_audiocpu = machine.device("audiocpu");
+	state->m_k051316_1 = machine.device("k051316_1");
+	state->m_k051316_2 = machine.device("k051316_2");
+	state->m_k051960 = machine.device("k051960");
+	state->m_k007232_1 = machine.device("k007232_1");
+	state->m_k007232_2 = machine.device("k007232_2");
 
-	state_save_register_global(machine, state->k051316_readroms);
-	state_save_register_global(machine, state->last_vreg);
-	state_save_register_global(machine, state->analog_ctrl);
-	state_save_register_global(machine, state->accel);
-	state_save_register_global(machine, state->wheel);
+	state->save_item(NAME(state->m_k051316_readroms));
+	state->save_item(NAME(state->m_last_vreg));
+	state->save_item(NAME(state->m_analog_ctrl));
+	state->save_item(NAME(state->m_accel));
+	state->save_item(NAME(state->m_wheel));
 }
 
 static MACHINE_RESET( chqflag )
 {
-	chqflag_state *state = machine->driver_data<chqflag_state>();
+	chqflag_state *state = machine.driver_data<chqflag_state>();
 
-	state->k051316_readroms = 0;
-	state->last_vreg = 0;
-	state->analog_ctrl = 0;
-	state->accel = 0;
-	state->wheel = 0;
+	state->m_k051316_readroms = 0;
+	state->m_last_vreg = 0;
+	state->m_analog_ctrl = 0;
+	state->m_accel = 0;
+	state->m_wheel = 0;
 }
 
 static MACHINE_CONFIG_START( chqflag, chqflag_state )
@@ -390,12 +384,12 @@ static MACHINE_CONFIG_START( chqflag, chqflag_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", KONAMI,XTAL_24MHz/8)	/* 052001 (verified on pcb) */
 	MCFG_CPU_PROGRAM_MAP(chqflag_map)
-	MCFG_CPU_VBLANK_INT_HACK(chqflag_interrupt,16)	/* ? */
+	MCFG_TIMER_ADD_SCANLINE("scantimer", chqflag_scanline, "screen", 0, 1)
 
 	MCFG_CPU_ADD("audiocpu", Z80, XTAL_3_579545MHz) /* verified on pcb */
 	MCFG_CPU_PROGRAM_MAP(chqflag_sound_map)
 
-	MCFG_QUANTUM_TIME(HZ(600))
+	MCFG_QUANTUM_TIME(attotime::from_hz(600))
 
 	MCFG_MACHINE_START(chqflag)
 	MCFG_MACHINE_RESET(chqflag)
@@ -403,17 +397,18 @@ static MACHINE_CONFIG_START( chqflag, chqflag_state )
 	/* video hardware */
 	MCFG_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
 
+	//TODO: Vsync 59.17hz Hsync 15.13 / 15.19khz
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(12*8, (64-14)*8-1, 2*8, 30*8-1 )
+	MCFG_SCREEN_UPDATE(chqflag)
 
 	MCFG_PALETTE_LENGTH(1024)
 
 	MCFG_VIDEO_START(chqflag)
-	MCFG_VIDEO_UPDATE(chqflag)
 
 	MCFG_K051960_ADD("k051960", chqflag_k051960_intf)
 	MCFG_K051316_ADD("k051316_1", chqflag_k051316_intf_1)
@@ -502,5 +497,5 @@ ROM_START( chqflagj )
 ROM_END
 
 
-GAMEL( 1988, chqflag,  0,       chqflag, chqflag, 0, ROT90, "Konami", "Chequered Flag", GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE, layout_chqflag )
-GAMEL( 1988, chqflagj, chqflag, chqflag, chqflag, 0, ROT90, "Konami", "Chequered Flag (Japan)", GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE, layout_chqflag )
+GAMEL( 1988, chqflag,  0,       chqflag, chqflag, 0, ROT90, "Konami", "Chequered Flag", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE, layout_chqflag )
+GAMEL( 1988, chqflagj, chqflag, chqflag, chqflag, 0, ROT90, "Konami", "Chequered Flag (Japan)", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE, layout_chqflag )
