@@ -1,12 +1,3 @@
-#define ADDRESS_MAP_MODERN
-
-#include "emu.h"
-#include "cpu/cosmac/cosmac.h"
-#include "cpu/cop400/cop400.h"
-#include "sound/cdp1869.h"
-#include "sound/ay8910.h"
-#include "machine/cdp1852.h"
-#include "machine/nvram.h"
 #include "includes/cidelsa.h"
 
 /* CDP1802 Interface */
@@ -39,7 +30,7 @@ static COSMAC_INTERFACE( cidelsa_cdp1802_config )
 
 /* Sound Interface */
 
-WRITE8_MEMBER( cidelsa_state::draco_sound_bankswitch_w )
+WRITE8_MEMBER( draco_state::sound_bankswitch_w )
 {
 	/*
 
@@ -54,10 +45,10 @@ WRITE8_MEMBER( cidelsa_state::draco_sound_bankswitch_w )
 
 	int bank = BIT(data, 3);
 
-	memory_set_bank(&m_machine, "bank1", bank);
+	memory_set_bank(machine(), "bank1", bank);
 }
 
-WRITE8_MEMBER( cidelsa_state::draco_sound_g_w )
+WRITE8_MEMBER( draco_state::sound_g_w )
 {
 	/*
 
@@ -73,32 +64,32 @@ WRITE8_MEMBER( cidelsa_state::draco_sound_g_w )
 	switch (data)
 	{
 	case 0x01:
-		ay8910_data_w(m_psg, 0, m_draco_ay_latch);
+		ay8910_data_w(m_psg, 0, m_psg_latch);
 		break;
 
 	case 0x02:
-		m_draco_ay_latch = ay8910_r(m_psg, 0);
+		m_psg_latch = ay8910_r(m_psg, 0);
 		break;
 
 	case 0x03:
-		ay8910_address_w(m_psg, 0, m_draco_ay_latch);
+		ay8910_address_w(m_psg, 0, m_psg_latch);
 		break;
 	}
 }
 
-READ8_MEMBER( cidelsa_state::draco_sound_in_r )
+READ8_MEMBER( draco_state::sound_in_r )
 {
-	return ~(m_draco_sound) & 0x07;
+	return ~(m_sound) & 0x07;
 }
 
-READ8_MEMBER( cidelsa_state::draco_sound_ay8910_r )
+READ8_MEMBER( draco_state::psg_r )
 {
-	return m_draco_ay_latch;
+	return m_psg_latch;
 }
 
-WRITE8_MEMBER( cidelsa_state::draco_sound_ay8910_w )
+WRITE8_MEMBER( draco_state::psg_w )
 {
-	m_draco_ay_latch = data;
+	m_psg_latch = data;
 }
 
 /* Read/Write Handlers */
@@ -136,12 +127,12 @@ WRITE8_MEMBER( cidelsa_state::altair_out1_w )
         7   CONT. M1
     */
 
-	set_led_status(&m_machine, 0, data & 0x08); // 1P
-	set_led_status(&m_machine, 1, data & 0x10); // 2P
-	set_led_status(&m_machine, 2, data & 0x20); // FIRE
+	set_led_status(machine(), 0, data & 0x08); // 1P
+	set_led_status(machine(), 1, data & 0x10); // 2P
+	set_led_status(machine(), 2, data & 0x20); // FIRE
 }
 
-WRITE8_MEMBER( cidelsa_state::draco_out1_w )
+WRITE8_MEMBER( draco_state::out1_w )
 {
 	/*
       bit   description
@@ -156,7 +147,7 @@ WRITE8_MEMBER( cidelsa_state::draco_out1_w )
         7   SONIDO C -> COP402 IN2
     */
 
-	m_draco_sound = (data & 0xe0) >> 5;
+	m_sound = (data & 0xe0) >> 5;
 }
 
 static CDP1852_INTERFACE( cidelsa_cdp1852_in0_intf )
@@ -195,7 +186,7 @@ static CDP1852_INTERFACE( draco_cdp1852_out1_intf )
 {
 	CDP1852_MODE_OUTPUT,
 	DEVCB_NULL,
-	DEVCB_DRIVER_MEMBER(cidelsa_state, draco_out1_w),
+	DEVCB_DRIVER_MEMBER(draco_state, out1_w),
 	DEVCB_NULL
 };
 
@@ -212,21 +203,21 @@ static COP400_INTERFACE( draco_cop_intf )
 
 // Destroyer
 
-static ADDRESS_MAP_START( destryer_map, ADDRESS_SPACE_PROGRAM, 8, cidelsa_state )
+static ADDRESS_MAP_START( destryer_map, AS_PROGRAM, 8, cidelsa_state )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x20ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0xf400, 0xf7ff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, char_ram_r, char_ram_w)
 	AM_RANGE(0xf800, 0xffff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, page_ram_r, page_ram_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( destryera_map, ADDRESS_SPACE_PROGRAM, 8, cidelsa_state )
+static ADDRESS_MAP_START( destryera_map, AS_PROGRAM, 8, cidelsa_state )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x3000, 0x30ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0xf400, 0xf7ff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, char_ram_r, char_ram_w)
 	AM_RANGE(0xf800, 0xffff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, page_ram_r, page_ram_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( destryer_io_map, ADDRESS_SPACE_IO, 8, cidelsa_state )
+static ADDRESS_MAP_START( destryer_io_map, AS_IO, 8, cidelsa_state )
 	AM_RANGE(0x01, 0x01) AM_READ_PORT("IN0") AM_WRITE(destryer_out1_w)
 	AM_RANGE(0x02, 0x02) AM_READ_PORT("IN1")
 	AM_RANGE(0x03, 0x07) AM_WRITE(cdp1869_w)
@@ -234,45 +225,45 @@ ADDRESS_MAP_END
 
 // Altair
 
-static ADDRESS_MAP_START( altair_map, ADDRESS_SPACE_PROGRAM, 8, cidelsa_state )
+static ADDRESS_MAP_START( altair_map, AS_PROGRAM, 8, cidelsa_state )
 	AM_RANGE(0x0000, 0x2fff) AM_ROM
 	AM_RANGE(0x3000, 0x30ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0xf400, 0xf7ff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, char_ram_r, char_ram_w)
 	AM_RANGE(0xf800, 0xffff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, page_ram_r, page_ram_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( altair_io_map, ADDRESS_SPACE_IO, 8, cidelsa_state )
-	AM_RANGE(0x01, 0x01) AM_DEVREAD_LEGACY("ic23", cdp1852_data_r) AM_DEVWRITE_LEGACY("ic26", cdp1852_data_w)
-	AM_RANGE(0x02, 0x02) AM_DEVREAD_LEGACY("ic24", cdp1852_data_r)
-	AM_RANGE(0x04, 0x04) AM_DEVREAD_LEGACY("ic25", cdp1852_data_r)
+static ADDRESS_MAP_START( altair_io_map, AS_IO, 8, cidelsa_state )
+	AM_RANGE(0x01, 0x01) AM_DEVREAD("ic23", cdp1852_device, read) AM_DEVWRITE("ic26", cdp1852_device, write)
+	AM_RANGE(0x02, 0x02) AM_DEVREAD("ic24", cdp1852_device, read)
+	AM_RANGE(0x04, 0x04) AM_DEVREAD("ic25", cdp1852_device, read)
 	AM_RANGE(0x03, 0x07) AM_WRITE(cdp1869_w)
 ADDRESS_MAP_END
 
 // Draco
 
-static ADDRESS_MAP_START( draco_map, ADDRESS_SPACE_PROGRAM, 8, cidelsa_state )
+static ADDRESS_MAP_START( draco_map, AS_PROGRAM, 8, draco_state )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x8000, 0x83ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0xf400, 0xf7ff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, char_ram_r, char_ram_w)
 	AM_RANGE(0xf800, 0xffff) AM_DEVREADWRITE(CDP1869_TAG, cdp1869_device, page_ram_r, page_ram_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( draco_io_map, ADDRESS_SPACE_IO, 8, cidelsa_state )
-	AM_RANGE(0x01, 0x01) AM_DEVREAD_LEGACY("ic29", cdp1852_data_r) AM_DEVWRITE_LEGACY("ic32", cdp1852_data_w)
-	AM_RANGE(0x02, 0x02) AM_DEVREAD_LEGACY("ic30", cdp1852_data_r)
-	AM_RANGE(0x04, 0x04) AM_DEVREAD_LEGACY("ic31", cdp1852_data_r)
-	AM_RANGE(0x03, 0x07) AM_WRITE(cdp1869_w)
+static ADDRESS_MAP_START( draco_io_map, AS_IO, 8, draco_state )
+	AM_RANGE(0x01, 0x01) AM_DEVREAD("ic29", cdp1852_device, read) AM_DEVWRITE("ic32", cdp1852_device, write)
+	AM_RANGE(0x02, 0x02) AM_DEVREAD("ic30", cdp1852_device, read)
+	AM_RANGE(0x04, 0x04) AM_DEVREAD("ic31", cdp1852_device, read)
+	AM_RANGE(0x03, 0x07) AM_WRITE_BASE(cidelsa_state, cdp1869_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( draco_sound_map, ADDRESS_SPACE_PROGRAM, 8, cidelsa_state )
+static ADDRESS_MAP_START( draco_sound_map, AS_PROGRAM, 8, draco_state )
 	AM_RANGE(0x000, 0x3ff) AM_ROMBANK("bank1")
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( draco_sound_io_map, ADDRESS_SPACE_IO, 8, cidelsa_state )
-	AM_RANGE(COP400_PORT_D, COP400_PORT_D) AM_WRITE(draco_sound_bankswitch_w)
-	AM_RANGE(COP400_PORT_G, COP400_PORT_G) AM_WRITE(draco_sound_g_w)
-	AM_RANGE(COP400_PORT_L, COP400_PORT_L) AM_READWRITE(draco_sound_ay8910_r, draco_sound_ay8910_w)
-	AM_RANGE(COP400_PORT_IN, COP400_PORT_IN) AM_READ(draco_sound_in_r)
+static ADDRESS_MAP_START( draco_sound_io_map, AS_IO, 8, draco_state )
+	AM_RANGE(COP400_PORT_D, COP400_PORT_D) AM_WRITE(sound_bankswitch_w)
+	AM_RANGE(COP400_PORT_G, COP400_PORT_G) AM_WRITE(sound_g_w)
+	AM_RANGE(COP400_PORT_L, COP400_PORT_L) AM_READWRITE(psg_r, psg_w)
+	AM_RANGE(COP400_PORT_IN, COP400_PORT_IN) AM_READ(sound_in_r)
 	AM_RANGE(COP400_PORT_SIO, COP400_PORT_SIO) AM_NOP
 	AM_RANGE(COP400_PORT_SK, COP400_PORT_SK) AM_WRITENOP
 ADDRESS_MAP_END
@@ -281,14 +272,14 @@ ADDRESS_MAP_END
 
 static CUSTOM_INPUT( cdp1869_pcb_r )
 {
-	cidelsa_state *state = field->port->machine->driver_data<cidelsa_state>();
+	cidelsa_state *state = field.machine().driver_data<cidelsa_state>();
 
 	return state->m_cdp1869_pcb;
 }
 
 static INPUT_CHANGED( ef_w )
 {
-	cputag_set_input_line(field->port->machine, CDP1802_TAG, (int)(FPTR)param, newval);
+	cputag_set_input_line(field.machine(), CDP1802_TAG, (int)(FPTR)param, newval);
 }
 
 static INPUT_PORTS_START( destryer )
@@ -437,32 +428,27 @@ INPUT_PORTS_END
 
 static TIMER_CALLBACK( set_cpu_mode )
 {
-	cidelsa_state *state = machine->driver_data<cidelsa_state>();
+	cidelsa_state *state = machine.driver_data<cidelsa_state>();
 
 	state->m_reset = 1;
 }
 
-static MACHINE_START( cidelsa )
+void cidelsa_state::machine_start()
 {
-	cidelsa_state *state = machine->driver_data<cidelsa_state>();
-
 	/* register for state saving */
-	state_save_register_global(machine, state->m_reset);
+	save_item(NAME(m_reset));
 }
 
-static MACHINE_START( draco )
+void draco_state::machine_start()
 {
-	cidelsa_state *state = machine->driver_data<cidelsa_state>();
-
-	MACHINE_START_CALL( cidelsa );
-
 	/* setup COP402 memory banking */
-	memory_configure_bank(machine, "bank1", 0, 2, machine->region(COP402N_TAG)->base(), 0x400);
-	memory_set_bank(machine, "bank1", 0);
+	memory_configure_bank(machine(), "bank1", 0, 2, machine().region(COP402N_TAG)->base(), 0x400);
+	memory_set_bank(machine(), "bank1", 0);
 
 	/* register for state saving */
-	state_save_register_global(machine, state->m_draco_sound);
-	state_save_register_global(machine, state->m_draco_ay_latch);
+	save_item(NAME(m_reset));
+	save_item(NAME(m_sound));
+	save_item(NAME(m_psg_latch));
 }
 
 /* Machine Reset */
@@ -471,7 +457,7 @@ void cidelsa_state::machine_reset()
 {
 	/* reset the CPU */
 	m_reset = 0;
-	timer_set(&m_machine, ATTOTIME_IN_MSEC(200), NULL, 0, set_cpu_mode);
+	machine().scheduler().timer_set(attotime::from_msec(200), FUNC(set_cpu_mode));
 }
 
 /* Machine Drivers */
@@ -484,8 +470,6 @@ static MACHINE_CONFIG_START( destryer, cidelsa_state )
 	MCFG_CPU_CONFIG(cidelsa_cdp1802_config)
 	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MCFG_MACHINE_START(cidelsa)
-
 	/* sound and video hardware */
 	MCFG_FRAGMENT_ADD(destryer_video)
 MACHINE_CONFIG_END
@@ -498,8 +482,6 @@ static MACHINE_CONFIG_START( destryera, cidelsa_state )
 	MCFG_CPU_CONFIG(cidelsa_cdp1802_config)
 	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MCFG_MACHINE_START(cidelsa)
-
 	/* sound and video hardware */
 	MCFG_FRAGMENT_ADD(destryer_video)
 MACHINE_CONFIG_END
@@ -512,8 +494,6 @@ static MACHINE_CONFIG_START( altair, cidelsa_state )
 	MCFG_CPU_CONFIG(cidelsa_cdp1802_config)
 	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MCFG_MACHINE_START(cidelsa)
-
 	/* input/output hardware */
 	MCFG_CDP1852_ADD("ic23", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in0_intf)	/* clock is really tied to CDP1869 CMSEL (pin 37) */
 	MCFG_CDP1852_ADD("ic24", CDP1852_CLOCK_HIGH, cidelsa_cdp1852_in1_intf)
@@ -524,7 +504,7 @@ static MACHINE_CONFIG_START( altair, cidelsa_state )
 	MCFG_FRAGMENT_ADD(altair_video)
 MACHINE_CONFIG_END
 
-static MACHINE_CONFIG_START( draco, cidelsa_state )
+static MACHINE_CONFIG_START( draco, draco_state )
 	/* basic system hardware */
 	MCFG_CPU_ADD(CDP1802_TAG, COSMAC, DRACO_CHR1)
 	MCFG_CPU_PROGRAM_MAP(draco_map)
@@ -532,8 +512,6 @@ static MACHINE_CONFIG_START( draco, cidelsa_state )
 	MCFG_CPU_CONFIG(cidelsa_cdp1802_config)
 	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MCFG_MACHINE_START(draco)
-
 	MCFG_CPU_ADD(COP402N_TAG, COP402, DRACO_SND_CHR1)
 	MCFG_CPU_PROGRAM_MAP(draco_sound_map)
 	MCFG_CPU_IO_MAP(draco_sound_io_map)
