@@ -43,17 +43,6 @@
 #define MASTER_CLOCK			XTAL_19_923MHz
 
 
-
-static UINT16 *rambase;
-
-static UINT8 coin_detected;
-static UINT8 coin_last_reset;
-
-static UINT8 mux_select;
-static int gear;
-
-
-
 /*************************************
  *
  *  General machine init
@@ -62,20 +51,22 @@ static int gear;
 
 static MACHINE_START( cinemat )
 {
-	state_save_register_global(machine, coin_detected);
-	state_save_register_global(machine, coin_last_reset);
-	state_save_register_global(machine, mux_select);
+	cinemat_state *state = machine.driver_data<cinemat_state>();
+	state_save_register_global(machine, state->m_coin_detected);
+	state_save_register_global(machine, state->m_coin_last_reset);
+	state_save_register_global(machine, state->m_mux_select);
 }
 
 
 MACHINE_RESET( cinemat )
 {
+	cinemat_state *state = machine.driver_data<cinemat_state>();
 	/* reset the coin states */
-	coin_detected = 0;
-	coin_last_reset = 0;
+	state->m_coin_detected = 0;
+	state->m_coin_last_reset = 0;
 
 	/* reset mux select */
-	mux_select = 0;
+	state->m_mux_select = 0;
 }
 
 
@@ -88,14 +79,14 @@ MACHINE_RESET( cinemat )
 
 static READ8_HANDLER( inputs_r )
 {
-	return (input_port_read(space->machine, "INPUTS") >> offset) & 1;
+	return (input_port_read(space->machine(), "INPUTS") >> offset) & 1;
 }
 
 
 static READ8_HANDLER( switches_r )
 {
 	static const UINT8 switch_shuffle[8] = { 2,5,4,3,0,1,6,7 };
-	return (input_port_read(space->machine, "SWITCHES") >> switch_shuffle[offset]) & 1;
+	return (input_port_read(space->machine(), "SWITCHES") >> switch_shuffle[offset]) & 1;
 }
 
 
@@ -108,15 +99,17 @@ static READ8_HANDLER( switches_r )
 
 static INPUT_CHANGED( coin_inserted )
 {
+	cinemat_state *state = field.machine().driver_data<cinemat_state>();
 	/* on the falling edge of a new coin, set the coin_detected flag */
 	if (newval == 0)
-		coin_detected = 1;
+		state->m_coin_detected = 1;
 }
 
 
 static READ8_HANDLER( coin_input_r )
 {
-	return !coin_detected;
+	cinemat_state *state = space->machine().driver_data<cinemat_state>();
+	return !state->m_coin_detected;
 }
 
 
@@ -129,16 +122,18 @@ static READ8_HANDLER( coin_input_r )
 
 static WRITE8_HANDLER( coin_reset_w )
 {
+	cinemat_state *state = space->machine().driver_data<cinemat_state>();
 	/* on the rising edge of a coin reset, clear the coin_detected flag */
-	if (coin_last_reset != data && data != 0)
-		coin_detected = 0;
-	coin_last_reset = data;
+	if (state->m_coin_last_reset != data && data != 0)
+		state->m_coin_detected = 0;
+	state->m_coin_last_reset = data;
 }
 
 
 static WRITE8_HANDLER( mux_select_w )
 {
-	mux_select = data;
+	cinemat_state *state = space->machine().driver_data<cinemat_state>();
+	state->m_mux_select = data;
 	cinemat_sound_control_w(space, 0x07, data);
 }
 
@@ -152,12 +147,13 @@ static WRITE8_HANDLER( mux_select_w )
 
 static UINT8 joystick_read(device_t *device)
 {
-	if (device->machine->phase() != MACHINE_PHASE_RUNNING)
+	cinemat_state *state = device->machine().driver_data<cinemat_state>();
+	if (device->machine().phase() != MACHINE_PHASE_RUNNING)
 		return 0;
 	else
 	{
 		int xval = (INT16)(cpu_get_reg(device, CCPU_X) << 4) >> 4;
-		return (input_port_read_safe(device->machine, mux_select ? "ANALOGX" : "ANALOGY", 0) - xval) < 0x800;
+		return (input_port_read_safe(device->machine(), state->m_mux_select ? "ANALOGX" : "ANALOGY", 0) - xval) < 0x800;
 	}
 }
 
@@ -175,7 +171,7 @@ static READ8_HANDLER( speedfrk_wheel_r )
 	int delta_wheel;
 
     /* the shift register is cleared once per 'frame' */
-    delta_wheel = (INT8)input_port_read(space->machine, "WHEEL") / 8;
+    delta_wheel = (INT8)input_port_read(space->machine(), "WHEEL") / 8;
     if (delta_wheel > 3)
         delta_wheel = 3;
     else if (delta_wheel < -3)
@@ -187,17 +183,18 @@ static READ8_HANDLER( speedfrk_wheel_r )
 
 static READ8_HANDLER( speedfrk_gear_r )
 {
-	int gearval = input_port_read(space->machine, "GEAR");
+	cinemat_state *state = space->machine().driver_data<cinemat_state>();
+	int gearval = input_port_read(space->machine(), "GEAR");
 
 	/* check the fake gear input port and determine the bit settings for the gear */
 	if ((gearval & 0x0f) != 0x0f)
-        gear = gearval & 0x0f;
+        state->m_gear = gearval & 0x0f;
 
 	/* add the start key into the mix -- note that it overlaps 4th gear */
-	if (!(input_port_read(space->machine, "INPUTS") & 0x80))
-        gear &= ~0x08;
+	if (!(input_port_read(space->machine(), "INPUTS") & 0x80))
+        state->m_gear &= ~0x08;
 
-	return (gear >> offset) & 1;
+	return (state->m_gear >> offset) & 1;
 }
 
 
@@ -240,9 +237,9 @@ static READ8_HANDLER( sundance_inputs_r )
 {
 	/* handle special keys first */
 	if (sundance_port_map[offset].portname)
-		return (input_port_read(space->machine, sundance_port_map[offset].portname) & sundance_port_map[offset].bitmask) ? 0 : 1;
+		return (input_port_read(space->machine(), sundance_port_map[offset].portname) & sundance_port_map[offset].bitmask) ? 0 : 1;
 	else
-		return (input_port_read(space->machine, "INPUTS") >> offset) & 1;
+		return (input_port_read(space->machine(), "INPUTS") >> offset) & 1;
 }
 
 
@@ -255,8 +252,9 @@ static READ8_HANDLER( sundance_inputs_r )
 
 static READ8_HANDLER( boxingb_dial_r )
 {
-	int value = input_port_read(space->machine, "DIAL");
-	if (!mux_select) offset += 4;
+	cinemat_state *state = space->machine().driver_data<cinemat_state>();
+	int value = input_port_read(space->machine(), "DIAL");
+	if (!state->m_mux_select) offset += 4;
 	return (value >> offset) & 1;
 }
 
@@ -270,8 +268,8 @@ static READ8_HANDLER( boxingb_dial_r )
 
 static READ8_HANDLER( qb3_frame_r )
 {
-	attotime next_update = space->machine->primary_screen->time_until_update();
-	attotime frame_period = space->machine->primary_screen->frame_period();
+	attotime next_update = space->machine().primary_screen->time_until_update();
+	attotime frame_period = space->machine().primary_screen->frame_period();
 	int percent = next_update.attoseconds / (frame_period.attoseconds / 100);
 
 	/* note this is just an approximation... */
@@ -281,7 +279,7 @@ static READ8_HANDLER( qb3_frame_r )
 
 static WRITE8_HANDLER( qb3_ram_bank_w )
 {
-	memory_set_bank(space->machine, "bank1", cpu_get_reg(space->machine->device("maincpu"), CCPU_P) & 3);
+	memory_set_bank(space->machine(), "bank1", cpu_get_reg(space->machine().device("maincpu"), CCPU_P) & 3);
 }
 
 
@@ -292,38 +290,38 @@ static WRITE8_HANDLER( qb3_ram_bank_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( program_map_4k, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( program_map_4k, AS_PROGRAM, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xfff)
 	AM_RANGE(0x0000, 0x0fff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( program_map_8k, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( program_map_8k, AS_PROGRAM, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0x3fff)
 	AM_RANGE(0x0000, 0x0fff) AM_MIRROR(0x1000) AM_ROM
 	AM_RANGE(0x2000, 0x2fff) AM_MIRROR(0x1000) AM_ROM AM_REGION("maincpu", 0x1000)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( program_map_16k, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( program_map_16k, AS_PROGRAM, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0x3fff)
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( program_map_32k, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( program_map_32k, AS_PROGRAM, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0x7fff)
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( data_map, ADDRESS_SPACE_DATA, 16 )
+static ADDRESS_MAP_START( data_map, AS_DATA, 16 )
 	AM_RANGE(0x0000, 0x00ff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( data_map_qb3, ADDRESS_SPACE_DATA, 16 )
-	AM_RANGE(0x0000, 0x03ff) AM_RAMBANK("bank1") AM_BASE(&rambase)
+static ADDRESS_MAP_START( data_map_qb3, AS_DATA, 16 )
+	AM_RANGE(0x0000, 0x03ff) AM_RAMBANK("bank1") AM_BASE_MEMBER(cinemat_state, m_rambase)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( io_map, AS_IO, 8 )
 	AM_RANGE(0x00, 0x0f) AM_READ(inputs_r)
 	AM_RANGE(0x10, 0x16) AM_READ(switches_r)
 	AM_RANGE(0x17, 0x17) AM_READ(coin_input_r)
@@ -992,7 +990,7 @@ static const ccpu_config config_jmi =
  *
  *************************************/
 
-static MACHINE_CONFIG_START( cinemat_nojmi_4k, driver_device )
+static MACHINE_CONFIG_START( cinemat_nojmi_4k, cinemat_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", CCPU, MASTER_CLOCK/4)
@@ -1011,9 +1009,9 @@ static MACHINE_CONFIG_START( cinemat_nojmi_4k, driver_device )
 	MCFG_SCREEN_REFRESH_RATE(MASTER_CLOCK/4/16/16/16/16/2)
 	MCFG_SCREEN_SIZE(1024, 768)
 	MCFG_SCREEN_VISIBLE_AREA(0, 1023, 0, 767)
+	MCFG_SCREEN_UPDATE(cinemat)
 
 	MCFG_VIDEO_START(cinemat_bilevel)
-	MCFG_VIDEO_UPDATE(cinemat)
 MACHINE_CONFIG_END
 
 
@@ -1057,7 +1055,8 @@ MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( spacewar, cinemat_nojmi_4k )
 	MCFG_FRAGMENT_ADD(spacewar_sound)
-	MCFG_VIDEO_UPDATE(spacewar)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_UPDATE(spacewar)
 MACHINE_CONFIG_END
 
 
@@ -1459,37 +1458,39 @@ ROM_END
 
 static DRIVER_INIT( speedfrk )
 {
-	gear = 0xe;
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x00, 0x03, 0, 0, speedfrk_wheel_r);
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x04, 0x06, 0, 0, speedfrk_gear_r);
+	cinemat_state *state = machine.driver_data<cinemat_state>();
+	state->m_gear = 0xe;
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x00, 0x03, FUNC(speedfrk_wheel_r));
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x04, 0x06, FUNC(speedfrk_gear_r));
 }
 
 
 static DRIVER_INIT( sundance )
 {
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x00, 0x0f, 0, 0, sundance_inputs_r);
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x00, 0x0f, FUNC(sundance_inputs_r));
 }
 
 
 static DRIVER_INIT( tailg )
 {
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x07, 0x07, 0, 0, mux_select_w);
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_write_handler(0x07, 0x07, FUNC(mux_select_w));
 }
 
 
 static DRIVER_INIT( boxingb )
 {
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x0c, 0x0f, 0, 0, boxingb_dial_r);
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x07, 0x07, 0, 0, mux_select_w);
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x0c, 0x0f, FUNC(boxingb_dial_r));
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_write_handler(0x07, 0x07, FUNC(mux_select_w));
 }
 
 
 static DRIVER_INIT( qb3 )
 {
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x0f, 0x0f, 0, 0, qb3_frame_r);
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x00, 0x00, 0, 0, qb3_ram_bank_w);
+	cinemat_state *state = machine.driver_data<cinemat_state>();
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x0f, 0x0f, FUNC(qb3_frame_r));
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_write_handler(0x00, 0x00, FUNC(qb3_ram_bank_w));
 
-	memory_configure_bank(machine, "bank1", 0, 4, rambase, 0x100*2);
+	memory_configure_bank(machine, "bank1", 0, 4, state->m_rambase, 0x100*2);
 }
 
 
