@@ -1,14 +1,25 @@
 /***************************************************************************
 
-Multipede (c) 1980-2 Infogrames / 199x CosmoDog
+Centipede, Millipede, Missile Command, Let's Go Bowling "Multipede"
+(c) 1980-2 / 2002 - Infogrames / CosmoDog
 
 preliminary driver by Angelo Salese
 
+Earlier revisions of this cabinet did not include the bowling game.
+
 TODO:
 - program banking;
 - finish video emulation;
 - inputs;
 - sound;
+- change the CPU when a G658C02 core will be available;
+- driver probably needs rewriting, at least the i/o part;
+
+Probably on the CPLD (CY39100V208B) - Quoted from Cosmodog's website:
+ "Instead, we used a programmable chip that we could reconfigure very
+ quickly while the game is running. So, during that 1/8th of a second
+ or so when the screen goes black while it switches games, it's actually
+ reloading the hardware with a whole new design to run the next game."
 
 ============================================================================
 
@@ -28,16 +39,17 @@ CYC1399
 ***************************************************************************/
 
 #include "emu.h"
-#include "cpu/m6502/m6502.h"
+#include "cpu/g65816/g65816.h"
 
 
 class cmmb_state : public driver_device
 {
 public:
-	cmmb_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	cmmb_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	UINT8 *videoram;
+	UINT8 *m_videoram;
+	UINT8 m_irq_mask;
 };
 
 
@@ -46,11 +58,11 @@ static VIDEO_START( cmmb )
 
 }
 
-static VIDEO_UPDATE( cmmb )
+static SCREEN_UPDATE( cmmb )
 {
-	cmmb_state *state = screen->machine->driver_data<cmmb_state>();
-	UINT8 *videoram = state->videoram;
-	const gfx_element *gfx = screen->machine->gfx[0];
+	cmmb_state *state = screen->machine().driver_data<cmmb_state>();
+	UINT8 *videoram = state->m_videoram;
+	const gfx_element *gfx = screen->machine().gfx[0];
 	int count = 0x00000;
 
 	int y,x;
@@ -73,22 +85,22 @@ static VIDEO_UPDATE( cmmb )
 
 static READ8_HANDLER( cmmb_charram_r )
 {
-	UINT8 *GFX = space->machine->region("gfx")->base();
+	UINT8 *GFX = space->machine().region("gfx")->base();
 
 	return GFX[offset];
 }
 
 static WRITE8_HANDLER( cmmb_charram_w )
 {
-	UINT8 *GFX = space->machine->region("gfx")->base();
+	UINT8 *GFX = space->machine().region("gfx")->base();
 
 	GFX[offset] = data;
 
 	offset&=0xfff;
 
 	/* dirty char */
-	gfx_element_mark_dirty(space->machine->gfx[0], offset >> 4);
-    gfx_element_mark_dirty(space->machine->gfx[1], offset >> 5);
+	gfx_element_mark_dirty(space->machine().gfx[0], offset >> 4);
+    gfx_element_mark_dirty(space->machine().gfx[1], offset >> 5);
 }
 
 
@@ -103,43 +115,43 @@ static READ8_HANDLER( cmmb_input_r )
 	//printf("%02x R\n",offset);
 	switch(offset)
 	{
-		case 0x00: return input_port_read(space->machine, "IN2");
+		case 0x00: return input_port_read(space->machine(), "IN2");
 		case 0x03: return 4; //eeprom?
-		case 0x0e: return input_port_read(space->machine, "IN0");
-		case 0x0f: return input_port_read(space->machine, "IN1");
+		case 0x0e: return input_port_read(space->machine(), "IN0");
+		case 0x0f: return input_port_read(space->machine(), "IN1");
 	}
 
 	return 0xff;
 }
 
-static UINT8 irq_mask;
 
 /*
     {
-        UINT8 *ROM = space->machine->region("maincpu")->base();
+        UINT8 *ROM = space->machine().region("maincpu")->base();
         UINT32 bankaddress;
 
         bankaddress = 0x10000 + (0x10000 * (data & 0x03));
-        memory_set_bankptr(space->machine, "bank1", &ROM[bankaddress]);
+        memory_set_bankptr(space->machine(), "bank1", &ROM[bankaddress]);
     }
 */
 
 static WRITE8_HANDLER( cmmb_output_w )
 {
+	cmmb_state *state = space->machine().driver_data<cmmb_state>();
 	//printf("%02x -> [%02x] W\n",data,offset);
 	switch(offset)
 	{
 		case 0x01:
 			{
-				UINT8 *ROM = space->machine->region("maincpu")->base();
+				UINT8 *ROM = space->machine().region("maincpu")->base();
 				UINT32 bankaddress;
 
 				bankaddress = 0x1c000 + (0x10000 * (data & 0x03));
-				memory_set_bankptr(space->machine, "bank1", &ROM[bankaddress]);
+				memory_set_bankptr(space->machine(), "bank1", &ROM[bankaddress]);
 			}
 			break;
 		case 0x03:
-			irq_mask = data & 0x80;
+			state->m_irq_mask = data & 0x80;
 			break;
 		case 0x07:
 			break;
@@ -148,14 +160,15 @@ static WRITE8_HANDLER( cmmb_output_w )
 
 static READ8_HANDLER( kludge_r )
 {
-	return space->machine->rand();
+	return space->machine().rand();
 }
 
 /* overlap empty addresses */
-static ADDRESS_MAP_START( cmmb_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( cmmb_map, AS_PROGRAM, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xffff)
 	AM_RANGE(0x0000, 0x01ff) AM_RAM /* zero page address */
 //  AM_RANGE(0x13c0, 0x13ff) AM_RAM //spriteram
-	AM_RANGE(0x1000, 0x13ff) AM_RAM AM_BASE_MEMBER(cmmb_state, videoram)
+	AM_RANGE(0x1000, 0x13ff) AM_RAM AM_BASE_MEMBER(cmmb_state, m_videoram)
 	AM_RANGE(0x2480, 0x249f) AM_RAM_WRITE(cmmb_paletteram_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x4000, 0x400f) AM_READWRITE(cmmb_input_r,cmmb_output_w) //i/o
 	AM_RANGE(0x4900, 0x4900) AM_READ(kludge_r)
@@ -275,8 +288,8 @@ GFXDECODE_END
 
 static INTERRUPT_GEN( cmmb_irq )
 {
-	//if(input_code_pressed_once(device->machine, KEYCODE_Z))
-	//  cpu_set_input_line(device, 0, HOLD_LINE);
+	//if(device->machine().input().code_pressed_once(KEYCODE_Z))
+	//  device_set_input_line(device, 0, HOLD_LINE);
 }
 
 static MACHINE_RESET( cmmb )
@@ -286,7 +299,7 @@ static MACHINE_RESET( cmmb )
 static MACHINE_CONFIG_START( cmmb, cmmb_state )
 
 	/* basic machine hardware */
-	MCFG_CPU_ADD("maincpu",M65C02,8000000/2) // unknown clock
+	MCFG_CPU_ADD("maincpu",G65816,8000000/2) // G658C02 (a G65816 with 64k of address line space), unknown clock
 	MCFG_CPU_PROGRAM_MAP(cmmb_map)
 	MCFG_CPU_VBLANK_INT("screen",cmmb_irq)
 
@@ -297,11 +310,12 @@ static MACHINE_CONFIG_START( cmmb, cmmb_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 32*8-1)
+	MCFG_SCREEN_UPDATE(cmmb)
+
 	MCFG_GFXDECODE(cmmb)
 	MCFG_PALETTE_LENGTH(512)
 
 	MCFG_VIDEO_START(cmmb)
-	MCFG_VIDEO_UPDATE(cmmb)
 
 	MCFG_MACHINE_RESET(cmmb)
 
@@ -325,4 +339,4 @@ ROM_START( cmmb162 )
 	ROM_REGION( 0x1000, "gfx", ROMREGION_ERASE00 )
 ROM_END
 
-GAME( 199?, cmmb162,  0,       cmmb,  cmmb,  0, ROT270, "Infogrames / Cosmodog", "Multipede (V1.00)", GAME_NO_SOUND|GAME_NOT_WORKING )
+GAME( 2002, cmmb162,  0,       cmmb,  cmmb,  0, ROT270, "Infogrames / Cosmodog", "Multipede (rev 1.62)", GAME_NO_SOUND|GAME_NOT_WORKING )
