@@ -32,31 +32,30 @@ x
 class coinmstr_state : public driver_device
 {
 public:
-	coinmstr_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	coinmstr_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	UINT8 *videoram;
+	UINT8 *m_videoram;
+	UINT8 *m_attr_ram1;
+	UINT8 *m_attr_ram2;
+	UINT8 *m_attr_ram3;
+	tilemap_t *m_bg_tilemap;
+	UINT8 m_question_adr[4];
 };
 
 
-
-static UINT8 *attr_ram1, *attr_ram2, *attr_ram3;
-static tilemap_t *bg_tilemap;
-
-static UINT8 question_adr[4];
-
 static WRITE8_HANDLER( quizmstr_bg_w )
 {
-	coinmstr_state *state = space->machine->driver_data<coinmstr_state>();
-	UINT8 *videoram = state->videoram;
+	coinmstr_state *state = space->machine().driver_data<coinmstr_state>();
+	UINT8 *videoram = state->m_videoram;
 	videoram[offset] = data;
 
 	if(offset >= 0x0240)
-		tilemap_mark_tile_dirty(bg_tilemap,offset - 0x0240);
+		tilemap_mark_tile_dirty(state->m_bg_tilemap,offset - 0x0240);
 }
 
 
-static void coinmstr_set_pal(running_machine *machine, UINT32 paldat, int col)
+static void coinmstr_set_pal(running_machine &machine, UINT32 paldat, int col)
 {
 	col = col *4;
 
@@ -91,100 +90,105 @@ static void coinmstr_set_pal(running_machine *machine, UINT32 paldat, int col)
 
 static WRITE8_HANDLER( quizmstr_attr1_w )
 {
-	attr_ram1[offset] = data;
+	coinmstr_state *state = space->machine().driver_data<coinmstr_state>();
+	state->m_attr_ram1[offset] = data;
 
 	if(offset >= 0x0240)
 	{
 		// the later games also use attr3 for something..
-		UINT32	paldata = (attr_ram1[offset] & 0x7f) | ((attr_ram2[offset] & 0x7f) << 7);
-		tilemap_mark_tile_dirty(bg_tilemap, offset - 0x0240);
+		UINT32	paldata = (state->m_attr_ram1[offset] & 0x7f) | ((state->m_attr_ram2[offset] & 0x7f) << 7);
+		tilemap_mark_tile_dirty(state->m_bg_tilemap, offset - 0x0240);
 
-		coinmstr_set_pal(space->machine, paldata, offset - 0x240);
+		coinmstr_set_pal(space->machine(), paldata, offset - 0x240);
 
 	}
 }
 
 static WRITE8_HANDLER( quizmstr_attr2_w )
 {
-	attr_ram2[offset] = data;
+	coinmstr_state *state = space->machine().driver_data<coinmstr_state>();
+	state->m_attr_ram2[offset] = data;
 
 	if(offset >= 0x0240)
 	{
 		// the later games also use attr3 for something..
-		UINT32	paldata = (attr_ram1[offset] & 0x7f) | ((attr_ram2[offset] & 0x7f) << 7);
-		tilemap_mark_tile_dirty(bg_tilemap, offset - 0x0240);
+		UINT32	paldata = (state->m_attr_ram1[offset] & 0x7f) | ((state->m_attr_ram2[offset] & 0x7f) << 7);
+		tilemap_mark_tile_dirty(state->m_bg_tilemap, offset - 0x0240);
 
-		coinmstr_set_pal(space->machine, paldata, offset - 0x240);
+		coinmstr_set_pal(space->machine(), paldata, offset - 0x240);
 
 	}
 }
 
 static WRITE8_HANDLER( quizmstr_attr3_w )
 {
-	attr_ram3[offset] = data;
+	coinmstr_state *state = space->machine().driver_data<coinmstr_state>();
+	state->m_attr_ram3[offset] = data;
 
 	if(offset >= 0x0240)
-		tilemap_mark_tile_dirty(bg_tilemap, offset - 0x0240);
+		tilemap_mark_tile_dirty(state->m_bg_tilemap, offset - 0x0240);
 
 }
 
 
 static READ8_HANDLER( question_r )
 {
+	coinmstr_state *state = space->machine().driver_data<coinmstr_state>();
 	int address;
-	UINT8 *questions = space->machine->region("user1")->base();
+	UINT8 *questions = space->machine().region("user1")->base();
 
-	switch(question_adr[2])
+	switch(state->m_question_adr[2])
 	{
-		case 0x38: address = 0x00000; break; // question_adr[3] == 7
-		case 0x39: address = 0x08000; break; // question_adr[3] == 7
-		case 0x3a: address = 0x10000; break; // question_adr[3] == 7
-		case 0x3b: address = 0x18000; break; // question_adr[3] == 7
-		case 0x3c: address = 0x20000; break; // question_adr[3] == 7
-		case 0x3d: address = 0x28000; break; // question_adr[3] == 7
-		case 0x3e: address = 0x30000; break; // question_adr[3] == 7
-		case 0x07: address = 0x38000; break; // question_adr[3] == 7
-		case 0x0f: address = 0x40000; break; // question_adr[3] == 7
-		case 0x17: address = 0x48000; break; // question_adr[3] == 7
-		case 0x1f: address = 0x50000; break; // question_adr[3] == 7
-		case 0x27: address = 0x58000; break; // question_adr[3] == 7
-		case 0x2f: address = 0x60000; break; // question_adr[3] == 7
-		case 0x37: address = 0x68000; break; // question_adr[3] == 7
-		case 0x3f: address = 0x70000 + question_adr[3] * 0x8000; break;
+		case 0x38: address = 0x00000; break; // state->m_question_adr[3] == 7
+		case 0x39: address = 0x08000; break; // state->m_question_adr[3] == 7
+		case 0x3a: address = 0x10000; break; // state->m_question_adr[3] == 7
+		case 0x3b: address = 0x18000; break; // state->m_question_adr[3] == 7
+		case 0x3c: address = 0x20000; break; // state->m_question_adr[3] == 7
+		case 0x3d: address = 0x28000; break; // state->m_question_adr[3] == 7
+		case 0x3e: address = 0x30000; break; // state->m_question_adr[3] == 7
+		case 0x07: address = 0x38000; break; // state->m_question_adr[3] == 7
+		case 0x0f: address = 0x40000; break; // state->m_question_adr[3] == 7
+		case 0x17: address = 0x48000; break; // state->m_question_adr[3] == 7
+		case 0x1f: address = 0x50000; break; // state->m_question_adr[3] == 7
+		case 0x27: address = 0x58000; break; // state->m_question_adr[3] == 7
+		case 0x2f: address = 0x60000; break; // state->m_question_adr[3] == 7
+		case 0x37: address = 0x68000; break; // state->m_question_adr[3] == 7
+		case 0x3f: address = 0x70000 + state->m_question_adr[3] * 0x8000; break;
 
 		default:
 			address = 0;
-			logerror("unknown question rom # = %02X\n",question_adr[2]);
+			logerror("unknown question rom # = %02X\n",state->m_question_adr[2]);
 	}
 
-	if(question_adr[3] == 6 || question_adr[3] > 7)
-		logerror("question_adr[3] = %02X\n",question_adr[3]);
+	if(state->m_question_adr[3] == 6 || state->m_question_adr[3] > 7)
+		logerror("question_adr[3] = %02X\n",state->m_question_adr[3]);
 
 /*
     in these offsets they set 0x80... why?
 
-    if( (question_adr[0] & 0x5f) == 0x00 ||
-        (question_adr[0] & 0x5f) == 0x01 ||
-        (question_adr[0] & 0x5f) == 0x0f ||
-        (question_adr[0] & 0x5f) == 0x56 )
+    if( (state->m_question_adr[0] & 0x5f) == 0x00 ||
+        (state->m_question_adr[0] & 0x5f) == 0x01 ||
+        (state->m_question_adr[0] & 0x5f) == 0x0f ||
+        (state->m_question_adr[0] & 0x5f) == 0x56 )
 */
 
 
 //  don't know...
-//  address |= ((question_adr[0] & 0x7f) << 8) | question_adr[1];
-	address |= (question_adr[1] << 7) | (question_adr[0] & 0x7f);
+//  address |= ((state->m_question_adr[0] & 0x7f) << 8) | state->m_question_adr[1];
+	address |= (state->m_question_adr[1] << 7) | (state->m_question_adr[0] & 0x7f);
 
 	return questions[address];
 }
 
 static WRITE8_HANDLER( question_w )
 {
-	if(data != question_adr[offset])
+	coinmstr_state *state = space->machine().driver_data<coinmstr_state>();
+	if(data != state->m_question_adr[offset])
 	{
 		logerror("offset = %d data = %02X\n",offset,data);
 	}
 
-	question_adr[offset] = data;
+	state->m_question_adr[offset] = data;
 }
 
 static READ8_HANDLER( ff_r )
@@ -194,49 +198,49 @@ static READ8_HANDLER( ff_r )
 
 // Common memory map
 
-static ADDRESS_MAP_START( coinmstr_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( coinmstr_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xdfff) AM_RAM
-	AM_RANGE(0xe000, 0xe7ff) AM_RAM_WRITE(quizmstr_bg_w) AM_BASE_MEMBER(coinmstr_state, videoram)
-	AM_RANGE(0xe800, 0xefff) AM_RAM_WRITE(quizmstr_attr1_w) AM_BASE(&attr_ram1)
-	AM_RANGE(0xf000, 0xf7ff) AM_RAM_WRITE(quizmstr_attr2_w) AM_BASE(&attr_ram2)
-	AM_RANGE(0xf800, 0xffff) AM_RAM_WRITE(quizmstr_attr3_w) AM_BASE(&attr_ram3)
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM_WRITE(quizmstr_bg_w) AM_BASE_MEMBER(coinmstr_state, m_videoram)
+	AM_RANGE(0xe800, 0xefff) AM_RAM_WRITE(quizmstr_attr1_w) AM_BASE_MEMBER(coinmstr_state, m_attr_ram1)
+	AM_RANGE(0xf000, 0xf7ff) AM_RAM_WRITE(quizmstr_attr2_w) AM_BASE_MEMBER(coinmstr_state, m_attr_ram2)
+	AM_RANGE(0xf800, 0xffff) AM_RAM_WRITE(quizmstr_attr3_w) AM_BASE_MEMBER(coinmstr_state, m_attr_ram3)
 ADDRESS_MAP_END
 
 // Different I/O mappping for every game
 
-static ADDRESS_MAP_START( quizmstr_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( quizmstr_io_map, AS_IO, 8 )
 	ADDRESS_MAP_UNMAP_HIGH
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(question_r)
 	AM_RANGE(0x00, 0x03) AM_WRITE(question_w)
 	AM_RANGE(0x40, 0x41) AM_DEVWRITE("aysnd", ay8910_address_data_w)
 	AM_RANGE(0x41, 0x41) AM_DEVREAD("aysnd", ay8910_r)
-	AM_RANGE(0x48, 0x4b) AM_DEVREADWRITE("pia0", pia6821_r, pia6821_w)
+	AM_RANGE(0x48, 0x4b) AM_DEVREADWRITE_MODERN("pia0", pia6821_device, read, write)
 	AM_RANGE(0x50, 0x53) AM_READNOP
 	AM_RANGE(0x50, 0x53) AM_WRITENOP
-	AM_RANGE(0x58, 0x5b) AM_DEVREADWRITE("pia2", pia6821_r, pia6821_w)
-	AM_RANGE(0x70, 0x70) AM_DEVWRITE("crtc", mc6845_address_w)
-	AM_RANGE(0x71, 0x71) AM_DEVWRITE("crtc", mc6845_register_w)
+	AM_RANGE(0x58, 0x5b) AM_DEVREADWRITE_MODERN("pia2", pia6821_device, read, write)
+	AM_RANGE(0x70, 0x70) AM_DEVWRITE_MODERN("crtc", mc6845_device, address_w)
+	AM_RANGE(0x71, 0x71) AM_DEVWRITE_MODERN("crtc", mc6845_device, register_w)
 	AM_RANGE(0xc0, 0xc3) AM_READNOP
 	AM_RANGE(0xc0, 0xc3) AM_WRITENOP
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( trailblz_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( trailblz_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(question_r)
 	AM_RANGE(0x00, 0x03) AM_WRITE(question_w)
-	AM_RANGE(0x40, 0x40) AM_DEVWRITE("crtc", mc6845_address_w)
-	AM_RANGE(0x41, 0x41) AM_DEVWRITE("crtc", mc6845_register_w)
+	AM_RANGE(0x40, 0x40) AM_DEVWRITE_MODERN("crtc", mc6845_device, address_w)
+	AM_RANGE(0x41, 0x41) AM_DEVWRITE_MODERN("crtc", mc6845_device, register_w)
 	AM_RANGE(0x48, 0x49) AM_DEVWRITE("aysnd", ay8910_address_data_w)
 	AM_RANGE(0x49, 0x49) AM_DEVREAD("aysnd", ay8910_r)
-	AM_RANGE(0x50, 0x53) AM_DEVREADWRITE("pia0", pia6821_r, pia6821_w) //?
-	AM_RANGE(0x60, 0x63) AM_DEVREADWRITE("pia1", pia6821_r, pia6821_w)
-	AM_RANGE(0x70, 0x73) AM_DEVREADWRITE("pia2", pia6821_r, pia6821_w)
+	AM_RANGE(0x50, 0x53) AM_DEVREADWRITE_MODERN("pia0", pia6821_device, read, write) //?
+	AM_RANGE(0x60, 0x63) AM_DEVREADWRITE_MODERN("pia1", pia6821_device, read, write)
+	AM_RANGE(0x70, 0x73) AM_DEVREADWRITE_MODERN("pia2", pia6821_device, read, write)
 	AM_RANGE(0xc1, 0xc3) AM_WRITENOP
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( supnudg2_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( supnudg2_io_map, AS_IO, 8 )
 	ADDRESS_MAP_UNMAP_HIGH
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(question_r)
@@ -244,8 +248,8 @@ static ADDRESS_MAP_START( supnudg2_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x40, 0x41) AM_READNOP
 	AM_RANGE(0x40, 0x43) AM_WRITENOP
 	AM_RANGE(0x43, 0x43) AM_READNOP
-	AM_RANGE(0x48, 0x48) AM_DEVWRITE("crtc", mc6845_address_w)
-	AM_RANGE(0x49, 0x49) AM_DEVWRITE("crtc", mc6845_register_w)
+	AM_RANGE(0x48, 0x48) AM_DEVWRITE_MODERN("crtc", mc6845_device, address_w)
+	AM_RANGE(0x49, 0x49) AM_DEVWRITE_MODERN("crtc", mc6845_device, register_w)
 	AM_RANGE(0x50, 0x51) AM_READNOP
 	AM_RANGE(0x50, 0x53) AM_WRITENOP
 	AM_RANGE(0x53, 0x53) AM_READNOP
@@ -258,15 +262,15 @@ static ADDRESS_MAP_START( supnudg2_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0xc0, 0xc3) AM_WRITENOP
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( pokeroul_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( pokeroul_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE(0x40, 0x40) AM_DEVWRITE("crtc", mc6845_address_w)
-	AM_RANGE(0x41, 0x41) AM_DEVWRITE("crtc", mc6845_register_w)
+	AM_RANGE(0x40, 0x40) AM_DEVWRITE_MODERN("crtc", mc6845_device, address_w)
+	AM_RANGE(0x41, 0x41) AM_DEVWRITE_MODERN("crtc", mc6845_device, register_w)
 	AM_RANGE(0x48, 0x49) AM_DEVWRITE("aysnd", ay8910_address_data_w)
 	AM_RANGE(0x49, 0x49) AM_DEVREAD("aysnd", ay8910_r)
-	AM_RANGE(0x58, 0x5b) AM_DEVREADWRITE("pia0", pia6821_r, pia6821_w) /* confirmed */
-	AM_RANGE(0x68, 0x6b) AM_DEVREADWRITE("pia1", pia6821_r, pia6821_w) /* confirmed */
-	AM_RANGE(0x78, 0x7b) AM_DEVREADWRITE("pia2", pia6821_r, pia6821_w) /* confirmed */
+	AM_RANGE(0x58, 0x5b) AM_DEVREADWRITE_MODERN("pia0", pia6821_device, read, write) /* confirmed */
+	AM_RANGE(0x68, 0x6b) AM_DEVREADWRITE_MODERN("pia1", pia6821_device, read, write) /* confirmed */
+	AM_RANGE(0x78, 0x7b) AM_DEVREADWRITE_MODERN("pia2", pia6821_device, read, write) /* confirmed */
 	AM_RANGE(0xc0, 0xc1) AM_READ(ff_r)	/* needed to boot */
 ADDRESS_MAP_END
 
@@ -891,27 +895,29 @@ GFXDECODE_END
 
 static TILE_GET_INFO( get_bg_tile_info )
 {
-	coinmstr_state *state = machine->driver_data<coinmstr_state>();
-	UINT8 *videoram = state->videoram;
+	coinmstr_state *state = machine.driver_data<coinmstr_state>();
+	UINT8 *videoram = state->m_videoram;
 	int tile = videoram[tile_index + 0x0240];
 	int color = tile_index;
 
-	tile |= (attr_ram1[tile_index + 0x0240] & 0x80) << 1;
-	tile |= (attr_ram2[tile_index + 0x0240] & 0x80) << 2;
+	tile |= (state->m_attr_ram1[tile_index + 0x0240] & 0x80) << 1;
+	tile |= (state->m_attr_ram2[tile_index + 0x0240] & 0x80) << 2;
 
-	tile |= (attr_ram3[tile_index + 0x0240] & 0x03) << (6+4);
+	tile |= (state->m_attr_ram3[tile_index + 0x0240] & 0x03) << (6+4);
 
 	SET_TILE_INFO(0, tile, color, 0);
 }
 
 static VIDEO_START( coinmstr )
 {
-	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows, 8, 8, 46, 32);
+	coinmstr_state *state = machine.driver_data<coinmstr_state>();
+	state->m_bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows, 8, 8, 46, 32);
 }
 
-static VIDEO_UPDATE( coinmstr )
+static SCREEN_UPDATE( coinmstr )
 {
-	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
+	coinmstr_state *state = screen->machine().driver_data<coinmstr_state>();
+	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
 	return 0;
 }
 
@@ -1011,12 +1017,12 @@ static MACHINE_CONFIG_START( coinmstr, coinmstr_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 46*8-1, 0*8, 32*8-1)
+	MCFG_SCREEN_UPDATE(coinmstr)
 
 	MCFG_GFXDECODE(coinmstr)
 	MCFG_PALETTE_LENGTH(46*32*4)
 
 	MCFG_VIDEO_START(coinmstr)
-	MCFG_VIDEO_UPDATE(coinmstr)
 
 	MCFG_MC6845_ADD("crtc", H46505, 14000000 / 16, h46505_intf)
 
@@ -1205,8 +1211,8 @@ ROM_END
 
 static DRIVER_INIT( coinmstr )
 {
-	UINT8 *rom = machine->region("user1")->base();
-	int length = machine->region("user1")->bytes();
+	UINT8 *rom = machine.region("user1")->base();
+	int length = machine.region("user1")->bytes();
 	UINT8 *buf = auto_alloc_array(machine, UINT8, length);
 	int i;
 
