@@ -8,6 +8,8 @@ Magical Spot    - 8013
 Magical Spot II - 8013
 Devil Zone      - 8022
 
+TODO:
+- double check irq sources via schematics
 
 2008-08
 Dip locations verified with manuals for all the games.
@@ -23,22 +25,11 @@ a physical DSW B but only read when SWA:3,4 are both set to OFF. Currently,
 * In devzone, setting SWA:3,4 on anything but OFF,OFF results in no coins
     accepted at all
 
-TODO: Cosmic alien colors in-game are wrong;
-See http://www.andysarcade.net/pix/dumping/cosmic/
-The colors for the text on the "titlescreen" (with the 1979 universal
-copyright), and the status bars are correct in mame, but the sprite colors
-for the aliens when in formation are clearly wrong as compared to andy's pics.
-The shots on andy's page are the correct ones, as the aliens when 'breaking
-formation' in mame change to colors which match the ones in his pictures.
-There is probably a missing bit for color prom banking or for
-forcing all sprites on a row to have an added blue component.
-
 ***************************************************************************/
 
 
 #include "emu.h"
 #include "cpu/tms9900/tms9900.h"
-#include "deprecat.h"
 #include "cpu/z80/z80.h"
 #include "sound/samples.h"
 #include "sound/dac.h"
@@ -49,7 +40,7 @@ forcing all sprites on a row to have an added blue component.
 
 static WRITE8_HANDLER( panic_sound_output_w )
 {
-	cosmic_state *state = (cosmic_state *)space->machine->driver_data;
+	cosmic_state *state = space->machine().driver_data<cosmic_state>();
 
 	/* Sound Enable / Disable */
 	if (offset == 11)
@@ -57,59 +48,59 @@ static WRITE8_HANDLER( panic_sound_output_w )
 		int count;
 		if (data == 0)
 			for (count = 0; count < 9; count++)
-				sample_stop(state->samples, count);
+				sample_stop(state->m_samples, count);
 
-		state->sound_enabled = data;
+		state->m_sound_enabled = data;
 	}
 
-	if (state->sound_enabled)
+	if (state->m_sound_enabled)
 	{
 		switch (offset)
 		{
-		case 0:	if (data) sample_start(state->samples, 0, 0, 0); break; 	/* Walk */
-		case 1:	if (data) sample_start(state->samples, 0, 5, 0); break; 	/* Enemy Die 1 */
+		case 0:	if (data) sample_start(state->m_samples, 0, 0, 0); break;	/* Walk */
+		case 1:	if (data) sample_start(state->m_samples, 0, 5, 0); break;	/* Enemy Die 1 */
 		case 2:	if (data)									/* Drop 1 */
 				{
-					if (!sample_playing(state->samples, 1))
+					if (!sample_playing(state->m_samples, 1))
 					{
-						sample_stop(state->samples, 2);
-						sample_start(state->samples, 1, 3, 0);
+						sample_stop(state->m_samples, 2);
+						sample_start(state->m_samples, 1, 3, 0);
 					}
 				}
 				else
-					sample_stop(state->samples, 1);
+					sample_stop(state->m_samples, 1);
 				break;
 
-		case 3:	if (data && !sample_playing(state->samples, 6))			/* Oxygen */
-					sample_start(state->samples, 6, 9, 1);
+		case 3:	if (data && !sample_playing(state->m_samples, 6))			/* Oxygen */
+					sample_start(state->m_samples, 6, 9, 1);
 				break;
 
 		case 4:	break;										/* Drop 2 */
-		case 5:	if (data) sample_start(state->samples, 0, 5, 0); break;	/* Enemy Die 2 (use same sample as 1) */
-		case 6:	if (data && !sample_playing(state->samples, 1) && !sample_playing(state->samples, 3))   /* Hang */
-					sample_start(state->samples, 2, 2, 0);
+		case 5:	if (data) sample_start(state->m_samples, 0, 5, 0); break;	/* Enemy Die 2 (use same sample as 1) */
+		case 6:	if (data && !sample_playing(state->m_samples, 1) && !sample_playing(state->m_samples, 3))   /* Hang */
+					sample_start(state->m_samples, 2, 2, 0);
 				break;
 
 		case 7:	if (data)									/* Escape */
 				{
-					sample_stop(state->samples, 2);
-					sample_start(state->samples, 3, 4, 0);
+					sample_stop(state->m_samples, 2);
+					sample_start(state->m_samples, 3, 4, 0);
 				}
 				else
-					sample_stop(state->samples, 3);
+					sample_stop(state->m_samples, 3);
 				break;
 
-		case 8:	if (data) sample_start(state->samples, 0, 1, 0); break;	/* Stairs */
+		case 8:	if (data) sample_start(state->m_samples, 0, 1, 0); break;	/* Stairs */
 		case 9:	if (data)									/* Extend */
-					sample_start(state->samples, 4, 8, 0);
+					sample_start(state->m_samples, 4, 8, 0);
 				else
-					sample_stop(state->samples, 4);
+					sample_stop(state->m_samples, 4);
 				break;
 
-		case 10:	dac_data_w(state->dac, data); break;/* Bonus */
-		case 15:	if (data) sample_start(state->samples, 0, 6, 0); break;	/* Player Die */
-		case 16:	if (data) sample_start(state->samples, 5, 7, 0); break;	/* Enemy Laugh */
-		case 17:	if (data) sample_start(state->samples, 0, 10, 0); break;	/* Coin - Not triggered by software */
+		case 10:	dac_data_w(state->m_dac, data); break;/* Bonus */
+		case 15:	if (data) sample_start(state->m_samples, 0, 6, 0); break;	/* Player Die */
+		case 16:	if (data) sample_start(state->m_samples, 5, 7, 0); break;	/* Enemy Laugh */
+		case 17:	if (data) sample_start(state->m_samples, 0, 10, 0); break;	/* Coin - Not triggered by software */
 		}
 	}
 
@@ -125,20 +116,20 @@ static WRITE8_HANDLER( panic_sound_output2_w )
 
 static WRITE8_HANDLER( cosmicg_output_w )
 {
-	cosmic_state *state = (cosmic_state *)space->machine->driver_data;
+	cosmic_state *state = space->machine().driver_data<cosmic_state>();
 
 	/* Sound Enable / Disable */
 	if (offset == 12)
 	{
 		int count;
 
-		state->sound_enabled = data;
+		state->m_sound_enabled = data;
 		if (data == 0)
 			for (count = 0; count < 9; count++)
-				sample_stop(state->samples, count);
+				sample_stop(state->m_samples, count);
 	}
 
-	if (state->sound_enabled)
+	if (state->m_sound_enabled)
 	{
 		switch (offset)
 		{
@@ -146,38 +137,38 @@ static WRITE8_HANDLER( cosmicg_output_w )
 		/* as other cosmic series games, but it never seems to */
 		/* be used for anything. It is implemented for sake of */
 		/* completness. Maybe it plays a tune if you win ?     */
-		case 1:	dac_data_w(state->dac, -data); break;
-		case 2:	if (data) sample_start(state->samples, 0, state->march_select, 0); break;	/* March Sound */
-		case 3:	state->march_select = (state->march_select & 0xfe) | data; break;
-		case 4:	state->march_select = (state->march_select & 0xfd) | (data << 1); break;
-		case 5:	state->march_select = (state->march_select & 0xfb) | (data << 2); break;
+		case 1:	dac_data_w(state->m_dac, -data); break;
+		case 2:	if (data) sample_start(state->m_samples, 0, state->m_march_select, 0); break;	/* March Sound */
+		case 3:	state->m_march_select = (state->m_march_select & 0xfe) | data; break;
+		case 4:	state->m_march_select = (state->m_march_select & 0xfd) | (data << 1); break;
+		case 5:	state->m_march_select = (state->m_march_select & 0xfb) | (data << 2); break;
 
 		case 6:	if (data)							/* Killer Attack (crawly thing at bottom of screen) */
-					sample_start(state->samples, 1, 8, 1);
+					sample_start(state->m_samples, 1, 8, 1);
 				else
-					sample_stop(state->samples, 1);
+					sample_stop(state->m_samples, 1);
 				break;
 
 		case 7:	if (data)								/* Bonus Chance & Got Bonus */
 				{
-					sample_stop(state->samples, 4);
-					sample_start(state->samples, 4, 10, 0);
+					sample_stop(state->m_samples, 4);
+					sample_start(state->m_samples, 4, 10, 0);
 				}
 				break;
 
 		case 8:	if (data)
 				{
-					if (!sample_playing(state->samples, 4)) sample_start(state->samples, 4, 9, 1);
+					if (!sample_playing(state->m_samples, 4)) sample_start(state->m_samples, 4, 9, 1);
 				}
 				else
-					sample_stop(state->samples, 4);
+					sample_stop(state->m_samples, 4);
 				break;
 
-		case 9:	if (data) sample_start(state->samples, 3, 11, 0); break;	/* Got Ship */
+		case 9:	if (data) sample_start(state->m_samples, 3, 11, 0); break;	/* Got Ship */
 //      case 11: watchdog_reset_w(0, 0); break;             /* Watchdog */
-		case 13:	if (data) sample_start(state->samples, 8, 13 - state->gun_die_select, 0); break;  /* Got Monster / Gunshot */
-		case 14:	state->gun_die_select = data; break;
-		case 15:	if (data) sample_start(state->samples, 5, 14, 0); break;	/* Coin Extend (extra base) */
+		case 13:	if (data) sample_start(state->m_samples, 8, 13 - state->m_gun_die_select, 0); break;  /* Got Monster / Gunshot */
+		case 14:	state->m_gun_die_select = data; break;
+		case 15:	if (data) sample_start(state->m_samples, 5, 14, 0); break;	/* Coin Extend (extra base) */
 		}
 	}
 
@@ -189,7 +180,7 @@ static WRITE8_HANDLER( cosmicg_output_w )
 
 static WRITE8_HANDLER( cosmica_sound_output_w )
 {
-	cosmic_state *state = (cosmic_state *)space->machine->driver_data;
+	cosmic_state *state = space->machine().driver_data<cosmic_state>();
 
 	/* Sound Enable / Disable */
 	if (offset == 11)
@@ -197,119 +188,119 @@ static WRITE8_HANDLER( cosmica_sound_output_w )
 		int count;
 		if (data == 0)
 			for (count = 0; count < 12; count++)
-				sample_stop(state->samples, count);
+				sample_stop(state->m_samples, count);
 		else
 		{
-			sample_start(state->samples, 0, 0, 1); /*Background Noise*/
+			sample_start(state->m_samples, 0, 0, 1); /*Background Noise*/
 		}
 
-		state->sound_enabled = data;
+		state->m_sound_enabled = data;
 	}
 
-	if (state->sound_enabled)
+	if (state->m_sound_enabled)
 	{
 		switch (offset)
 		{
-		case 0:	if (data) sample_start(state->samples, 1, 2, 0); break; /*Dive Bombing Type A*/
+		case 0:	if (data) sample_start(state->m_samples, 1, 2, 0); break; /*Dive Bombing Type A*/
 
 		case 2:	/*Dive Bombing Type B (Main Control)*/
 			if (data)
 			{
-				switch (state->dive_bomb_b_select)
+				switch (state->m_dive_bomb_b_select)
 				{
 				case 2:
-					if (sample_playing(state->samples, 2))
+					if (sample_playing(state->m_samples, 2))
 					{
-						sample_stop(state->samples, 2);
-						sample_start(state->samples, 2, 3, 0); break;
+						sample_stop(state->m_samples, 2);
+						sample_start(state->m_samples, 2, 3, 0); break;
 					}
 					else
-						sample_start(state->samples, 2, 3, 0); break;
+						sample_start(state->m_samples, 2, 3, 0); break;
 
 				case 3:
-					if (sample_playing(state->samples, 3))
+					if (sample_playing(state->m_samples, 3))
 					{
-						sample_stop(state->samples, 3);
-						sample_start(state->samples, 3, 4, 0); break;
+						sample_stop(state->m_samples, 3);
+						sample_start(state->m_samples, 3, 4, 0); break;
 					}
 					else
-						sample_start(state->samples, 3, 4, 0); break;
+						sample_start(state->m_samples, 3, 4, 0); break;
 
 				case 4:
-					if (sample_playing(state->samples, 4))
+					if (sample_playing(state->m_samples, 4))
 					{
-						sample_stop(state->samples, 4);
-						sample_start(state->samples, 4, 5, 0); break;
+						sample_stop(state->m_samples, 4);
+						sample_start(state->m_samples, 4, 5, 0); break;
 					}
 					else
-						sample_start(state->samples, 4, 5, 0); break;
+						sample_start(state->m_samples, 4, 5, 0); break;
 
 				case 5:
-					if (sample_playing(state->samples, 5))
+					if (sample_playing(state->m_samples, 5))
 					{
-						sample_stop(state->samples, 5);
-						sample_start(state->samples, 5, 6, 0); break;
+						sample_stop(state->m_samples, 5);
+						sample_start(state->m_samples, 5, 6, 0); break;
 					}
 					else
-						sample_start(state->samples, 5, 6, 0); break;
+						sample_start(state->m_samples, 5, 6, 0); break;
 
 				case 6:
-					if (sample_playing(state->samples, 6))
+					if (sample_playing(state->m_samples, 6))
 					{
-						sample_stop(state->samples, 6);
-						sample_start(state->samples, 6, 7, 0); break;
+						sample_stop(state->m_samples, 6);
+						sample_start(state->m_samples, 6, 7, 0); break;
 					}
 					else
-						sample_start(state->samples, 6, 7, 0); break;
+						sample_start(state->m_samples, 6, 7, 0); break;
 
 				case 7:
-					if (sample_playing(state->samples, 7))
+					if (sample_playing(state->m_samples, 7))
 					{
-						sample_stop(state->samples, 7);
-						sample_start(state->samples, 7, 8, 0); break;
+						sample_stop(state->m_samples, 7);
+						sample_start(state->m_samples, 7, 8, 0); break;
 					}
 					else
-						sample_start(state->samples, 7, 8, 0); break;
+						sample_start(state->m_samples, 7, 8, 0); break;
 				}
 			}
 
 		case 3: /*Dive Bombing Type B (G.S.B)*/
 			if (data)
-				state->dive_bomb_b_select |= 0x04;
+				state->m_dive_bomb_b_select |= 0x04;
 			else
-				state->dive_bomb_b_select &= 0xfb;
+				state->m_dive_bomb_b_select &= 0xfb;
 			break;
 
 
 		case 4: /*Dive Bombing Type B (M.S.B)*/
 			if (data)
-				state->dive_bomb_b_select |= 0x02;
+				state->m_dive_bomb_b_select |= 0x02;
 			else
-				state->dive_bomb_b_select &= 0xfd;
+				state->m_dive_bomb_b_select &= 0xfd;
 			break;
 
 		case 5: /*Dive Bombing Type B (L.S.B)*/
 			if (data)
-				state->dive_bomb_b_select |= 0x01;
+				state->m_dive_bomb_b_select |= 0x01;
 			else
-				state->dive_bomb_b_select &= 0xfe;
+				state->m_dive_bomb_b_select &= 0xfe;
 			break;
 
 
-		case 6:	if (data) sample_start(state->samples, 8, 9, 0); break; /*Fire Control*/
+		case 6:	if (data) sample_start(state->m_samples, 8, 9, 0); break; /*Fire Control*/
 
-		case 7:	if (data) sample_start(state->samples, 9, 10, 0); break; /*Small Explosion*/
+		case 7:	if (data) sample_start(state->m_samples, 9, 10, 0); break; /*Small Explosion*/
 
-		case 8:	if (data) sample_start(state->samples, 10, 11, 0); break; /*Loud Explosion*/
+		case 8:	if (data) sample_start(state->m_samples, 10, 11, 0); break; /*Loud Explosion*/
 
 		case 9:
 			if (data)
-				sample_start(state->samples, 11, 1, 1);
+				sample_start(state->m_samples, 11, 1, 1);
 			else
-				sample_stop(state->samples, 11);
+				sample_stop(state->m_samples, 11);
 			break; /*Extend Sound control*/
 
-		case 12:	if (data) sample_start(state->samples, 11,12, 0); break; /*Insert Coin*/
+		case 12:	if (data) sample_start(state->m_samples, 11,12, 0); break; /*Insert Coin*/
 		}
 	}
 
@@ -319,84 +310,20 @@ static WRITE8_HANDLER( cosmica_sound_output_w )
 }
 
 
-static INTERRUPT_GEN( panic_interrupt )
-{
-	if (cpu_getiloops(device) != 0)
-	{
-		/* Coin insert - Trigger Sample */
-
-		/* mostly not noticed since sound is */
-		/* only enabled if game in progress! */
-
-		if ((input_port_read(device->machine, "SYSTEM") & 0xc0) != 0xc0)
-			panic_sound_output_w(cpu_get_address_space(device, ADDRESS_SPACE_PROGRAM), 17, 1);
-
-		cpu_set_input_line_and_vector(device, 0, HOLD_LINE, 0xcf);	/* RST 08h */
-	}
-	else
-		cpu_set_input_line_and_vector(device, 0, HOLD_LINE, 0xd7);	/* RST 10h */
-}
-
-static INTERRUPT_GEN( cosmica_interrupt )
-{
-	cosmic_state *state = (cosmic_state *)device->machine->driver_data;
-	state->pixel_clock = (state->pixel_clock + 2) & 0x3f;
-
-	if (state->pixel_clock == 0)
-	{
-		if (input_port_read(device->machine, "FAKE") & 1)	/* Left Coin */
-			cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
-	}
-}
-
-static INTERRUPT_GEN( cosmicg_interrupt )
-{
-	/* Insert Coin */
-
-	/* R Nabet : fixed to make this piece of code sensible.
-    I assumed that the interrupt request lasted for as long as the coin was "sensed".
-    It makes sense and works fine, but I cannot be 100% sure this is correct,
-    as I have no Cosmic Guerilla console :-) . */
-
-	if ((input_port_read(device->machine, "IN2") & 1))	/* Coin */
-		/* on tms9980, a 6 on the interrupt bus means level 4 interrupt */
-		cpu_set_input_line_and_vector(device, 0, ASSERT_LINE, 6);
-	else
-		cpu_set_input_line(device, 0, CLEAR_LINE);
-}
-
-static INTERRUPT_GEN( magspot_interrupt )
-{
-	/* Coin 1 causes an IRQ, Coin 2 an NMI */
-	if (input_port_read(device->machine, "COINS") & 0x01)
-		cpu_set_input_line(device, 0, HOLD_LINE);
-	else if (input_port_read(device->machine, "COINS") & 0x02)
-		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
-}
-
-static INTERRUPT_GEN( nomnlnd_interrupt )
-{
-	/* Coin causes an NMI */
-	if (input_port_read(device->machine, "COIN") & 0x01)
-		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
-}
-
-
 static READ8_HANDLER( cosmica_pixel_clock_r )
 {
-	cosmic_state *state = (cosmic_state *)space->machine->driver_data;
-	return state->pixel_clock;
+	return (space->machine().primary_screen->vpos() >> 2) & 0x3f;
 }
 
 static READ8_HANDLER( cosmicg_port_0_r )
 {
 	/* The top four address lines from the CRTC are bits 0-3 */
-	return (input_port_read(space->machine, "IN0") & 0xf0) | ((space->machine->primary_screen->vpos() & 0xf0) >> 4);
+	return (input_port_read(space->machine(), "IN0") & 0xf0) | ((space->machine().primary_screen->vpos() & 0xf0) >> 4);
 }
 
 static READ8_HANDLER( magspot_coinage_dip_r )
 {
-	return (input_port_read_safe(space->machine, "DSW", 0) & (1 << (7 - offset))) ? 0 : 1;
+	return (input_port_read_safe(space->machine(), "DSW", 0) & (1 << (7 - offset))) ? 0 : 1;
 }
 
 
@@ -404,8 +331,8 @@ static READ8_HANDLER( magspot_coinage_dip_r )
 
 static READ8_HANDLER( nomnlnd_port_0_1_r )
 {
-	int control = input_port_read(space->machine, offset ? "IN1" : "IN0");
-	int fire = input_port_read(space->machine, "IN3");
+	int control = input_port_read(space->machine(), offset ? "IN1" : "IN0");
+	int fire = input_port_read(space->machine(), "IN3");
 
 	/* If firing - stop tank */
 	if ((fire & 0xc0) == 0) return 0xff;
@@ -423,14 +350,14 @@ static READ8_HANDLER( nomnlnd_port_0_1_r )
 
 static WRITE8_HANDLER( flip_screen_w )
 {
-	flip_screen_set(space->machine, data & 0x80);
+	flip_screen_set(space->machine(), data & 0x80);
 }
 
 
-static ADDRESS_MAP_START( panic_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( panic_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
-	AM_RANGE(0x4000, 0x5fff) AM_RAM AM_BASE_SIZE_MEMBER(cosmic_state, videoram, videoram_size)
-	AM_RANGE(0x6000, 0x601f) AM_WRITEONLY AM_BASE_SIZE_MEMBER(cosmic_state, spriteram, spriteram_size)
+	AM_RANGE(0x4000, 0x5fff) AM_RAM AM_BASE_SIZE_MEMBER(cosmic_state, m_videoram, m_videoram_size)
+	AM_RANGE(0x6000, 0x601f) AM_WRITEONLY AM_BASE_SIZE_MEMBER(cosmic_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x6800, 0x6800) AM_READ_PORT("P1")
 	AM_RANGE(0x6801, 0x6801) AM_READ_PORT("P2")
 	AM_RANGE(0x6802, 0x6802) AM_READ_PORT("DSW")
@@ -442,10 +369,10 @@ static ADDRESS_MAP_START( panic_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( cosmica_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( cosmica_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
-	AM_RANGE(0x4000, 0x5fff) AM_RAM AM_BASE_SIZE_MEMBER(cosmic_state, videoram, videoram_size)
-	AM_RANGE(0x6000, 0x601f) AM_WRITEONLY AM_BASE_SIZE_MEMBER(cosmic_state, spriteram, spriteram_size)
+	AM_RANGE(0x4000, 0x5fff) AM_RAM AM_BASE_SIZE_MEMBER(cosmic_state, m_videoram, m_videoram_size)
+	AM_RANGE(0x6000, 0x601f) AM_WRITEONLY AM_BASE_SIZE_MEMBER(cosmic_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x6800, 0x6800) AM_READ_PORT("P1")
 	AM_RANGE(0x6801, 0x6801) AM_READ_PORT("P2")
 	AM_RANGE(0x6802, 0x6802) AM_READ_PORT("DSW")
@@ -456,12 +383,12 @@ static ADDRESS_MAP_START( cosmica_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( cosmicg_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( cosmicg_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
-	AM_RANGE(0x2000, 0x3fff) AM_RAM AM_BASE_SIZE_MEMBER(cosmic_state, videoram, videoram_size)
+	AM_RANGE(0x2000, 0x3fff) AM_RAM AM_BASE_SIZE_MEMBER(cosmic_state, m_videoram, m_videoram_size)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( cosmicg_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( cosmicg_io_map, AS_IO, 8 )
 	AM_RANGE(0x00, 0x00) AM_READ(cosmicg_port_0_r)
 	AM_RANGE(0x01, 0x01) AM_READ_PORT("IN1")
 	AM_RANGE(0x00, 0x15) AM_WRITE(cosmicg_output_w)
@@ -469,10 +396,10 @@ static ADDRESS_MAP_START( cosmicg_io_map, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( magspot_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( magspot_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x2fff) AM_ROM
 	AM_RANGE(0x3800, 0x3807) AM_READ(magspot_coinage_dip_r)
-	AM_RANGE(0x4000, 0x401f) AM_WRITEONLY AM_BASE_SIZE_MEMBER(cosmic_state, spriteram, spriteram_size)
+	AM_RANGE(0x4000, 0x401f) AM_WRITEONLY AM_BASE_SIZE_MEMBER(cosmic_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x4800, 0x4800) AM_DEVWRITE("dac", dac_w)
 	AM_RANGE(0x480c, 0x480d) AM_WRITE(cosmic_color_register_w)
 	AM_RANGE(0x480f, 0x480f) AM_WRITE(flip_screen_w)
@@ -480,10 +407,16 @@ static ADDRESS_MAP_START( magspot_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x5001, 0x5001) AM_READ_PORT("IN1")
 	AM_RANGE(0x5002, 0x5002) AM_READ_PORT("IN2")
 	AM_RANGE(0x5003, 0x5003) AM_READ_PORT("IN3")
-	AM_RANGE(0x6000, 0x7fff) AM_RAM AM_BASE_SIZE_MEMBER(cosmic_state, videoram, videoram_size)
+	AM_RANGE(0x6000, 0x7fff) AM_RAM AM_BASE_SIZE_MEMBER(cosmic_state, m_videoram, m_videoram_size)
 ADDRESS_MAP_END
 
 
+
+static INPUT_CHANGED( panic_coin_inserted )
+{
+	panic_sound_output_w(field.machine().device("maincpu")->memory().space(AS_PROGRAM), 17, newval == 0);
+}
+
 static INPUT_PORTS_START( panic )
 	PORT_START("P1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 )
@@ -536,11 +469,15 @@ static INPUT_PORTS_START( panic )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )
-
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_CHANGED(panic_coin_inserted, 0)
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_CHANGED(panic_coin_inserted, 0)
 INPUT_PORTS_END
 
+static INPUT_CHANGED( cosmica_coin_inserted )
+{
+	cputag_set_input_line(field.machine(), "maincpu", INPUT_LINE_NMI, newval ? ASSERT_LINE : CLEAR_LINE);
+}
+
 static INPUT_PORTS_START( cosmica )
 	PORT_START("P1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 )
@@ -582,14 +519,8 @@ static INPUT_PORTS_START( cosmica )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START1 )
 
-	/* The coin slots are not memory mapped.  Coin causes a NMI, */
-	/* This fake input port is used by the interrupt */
-	/* handler to be notified of coin insertions. We use IMPULSE to */
-	/* trigger exactly one interrupt, without having to check when the */
-	/* user releases the key. */
-
 	PORT_START("FAKE")
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(cosmica_coin_inserted, 0)
 INPUT_PORTS_END
 
 /* These are used for the CR handling - This can be used to */
@@ -597,6 +528,11 @@ INPUT_PORTS_END
 
 /* Offsets are in BYTES, so bits 0-7 are at offset 0 etc.   */
 
+static INPUT_CHANGED( cosmicg_coin_inserted )
+{
+	cputag_set_input_line_and_vector(field.machine(), "maincpu", 0, newval ? ASSERT_LINE : CLEAR_LINE, 6);
+}
+
 static INPUT_PORTS_START( cosmicg )
 	PORT_START("IN0")	/* 4-7 */
 	PORT_BIT( 0x0f, IP_ACTIVE_LOW, IPT_SPECIAL )	/* pixel clock */
@@ -623,11 +559,7 @@ static INPUT_PORTS_START( cosmicg )
 	PORT_DIPSETTING(    0x80, "5" )
 
 	PORT_START("IN2")	/* Hard wired settings */
-
-	/* The coin slots are not memory mapped. Coin causes INT 4  */
-	/* This fake input port is used by the interrupt handler    */
-	/* to be notified of coin insertions. */
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(cosmicg_coin_inserted, 0)
 
 	/* This dip switch is not read by the program at any time   */
 	/* but is wired to enable or disable the flip screen output */
@@ -643,6 +575,15 @@ static INPUT_PORTS_START( cosmicg )
 	PORT_DIPUNUSED_DIPLOC( 0x04, 0x00, "SW:6" )
 INPUT_PORTS_END
 
+static INPUT_CHANGED( coin_inserted_irq0 )
+{
+	cputag_set_input_line(field.machine(), "maincpu", 0, newval ? HOLD_LINE : CLEAR_LINE);
+}
+
+static INPUT_CHANGED( coin_inserted_nmi )
+{
+	cputag_set_input_line(field.machine(), "maincpu", INPUT_LINE_NMI, newval ? ASSERT_LINE : CLEAR_LINE);
+}
 
 static INPUT_PORTS_START( magspot )
 	PORT_START("IN0")
@@ -700,8 +641,8 @@ static INPUT_PORTS_START( magspot )
 
 	/* Fake port to handle coins */
 	PORT_START("COINS")
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
-	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin_inserted_irq0, 0) PORT_IMPULSE(1)
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_CHANGED(coin_inserted_nmi, 0)
 
 	/* Fake port to handle coinage dip switches. Each bit goes to 3800-3807 */
 	PORT_START("DSW")
@@ -784,8 +725,8 @@ static INPUT_PORTS_START( devzone )
 
 	/* Fake port to handle coins */
 	PORT_START("COINS")
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
-	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin_inserted_irq0, 0) PORT_IMPULSE(1)
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_CHANGED(coin_inserted_nmi, 0)
 
 	PORT_START("DSW")
 	PORT_DIPNAME( 0x0f, 0x00, DEF_STR( Coin_A ) )
@@ -881,7 +822,7 @@ static INPUT_PORTS_START( nomnlnd )
 
 	/* Fake port to handle coin */
 	PORT_START("COIN")
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin_inserted_nmi, 0)
 INPUT_PORTS_END
 
 
@@ -1022,208 +963,205 @@ static const samples_interface cosmicg_samples_interface =
 
 static MACHINE_START( cosmic )
 {
-	cosmic_state *state = (cosmic_state *)machine->driver_data;
+	cosmic_state *state = machine.driver_data<cosmic_state>();
 
-	state->samples = machine->device("samples");
-	state->dac = machine->device("dac");
+	state->m_samples = machine.device("samples");
+	state->m_dac = machine.device("dac");
 
-	state_save_register_global(machine, state->sound_enabled);
-	state_save_register_global(machine, state->march_select);
-	state_save_register_global(machine, state->gun_die_select);
-	state_save_register_global(machine, state->dive_bomb_b_select);
-	state_save_register_global(machine, state->pixel_clock);
+	state->save_item(NAME(state->m_sound_enabled));
+	state->save_item(NAME(state->m_march_select));
+	state->save_item(NAME(state->m_gun_die_select));
+	state->save_item(NAME(state->m_dive_bomb_b_select));
+	state->save_item(NAME(state->m_pixel_clock));
 
-	state_save_register_global(machine, state->background_enable);
-	state_save_register_global_array(machine, state->color_registers);
+	state->save_item(NAME(state->m_background_enable));
+	state->save_item(NAME(state->m_color_registers));
 }
 
 static MACHINE_RESET( cosmic )
 {
-	cosmic_state *state = (cosmic_state *)machine->driver_data;
+	cosmic_state *state = machine.driver_data<cosmic_state>();
 
-	state->pixel_clock = 0;
-	state->background_enable = 0;
-	state->color_registers[0] = 0;
-	state->color_registers[1] = 0;
-	state->color_registers[2] = 0;
+	state->m_pixel_clock = 0;
+	state->m_background_enable = 0;
+	state->m_color_registers[0] = 0;
+	state->m_color_registers[1] = 0;
+	state->m_color_registers[2] = 0;
 }
 
 
-static MACHINE_DRIVER_START( cosmic )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(cosmic_state)
+static MACHINE_CONFIG_START( cosmic, cosmic_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80,Z80_MASTER_CLOCK/6)	/* 1.8026 MHz*/
+	MCFG_CPU_ADD("maincpu", Z80,Z80_MASTER_CLOCK/6)	/* 1.8026 MHz*/
 
-	MDRV_MACHINE_START(cosmic)
-	MDRV_MACHINE_RESET(cosmic)
+	MCFG_MACHINE_START(cosmic)
+	MCFG_MACHINE_RESET(cosmic)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
-MACHINE_DRIVER_END
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
+MACHINE_CONFIG_END
+
+static TIMER_DEVICE_CALLBACK( panic_scanline )
+{
+	int scanline = param;
+
+	if(scanline == 224) // vblank-out irq
+		cputag_set_input_line_and_vector(timer.machine(), "maincpu", 0, HOLD_LINE,0xd7); /* RST 10h */
+
+	if(scanline == 0) // vblank-in irq
+		cputag_set_input_line_and_vector(timer.machine(), "maincpu", 0, HOLD_LINE,0xcf); /* RST 08h */
+}
 
 
-static MACHINE_DRIVER_START( panic )
+static MACHINE_CONFIG_DERIVED( panic, cosmic )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(cosmic)
-	MDRV_CPU_MODIFY("maincpu")
-
-	MDRV_CPU_PROGRAM_MAP(panic_map)
-	MDRV_CPU_VBLANK_INT_HACK(panic_interrupt,2)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(panic_map)
+	MCFG_TIMER_ADD_SCANLINE("scantimer", panic_scanline, "screen", 0, 1)
 
 	/* video hardware */
-	MDRV_GFXDECODE(panic)
-	MDRV_PALETTE_LENGTH(16+8*4)
+	MCFG_GFXDECODE(panic)
+	MCFG_PALETTE_LENGTH(16+8*4)
 
-	MDRV_PALETTE_INIT(panic)
-	MDRV_VIDEO_UPDATE(panic)
+	MCFG_PALETTE_INIT(panic)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_UPDATE(panic)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(panic_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(panic_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( cosmica )
+static MACHINE_CONFIG_DERIVED( cosmica, cosmic )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(cosmic)
-	MDRV_CPU_MODIFY("maincpu")
-
-	MDRV_CPU_PROGRAM_MAP(cosmica_map)
-	MDRV_CPU_VBLANK_INT_HACK(cosmica_interrupt,32)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(cosmica_map)
 
 	/* video hardware */
-	MDRV_GFXDECODE(cosmica)
-	MDRV_PALETTE_LENGTH(8+16*4)
+	MCFG_GFXDECODE(cosmica)
+	MCFG_PALETTE_LENGTH(8+16*4)
 
-	MDRV_PALETTE_INIT(cosmica)
-	MDRV_VIDEO_UPDATE(cosmica)
+	MCFG_PALETTE_INIT(cosmica)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_UPDATE(cosmica)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(cosmica_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(cosmica_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-MACHINE_DRIVER_END
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( cosmicg )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(cosmic_state)
+static MACHINE_CONFIG_START( cosmicg, cosmic_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", TMS9980, COSMICG_MASTER_CLOCK/8)
+	MCFG_CPU_ADD("maincpu", TMS9980, COSMICG_MASTER_CLOCK/8)
 			/* 9.828 MHz Crystal */
 			/* R Nabet : huh ? This would imply the crystal frequency is somehow divided by 2 before being
             fed to the tms9904 or tms9980.  Also, I have never heard of a tms9900/9980 operating under
             1.5MHz.  So, if someone can check this... */
-	MDRV_CPU_PROGRAM_MAP(cosmicg_map)
-	MDRV_CPU_IO_MAP(cosmicg_io_map)
-	MDRV_CPU_VBLANK_INT("screen", cosmicg_interrupt)
+	MCFG_CPU_PROGRAM_MAP(cosmicg_map)
+	MCFG_CPU_IO_MAP(cosmicg_io_map)
 
-	MDRV_MACHINE_START(cosmic)
-	MDRV_MACHINE_RESET(cosmic)
+	MCFG_MACHINE_START(cosmic)
+	MCFG_MACHINE_RESET(cosmic)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
+	MCFG_SCREEN_UPDATE(cosmicg)
 
-	MDRV_PALETTE_LENGTH(16)
+	MCFG_PALETTE_LENGTH(16)
 
-	MDRV_PALETTE_INIT(cosmicg)
-	MDRV_VIDEO_UPDATE(cosmicg)
+	MCFG_PALETTE_INIT(cosmicg)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("samples", SAMPLES, 0)
-	MDRV_SOUND_CONFIG(cosmicg_samples_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
+	MCFG_SOUND_ADD("samples", SAMPLES, 0)
+	MCFG_SOUND_CONFIG(cosmicg_samples_interface)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( magspot )
+static MACHINE_CONFIG_DERIVED( magspot, cosmic )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(cosmic)
-	MDRV_CPU_MODIFY("maincpu")
-
-	MDRV_CPU_PROGRAM_MAP(magspot_map)
-	MDRV_CPU_VBLANK_INT("screen", magspot_interrupt)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(magspot_map)
 
 	/* video hardware */
-	MDRV_GFXDECODE(panic)
-	MDRV_PALETTE_LENGTH(16+8*4)
+	MCFG_GFXDECODE(panic)
+	MCFG_PALETTE_LENGTH(16+8*4)
 
-	MDRV_PALETTE_INIT(magspot)
-	MDRV_VIDEO_UPDATE(magspot)
+	MCFG_PALETTE_INIT(magspot)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_UPDATE(magspot)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( devzone )
+static MACHINE_CONFIG_DERIVED( devzone, magspot )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(magspot)
 
 	/* video hardware */
-	MDRV_VIDEO_UPDATE(devzone)
-MACHINE_DRIVER_END
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_UPDATE(devzone)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( nomnlnd )
+static MACHINE_CONFIG_DERIVED( nomnlnd, cosmic )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(cosmic)
-	MDRV_CPU_MODIFY("maincpu")
-
-	MDRV_CPU_PROGRAM_MAP(magspot_map)
-	MDRV_CPU_VBLANK_INT("screen", nomnlnd_interrupt)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_PROGRAM_MAP(magspot_map)
 
 	/* video hardware */
-	MDRV_GFXDECODE(panic)
-	MDRV_PALETTE_LENGTH(16+8*4)
+	MCFG_GFXDECODE(panic)
+	MCFG_PALETTE_LENGTH(16+8*4)
 
-	MDRV_PALETTE_INIT(nomnlnd)
-	MDRV_VIDEO_UPDATE(nomnlnd)
+	MCFG_PALETTE_INIT(nomnlnd)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_UPDATE(nomnlnd)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
 
 ROM_START( panic )
@@ -1579,11 +1517,11 @@ ROM_END
 static DRIVER_INIT( cosmicg )
 {
 	/* Program ROMs have data pins connected different from normal */
-	cosmic_state *state = (cosmic_state *)machine->driver_data;
+	cosmic_state *state = machine.driver_data<cosmic_state>();
 	offs_t offs, len;
 	UINT8 *rom;
-	len = memory_region_length(machine, "maincpu");
-	rom = memory_region(machine, "maincpu");
+	len = machine.region("maincpu")->bytes();
+	rom = machine.region("maincpu")->base();
 	for (offs = 0; offs < len; offs++)
 	{
 		UINT8 scrambled = rom[offs];
@@ -1596,46 +1534,46 @@ static DRIVER_INIT( cosmicg )
 		rom[offs] = normal;
 	}
 
-	state->sound_enabled = 0;
-	state->march_select = 0;
-	state->gun_die_select = 0;
+	state->m_sound_enabled = 0;
+	state->m_march_select = 0;
+	state->m_gun_die_select = 0;
 }
 
 
 static DRIVER_INIT( cosmica )
 {
-	cosmic_state *state = (cosmic_state *)machine->driver_data;
-	state->sound_enabled = 1;
-	state->dive_bomb_b_select = 0;
+	cosmic_state *state = machine.driver_data<cosmic_state>();
+	state->m_sound_enabled = 1;
+	state->m_dive_bomb_b_select = 0;
 }
 
 
 static DRIVER_INIT( devzone )
 {
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x4807, 0x4807, 0, 0, cosmic_background_enable_w);
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0x4807, 0x4807, FUNC(cosmic_background_enable_w));
 }
 
 
 static DRIVER_INIT( nomnlnd )
 {
-	running_device *dac = machine->device("dac");
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x5000, 0x5001, 0, 0, nomnlnd_port_0_1_r);
-	memory_nop_write(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x4800, 0x4800, 0, 0);
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x4807, 0x4807, 0, 0, cosmic_background_enable_w);
-	memory_install_write8_device_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), dac, 0x480a, 0x480a, 0, 0, dac_w);
+	device_t *dac = machine.device("dac");
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x5000, 0x5001, FUNC(nomnlnd_port_0_1_r));
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->nop_write(0x4800, 0x4800);
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0x4807, 0x4807, FUNC(cosmic_background_enable_w));
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(*dac, 0x480a, 0x480a, FUNC(dac_w));
 }
 
 static DRIVER_INIT( panic )
 {
-	cosmic_state *state = (cosmic_state *)machine->driver_data;
-	state->sound_enabled = 1;
+	cosmic_state *state = machine.driver_data<cosmic_state>();
+	state->m_sound_enabled = 1;
 }
 
 
 GAME( 1979, cosmicg,  0,       cosmicg,  cosmicg,  cosmicg, ROT270, "Universal", "Cosmic Guerilla", GAME_IMPERFECT_SOUND | GAME_NO_COCKTAIL | GAME_SUPPORTS_SAVE )
-GAME( 1979, cosmica,  0,       cosmica,  cosmica,  cosmica, ROT270, "Universal", "Cosmic Alien (version II)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_COLORS | GAME_SUPPORTS_SAVE )
-GAME( 1979, cosmica1, cosmica, cosmica,  cosmica,  cosmica, ROT270, "Universal", "Cosmic Alien (first version)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_COLORS | GAME_SUPPORTS_SAVE )
-GAME( 1979, cosmica2, cosmica, cosmica,  cosmica,  cosmica, ROT270, "Universal", "Cosmic Alien (early version II?)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_COLORS | GAME_SUPPORTS_SAVE )
+GAME( 1979, cosmica,  0,       cosmica,  cosmica,  cosmica, ROT270, "Universal", "Cosmic Alien (version II)", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
+GAME( 1979, cosmica1, cosmica, cosmica,  cosmica,  cosmica, ROT270, "Universal", "Cosmic Alien (first version)", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
+GAME( 1979, cosmica2, cosmica, cosmica,  cosmica,  cosmica, ROT270, "Universal", "Cosmic Alien (early version II?)", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
 GAME( 1980, nomnlnd,  0,       nomnlnd,  nomnlnd,  nomnlnd, ROT270, "Universal", "No Man's Land", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
 GAME( 1980, nomnlndg, nomnlnd, nomnlnd,  nomnlndg, nomnlnd, ROT270, "Universal (Gottlieb license)", "No Man's Land (Gottlieb)", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
 GAME( 1980, magspot,  0,       magspot,  magspot,  0,       ROT270, "Universal", "Magical Spot", GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
