@@ -47,21 +47,21 @@ Driver Notes:
 class dai3wksi_state : public driver_device
 {
 public:
-	dai3wksi_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	dai3wksi_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* video */
-	UINT8 *     dai3wksi_videoram;
-	size_t      dai3wksi_videoram_size;
-	int         dai3wksi_flipscreen;
-	int         dai3wksi_redscreen;
-	int         dai3wksi_redterop;
+	UINT8 *     m_dai3wksi_videoram;
+	size_t      m_dai3wksi_videoram_size;
+	int         m_dai3wksi_flipscreen;
+	int         m_dai3wksi_redscreen;
+	int         m_dai3wksi_redterop;
 
 	/* sound */
-	UINT8       port_last1;
-	UINT8       port_last2;
-	int         enabled_sound;
-	int         sound3_counter;
+	UINT8       m_port_last1;
+	UINT8       m_port_last2;
+	int         m_enabled_sound;
+	int         m_sound3_counter;
 };
 
 
@@ -123,31 +123,31 @@ static void dai3wksi_get_pens(pen_t *pens)
 }
 
 
-static VIDEO_UPDATE( dai3wksi )
+static SCREEN_UPDATE( dai3wksi )
 {
-	dai3wksi_state *state = screen->machine->driver_data<dai3wksi_state>();
+	dai3wksi_state *state = screen->machine().driver_data<dai3wksi_state>();
 	offs_t offs;
 	pen_t pens[8];
 
 	dai3wksi_get_pens(pens);
 
-	for (offs = 0; offs < state->dai3wksi_videoram_size; offs++)
+	for (offs = 0; offs < state->m_dai3wksi_videoram_size; offs++)
 	{
 		offs_t i;
 
 		UINT8 x = offs << 2;
 		UINT8 y = offs >> 6;
-		UINT8 data = state->dai3wksi_videoram[offs];
+		UINT8 data = state->m_dai3wksi_videoram[offs];
 		UINT8 color;
-		int value = (x >> 2) + ((y >> 5) << 6) + 64 * 8 * (state->dai3wksi_redterop ? 1 : 0);
+		int value = (x >> 2) + ((y >> 5) << 6) + 64 * 8 * (state->m_dai3wksi_redterop ? 1 : 0);
 
-		if (state->dai3wksi_redscreen)
+		if (state->m_dai3wksi_redscreen)
 		{
 			color = 0x02;
 		}
 		else
 		{
-			if (input_port_read(screen->machine, "IN2") & 0x03)
+			if (input_port_read(screen->machine(), "IN2") & 0x03)
 				color = vr_prom2[value];
 			else
 				color = vr_prom1[value];
@@ -157,7 +157,7 @@ static VIDEO_UPDATE( dai3wksi )
 		{
 			pen_t pen = (data & (1 << i)) ? pens[color] : pens[0];
 
-			if (state->dai3wksi_flipscreen)
+			if (state->m_dai3wksi_flipscreen)
 				*BITMAP_ADDR32(bitmap, 255-y, 255-x) = pen;
 			else
 				*BITMAP_ADDR32(bitmap, y, x) = pen;
@@ -196,60 +196,60 @@ static VIDEO_UPDATE( dai3wksi )
 #if (USE_SAMPLES)
 static WRITE8_HANDLER( dai3wksi_audio_1_w )
 {
-	dai3wksi_state *state = space->machine->driver_data<dai3wksi_state>();
-	device_t *samples = space->machine->device("samples");
-	UINT8 rising_bits = data & ~state->port_last1;
+	dai3wksi_state *state = space->machine().driver_data<dai3wksi_state>();
+	device_t *samples = space->machine().device("samples");
+	UINT8 rising_bits = data & ~state->m_port_last1;
 
-	state->enabled_sound = data & 0x80;
+	state->m_enabled_sound = data & 0x80;
 
-	if ((rising_bits & 0x20) && state->enabled_sound)
+	if ((rising_bits & 0x20) && state->m_enabled_sound)
 	{
 		if (data & 0x04)
 			sample_start(samples, CHANNEL_SOUND5, SAMPLE_SOUND5, 0);
 		else
 			sample_start(samples, CHANNEL_SOUND5, SAMPLE_SOUND5, 1);
 	}
-	if (!(data & 0x20) && (state->port_last1 & 0x20))
+	if (!(data & 0x20) && (state->m_port_last1 & 0x20))
 		sample_stop(samples, CHANNEL_SOUND5);
 
-	state->port_last1 = data;
+	state->m_port_last1 = data;
 }
 
 static WRITE8_HANDLER( dai3wksi_audio_2_w )
 {
-	dai3wksi_state *state = space->machine->driver_data<dai3wksi_state>();
-	device_t *samples = space->machine->device("samples");
-	UINT8 rising_bits = data & ~state->port_last2;
+	dai3wksi_state *state = space->machine().driver_data<dai3wksi_state>();
+	device_t *samples = space->machine().device("samples");
+	UINT8 rising_bits = data & ~state->m_port_last2;
 
-	state->dai3wksi_flipscreen = data & 0x10;
-	state->dai3wksi_redscreen  = ~data & 0x20;
-	state->dai3wksi_redterop   = data & 0x40;
+	state->m_dai3wksi_flipscreen = data & 0x10;
+	state->m_dai3wksi_redscreen  = ~data & 0x20;
+	state->m_dai3wksi_redterop   = data & 0x40;
 
-	if (state->enabled_sound)
+	if (state->m_enabled_sound)
 	{
 		if (rising_bits & 0x01) sample_start(samples, CHANNEL_SOUND1, SAMPLE_SOUND1, 0);
 		if (rising_bits & 0x02) sample_start(samples, CHANNEL_SOUND2, SAMPLE_SOUND2, 0);
 		if (rising_bits & 0x08) sample_start(samples, CHANNEL_SOUND4, SAMPLE_SOUND4, 0);
 		if (rising_bits & 0x04)
 		{
-			if (!state->sound3_counter)
+			if (!state->m_sound3_counter)
 				sample_start(samples, CHANNEL_SOUND3, SAMPLE_SOUND3_1, 0);
 			else
 				sample_start(samples, CHANNEL_SOUND3, SAMPLE_SOUND3_2, 0);
 
-			state->sound3_counter ^= 1;
+			state->m_sound3_counter ^= 1;
 		}
 	}
 
-	state->port_last2 = data;
+	state->m_port_last2 = data;
 }
 
 static WRITE8_HANDLER( dai3wksi_audio_3_w )
 {
-	dai3wksi_state *state = space->machine->driver_data<dai3wksi_state>();
-	device_t *samples = space->machine->device("samples");
+	dai3wksi_state *state = space->machine().driver_data<dai3wksi_state>();
+	device_t *samples = space->machine().device("samples");
 
-	if (state->enabled_sound)
+	if (state->m_enabled_sound)
 	{
 		if (data & 0x40)
 			sample_start(samples, CHANNEL_SOUND6, SAMPLE_SOUND6_1, 0);
@@ -284,9 +284,9 @@ static const samples_interface dai3wksi_samples_interface =
 
 static WRITE8_HANDLER( dai3wksi_audio_1_w )
 {
-	device_t *ic79 = space->machine->device("ic79");
+	device_t *ic79 = space->machine().device("ic79");
 
-	sound_global_enable(space->machine, data & 0x80);
+	space->machine().sound().system_enable(data & 0x80);
 
 	sn76477_enable_w(ic79, (~data >> 5) & 0x01);		/* invader movement enable */
 	sn76477_envelope_1_w(ic79, (~data >> 2) & 0x01);	/* invader movement envelope control*/
@@ -295,14 +295,14 @@ static WRITE8_HANDLER( dai3wksi_audio_1_w )
 static WRITE8_HANDLER( dai3wksi_audio_2_w )
 {
 
-	dai3wksi_state *state = space->machine->driver_data<dai3wksi_state>();
-	device_t *ic77 = space->machine->device("ic77");
-	device_t *ic78 = space->machine->device("ic78");
-	device_t *ic80 = space->machine->device("ic80");
+	dai3wksi_state *state = space->machine().driver_data<dai3wksi_state>();
+	device_t *ic77 = space->machine().device("ic77");
+	device_t *ic78 = space->machine().device("ic78");
+	device_t *ic80 = space->machine().device("ic80");
 
-	state->dai3wksi_flipscreen =  data & 0x10;
-	state->dai3wksi_redscreen  = ~data & 0x20;
-	state->dai3wksi_redterop   =  data & 0x40;
+	state->m_dai3wksi_flipscreen =  data & 0x10;
+	state->m_dai3wksi_redscreen  = ~data & 0x20;
+	state->m_dai3wksi_redterop   =  data & 0x40;
 
 	sn76477_enable_w(ic77, (~data >> 0) & 0x01);	/* ship movement */
 	sn76477_enable_w(ic78, (~data >> 1) & 0x01);	/* danger text */
@@ -312,7 +312,7 @@ static WRITE8_HANDLER( dai3wksi_audio_2_w )
 
 static WRITE8_HANDLER( dai3wksi_audio_3_w )
 {
-	device_t *ic81 = space->machine->device("ic81");
+	device_t *ic81 = space->machine().device("ic81");
 
 	sn76477_enable_w(ic81, (~data >> 2) & 0x01);	/* player shoot enable */
 	sn76477_vco_w(ic81, (~data >> 3) & 0x01);		/* player shoot vco control */
@@ -502,7 +502,7 @@ static const sn76477_interface dai3wksi_sn76477_ic81 =
  *
  *************************************/
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1bff) AM_ROM
 	AM_RANGE(0x2000, 0x23ff) AM_RAM
 	AM_RANGE(0x2400, 0x24ff) AM_MIRROR(0x100) AM_READ_PORT("IN0")
@@ -510,7 +510,7 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x3000, 0x3000) AM_WRITE(dai3wksi_audio_1_w)
 	AM_RANGE(0x3400, 0x3400) AM_WRITE(dai3wksi_audio_2_w)
 	AM_RANGE(0x3800, 0x3800) AM_WRITE(dai3wksi_audio_3_w)
-	AM_RANGE(0x8000, 0xbfff) AM_RAM AM_BASE_SIZE_MEMBER(dai3wksi_state, dai3wksi_videoram, dai3wksi_videoram_size)
+	AM_RANGE(0x8000, 0xbfff) AM_RAM AM_BASE_SIZE_MEMBER(dai3wksi_state, m_dai3wksi_videoram, m_dai3wksi_videoram_size)
 ADDRESS_MAP_END
 
 
@@ -564,26 +564,26 @@ INPUT_PORTS_END
 
 static MACHINE_START( dai3wksi )
 {
-	dai3wksi_state *state = machine->driver_data<dai3wksi_state>();
+	dai3wksi_state *state = machine.driver_data<dai3wksi_state>();
 
 	/* Set up save state */
-	state_save_register_global(machine, state->dai3wksi_flipscreen);
-	state_save_register_global(machine, state->dai3wksi_redscreen);
-	state_save_register_global(machine, state->dai3wksi_redterop);
-	state_save_register_global(machine, state->port_last1);
-	state_save_register_global(machine, state->port_last2);
-	state_save_register_global(machine, state->enabled_sound);
-	state_save_register_global(machine, state->sound3_counter);
+	state->save_item(NAME(state->m_dai3wksi_flipscreen));
+	state->save_item(NAME(state->m_dai3wksi_redscreen));
+	state->save_item(NAME(state->m_dai3wksi_redterop));
+	state->save_item(NAME(state->m_port_last1));
+	state->save_item(NAME(state->m_port_last2));
+	state->save_item(NAME(state->m_enabled_sound));
+	state->save_item(NAME(state->m_sound3_counter));
 }
 
 static MACHINE_RESET( dai3wksi )
 {
-	dai3wksi_state *state = machine->driver_data<dai3wksi_state>();
+	dai3wksi_state *state = machine.driver_data<dai3wksi_state>();
 
-	state->port_last1 = 0;
-	state->port_last2 = 0;
-	state->enabled_sound = 0;
-	state->sound3_counter = 0;
+	state->m_port_last1 = 0;
+	state->m_port_last2 = 0;
+	state->m_enabled_sound = 0;
+	state->m_sound3_counter = 0;
 }
 
 
@@ -598,13 +598,12 @@ static MACHINE_CONFIG_START( dai3wksi, dai3wksi_state )
 	MCFG_MACHINE_RESET(dai3wksi)
 
 	/* video hardware */
-	MCFG_VIDEO_UPDATE(dai3wksi)
-
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(4, 251, 8, 247)
 	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_UPDATE(dai3wksi)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
