@@ -51,55 +51,50 @@ Notes:
 */
 
 #include "emu.h"
-#include "deprecat.h"
-
-#include "video/konicdev.h"
 #include "cpu/m68000/m68000.h"
 #include "cpu/z80/z80.h"
 #include "sound/2151intf.h"
 #include "sound/okim6295.h"
 #include "includes/dbz.h"
+#include "video/konicdev.h"
+#include "machine/k053252.h"
 
 
-static INTERRUPT_GEN( dbz_interrupt )
+
+static TIMER_DEVICE_CALLBACK( dbz_scanline )
 {
-	dbz_state *state = (dbz_state *)device->machine->driver_data;
+	dbz_state *state = timer.machine().driver_data<dbz_state>();
+	int scanline = param;
 
-	switch (cpu_getiloops(device))
-	{
-		case 0:
-			cpu_set_input_line(device, M68K_IRQ_2, HOLD_LINE);
-			break;
+	if(scanline == 256) // vblank-out irq
+		cputag_set_input_line(timer.machine(), "maincpu", M68K_IRQ_2, ASSERT_LINE);
 
-		case 1:
-			if (k053246_is_irq_enabled(state->k053246))
-				cpu_set_input_line(device, M68K_IRQ_4, HOLD_LINE);
-			break;
-	}
+	if(scanline == 0 && k053246_is_irq_enabled(state->m_k053246)) // vblank-in irq
+		cputag_set_input_line(timer.machine(), "maincpu", M68K_IRQ_4, HOLD_LINE); //auto-acks apparently
 }
 
 #if 0
 static READ16_HANDLER( dbzcontrol_r )
 {
-	dbz_state *state = (dbz_state *)space->machine->driver_data;
-	return state->control;
+	dbz_state *state = space->machine().driver_data<dbz_state>();
+	return state->m_control;
 }
 #endif
 
 static WRITE16_HANDLER( dbzcontrol_w )
 {
-	dbz_state *state = (dbz_state *)space->machine->driver_data;
+	dbz_state *state = space->machine().driver_data<dbz_state>();
 	/* bit 10 = enable '246 readback */
 
-	COMBINE_DATA(&state->control);
+	COMBINE_DATA(&state->m_control);
 
 	if (data & 0x400)
-		k053246_set_objcha_line(state->k053246, ASSERT_LINE);
+		k053246_set_objcha_line(state->m_k053246, ASSERT_LINE);
 	else
-		k053246_set_objcha_line(state->k053246, CLEAR_LINE);
+		k053246_set_objcha_line(state->m_k053246, CLEAR_LINE);
 
-	coin_counter_w(space->machine, 0, data & 1);
-	coin_counter_w(space->machine, 1, data & 2);
+	coin_counter_w(space->machine(), 0, data & 1);
+	coin_counter_w(space->machine(), 1, data & 2);
 }
 
 static WRITE16_HANDLER( dbz_sound_command_w )
@@ -109,21 +104,18 @@ static WRITE16_HANDLER( dbz_sound_command_w )
 
 static WRITE16_HANDLER( dbz_sound_cause_nmi )
 {
-	dbz_state *state = (dbz_state *)space->machine->driver_data;
-	cpu_set_input_line(state->audiocpu, INPUT_LINE_NMI, PULSE_LINE);
+	dbz_state *state = space->machine().driver_data<dbz_state>();
+	device_set_input_line(state->m_audiocpu, INPUT_LINE_NMI, PULSE_LINE);
 }
 
-static void dbz_sound_irq( running_device *device, int irq )
+static void dbz_sound_irq( device_t *device, int irq )
 {
-	dbz_state *state = (dbz_state *)device->machine->driver_data;
+	dbz_state *state = device->machine().driver_data<dbz_state>();
 
-	if (irq)
-		cpu_set_input_line(state->audiocpu, 0, ASSERT_LINE);
-	else
-		cpu_set_input_line(state->audiocpu, 0, CLEAR_LINE);
+	device_set_input_line(state->m_audiocpu, 0, (irq) ? ASSERT_LINE : CLEAR_LINE);
 }
 
-static ADDRESS_MAP_START( dbz_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( dbz_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x480000, 0x48ffff) AM_RAM
 	AM_RANGE(0x490000, 0x491fff) AM_DEVREADWRITE("k056832", k056832_ram_word_r, k056832_ram_word_w)	// '157 RAM is mirrored twice
@@ -146,11 +138,11 @@ static ADDRESS_MAP_START( dbz_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x4ec000, 0x4ec001) AM_WRITE(dbzcontrol_w)
 	AM_RANGE(0x4f0000, 0x4f0001) AM_WRITE(dbz_sound_command_w)
 	AM_RANGE(0x4f4000, 0x4f4001) AM_WRITE(dbz_sound_cause_nmi)
-	AM_RANGE(0x4f8000, 0x4f801f) AM_WRITENOP		// 251 #1
+	AM_RANGE(0x4f8000, 0x4f801f) AM_DEVREADWRITE8("k053252",k053252_r,k053252_w,0xff00)		// 251 #1
 	AM_RANGE(0x4fc000, 0x4fc01f) AM_DEVWRITE("k053251", k053251_lsb_w)	// 251 #2
 
-	AM_RANGE(0x500000, 0x501fff) AM_RAM_WRITE(dbz_bg2_videoram_w) AM_BASE_MEMBER(dbz_state, bg2_videoram)
-	AM_RANGE(0x508000, 0x509fff) AM_RAM_WRITE(dbz_bg1_videoram_w) AM_BASE_MEMBER(dbz_state, bg1_videoram)
+	AM_RANGE(0x500000, 0x501fff) AM_RAM_WRITE(dbz_bg2_videoram_w) AM_BASE_MEMBER(dbz_state, m_bg2_videoram)
+	AM_RANGE(0x508000, 0x509fff) AM_RAM_WRITE(dbz_bg1_videoram_w) AM_BASE_MEMBER(dbz_state, m_bg1_videoram)
 	AM_RANGE(0x510000, 0x513fff) AM_DEVREADWRITE("k053936_1", k053936_linectrl_r, k053936_linectrl_w) // ?? guess, it might not be
 	AM_RANGE(0x518000, 0x51bfff) AM_DEVREADWRITE("k053936_2", k053936_linectrl_r, k053936_linectrl_w) // ?? guess, it might not be
 	AM_RANGE(0x600000, 0x6fffff) AM_READNOP 			// PSAC 1 ROM readback window
@@ -160,15 +152,15 @@ ADDRESS_MAP_END
 /* dbz sound */
 /* IRQ: from YM2151.  NMI: from 68000.  Port 0: write to ack NMI */
 
-static ADDRESS_MAP_START( dbz_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( dbz_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0xbfff) AM_RAM
 	AM_RANGE(0xc000, 0xc001) AM_DEVREADWRITE("ymsnd", ym2151_r, ym2151_w)
-	AM_RANGE(0xd000, 0xd002) AM_DEVREADWRITE("oki", okim6295_r, okim6295_w)
+	AM_RANGE(0xd000, 0xd002) AM_DEVREADWRITE_MODERN("oki", okim6295_device, read, write)
 	AM_RANGE(0xe000, 0xe001) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( dbz_sound_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( dbz_sound_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_WRITENOP
 ADDRESS_MAP_END
@@ -335,91 +327,104 @@ static const k053936_interface dbz_k053936_intf =
 	1, -46, -16
 };
 
+static WRITE_LINE_DEVICE_HANDLER( dbz_irq2_ack_w )
+{
+	cputag_set_input_line(device->machine(), "maincpu", M68K_IRQ_2, CLEAR_LINE);
+}
+
+
+static const k053252_interface dbz_k053252_intf =
+{
+	"screen",
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_LINE(dbz_irq2_ack_w),
+	DEVCB_NULL,
+	0, 0
+};
 
 static MACHINE_START( dbz )
 {
-	dbz_state *state = (dbz_state *)machine->driver_data;
+	dbz_state *state = machine.driver_data<dbz_state>();
 
-	state->maincpu = machine->device("maincpu");
-	state->audiocpu = machine->device("audiocpu");
-	state->k053936_1 = machine->device("k053936_1");
-	state->k053936_2 = machine->device("k053936_2");
-	state->k056832 = machine->device("k056832");
-	state->k053246 = machine->device("k053246");
-	state->k053251 = machine->device("k053251");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_audiocpu = machine.device("audiocpu");
+	state->m_k053936_1 = machine.device("k053936_1");
+	state->m_k053936_2 = machine.device("k053936_2");
+	state->m_k056832 = machine.device("k056832");
+	state->m_k053246 = machine.device("k053246");
+	state->m_k053251 = machine.device("k053251");
 
-	state_save_register_global(machine, state->control);
-	state_save_register_global(machine, state->sprite_colorbase);
-	state_save_register_global_array(machine, state->layerpri);
-	state_save_register_global_array(machine, state->layer_colorbase);
+	state->save_item(NAME(state->m_control));
+	state->save_item(NAME(state->m_sprite_colorbase));
+	state->save_item(NAME(state->m_layerpri));
+	state->save_item(NAME(state->m_layer_colorbase));
 }
 
 static MACHINE_RESET( dbz )
 {
-	dbz_state *state = (dbz_state *)machine->driver_data;
+	dbz_state *state = machine.driver_data<dbz_state>();
 	int i;
 
 	for (i = 0; i < 5; i++)
-		state->layerpri[i] = 0;
+		state->m_layerpri[i] = 0;
 
 	for (i = 0; i < 6; i++)
-		state->layer_colorbase[i] = 0;
+		state->m_layer_colorbase[i] = 0;
 
-	state->sprite_colorbase = 0;
-	state->control = 0;
+	state->m_sprite_colorbase = 0;
+	state->m_control = 0;
 }
 
-static MACHINE_DRIVER_START( dbz )
-
-	/* driver data */
-	MDRV_DRIVER_DATA(dbz_state)
+static MACHINE_CONFIG_START( dbz, dbz_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", M68000, 16000000)
-	MDRV_CPU_PROGRAM_MAP(dbz_map)
-	MDRV_CPU_VBLANK_INT_HACK(dbz_interrupt,2)
+	MCFG_CPU_ADD("maincpu", M68000, 16000000)
+	MCFG_CPU_PROGRAM_MAP(dbz_map)
+	MCFG_TIMER_ADD_SCANLINE("scantimer", dbz_scanline, "screen", 0, 1)
 
-	MDRV_CPU_ADD("audiocpu", Z80, 4000000)
-	MDRV_CPU_PROGRAM_MAP(dbz_sound_map)
-	MDRV_CPU_IO_MAP(dbz_sound_io_map)
+	MCFG_CPU_ADD("audiocpu", Z80, 4000000)
+	MCFG_CPU_PROGRAM_MAP(dbz_sound_map)
+	MCFG_CPU_IO_MAP(dbz_sound_io_map)
 
-	MDRV_MACHINE_START(dbz)
-	MDRV_MACHINE_RESET(dbz)
+	MCFG_MACHINE_START(dbz)
+	MCFG_MACHINE_RESET(dbz)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
+	MCFG_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(55)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0, 48*8-1, 0, 32*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(55)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(64*8, 40*8)
+	MCFG_SCREEN_VISIBLE_AREA(0, 48*8-1, 0, 32*8-1)
+	MCFG_SCREEN_UPDATE(dbz)
 
-	MDRV_GFXDECODE(dbz)
+	MCFG_GFXDECODE(dbz)
 
-	MDRV_VIDEO_START(dbz)
-	MDRV_VIDEO_UPDATE(dbz)
-	MDRV_PALETTE_LENGTH(0x4000/2)
+	MCFG_VIDEO_START(dbz)
+	MCFG_PALETTE_LENGTH(0x4000/2)
 
-	MDRV_K056832_ADD("k056832", dbz_k056832_intf)
-	MDRV_K053246_ADD("k053246", dbz_k053246_intf)
-	MDRV_K053251_ADD("k053251")
-	MDRV_K053936_ADD("k053936_1", dbz_k053936_intf)
-	MDRV_K053936_ADD("k053936_2", dbz_k053936_intf)
+	MCFG_K056832_ADD("k056832", dbz_k056832_intf)
+	MCFG_K053246_ADD("k053246", dbz_k053246_intf)
+	MCFG_K053251_ADD("k053251")
+	MCFG_K053936_ADD("k053936_1", dbz_k053936_intf)
+	MCFG_K053936_ADD("k053936_2", dbz_k053936_intf)
+	MCFG_K053252_ADD("k053252", 16000000/2, dbz_k053252_intf)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MDRV_SOUND_ADD("ymsnd", YM2151, 4000000)
-	MDRV_SOUND_CONFIG(ym2151_config)
-	MDRV_SOUND_ROUTE(0, "lspeaker", 1.0)
-	MDRV_SOUND_ROUTE(1, "rspeaker", 1.0)
+	MCFG_SOUND_ADD("ymsnd", YM2151, 4000000)
+	MCFG_SOUND_CONFIG(ym2151_config)
+	MCFG_SOUND_ROUTE(0, "lspeaker", 1.0)
+	MCFG_SOUND_ROUTE(1, "rspeaker", 1.0)
 
-	MDRV_OKIM6295_ADD("oki", 1056000, OKIM6295_PIN7_HIGH)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
-MACHINE_DRIVER_END
+	MCFG_OKIM6295_ADD("oki", 1056000, OKIM6295_PIN7_HIGH)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "lspeaker", 1.0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
+MACHINE_CONFIG_END
 
 /**********************************************************************************/
 
@@ -503,7 +508,7 @@ static DRIVER_INIT( dbz )
 {
 	UINT16 *ROM;
 
-	ROM = (UINT16 *)memory_region(machine, "maincpu");
+	ROM = (UINT16 *)machine.region("maincpu")->base();
 
 	// nop out dbz1's mask rom test
 	// tile ROM test
