@@ -47,10 +47,14 @@
 class dlair_state : public driver_device
 {
 public:
-	dlair_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	dlair_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	UINT8 *videoram;
+	UINT8 *m_videoram;
+	device_t *m_laserdisc;
+	UINT8 m_last_misc;
+	UINT8 m_laserdisc_type;
+	UINT8 m_laserdisc_data;
 };
 
 
@@ -76,11 +80,7 @@ public:
  *
  *************************************/
 
-static laserdisc_device *laserdisc;
-static UINT8 last_misc;
 
-static UINT8 laserdisc_type;
-static UINT8 laserdisc_data;
 
 static const UINT8 led_map[16] =
 	{ 0x3f,0x06,0x5b,0x4f,0x66,0x6d,0x7c,0x07,0x7f,0x67,0x77,0x7c,0x39,0x5e,0x79,0x00 };
@@ -95,21 +95,23 @@ static const UINT8 led_map[16] =
 
 static void dleuro_interrupt(device_t *device, int state)
 {
-	cputag_set_input_line(device->machine, "maincpu", 0, state);
+	cputag_set_input_line(device->machine(), "maincpu", 0, state);
 }
 
 
 static WRITE8_DEVICE_HANDLER( serial_transmit )
 {
-	laserdisc_data_w(laserdisc, data);
+	dlair_state *state = device->machine().driver_data<dlair_state>();
+	laserdisc_data_w(state->m_laserdisc, data);
 }
 
 
 static int serial_receive(device_t *device, int channel)
 {
+	dlair_state *state = device->machine().driver_data<dlair_state>();
 	/* if we still have data to send, do it now */
-	if (channel == 0 && laserdisc_line_r(laserdisc, LASERDISC_LINE_DATA_AVAIL) == ASSERT_LINE)
-		return laserdisc_data_r(laserdisc);
+	if (channel == 0 && laserdisc_line_r(state->m_laserdisc, LASERDISC_LINE_DATA_AVAIL) == ASSERT_LINE)
+		return laserdisc_data_r(state->m_laserdisc);
 
 	return -1;
 }
@@ -170,10 +172,10 @@ static PALETTE_INIT( dleuro )
  *
  *************************************/
 
-static VIDEO_UPDATE( dleuro )
+static SCREEN_UPDATE( dleuro )
 {
-	dlair_state *state = screen->machine->driver_data<dlair_state>();
-	UINT8 *videoram = state->videoram;
+	dlair_state *state = screen->machine().driver_data<dlair_state>();
+	UINT8 *videoram = state->m_videoram;
 	int x, y;
 
 	/* redraw the overlay */
@@ -181,7 +183,7 @@ static VIDEO_UPDATE( dleuro )
 		for (x = 0; x < 32; x++)
 		{
 			UINT8 *base = &videoram[y * 64 + x * 2 + 1];
-			drawgfx_opaque(bitmap, cliprect, screen->machine->gfx[0], base[0], base[1], 0, 0, 10 * x, 16 * y);
+			drawgfx_opaque(bitmap, cliprect, screen->machine().gfx[0], base[0], base[1], 0, 0, 10 * x, 16 * y);
 		}
 
 	return 0;
@@ -197,17 +199,19 @@ static VIDEO_UPDATE( dleuro )
 
 static MACHINE_START( dlair )
 {
-	laserdisc = machine->device<laserdisc_device>("laserdisc");
+	dlair_state *state = machine.driver_data<dlair_state>();
+	state->m_laserdisc = machine.device<device_t>("laserdisc");
 }
 
 
 static MACHINE_RESET( dlair )
 {
+	dlair_state *state = machine.driver_data<dlair_state>();
 	/* determine the laserdisc player from the DIP switches */
-	if (laserdisc_type == LASERDISC_TYPE_VARIABLE)
+	if (state->m_laserdisc_type == LASERDISC_TYPE_VARIABLE)
 	{
 		int newtype = (input_port_read(machine, "DSW2") & 0x08) ? LASERDISC_TYPE_PIONEER_LDV1000 : LASERDISC_TYPE_PIONEER_PR7820;
-		laserdisc_set_type(laserdisc, newtype);
+		laserdisc_set_type(state->m_laserdisc, newtype);
 	}
 }
 
@@ -222,10 +226,10 @@ static MACHINE_RESET( dlair )
 static INTERRUPT_GEN( vblank_callback )
 {
 	/* also update the speaker on the European version */
-	beep_device *beep = device->machine->device<beep_device>("beep");
+	beep_device *beep = device->machine().device<beep_device>("beep");
 	if (beep != NULL)
 	{
-		z80ctc_device *ctc = device->machine->device<z80ctc_device>("ctc");
+		z80ctc_device *ctc = device->machine().device<z80ctc_device>("ctc");
 		beep_set_state(beep, 1);
 		beep_set_frequency(beep, ATTOSECONDS_TO_HZ(ctc->period(0).attoseconds));
 	}
@@ -241,6 +245,7 @@ static INTERRUPT_GEN( vblank_callback )
 
 static WRITE8_HANDLER( misc_w )
 {
+	dlair_state *state = space->machine().driver_data<dlair_state>();
 	/*
         D0-D3 = B0-B3
            D4 = coin counter
@@ -248,22 +253,23 @@ static WRITE8_HANDLER( misc_w )
            D6 = ENTER
            D7 = INT/EXT
     */
-	UINT8 diff = data ^ last_misc;
-	last_misc = data;
+	UINT8 diff = data ^ state->m_last_misc;
+	state->m_last_misc = data;
 
-	coin_counter_w(space->machine, 0, (~data >> 4) & 1);
+	coin_counter_w(space->machine(), 0, (~data >> 4) & 1);
 
 	/* on bit 5 going low, push the data out to the laserdisc player */
 	if ((diff & 0x20) && !(data & 0x20))
-		laserdisc_data_w(laserdisc, laserdisc_data);
+		laserdisc_data_w(state->m_laserdisc, state->m_laserdisc_data);
 
 	/* on bit 6 going low, we need to signal enter */
-	laserdisc_line_w(laserdisc, LASERDISC_LINE_ENTER, (data & 0x40) ? CLEAR_LINE : ASSERT_LINE);
+	laserdisc_line_w(state->m_laserdisc, LASERDISC_LINE_ENTER, (data & 0x40) ? CLEAR_LINE : ASSERT_LINE);
 }
 
 
 static WRITE8_HANDLER( dleuro_misc_w )
 {
+	dlair_state *state = space->machine().driver_data<dlair_state>();
 	/*
            D0 = CHAR GEN ON+
            D1 = KILL VIDEO+
@@ -274,18 +280,18 @@ static WRITE8_HANDLER( dleuro_misc_w )
            D6 = ENTER
            D7 = INT/EXT
     */
-	UINT8 diff = data ^ last_misc;
-	last_misc = data;
+	UINT8 diff = data ^ state->m_last_misc;
+	state->m_last_misc = data;
 
-	coin_counter_w(space->machine, 1, (~data >> 3) & 1);
-	coin_counter_w(space->machine, 0, (~data >> 4) & 1);
+	coin_counter_w(space->machine(), 1, (~data >> 3) & 1);
+	coin_counter_w(space->machine(), 0, (~data >> 4) & 1);
 
 	/* on bit 5 going low, push the data out to the laserdisc player */
 	if ((diff & 0x20) && !(data & 0x20))
-		laserdisc_data_w(laserdisc, laserdisc_data);
+		laserdisc_data_w(state->m_laserdisc, state->m_laserdisc_data);
 
 	/* on bit 6 going low, we need to signal enter */
-	laserdisc_line_w(laserdisc, LASERDISC_LINE_ENTER, (data & 0x40) ? CLEAR_LINE : ASSERT_LINE);
+	laserdisc_line_w(state->m_laserdisc, LASERDISC_LINE_ENTER, (data & 0x40) ? CLEAR_LINE : ASSERT_LINE);
 }
 
 
@@ -310,13 +316,14 @@ static WRITE8_HANDLER( led_den2_w )
 
 static CUSTOM_INPUT( laserdisc_status_r )
 {
-	switch (laserdisc_get_type(laserdisc))
+	dlair_state *state = field.machine().driver_data<dlair_state>();
+	switch (laserdisc_get_type(state->m_laserdisc))
 	{
 		case LASERDISC_TYPE_PIONEER_PR7820:
 			return 0;
 
 		case LASERDISC_TYPE_PIONEER_LDV1000:
-			return (laserdisc_line_r(laserdisc, LASERDISC_LINE_STATUS) == ASSERT_LINE) ? 0 : 1;
+			return (laserdisc_line_r(state->m_laserdisc, LASERDISC_LINE_STATUS) == ASSERT_LINE) ? 0 : 1;
 
 		case LASERDISC_TYPE_PHILLIPS_22VP932:
 			return 0;
@@ -327,13 +334,14 @@ static CUSTOM_INPUT( laserdisc_status_r )
 
 static CUSTOM_INPUT( laserdisc_command_r )
 {
-	switch (laserdisc_get_type(laserdisc))
+	dlair_state *state = field.machine().driver_data<dlair_state>();
+	switch (laserdisc_get_type(state->m_laserdisc))
 	{
 		case LASERDISC_TYPE_PIONEER_PR7820:
-			return (laserdisc_line_r(laserdisc, LASERDISC_LINE_READY) == ASSERT_LINE) ? 0 : 1;
+			return (laserdisc_line_r(state->m_laserdisc, LASERDISC_LINE_READY) == ASSERT_LINE) ? 0 : 1;
 
 		case LASERDISC_TYPE_PIONEER_LDV1000:
-			return (laserdisc_line_r(laserdisc, LASERDISC_LINE_COMMAND) == ASSERT_LINE) ? 0 : 1;
+			return (laserdisc_line_r(state->m_laserdisc, LASERDISC_LINE_COMMAND) == ASSERT_LINE) ? 0 : 1;
 
 		case LASERDISC_TYPE_PHILLIPS_22VP932:
 			return 0;
@@ -344,7 +352,8 @@ static CUSTOM_INPUT( laserdisc_command_r )
 
 static READ8_HANDLER( laserdisc_r )
 {
-	UINT8 result = laserdisc_data_r(laserdisc);
+	dlair_state *state = space->machine().driver_data<dlair_state>();
+	UINT8 result = laserdisc_data_r(state->m_laserdisc);
 	mame_printf_debug("laserdisc_r = %02X\n", result);
 	return result;
 }
@@ -352,7 +361,8 @@ static READ8_HANDLER( laserdisc_r )
 
 static WRITE8_HANDLER( laserdisc_w )
 {
-	laserdisc_data = data;
+	dlair_state *state = space->machine().driver_data<dlair_state>();
+	state->m_laserdisc_data = data;
 }
 
 
@@ -364,7 +374,7 @@ static WRITE8_HANDLER( laserdisc_w )
  *************************************/
 
 /* complete memory map derived from schematics */
-static ADDRESS_MAP_START( dlus_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( dlus_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x9fff) AM_ROM
 	AM_RANGE(0xa000, 0xa7ff) AM_MIRROR(0x1800) AM_RAM
 	AM_RANGE(0xc000, 0xc000) AM_MIRROR(0x1fc7) AM_DEVREAD("aysnd", ay8910_r)
@@ -388,10 +398,10 @@ ADDRESS_MAP_END
  *************************************/
 
 /* complete memory map derived from schematics */
-static ADDRESS_MAP_START( dleuro_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( dleuro_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x9fff) AM_ROM
 	AM_RANGE(0xa000, 0xa7ff) AM_MIRROR(0x1800) AM_RAM
-	AM_RANGE(0xc000, 0xc7ff) AM_MIRROR(0x1800) AM_RAM AM_BASE_MEMBER(dlair_state, videoram)
+	AM_RANGE(0xc000, 0xc7ff) AM_MIRROR(0x1800) AM_RAM AM_BASE_MEMBER(dlair_state, m_videoram)
 	AM_RANGE(0xe000, 0xe000) AM_MIRROR(0x1f47) // WT LED 1
 	AM_RANGE(0xe008, 0xe008) AM_MIRROR(0x1f47) // WT LED 2
 	AM_RANGE(0xe010, 0xe010) AM_MIRROR(0x1f47) AM_WRITE(led_den1_w)			// WT EXT LED 1
@@ -408,7 +418,7 @@ ADDRESS_MAP_END
 
 
 /* complete memory map derived from schematics */
-static ADDRESS_MAP_START( dleuro_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( dleuro_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x03) AM_MIRROR(0x7c) AM_DEVREADWRITE("ctc", z80ctc_r, z80ctc_w)
 	AM_RANGE(0x80, 0x83) AM_MIRROR(0x7c) AM_DEVREADWRITE("sio", z80sio_ba_cd_r, z80sio_ba_cd_w)
@@ -731,7 +741,7 @@ static MACHINE_CONFIG_START( dleuro, dlair_state )
 	MCFG_Z80CTC_ADD("ctc", MASTER_CLOCK_EURO/4 /* same as "maincpu" */, ctc_intf)
 	MCFG_Z80SIO_ADD("sio", MASTER_CLOCK_EURO/4 /* same as "maincpu" */, sio_intf)
 
-	MCFG_WATCHDOG_TIME_INIT(HZ(MASTER_CLOCK_EURO/(16*16*16*16*16*8)))
+	MCFG_WATCHDOG_TIME_INIT(attotime::from_hz(MASTER_CLOCK_EURO/(16*16*16*16*16*8)))
 
 	MCFG_MACHINE_START(dlair)
 	MCFG_MACHINE_RESET(dlair)
@@ -939,13 +949,15 @@ ROM_END
 
 static DRIVER_INIT( fixed )
 {
-	laserdisc_type = LASERDISC_TYPE_FIXED;
+	dlair_state *state = machine.driver_data<dlair_state>();
+	state->m_laserdisc_type = LASERDISC_TYPE_FIXED;
 }
 
 
 static DRIVER_INIT( variable )
 {
-	laserdisc_type = LASERDISC_TYPE_VARIABLE;
+	dlair_state *state = machine.driver_data<dlair_state>();
+	state->m_laserdisc_type = LASERDISC_TYPE_VARIABLE;
 }
 
 
