@@ -10,7 +10,6 @@ Todo:
 
 #include "emu.h"
 #include "cpu/z80/z80.h"
-#include "deprecat.h"
 
 
 #define NUM_PENS	(8)
@@ -19,18 +18,18 @@ Todo:
 class dorachan_state : public driver_device
 {
 public:
-	dorachan_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	dorachan_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *  videoram;
-	size_t   videoram_size;
+	UINT8 *  m_videoram;
+	size_t   m_videoram_size;
 
 	/* video-related */
-	UINT8    flip_screen;
+	UINT8    m_flip_screen;
 
 	/* devices */
-	device_t *main_cpu;
+	device_t *m_main_cpu;
 };
 
 
@@ -42,17 +41,17 @@ public:
 
 static CUSTOM_INPUT( dorachan_protection_r )
 {
-	dorachan_state *state = field->port->machine->driver_data<dorachan_state>();
+	dorachan_state *state = field.machine().driver_data<dorachan_state>();
 	UINT8 ret = 0;
 
-	switch (cpu_get_previouspc(state->main_cpu))
+	switch (cpu_get_previouspc(state->m_main_cpu))
 	{
 	case 0x70ce: ret = 0xf2; break;
 	case 0x72a2: ret = 0xd5; break;
 	case 0x72b5: ret = 0xcb; break;
 
 	default:
-		mame_printf_debug("unhandled $2400 read @ %x\n", cpu_get_previouspc(state->main_cpu));
+		mame_printf_debug("unhandled $2400 read @ %x\n", cpu_get_previouspc(state->m_main_cpu));
 		break;
 	}
 
@@ -78,18 +77,18 @@ static void get_pens(pen_t *pens)
 }
 
 
-static VIDEO_UPDATE( dorachan )
+static SCREEN_UPDATE( dorachan )
 {
-	dorachan_state *state = screen->machine->driver_data<dorachan_state>();
+	dorachan_state *state = screen->machine().driver_data<dorachan_state>();
 	pen_t pens[NUM_PENS];
 	offs_t offs;
 	const UINT8 *color_map_base;
 
 	get_pens(pens);
 
-	color_map_base = screen->machine->region("proms")->base();
+	color_map_base = screen->machine().region("proms")->base();
 
-	for (offs = 0; offs < state->videoram_size; offs++)
+	for (offs = 0; offs < state->m_videoram_size; offs++)
 	{
 		int i;
 		UINT8 fore_color;
@@ -100,9 +99,9 @@ static VIDEO_UPDATE( dorachan )
 		/* the need for +1 is extremely unusual, but definetely correct */
 		offs_t color_address = ((((offs << 2) & 0x03e0) | (offs >> 8)) + 1) & 0x03ff;
 
-		UINT8 data = state->videoram[offs];
+		UINT8 data = state->m_videoram[offs];
 
-		if (state->flip_screen)
+		if (state->m_flip_screen)
 			fore_color = (color_map_base[color_address] >> 3) & 0x07;
 		else
 			fore_color = (color_map_base[color_address] >> 0) & 0x07;
@@ -123,17 +122,17 @@ static VIDEO_UPDATE( dorachan )
 
 static WRITE8_HANDLER(dorachan_ctrl_w)
 {
-	dorachan_state *state = space->machine->driver_data<dorachan_state>();
-	state->flip_screen = (data >> 6) & 0x01;
+	dorachan_state *state = space->machine().driver_data<dorachan_state>();
+	state->m_flip_screen = (data >> 6) & 0x01;
 }
 
 
 static CUSTOM_INPUT( dorachan_v128_r )
 {
-	dorachan_state *state = field->port->machine->driver_data<dorachan_state>();
+	dorachan_state *state = field.machine().driver_data<dorachan_state>();
 
 	/* to avoid resetting (when player 2 starts) bit 0 need to be inverted when screen is flipped */
-	return ((field->port->machine->primary_screen->vpos() >> 7) & 0x01) ^ state->flip_screen;
+	return ((field.machine().primary_screen->vpos() >> 7) & 0x01) ^ state->m_flip_screen;
 }
 
 
@@ -144,7 +143,7 @@ static CUSTOM_INPUT( dorachan_v128_r )
  *
  *************************************/
 
-static ADDRESS_MAP_START( dorachan_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( dorachan_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x17ff) AM_ROM
 	AM_RANGE(0x1800, 0x1fff) AM_RAM
 	AM_RANGE(0x2000, 0x23ff) AM_ROM
@@ -152,7 +151,7 @@ static ADDRESS_MAP_START( dorachan_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x2800, 0x2800) AM_MIRROR(0x03ff) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x2c00, 0x2c00) AM_MIRROR(0x03ff) AM_READ_PORT("JOY")
 	AM_RANGE(0x3800, 0x3800) AM_MIRROR(0x03ff) AM_READ_PORT("V128")
-	AM_RANGE(0x4000, 0x5fff) AM_RAM AM_BASE_SIZE_MEMBER(dorachan_state, videoram, videoram_size)
+	AM_RANGE(0x4000, 0x5fff) AM_RAM AM_BASE_SIZE_MEMBER(dorachan_state, m_videoram, m_videoram_size)
 	AM_RANGE(0x6000, 0x77ff) AM_ROM
 ADDRESS_MAP_END
 
@@ -164,7 +163,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( dorachan_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( dorachan_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x01, 0x01) AM_WRITENOP
 	AM_RANGE(0x02, 0x02) AM_WRITENOP
@@ -224,18 +223,18 @@ INPUT_PORTS_END
 
 static MACHINE_START( dorachan )
 {
-	dorachan_state *state = machine->driver_data<dorachan_state>();
+	dorachan_state *state = machine.driver_data<dorachan_state>();
 
-	state->main_cpu = machine->device("maincpu");
+	state->m_main_cpu = machine.device("maincpu");
 
-	state_save_register_global(machine, state->flip_screen);
+	state->save_item(NAME(state->m_flip_screen));
 }
 
 static MACHINE_RESET( dorachan )
 {
-	dorachan_state *state = machine->driver_data<dorachan_state>();
+	dorachan_state *state = machine.driver_data<dorachan_state>();
 
-	state->flip_screen = 0;
+	state->m_flip_screen = 0;
 }
 
 static MACHINE_CONFIG_START( dorachan, dorachan_state )
@@ -244,19 +243,18 @@ static MACHINE_CONFIG_START( dorachan, dorachan_state )
 	MCFG_CPU_ADD("maincpu", Z80, 2000000)
 	MCFG_CPU_PROGRAM_MAP(dorachan_map)
 	MCFG_CPU_IO_MAP(dorachan_io_map)
-	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,2)
+	MCFG_CPU_PERIODIC_INT(irq0_line_hold,2*60)
 
 	MCFG_MACHINE_START(dorachan)
 	MCFG_MACHINE_RESET(dorachan)
 
 	/* video hardware */
-	MCFG_VIDEO_UPDATE(dorachan)
-
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 1*8, 31*8-1)
 	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_UPDATE(dorachan)
 
 MACHINE_CONFIG_END
 
