@@ -281,32 +281,32 @@ uPC1352C @ N3
 class dwarfd_state : public driver_device
 {
 public:
-	dwarfd_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
-
-	/* memory pointers */
-	UINT8 *  dw_ram;
-	UINT8 *  videobuf;
+	dwarfd_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* video-related */
-	int bank;
-	int line;
-	int idx;
-	int crt_access;
+	int m_bank;
+	int m_line;
+	int m_idx;
+	int m_crt_access;
 
 	/* i8275 */
-	int i8275Command;
-	int i8275HorizontalCharactersRow;
-	int i8275CommandSeqCnt;
-	int i8275SpacedRows;
-	int i8275VerticalRows;
-	int i8275VerticalRetraceRows;
-	int i8275Underline;
-	int i8275Lines;
-	int i8275LineCounterMode;
-	int i8275FieldAttributeMode;
-	int i8275CursorFormat;
-	int i8275HorizontalRetrace;
+	int m_i8275Command;
+	int m_i8275HorizontalCharactersRow;
+	int m_i8275CommandSeqCnt;
+	int m_i8275SpacedRows;
+	int m_i8275VerticalRows;
+	int m_i8275VerticalRetraceRows;
+	int m_i8275Underline;
+	int m_i8275Lines;
+	int m_i8275LineCounterMode;
+	int m_i8275FieldAttributeMode;
+	int m_i8275CursorFormat;
+	int m_i8275HorizontalRetrace;
+
+	/* memory */
+	UINT8    m_dw_ram[0x1000];
+	UINT8    m_videobuf[0x8000];
 };
 
 
@@ -349,29 +349,29 @@ enum
 
 static WRITE8_HANDLER (i8275_preg_w) //param reg
 {
-	dwarfd_state *state = space->machine->driver_data<dwarfd_state>();
+	dwarfd_state *state = space->machine().driver_data<dwarfd_state>();
 
-	switch (state->i8275Command)
+	switch (state->m_i8275Command)
 	{
 		case I8275_COMMAND_RESET:
 		{
-			switch (state->i8275CommandSeqCnt)
+			switch (state->m_i8275CommandSeqCnt)
 			{
 				case 4:
 				{
 					//screen byte comp byte 1
-					state->i8275SpacedRows = data >> 7;
-					state->i8275HorizontalCharactersRow = (data & 0x7f) + 1;
-					if (state->i8275HorizontalCharactersRow > 80)
+					state->m_i8275SpacedRows = data >> 7;
+					state->m_i8275HorizontalCharactersRow = (data & 0x7f) + 1;
+					if (state->m_i8275HorizontalCharactersRow > 80)
 					{
-						logerror("i8275 Undefined num of characters/Row! = %d\n", state->i8275HorizontalCharactersRow);
-						state->i8275HorizontalCharactersRow = CHARACTERS_UNDEFINED;
+						logerror("i8275 Undefined num of characters/Row! = %d\n", state->m_i8275HorizontalCharactersRow);
+						state->m_i8275HorizontalCharactersRow = CHARACTERS_UNDEFINED;
 					}
 					else
 					{
-						logerror("i8275 %d characters/row\n", state->i8275HorizontalCharactersRow);
+						logerror("i8275 %d characters/row\n", state->m_i8275HorizontalCharactersRow);
 					}
-					if (state->i8275SpacedRows & 1)
+					if (state->m_i8275SpacedRows & 1)
 					{
 						logerror("i8275 spaced rows\n");
 					}
@@ -379,44 +379,44 @@ static WRITE8_HANDLER (i8275_preg_w) //param reg
 					{
 						logerror("i8275 normal rows\n");
 					}
-					state->i8275CommandSeqCnt--;
+					state->m_i8275CommandSeqCnt--;
 				}
 				break;
 
 				case 3:
 				{
 					//screen byte comp byte 2
-					state->i8275VerticalRows = (data & 0x3f) + 1;
-					state->i8275VerticalRetraceRows = (data >> 6) + 1;
+					state->m_i8275VerticalRows = (data & 0x3f) + 1;
+					state->m_i8275VerticalRetraceRows = (data >> 6) + 1;
 
-					logerror("i8275 %d rows\n", state->i8275VerticalRows);
-					logerror("i8275 %d vertical retrace rows\n", state->i8275VerticalRetraceRows);
+					logerror("i8275 %d rows\n", state->m_i8275VerticalRows);
+					logerror("i8275 %d vertical retrace rows\n", state->m_i8275VerticalRetraceRows);
 
-					state->i8275CommandSeqCnt--;
+					state->m_i8275CommandSeqCnt--;
 				}
 				break;
 
 				case 2:
 				{
 					//screen byte comp byte 3
-					state->i8275Underline = (data >> 4) + 1;
-					state->i8275Lines = (data & 0xf) + 1;
-					logerror("i8275 underline placement: %d\n", state->i8275Underline);
-					logerror("i8275 %d lines/row\n", state->i8275Lines);
+					state->m_i8275Underline = (data >> 4) + 1;
+					state->m_i8275Lines = (data & 0xf) + 1;
+					logerror("i8275 underline placement: %d\n", state->m_i8275Underline);
+					logerror("i8275 %d lines/row\n", state->m_i8275Lines);
 
-					state->i8275CommandSeqCnt--;
+					state->m_i8275CommandSeqCnt--;
 				}
 				break;
 
 				case 1:
 				{
 					//screen byte comp byte 4
-					state->i8275LineCounterMode = data >> 7;
-					state->i8275FieldAttributeMode = (data >> 6) & 1;
-					state->i8275CursorFormat = (data >> 4) & 3;
-					state->i8275HorizontalRetrace = ((data & 0xf) + 1) << 1;
-					logerror("i8275 line counter mode: %d\n", state->i8275LineCounterMode);
-					if (state->i8275FieldAttributeMode)
+					state->m_i8275LineCounterMode = data >> 7;
+					state->m_i8275FieldAttributeMode = (data >> 6) & 1;
+					state->m_i8275CursorFormat = (data >> 4) & 3;
+					state->m_i8275HorizontalRetrace = ((data & 0xf) + 1) << 1;
+					logerror("i8275 line counter mode: %d\n", state->m_i8275LineCounterMode);
+					if (state->m_i8275FieldAttributeMode)
 					{
 						logerror("i8275 field attribute mode non-transparent\n");
 					}
@@ -425,7 +425,7 @@ static WRITE8_HANDLER (i8275_preg_w) //param reg
 						logerror("i8275 field attribute mode transparent\n");
 					}
 
-					switch (state->i8275CursorFormat)
+					switch (state->m_i8275CursorFormat)
 					{
 						case 0:	{logerror("i8275 cursor format - blinking reverse video block\n");}	break;
 						case 1:	{logerror("i8275 cursor format - blinking underline\n");}break;
@@ -433,8 +433,8 @@ static WRITE8_HANDLER (i8275_preg_w) //param reg
 						case 3:	{logerror("i8275 cursor format - nonblinking underline\n");}break;
 					}
 
-					logerror("i8275 %d chars for horizontal retrace\n",state->i8275HorizontalRetrace );
-					state->i8275CommandSeqCnt--;
+					logerror("i8275 %d chars for horizontal retrace\n",state->m_i8275HorizontalRetrace );
+					state->m_i8275CommandSeqCnt--;
 				}
 				break;
 
@@ -470,38 +470,38 @@ static READ8_HANDLER (i8275_preg_r) //param reg
 
 static WRITE8_HANDLER (i8275_creg_w) //comand reg
 {
-	dwarfd_state *state = space->machine->driver_data<dwarfd_state>();
+	dwarfd_state *state = space->machine().driver_data<dwarfd_state>();
 
 	switch (data>>5)
 	{
 		case 0:
 		{
 			/* reset */
-			state->i8275Command = I8275_COMMAND_RESET;
-			state->i8275CommandSeqCnt = I8275_COMMAND_RESET_LENGTH;
+			state->m_i8275Command = I8275_COMMAND_RESET;
+			state->m_i8275CommandSeqCnt = I8275_COMMAND_RESET_LENGTH;
 		}
 		break;
 
 		case 5:
 		{
 			/* enable interrupt */
-			state->i8275Command = I8275_COMMAND_EI;
-			state->i8275CommandSeqCnt = I8275_COMMAND_EI_LENGTH;
+			state->m_i8275Command = I8275_COMMAND_EI;
+			state->m_i8275CommandSeqCnt = I8275_COMMAND_EI_LENGTH;
 		}
 		break;
 
 		case 6:
 		{
 			/* disable interrupt */
-			state->i8275Command = I8275_COMMAND_DI;
-			state->i8275CommandSeqCnt = I8275_COMMAND_DI_LENGTH;
+			state->m_i8275Command = I8275_COMMAND_DI;
+			state->m_i8275CommandSeqCnt = I8275_COMMAND_DI_LENGTH;
 		}
 		break;
 
 		case 7:
 		{
 			/* preset counters */
-			state->i8275CommandSeqCnt = I8275_COMMAND_PRESET_LENGTH;
+			state->m_i8275CommandSeqCnt = I8275_COMMAND_PRESET_LENGTH;
 
 		}
 		break;
@@ -515,24 +515,24 @@ static READ8_HANDLER (i8275_sreg_r) //status
 
 static READ8_HANDLER(dwarfd_ram_r)
 {
-	dwarfd_state *state = space->machine->driver_data<dwarfd_state>();
+	dwarfd_state *state = space->machine().driver_data<dwarfd_state>();
 
-	if (state->crt_access == 0)
+	if (state->m_crt_access == 0)
 	{
-		return state->dw_ram[offset];
+		return state->m_dw_ram[offset];
 	}
 	else
 	{
-		state->videobuf[state->line * 256 + state->idx] = state->dw_ram[offset];
-		state->idx++;
-		return state->dw_ram[offset];
+		state->m_videobuf[state->m_line * 256 + state->m_idx] = state->m_dw_ram[offset];
+		state->m_idx++;
+		return state->m_dw_ram[offset];
 	}
 }
 
 static WRITE8_HANDLER(dwarfd_ram_w)
 {
-	dwarfd_state *state = space->machine->driver_data<dwarfd_state>();
-	state->dw_ram[offset] = data;
+	dwarfd_state *state = space->machine().driver_data<dwarfd_state>();
+	state->m_dw_ram[offset] = data;
 }
 
 static WRITE8_HANDLER(output1_w)
@@ -568,15 +568,15 @@ static WRITE8_HANDLER(output2_w)
 
 static READ8_HANDLER(qc_b8_r)
 {
-	return space->machine->rand();
+	return space->machine().rand();
 }
 
-static ADDRESS_MAP_START( mem_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( mem_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x4fff) AM_READWRITE(dwarfd_ram_r, dwarfd_ram_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x01, 0x01) AM_DEVREAD("aysnd", ay8910_r)
 	AM_RANGE(0x02, 0x03) AM_DEVWRITE("aysnd", ay8910_data_address_w)
@@ -590,12 +590,12 @@ static ADDRESS_MAP_START( io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0xc1, 0xc1) AM_READ_PORT("DSW2")
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( qc_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( qc_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0x8fff) AM_READWRITE(dwarfd_ram_r, dwarfd_ram_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( qc_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( qc_io_map, AS_IO, 8 )
 	AM_IMPORT_FROM( io_map )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0xb8, 0xb8) AM_READ(qc_b8_r)
@@ -680,9 +680,9 @@ static VIDEO_START(dwarfd)
 {
 }
 
-static void drawCrt( running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect )
+static void drawCrt( running_machine &machine, bitmap_t *bitmap,const rectangle *cliprect )
 {
-	dwarfd_state *state = machine->driver_data<dwarfd_state>();
+	dwarfd_state *state = machine.driver_data<dwarfd_state>();
 	int x, y;
 	for (y = 0; y < maxy; y++)
 	{
@@ -701,7 +701,7 @@ static void drawCrt( running_machine *machine, bitmap_t *bitmap,const rectangle
 			while (b == 0)
 			{
 				if (count < 0x8000)
-					tile = state->videobuf[count++];
+					tile = state->m_videobuf[count++];
 				else
 						return;
 
@@ -720,19 +720,19 @@ static void drawCrt( running_machine *machine, bitmap_t *bitmap,const rectangle
 					}
 					if ((tile & 0xc0) == 0x80)
 					{
-						state->bank = (tile >> 2) & 3;
+						state->m_bank = (tile >> 2) & 3;
 					}
 					if ((tile & 0xc0) == 0xc0)
 					{
 						b = 1;
-						tile = machine->rand() & 0x7f;//(tile >> 2) & 0xf;
+						tile = machine.rand() & 0x7f;//(tile >> 2) & 0xf;
 					}
 				}
 				else
 					b = 1;
 			}
-			drawgfx_transpen(bitmap, cliprect, machine->gfx[0],
-				tile + (state->bank + bank2) * 128,
+			drawgfx_transpen(bitmap, cliprect, machine.gfx[0],
+				tile + (state->m_bank + bank2) * 128,
 				0,
 				0, 0,
 				x*8,y*8,0);
@@ -741,17 +741,17 @@ static void drawCrt( running_machine *machine, bitmap_t *bitmap,const rectangle
 }
 
 
-static VIDEO_UPDATE( dwarfd )
+static SCREEN_UPDATE( dwarfd )
 {
-	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
-	drawCrt(screen->machine, bitmap, cliprect);
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine()));
+	drawCrt(screen->machine(), bitmap, cliprect);
 	return 0;
 }
 
 static WRITE_LINE_DEVICE_HANDLER( dwarfd_sod_callback )
 {
-	dwarfd_state *driver_state = device->machine->driver_data<dwarfd_state>();
-	driver_state->crt_access = state;
+	dwarfd_state *driver_state = device->machine().driver_data<dwarfd_state>();
+	driver_state->m_crt_access = state;
 }
 
 
@@ -767,19 +767,19 @@ static I8085_CONFIG( dwarfd_i8085_config )
 #define NUM_LINES 25
 static INTERRUPT_GEN( dwarfd_interrupt )
 {
-	dwarfd_state *state = device->machine->driver_data<dwarfd_state>();
+	dwarfd_state *state = device->machine().driver_data<dwarfd_state>();
 
 	if (cpu_getiloops(device) < NUM_LINES)
 	{
-		cpu_set_input_line(device, I8085_RST65_LINE, HOLD_LINE); // 34 - every 8th line
-		state->line = cpu_getiloops(device);
-		state->idx = 0;
+		device_set_input_line(device, I8085_RST65_LINE, HOLD_LINE); // 34 - every 8th line
+		state->m_line = cpu_getiloops(device);
+		state->m_idx = 0;
 	}
 	else
 	{
 		if (cpu_getiloops(device) == NUM_LINES)
 		{
-			cpu_set_input_line(device, I8085_RST55_LINE, HOLD_LINE);//2c - generated by  crt - end of frame
+			device_set_input_line(device, I8085_RST55_LINE, HOLD_LINE);//2c - generated by  crt - end of frame
 		}
 	}
 }
@@ -887,9 +887,9 @@ static PALETTE_INIT(dwarfd)
 
 	for (i = 0; i < 256; i++)
 	{
-		int r = machine->rand()|0x80;
-		int g = machine->rand()|0x80;
-		int b = machine->rand()|0x80;
+		int r = machine.rand()|0x80;
+		int g = machine.rand()|0x80;
+		int b = machine.rand()|0x80;
 		if (i == 0) r = g = b = 0;
 
 		palette_set_color(machine,i,MAKE_RGB(r,g,b));
@@ -913,48 +913,48 @@ static const ay8910_interface ay8910_config =
 
 static MACHINE_START( dwarfd )
 {
-	dwarfd_state *state = machine->driver_data<dwarfd_state>();
+	dwarfd_state *state = machine.driver_data<dwarfd_state>();
 
-	state_save_register_global(machine, state->bank);
-	state_save_register_global(machine, state->line);
-	state_save_register_global(machine, state->idx);
-	state_save_register_global(machine, state->crt_access);
+	state->save_item(NAME(state->m_bank));
+	state->save_item(NAME(state->m_line));
+	state->save_item(NAME(state->m_idx));
+	state->save_item(NAME(state->m_crt_access));
 
 	/* i8275 */
-	state_save_register_global(machine, state->i8275Command);
-	state_save_register_global(machine, state->i8275HorizontalCharactersRow);
-	state_save_register_global(machine, state->i8275CommandSeqCnt);
-	state_save_register_global(machine, state->i8275SpacedRows);
-	state_save_register_global(machine, state->i8275VerticalRows);
-	state_save_register_global(machine, state->i8275VerticalRetraceRows);
-	state_save_register_global(machine, state->i8275Underline);
-	state_save_register_global(machine, state->i8275Lines);
-	state_save_register_global(machine, state->i8275LineCounterMode);
-	state_save_register_global(machine, state->i8275FieldAttributeMode);
-	state_save_register_global(machine, state->i8275CursorFormat);
-	state_save_register_global(machine, state->i8275HorizontalRetrace);
+	state->save_item(NAME(state->m_i8275Command));
+	state->save_item(NAME(state->m_i8275HorizontalCharactersRow));
+	state->save_item(NAME(state->m_i8275CommandSeqCnt));
+	state->save_item(NAME(state->m_i8275SpacedRows));
+	state->save_item(NAME(state->m_i8275VerticalRows));
+	state->save_item(NAME(state->m_i8275VerticalRetraceRows));
+	state->save_item(NAME(state->m_i8275Underline));
+	state->save_item(NAME(state->m_i8275Lines));
+	state->save_item(NAME(state->m_i8275LineCounterMode));
+	state->save_item(NAME(state->m_i8275FieldAttributeMode));
+	state->save_item(NAME(state->m_i8275CursorFormat));
+	state->save_item(NAME(state->m_i8275HorizontalRetrace));
 }
 
 static MACHINE_RESET( dwarfd )
 {
-	dwarfd_state *state = machine->driver_data<dwarfd_state>();
+	dwarfd_state *state = machine.driver_data<dwarfd_state>();
 
-	state->bank = 0;
-	state->line = 0;
-	state->idx = 0;
-	state->crt_access = 0;
-	state->i8275Command = 0;
-	state->i8275HorizontalCharactersRow = 0;
-	state->i8275CommandSeqCnt = 0;
-	state->i8275SpacedRows = 0;
-	state->i8275VerticalRows = 0;
-	state->i8275VerticalRetraceRows = 0;
-	state->i8275Underline = 0;
-	state->i8275Lines = 0;
-	state->i8275LineCounterMode = 0;
-	state->i8275FieldAttributeMode = 0;
-	state->i8275CursorFormat = 0;
-	state->i8275HorizontalRetrace = 0;
+	state->m_bank = 0;
+	state->m_line = 0;
+	state->m_idx = 0;
+	state->m_crt_access = 0;
+	state->m_i8275Command = 0;
+	state->m_i8275HorizontalCharactersRow = 0;
+	state->m_i8275CommandSeqCnt = 0;
+	state->m_i8275SpacedRows = 0;
+	state->m_i8275VerticalRows = 0;
+	state->m_i8275VerticalRetraceRows = 0;
+	state->m_i8275Underline = 0;
+	state->m_i8275Lines = 0;
+	state->m_i8275LineCounterMode = 0;
+	state->m_i8275FieldAttributeMode = 0;
+	state->m_i8275CursorFormat = 0;
+	state->m_i8275HorizontalRetrace = 0;
 }
 
 static MACHINE_CONFIG_START( dwarfd, dwarfd_state )
@@ -978,13 +978,13 @@ static MACHINE_CONFIG_START( dwarfd, dwarfd_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(272*2, 200)
 	MCFG_SCREEN_VISIBLE_AREA(0, 272*2-1, 0, 200-1)
+	MCFG_SCREEN_UPDATE(dwarfd)
 
 	MCFG_GFXDECODE(dwarfd)
 	MCFG_PALETTE_LENGTH(0x100)
 	MCFG_PALETTE_INIT(dwarfd)
 
 	MCFG_VIDEO_START(dwarfd)
-	MCFG_VIDEO_UPDATE(dwarfd)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_SOUND_ADD("aysnd", AY8910, 1500000)
@@ -1136,13 +1136,13 @@ ROM_END
 
 static DRIVER_INIT(dwarfd)
 {
-	dwarfd_state *state = machine->driver_data<dwarfd_state>();
+	dwarfd_state *state = machine.driver_data<dwarfd_state>();
 	int i;
 	UINT8 *src, *dst;
 
 	/* expand gfx roms */
-	src = machine->region("gfx1")->base();
-	dst = machine->region("gfx2")->base();
+	src = machine.region("gfx1")->base();
+	dst = machine.region("gfx2")->base();
 
 	for (i = 0; i < 0x4000; i++)
 	{
@@ -1155,7 +1155,7 @@ static DRIVER_INIT(dwarfd)
 	}
 
 	/* use low bit as 'interpolation' bit */
-	src = machine->region("gfx2")->base();
+	src = machine.region("gfx2")->base();
 	for (i = 0; i < 0x8000; i++)
 	{
 		if (src[i] & 0x10)
@@ -1173,14 +1173,11 @@ static DRIVER_INIT(dwarfd)
 	//      src[i] = src[i] & 0xe0;
 	}
 
-	state->videobuf = auto_alloc_array(machine, UINT8, 0x8000);
-	state->dw_ram = auto_alloc_array(machine, UINT8, 0x1000);
+	state->save_item(NAME(state->m_videobuf));
+	state->save_item(NAME(state->m_dw_ram));
 
-	state_save_register_global_pointer(machine, state->videobuf, 0x8000);
-	state_save_register_global_pointer(machine, state->dw_ram, 0x1000);
-
-	memset(state->videobuf, 0, 0x8000);
-	memset(state->dw_ram, 0, 0x1000);
+	memset(state->m_videobuf, 0, sizeof(state->m_videobuf));
+	memset(state->m_dw_ram, 0, sizeof(state->m_dw_ram));
 
 }
 
@@ -1189,12 +1186,12 @@ static DRIVER_INIT(qc)
 	DRIVER_INIT_CALL(dwarfd);
 
 	// hacks for program to proceed
-	machine->region("maincpu")->base()[0x6564] = 0x00;
-	machine->region("maincpu")->base()[0x6565] = 0x00;
+	machine.region("maincpu")->base()[0x6564] = 0x00;
+	machine.region("maincpu")->base()[0x6565] = 0x00;
 
-	machine->region("maincpu")->base()[0x59b2] = 0x00;
-	machine->region("maincpu")->base()[0x59b3] = 0x00;
-	machine->region("maincpu")->base()[0x59b4] = 0x00;
+	machine.region("maincpu")->base()[0x59b2] = 0x00;
+	machine.region("maincpu")->base()[0x59b3] = 0x00;
+	machine.region("maincpu")->base()[0x59b4] = 0x00;
 
 }
 
