@@ -11,17 +11,17 @@
 class embargo_state : public driver_device
 {
 public:
-	embargo_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	embargo_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *  videoram;
-	size_t   videoram_size;
+	UINT8 *  m_videoram;
+	size_t   m_videoram_size;
 
 	/* misc */
-	UINT8    dial_enable_1;
-	UINT8    dial_enable_2;
-	UINT8    input_select;
+	UINT8    m_dial_enable_1;
+	UINT8    m_dial_enable_2;
+	UINT8    m_input_select;
 };
 
 
@@ -31,18 +31,18 @@ public:
  *
  *************************************/
 
-static VIDEO_UPDATE( embargo )
+static SCREEN_UPDATE( embargo )
 {
-	embargo_state *state = screen->machine->driver_data<embargo_state>();
+	embargo_state *state = screen->machine().driver_data<embargo_state>();
 	offs_t offs;
 
-	for (offs = 0; offs < state->videoram_size; offs++)
+	for (offs = 0; offs < state->m_videoram_size; offs++)
 	{
 		int i;
 
 		UINT8 x = offs << 3;
 		UINT8 y = offs >> 5;
-		UINT8 data = state->videoram[offs];
+		UINT8 data = state->m_videoram[offs];
 
 		for (i = 0; i < 8; i++)
 		{
@@ -67,14 +67,14 @@ static VIDEO_UPDATE( embargo )
 
 static READ8_HANDLER( input_port_bit_r )
 {
-	embargo_state *state = space->machine->driver_data<embargo_state>();
-	return (input_port_read(space->machine, "IN1") << (7 - state->input_select)) & 0x80;
+	embargo_state *state = space->machine().driver_data<embargo_state>();
+	return (input_port_read(space->machine(), "IN1") << (7 - state->m_input_select)) & 0x80;
 }
 
 
 static READ8_HANDLER( dial_r )
 {
-	embargo_state *state = space->machine->driver_data<embargo_state>();
+	embargo_state *state = space->machine().driver_data<embargo_state>();
 
 	UINT8 lo = 0;
 	UINT8 hi = 0;
@@ -92,16 +92,16 @@ static READ8_HANDLER( dial_r )
 		0x09, 0x0a, 0x08, 0x09, 0x08, 0x05, 0x07, 0x06
 	};
 
-	if (state->dial_enable_1 && !state->dial_enable_2)
+	if (state->m_dial_enable_1 && !state->m_dial_enable_2)
 	{
-		lo = input_port_read(space->machine, "DIAL0");
-		hi = input_port_read(space->machine, "DIAL1");
+		lo = input_port_read(space->machine(), "DIAL0");
+		hi = input_port_read(space->machine(), "DIAL1");
 	}
 
-	if (state->dial_enable_2 && !state->dial_enable_1)
+	if (state->m_dial_enable_2 && !state->m_dial_enable_1)
 	{
-		lo = input_port_read(space->machine, "DIAL2");
-		hi = input_port_read(space->machine, "DIAL3");
+		lo = input_port_read(space->machine(), "DIAL2");
+		hi = input_port_read(space->machine(), "DIAL3");
 	}
 
 	lo = 12 * lo / 256;
@@ -126,22 +126,22 @@ static READ8_HANDLER( dial_r )
 
 static WRITE8_HANDLER( port_1_w )
 {
-	embargo_state *state = space->machine->driver_data<embargo_state>();
-	state->dial_enable_1 = data & 0x01; /* other bits unknown */
+	embargo_state *state = space->machine().driver_data<embargo_state>();
+	state->m_dial_enable_1 = data & 0x01; /* other bits unknown */
 }
 
 
 static WRITE8_HANDLER( port_2_w )
 {
-	embargo_state *state = space->machine->driver_data<embargo_state>();
-	state->dial_enable_2 = data & 0x01; /* other bits unknown */
+	embargo_state *state = space->machine().driver_data<embargo_state>();
+	state->m_dial_enable_2 = data & 0x01; /* other bits unknown */
 }
 
 
 static WRITE8_HANDLER( input_select_w )
 {
-	embargo_state *state = space->machine->driver_data<embargo_state>();
-	state->input_select = data & 0x07;
+	embargo_state *state = space->machine().driver_data<embargo_state>();
+	state->m_input_select = data & 0x07;
 }
 
 
@@ -152,10 +152,10 @@ static WRITE8_HANDLER( input_select_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_ROM
 	AM_RANGE(0x1e00, 0x1fff) AM_RAM
-	AM_RANGE(0x2000, 0x3fff) AM_RAM AM_BASE_SIZE_MEMBER(embargo_state, videoram, videoram_size)
+	AM_RANGE(0x2000, 0x3fff) AM_RAM AM_BASE_SIZE_MEMBER(embargo_state, m_videoram, m_videoram_size)
 ADDRESS_MAP_END
 
 
@@ -166,7 +166,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( main_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( main_io_map, AS_IO, 8 )
 	AM_RANGE(0x01, 0x01) AM_READ_PORT("IN0") AM_WRITE(port_1_w)
 	AM_RANGE(0x02, 0x02) AM_READWRITE(dial_r, port_2_w)
 	AM_RANGE(0x03, 0x03) AM_WRITENOP /* always 0xFE */
@@ -228,22 +228,22 @@ INPUT_PORTS_END
 
 static MACHINE_START( embargo )
 {
-	embargo_state *state = machine->driver_data<embargo_state>();
+	embargo_state *state = machine.driver_data<embargo_state>();
 
 	/* register for state saving */
-	state_save_register_global(machine, state->dial_enable_1);
-	state_save_register_global(machine, state->dial_enable_2);
-	state_save_register_global(machine, state->input_select);
+	state->save_item(NAME(state->m_dial_enable_1));
+	state->save_item(NAME(state->m_dial_enable_2));
+	state->save_item(NAME(state->m_input_select));
 }
 
 
 static MACHINE_RESET( embargo )
 {
-	embargo_state *state = machine->driver_data<embargo_state>();
+	embargo_state *state = machine.driver_data<embargo_state>();
 
-	state->dial_enable_1 = 0;
-	state->dial_enable_2 = 0;
-	state->input_select = 0;
+	state->m_dial_enable_1 = 0;
+	state->m_dial_enable_2 = 0;
+	state->m_input_select = 0;
 }
 
 /*************************************
@@ -263,13 +263,12 @@ static MACHINE_CONFIG_START( embargo, embargo_state )
 	MCFG_MACHINE_RESET(embargo)
 
 	/* video hardware */
-	MCFG_VIDEO_UPDATE(embargo)
-
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 255, 0, 239)
 	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_UPDATE(embargo)
 
 MACHINE_CONFIG_END
 
