@@ -24,7 +24,6 @@ TODO:
 #include "emu.h"
 #include "cpu/z80/z80.h"
 #include "cpu/i8085/i8085.h"
-#include "deprecat.h"
 #include "sound/ay8910.h"
 
 #define LOG_PROT	(0)
@@ -60,25 +59,25 @@ TODO:
 class enigma2_state : public driver_device
 {
 public:
-	enigma2_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	enigma2_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *  videoram;
+	UINT8 *  m_videoram;
 
 	/* misc */
-	int blink_count;
-	UINT8 sound_latch;
-	UINT8 last_sound_data;
-	UINT8 protection_data;
-	UINT8 flip_screen;
+	int m_blink_count;
+	UINT8 m_sound_latch;
+	UINT8 m_last_sound_data;
+	UINT8 m_protection_data;
+	UINT8 m_flip_screen;
 
-	emu_timer *interrupt_clear_timer;
-	emu_timer *interrupt_assert_timer;
+	emu_timer *m_interrupt_clear_timer;
+	emu_timer *m_interrupt_assert_timer;
 
 	/* devices */
-	device_t *maincpu;
-	device_t *audiocpu;
+	device_t *m_maincpu;
+	device_t *m_audiocpu;
 };
 
 
@@ -103,22 +102,22 @@ INLINE int vysnc_chain_counter_to_vpos( UINT16 counter )
 
 static TIMER_CALLBACK( interrupt_clear_callback )
 {
-	enigma2_state *state = machine->driver_data<enigma2_state>();
-	cpu_set_input_line(state->maincpu, 0, CLEAR_LINE);
+	enigma2_state *state = machine.driver_data<enigma2_state>();
+	device_set_input_line(state->m_maincpu, 0, CLEAR_LINE);
 }
 
 
 static TIMER_CALLBACK( interrupt_assert_callback )
 {
-	enigma2_state *state = machine->driver_data<enigma2_state>();
+	enigma2_state *state = machine.driver_data<enigma2_state>();
 	UINT16 next_counter;
 	int next_vpos;
 
 	/* compute vector and set the interrupt line */
-	int vpos = machine->primary_screen->vpos();
+	int vpos = machine.primary_screen->vpos();
 	UINT16 counter = vpos_to_vysnc_chain_counter(vpos);
 	UINT8 vector = 0xc7 | ((counter & 0x80) >> 3) | ((~counter & 0x80) >> 4);
-	cpu_set_input_line_and_vector(state->maincpu, 0, ASSERT_LINE, vector);
+	device_set_input_line_and_vector(state->m_maincpu, 0, ASSERT_LINE, vector);
 
 	/* set up for next interrupt */
 	if (counter == INT_TRIGGER_COUNT_1)
@@ -127,53 +126,53 @@ static TIMER_CALLBACK( interrupt_assert_callback )
 		next_counter = INT_TRIGGER_COUNT_1;
 
 	next_vpos = vysnc_chain_counter_to_vpos(next_counter);
-	timer_adjust_oneshot(state->interrupt_assert_timer, machine->primary_screen->time_until_pos(next_vpos), 0);
-	timer_adjust_oneshot(state->interrupt_clear_timer, machine->primary_screen->time_until_pos(vpos + 1), 0);
+	state->m_interrupt_assert_timer->adjust(machine.primary_screen->time_until_pos(next_vpos));
+	state->m_interrupt_clear_timer->adjust(machine.primary_screen->time_until_pos(vpos + 1));
 }
 
 
-static void create_interrupt_timers( running_machine *machine )
+static void create_interrupt_timers( running_machine &machine )
 {
-	enigma2_state *state = machine->driver_data<enigma2_state>();
-	state->interrupt_clear_timer = timer_alloc(machine, interrupt_clear_callback, NULL);
-	state->interrupt_assert_timer = timer_alloc(machine, interrupt_assert_callback, NULL);
+	enigma2_state *state = machine.driver_data<enigma2_state>();
+	state->m_interrupt_clear_timer = machine.scheduler().timer_alloc(FUNC(interrupt_clear_callback));
+	state->m_interrupt_assert_timer = machine.scheduler().timer_alloc(FUNC(interrupt_assert_callback));
 }
 
 
-static void start_interrupt_timers( running_machine *machine )
+static void start_interrupt_timers( running_machine &machine )
 {
-	enigma2_state *state = machine->driver_data<enigma2_state>();
+	enigma2_state *state = machine.driver_data<enigma2_state>();
 	int vpos = vysnc_chain_counter_to_vpos(INT_TRIGGER_COUNT_1);
-	timer_adjust_oneshot(state->interrupt_assert_timer, machine->primary_screen->time_until_pos(vpos), 0);
+	state->m_interrupt_assert_timer->adjust(machine.primary_screen->time_until_pos(vpos));
 }
 
 
 
 static MACHINE_START( enigma2 )
 {
-	enigma2_state *state = machine->driver_data<enigma2_state>();
+	enigma2_state *state = machine.driver_data<enigma2_state>();
 	create_interrupt_timers(machine);
 
-	state->maincpu = machine->device("maincpu");
-	state->audiocpu = machine->device("audiocpu");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_audiocpu = machine.device("audiocpu");
 
-	state_save_register_global(machine, state->blink_count);
-	state_save_register_global(machine, state->sound_latch);
-	state_save_register_global(machine, state->last_sound_data);
-	state_save_register_global(machine, state->protection_data);
-	state_save_register_global(machine, state->flip_screen);
+	state->save_item(NAME(state->m_blink_count));
+	state->save_item(NAME(state->m_sound_latch));
+	state->save_item(NAME(state->m_last_sound_data));
+	state->save_item(NAME(state->m_protection_data));
+	state->save_item(NAME(state->m_flip_screen));
 }
 
 
 static MACHINE_RESET( enigma2 )
 {
-	enigma2_state *state = machine->driver_data<enigma2_state>();
+	enigma2_state *state = machine.driver_data<enigma2_state>();
 	cputag_set_input_line(machine, "audiocpu", INPUT_LINE_NMI, CLEAR_LINE);
 
-	state->last_sound_data = 0;
-	state->flip_screen = 0;
-	state->sound_latch = 0;
-	state->blink_count = 0;
+	state->m_last_sound_data = 0;
+	state->m_flip_screen = 0;
+	state->m_sound_latch = 0;
+	state->m_blink_count = 0;
 
 	start_interrupt_timers(machine);
 }
@@ -197,15 +196,15 @@ static void get_pens(pen_t *pens)
 }
 
 
-static VIDEO_UPDATE( enigma2 )
+static SCREEN_UPDATE( enigma2 )
 {
-	enigma2_state *state = screen->machine->driver_data<enigma2_state>();
+	enigma2_state *state = screen->machine().driver_data<enigma2_state>();
 	pen_t pens[NUM_PENS];
 
 	const rectangle &visarea = screen->visible_area();
-	UINT8 *prom = screen->machine->region("proms")->base();
-	UINT8 *color_map_base = state->flip_screen ? &prom[0x0400] : &prom[0x0000];
-	UINT8 *star_map_base = (state->blink_count & 0x08) ? &prom[0x0c00] : &prom[0x0800];
+	UINT8 *prom = screen->machine().region("proms")->base();
+	UINT8 *color_map_base = state->m_flip_screen ? &prom[0x0400] : &prom[0x0000];
+	UINT8 *star_map_base = (state->m_blink_count & 0x08) ? &prom[0x0c00] : &prom[0x0800];
 
 	UINT8 x = 0;
 	UINT16 bitmap_y = visarea.min_y;
@@ -227,7 +226,7 @@ static VIDEO_UPDATE( enigma2 )
 			offs_t color_map_address = (y >> 3 << 5) | (x >> 3);
 			/* the schematics shows it like this, but it doesn't work as this would
                produce no stars, due to the contents of the PROM -- maybe there is
-               a star disabled bit somewhere that's connected here instead of flip_screen_get(screen->machine) */
+               a star disabled bit somewhere that's connected here instead of flip_screen_get(screen->machine()) */
 			/* star_map_address = (y >> 4 << 6) | (engima2_flip_screen_get() << 5) | (x >> 3); */
 			offs_t star_map_address = (y >> 4 << 6) | 0x20 | (x >> 3);
 
@@ -235,16 +234,16 @@ static VIDEO_UPDATE( enigma2 )
 
 			/* when the screen is flipped, all the video address bits are inverted,
                and the adder at 16A is activated */
-			if (state->flip_screen)  videoram_address = (~videoram_address + 0x0400) & 0x1fff;
+			if (state->m_flip_screen)  videoram_address = (~videoram_address + 0x0400) & 0x1fff;
 
-			video_data = state->videoram[videoram_address];
+			video_data = state->m_videoram[videoram_address];
 
 			fore_color = color_map_base[color_map_address] & 0x07;
 			star_color = star_map_base[star_map_address] & 0x07;
 		}
 
 		/* plot the current pixel */
-		if (state->flip_screen)
+		if (state->m_flip_screen)
 		{
 			bit = video_data & 0x80;
 			video_data = video_data << 1;
@@ -279,15 +278,15 @@ static VIDEO_UPDATE( enigma2 )
 		}
 	}
 
-	state->blink_count++;
+	state->m_blink_count++;
 
 	return 0;
 }
 
 
-static VIDEO_UPDATE( enigma2a )
+static SCREEN_UPDATE( enigma2a )
 {
-	enigma2_state *state = screen->machine->driver_data<enigma2_state>();
+	enigma2_state *state = screen->machine().driver_data<enigma2_state>();
 	UINT8 x = 0;
 	const rectangle &visarea = screen->visible_area();
 	UINT16 bitmap_y = visarea.min_y;
@@ -306,13 +305,13 @@ static VIDEO_UPDATE( enigma2a )
 
 			/* when the screen is flipped, all the video address bits are inverted,
                and the adder at 16A is activated */
-			if (state->flip_screen)  videoram_address = (~videoram_address + 0x0400) & 0x1fff;
+			if (state->m_flip_screen)  videoram_address = (~videoram_address + 0x0400) & 0x1fff;
 
-			video_data = state->videoram[videoram_address];
+			video_data = state->m_videoram[videoram_address];
 		}
 
 		/* plot the current pixel */
-		if (state->flip_screen)
+		if (state->m_flip_screen)
 		{
 			bit = video_data & 0x80;
 			video_data = video_data << 1;
@@ -349,23 +348,23 @@ static VIDEO_UPDATE( enigma2a )
 
 static READ8_HANDLER( dip_switch_r )
 {
-	enigma2_state *state = space->machine->driver_data<enigma2_state>();
+	enigma2_state *state = space->machine().driver_data<enigma2_state>();
 	UINT8 ret = 0x00;
 
-	if (LOG_PROT) logerror("DIP SW Read: %x at %x (prot data %x)\n", offset, cpu_get_pc(space->cpu), state->protection_data);
+	if (LOG_PROT) logerror("DIP SW Read: %x at %x (prot data %x)\n", offset, cpu_get_pc(&space->device()), state->m_protection_data);
 	switch (offset)
 	{
 	case 0x01:
 		/* For the DIP switches to be read, protection_data must be
            0xff on reset. The AY8910 reset ensures this. */
-		if (state->protection_data != 0xff)
-			ret = state->protection_data ^ 0x88;
+		if (state->m_protection_data != 0xff)
+			ret = state->m_protection_data ^ 0x88;
 		else
-			ret = input_port_read(space->machine, "DSW");
+			ret = input_port_read(space->machine(), "DSW");
 		break;
 
 	case 0x02:
-		if (cpu_get_pc(space->cpu) == 0x07e5)
+		if (cpu_get_pc(&space->device()) == 0x07e5)
 			ret = 0xaa;
 		else
 			ret = 0xf4;
@@ -382,52 +381,52 @@ static READ8_HANDLER( dip_switch_r )
 
 static WRITE8_HANDLER( sound_data_w )
 {
-	enigma2_state *state = space->machine->driver_data<enigma2_state>();
+	enigma2_state *state = space->machine().driver_data<enigma2_state>();
 	/* clock sound latch shift register on rising edge of D2 */
-	if (!(data & 0x04) && (state->last_sound_data & 0x04))
-		state->sound_latch = (state->sound_latch << 1) | (~data & 0x01);
+	if (!(data & 0x04) && (state->m_last_sound_data & 0x04))
+		state->m_sound_latch = (state->m_sound_latch << 1) | (~data & 0x01);
 
-	cpu_set_input_line(state->audiocpu, INPUT_LINE_NMI, (data & 0x02) ? ASSERT_LINE : CLEAR_LINE);
+	device_set_input_line(state->m_audiocpu, INPUT_LINE_NMI, (data & 0x02) ? ASSERT_LINE : CLEAR_LINE);
 
-	state->last_sound_data = data;
+	state->m_last_sound_data = data;
 }
 
 
 static READ8_DEVICE_HANDLER( sound_latch_r )
 {
-	enigma2_state *state = device->machine->driver_data<enigma2_state>();
-	return BITSWAP8(state->sound_latch,0,1,2,3,4,5,6,7);
+	enigma2_state *state = device->machine().driver_data<enigma2_state>();
+	return BITSWAP8(state->m_sound_latch,0,1,2,3,4,5,6,7);
 }
 
 
 static WRITE8_DEVICE_HANDLER( protection_data_w )
 {
-	enigma2_state *state = device->machine->driver_data<enigma2_state>();
-	if (LOG_PROT) logerror("%s: Protection Data Write: %x\n", cpuexec_describe_context(device->machine), data);
-	state->protection_data = data;
+	enigma2_state *state = device->machine().driver_data<enigma2_state>();
+	if (LOG_PROT) logerror("%s: Protection Data Write: %x\n", device->machine().describe_context(), data);
+	state->m_protection_data = data;
 }
 
 
 static WRITE8_HANDLER( enigma2_flip_screen_w )
 {
-	enigma2_state *state = space->machine->driver_data<enigma2_state>();
-	state->flip_screen = ((data >> 5) & 0x01) && ((input_port_read(space->machine, "DSW") & 0x20) == 0x20);
+	enigma2_state *state = space->machine().driver_data<enigma2_state>();
+	state->m_flip_screen = ((data >> 5) & 0x01) && ((input_port_read(space->machine(), "DSW") & 0x20) == 0x20);
 }
 
 
 static CUSTOM_INPUT( p1_controls_r )
 {
-	return input_port_read(field->port->machine, "P1CONTROLS");
+	return input_port_read(field.machine(), "P1CONTROLS");
 }
 
 
 static CUSTOM_INPUT( p2_controls_r )
 {
-	enigma2_state *state = field->port->machine->driver_data<enigma2_state>();
-	if (state->flip_screen)
-		return input_port_read(field->port->machine, "P2CONTROLS");
+	enigma2_state *state = field.machine().driver_data<enigma2_state>();
+	if (state->m_flip_screen)
+		return input_port_read(field.machine(), "P2CONTROLS");
 	else
-		return input_port_read(field->port->machine, "P1CONTROLS");
+		return input_port_read(field.machine(), "P1CONTROLS");
 }
 
 
@@ -444,10 +443,10 @@ static const ay8910_interface ay8910_config =
 
 
 
-static ADDRESS_MAP_START( engima2_main_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( engima2_main_cpu_map, AS_PROGRAM, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0x7fff)
 	AM_RANGE(0x0000, 0x1fff) AM_ROM AM_WRITENOP
-	AM_RANGE(0x2000, 0x3fff) AM_MIRROR(0x4000) AM_RAM AM_BASE_MEMBER(enigma2_state, videoram)
+	AM_RANGE(0x2000, 0x3fff) AM_MIRROR(0x4000) AM_RAM AM_BASE_MEMBER(enigma2_state, m_videoram)
 	AM_RANGE(0x4000, 0x4fff) AM_ROM AM_WRITENOP
 	AM_RANGE(0x5000, 0x57ff) AM_READ(dip_switch_r) AM_WRITENOP
 	AM_RANGE(0x5800, 0x5800) AM_MIRROR(0x07f8) AM_NOP
@@ -460,16 +459,16 @@ static ADDRESS_MAP_START( engima2_main_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( engima2a_main_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( engima2a_main_cpu_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM AM_WRITENOP
-	AM_RANGE(0x2000, 0x3fff) AM_MIRROR(0x4000) AM_RAM AM_BASE_MEMBER(enigma2_state, videoram)
+	AM_RANGE(0x2000, 0x3fff) AM_MIRROR(0x4000) AM_RAM AM_BASE_MEMBER(enigma2_state, m_videoram)
 	AM_RANGE(0x4000, 0x4fff) AM_ROM AM_WRITENOP
 	AM_RANGE(0x5000, 0x57ff) AM_READ(dip_switch_r) AM_WRITENOP
 	AM_RANGE(0x5800, 0x5fff) AM_NOP
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( engima2a_main_cpu_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( engima2a_main_cpu_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0x7)
 	AM_RANGE(0x00, 0x00) AM_NOP
 	AM_RANGE(0x01, 0x01) AM_READ_PORT("IN0") AM_WRITENOP
@@ -481,7 +480,7 @@ static ADDRESS_MAP_START( engima2a_main_cpu_io_map, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( engima2_audio_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( engima2_audio_cpu_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_MIRROR(0x1000) AM_ROM AM_WRITENOP
 	AM_RANGE(0x2000, 0x7fff) AM_NOP
 	AM_RANGE(0x8000, 0x83ff) AM_MIRROR(0x1c00) AM_RAM
@@ -608,18 +607,17 @@ static MACHINE_CONFIG_START( enigma2, enigma2_state )
 	MCFG_CPU_PROGRAM_MAP(engima2_main_cpu_map)
 
 	MCFG_CPU_ADD("audiocpu", Z80, 2500000)
-	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,8)
 	MCFG_CPU_PROGRAM_MAP(engima2_audio_cpu_map)
+	MCFG_CPU_PERIODIC_INT(irq0_line_hold,8*52)
 
 	MCFG_MACHINE_START(enigma2)
 	MCFG_MACHINE_RESET(enigma2)
 
 	/* video hardware */
-	MCFG_VIDEO_UPDATE(enigma2)
-
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_RAW_PARAMS(PIXEL_CLOCK, HTOTAL, HBEND, HBSTART, VTOTAL, VBEND, VBSTART)
+	MCFG_SCREEN_UPDATE(enigma2)
 
 	/* audio hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -638,18 +636,17 @@ static MACHINE_CONFIG_START( enigma2a, enigma2_state )
 	MCFG_CPU_IO_MAP(engima2a_main_cpu_io_map)
 
 	MCFG_CPU_ADD("audiocpu", Z80, 2500000)
-	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,8)
 	MCFG_CPU_PROGRAM_MAP(engima2_audio_cpu_map)
+	MCFG_CPU_PERIODIC_INT(irq0_line_hold,8*52)
 
 	MCFG_MACHINE_START(enigma2)
 	MCFG_MACHINE_RESET(enigma2)
 
 	/* video hardware */
-	MCFG_VIDEO_UPDATE(enigma2a)
-
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_RAW_PARAMS(PIXEL_CLOCK, HTOTAL, HBEND, HBSTART, VTOTAL, VBEND, VBSTART)
+	MCFG_SCREEN_UPDATE(enigma2a)
 
 	/* audio hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -710,7 +707,7 @@ ROM_END
 static DRIVER_INIT(enigma2)
 {
 	offs_t i;
-	UINT8 *rom = machine->region("audiocpu")->base();
+	UINT8 *rom = machine.region("audiocpu")->base();
 
 	for(i = 0; i < 0x2000; i++)
 	{
@@ -720,6 +717,6 @@ static DRIVER_INIT(enigma2)
 
 
 
-GAME( 1981, enigma2,  0,	   enigma2,  enigma2,  enigma2, ROT270, "GamePlan (Zilec Electronics license)", "Enigma II", GAME_SUPPORTS_SAVE )
+GAME( 1981, enigma2,  0,	   enigma2,  enigma2,  enigma2, ROT270, "Game Plan (Zilec Electronics license)", "Enigma II", GAME_SUPPORTS_SAVE )
 GAME( 1984, enigma2a, enigma2, enigma2a, enigma2a, enigma2, ROT270, "Zilec Electronics", "Enigma II (Space Invaders hardware)", GAME_SUPPORTS_SAVE )
 GAME( 1981, enigma2b, enigma2, enigma2a, enigma2a, enigma2, ROT270, "Zilec Electronics", "Phantoms II (Space Invaders hardware)", GAME_SUPPORTS_SAVE )
