@@ -16,8 +16,18 @@
 #include "sound/okim6295.h"
 #include "includes/eolithsp.h"
 
-static UINT16 *vram;
-static int vbuffer = 0;
+
+class eolith16_state : public driver_device
+{
+public:
+	eolith16_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT16 *m_vram;
+	int m_vbuffer;
+};
+
+
 
 // It's configured for 512 bytes
 static const eeprom_interface eeprom_interface_93C66 =
@@ -33,10 +43,11 @@ static const eeprom_interface eeprom_interface_93C66 =
 
 static WRITE16_HANDLER( eeprom_w )
 {
-	vbuffer = (data & 0x80) >> 7;
-	coin_counter_w(space->machine, 0, data & 1);
+	eolith16_state *state = space->machine().driver_data<eolith16_state>();
+	state->m_vbuffer = (data & 0x80) >> 7;
+	coin_counter_w(space->machine(), 0, data & 1);
 
-	input_port_write(space->machine, "EEPROMOUT", data, 0xff);
+	input_port_write(space->machine(), "EEPROMOUT", data, 0xff);
 
 	//data & 0x100 and data & 0x004 always set
 }
@@ -44,22 +55,24 @@ static WRITE16_HANDLER( eeprom_w )
 static READ16_HANDLER( eolith16_custom_r )
 {
 	eolith_speedup_read(space);
-	return input_port_read(space->machine, "SPECIAL");
+	return input_port_read(space->machine(), "SPECIAL");
 }
 
 
 
 static WRITE16_HANDLER( vram_w )
 {
-	COMBINE_DATA(&vram[offset + (0x10000/2) * vbuffer]);
+	eolith16_state *state = space->machine().driver_data<eolith16_state>();
+	COMBINE_DATA(&state->m_vram[offset + (0x10000/2) * state->m_vbuffer]);
 }
 
 static READ16_HANDLER( vram_r )
 {
-	return vram[offset + (0x10000/2) * vbuffer];
+	eolith16_state *state = space->machine().driver_data<eolith16_state>();
+	return state->m_vram[offset + (0x10000/2) * state->m_vbuffer];
 }
 
-static ADDRESS_MAP_START( eolith16_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( eolith16_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x00000000, 0x001fffff) AM_RAM
 	AM_RANGE(0x50000000, 0x5000ffff) AM_READWRITE(vram_r, vram_w)
 	AM_RANGE(0x90000000, 0x9000002f) AM_WRITENOP //?
@@ -75,7 +88,7 @@ ADDRESS_MAP_END
 
 static INPUT_PORTS_START( eolith16 )
 	PORT_START("SPECIAL")
-	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_READ_LINE_DEVICE("eeprom", eeprom_read_bit)
+	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_READ_LINE_DEVICE_MEMBER("eeprom", eeprom_device, read_bit)
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_SPECIAL ) PORT_CUSTOM(eolith_speedup_getvblank, NULL)
 	PORT_BIT( 0xff6f, IP_ACTIVE_LOW, IPT_UNUSED )
 
@@ -98,18 +111,20 @@ static INPUT_PORTS_START( eolith16 )
 	PORT_BIT( 0xffe0, IP_ACTIVE_LOW, IPT_UNUSED )
 
 	PORT_START( "EEPROMOUT" )
-	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_set_cs_line)
-	PORT_BIT( 0x00000020, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_set_clock_line)
-	PORT_BIT( 0x00000040, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_write_bit)
+	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, set_cs_line)
+	PORT_BIT( 0x00000020, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, set_clock_line)
+	PORT_BIT( 0x00000040, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, write_bit)
 INPUT_PORTS_END
 
 static VIDEO_START( eolith16 )
 {
-	vram = auto_alloc_array(machine, UINT16, 0x10000);
+	eolith16_state *state = machine.driver_data<eolith16_state>();
+	state->m_vram = auto_alloc_array(machine, UINT16, 0x10000);
 }
 
-static VIDEO_UPDATE( eolith16 )
+static SCREEN_UPDATE( eolith16 )
 {
+	eolith16_state *state = screen->machine().driver_data<eolith16_state>();
 	int x,y,count;
 	int color;
 
@@ -118,10 +133,10 @@ static VIDEO_UPDATE( eolith16 )
 	{
 		for (x=0;x < 320/2;x++)
 		{
-			color = vram[count + (0x10000/2) * (vbuffer ^ 1)] & 0xff;
+			color = state->m_vram[count + (0x10000/2) * (state->m_vbuffer ^ 1)] & 0xff;
 			*BITMAP_ADDR16(bitmap, y, x*2 + 0) = color;
 
-			color = (vram[count + (0x10000/2) * (vbuffer ^ 1)] & 0xff00) >> 8;
+			color = (state->m_vram[count + (0x10000/2) * (state->m_vbuffer ^ 1)] & 0xff00) >> 8;
 			*BITMAP_ADDR16(bitmap, y, x*2 + 1) = color;
 
 			count++;
@@ -157,7 +172,7 @@ static PALETTE_INIT( eolith16 )
 
 
 
-static MACHINE_CONFIG_START( eolith16, driver_device )
+static MACHINE_CONFIG_START( eolith16, eolith16_state )
 	MCFG_CPU_ADD("maincpu", E116T, 60000000)		/* no internal multiplier */
 	MCFG_CPU_PROGRAM_MAP(eolith16_map)
 	MCFG_CPU_VBLANK_INT_HACK(eolith_speedup,262)
@@ -171,12 +186,12 @@ static MACHINE_CONFIG_START( eolith16, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(512, 512)
 	MCFG_SCREEN_VISIBLE_AREA(0, 319, 0, 199)
+	MCFG_SCREEN_UPDATE(eolith16)
 
 	MCFG_PALETTE_LENGTH(256)
 
 	MCFG_PALETTE_INIT(eolith16)
 	MCFG_VIDEO_START(eolith16)
-	MCFG_VIDEO_UPDATE(eolith16)
 
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
