@@ -366,7 +366,6 @@ D
 #include "emu.h"
 #include "cpu/m68000/m68000.h"
 #include "cpu/alph8201/alph8201.h"
-#include "deprecat.h"
 #include "cpu/i8085/i8085.h"
 #include "sound/ay8910.h"
 #include "sound/msm5232.h"
@@ -381,11 +380,16 @@ D
 #define FRQ_ADJUSTER_TAG	"FRQ"
 
 // MSM5232 clock is generated by a transistor oscillator circuit, not by the pcb xtal
-// The circuit is controlled by a pot to allow adjusting the frequency
+// The circuit is controlled by a pot to allow adjusting the frequency.  All games
+// have been hand-tuned to a recording claiming to be an original recording from the
+// boards.  You can adjust this in the Slider Controls while using -cheat if needed.
+
 #define MSM5232_MAX_CLOCK 6144000
 #define MSM5232_MIN_CLOCK  214000	// unstable
 
 
+
+
 /******************************************************************************/
 // Sound
 
@@ -393,51 +397,51 @@ D
 
 static TIMER_CALLBACK( equites_nmi_callback )
 {
-	equites_state *state = machine->driver_data<equites_state>();
-	cpu_set_input_line(state->audio_cpu, INPUT_LINE_NMI, ASSERT_LINE);
+	equites_state *state = machine.driver_data<equites_state>();
+	device_set_input_line(state->m_audio_cpu, INPUT_LINE_NMI, ASSERT_LINE);
 }
 
 static TIMER_CALLBACK( equites_frq_adjuster_callback )
 {
-	equites_state *state = machine->driver_data<equites_state>();
+	equites_state *state = machine.driver_data<equites_state>();
 	UINT8 frq = input_port_read(machine, FRQ_ADJUSTER_TAG);
 
-	msm5232_set_clock(state->msm, MSM5232_MIN_CLOCK + frq * (MSM5232_MAX_CLOCK - MSM5232_MIN_CLOCK) / 100);
-//popmessage("8155: C %02x A %02x  AY: A %02x B %02x Unk:%x", state->eq8155_port_c, state->eq8155_port_a, state->ay_port_a, state->ay_port_b, state->eq_cymbal_ctrl & 15);
+	msm5232_set_clock(state->m_msm, MSM5232_MIN_CLOCK + frq * (MSM5232_MAX_CLOCK - MSM5232_MIN_CLOCK) / 100);
+//popmessage("8155: C %02x A %02x  AY: A %02x B %02x Unk:%x", state->m_eq8155_port_c, state->m_eq8155_port_a, state->m_ay_port_a, state->m_ay_port_b, state->m_eq_cymbal_ctrl & 15);
 
-	state->cymvol *= 0.94f;
-	state->hihatvol *= 0.94f;
+	state->m_cymvol *= 0.94f;
+	state->m_hihatvol *= 0.94f;
 
-	sound_set_output_gain(state->msm, 10, state->hihatvol + state->cymvol * (state->ay_port_b & 3) * 0.33);	/* NO from msm5232 */
+	state->m_msm->set_output_gain(10, state->m_hihatvol + state->m_cymvol * (state->m_ay_port_b & 3) * 0.33);	/* NO from msm5232 */
 }
 
 static SOUND_START(equites)
 {
-	equites_state *state = machine->driver_data<equites_state>();
-	state->nmi_timer = timer_alloc(machine, equites_nmi_callback, NULL);
+	equites_state *state = machine.driver_data<equites_state>();
+	state->m_nmi_timer = machine.scheduler().timer_alloc(FUNC(equites_nmi_callback));
 
-	state->adjuster_timer = timer_alloc(machine, equites_frq_adjuster_callback, NULL);
-	timer_adjust_periodic(state->adjuster_timer, ATTOTIME_IN_HZ(60), 0, ATTOTIME_IN_HZ(60));
+	state->m_adjuster_timer = machine.scheduler().timer_alloc(FUNC(equites_frq_adjuster_callback));
+	state->m_adjuster_timer->adjust(attotime::from_hz(60), 0, attotime::from_hz(60));
 }
 
 static WRITE8_HANDLER(equites_c0f8_w)
 {
-	equites_state *state = space->machine->driver_data<equites_state>();
+	equites_state *state = space->machine().driver_data<equites_state>();
 
 	switch (offset)
 	{
 		case 0:	// c0f8: NMI ack (written by NMI handler)
-			cpu_set_input_line(state->audio_cpu, INPUT_LINE_NMI, CLEAR_LINE);
+			device_set_input_line(state->m_audio_cpu, INPUT_LINE_NMI, CLEAR_LINE);
 			break;
 
 		case 1: // c0f9: RST75 trigger (written by NMI handler)
 			// Note: solder pad CP3 on the pcb would allow to disable this
-			generic_pulse_irq_line(state->audio_cpu, I8085_RST75_LINE);
+			generic_pulse_irq_line(state->m_audio_cpu, I8085_RST75_LINE);
 			break;
 
 		case 2: // c0fa: INTR trigger (written by NMI handler)
 			// verified on PCB:
-			cpu_set_input_line(state->audio_cpu, I8085_INTR_LINE, HOLD_LINE);
+			device_set_input_line(state->m_audio_cpu, I8085_INTR_LINE, HOLD_LINE);
 			break;
 
 		case 3: // c0fb: n.c.
@@ -445,7 +449,7 @@ static WRITE8_HANDLER(equites_c0f8_w)
 			break;
 
 		case 4: // c0fc: increment PROM address (written by NMI handler)
-			state->sound_prom_address = (state->sound_prom_address + 1) & 0x1f;
+			state->m_sound_prom_address = (state->m_sound_prom_address + 1) & 0x1f;
 //       at this point, the 5-bit value
 //       goes to an op-amp and to the base of a transistor. The transistor is part
 //       of a resonator that is used to generate the M5232 clock. The PROM doesn't
@@ -471,71 +475,71 @@ static WRITE8_HANDLER(equites_c0f8_w)
 
 static WRITE8_DEVICE_HANDLER( equites_8910porta_w )
 {
-	equites_state *state = device->machine->driver_data<equites_state>();
+	equites_state *state = device->machine().driver_data<equites_state>();
 
 	// bongo 1
 	sample_set_volume(device, 0, ((data & 0x30) >> 4) * 0.33);
-	if (data & ~state->ay_port_a & 0x80)
+	if (data & ~state->m_ay_port_a & 0x80)
 		sample_start(device, 0, 0, 0);
 
 	// bongo 2
 	sample_set_volume(device, 1, (data & 0x03) * 0.33);
-	if (data & ~state->ay_port_a & 0x08)
+	if (data & ~state->m_ay_port_a & 0x08)
 		sample_start(device, 1, 1, 0);
 
-	state->ay_port_a = data;
+	state->m_ay_port_a = data;
 
 #if POPDRUMKIT
-popmessage("HH %d(%d) CYM %d(%d)", state->hihat, BIT(state->ay_port_b, 6), state->cymbal, state->ay_port_b & 3);
+popmessage("HH %d(%d) CYM %d(%d)", state->m_hihat, BIT(state->m_ay_port_b, 6), state->m_cymbal, state->m_ay_port_b & 3);
 #endif
 }
 
 static WRITE8_DEVICE_HANDLER( equites_8910portb_w )
 {
-	equites_state *state = device->machine->driver_data<equites_state>();
+	equites_state *state = device->machine().driver_data<equites_state>();
 #if POPDRUMKIT
-if (data & ~state->ay_port_b & 0x08) state->cymbal++;
-if (data & ~state->ay_port_b & 0x04) state->hihat++;
+if (data & ~state->m_ay_port_b & 0x08) state->m_cymbal++;
+if (data & ~state->m_ay_port_b & 0x04) state->m_hihat++;
 #endif
 
 	// bongo 3
 	sample_set_volume(device, 2, ((data & 0x30)>>4) * 0.33);
-	if (data & ~state->ay_port_b & 0x80)
+	if (data & ~state->m_ay_port_b & 0x80)
 		sample_start(device, 2, 2, 0);
 
 	// FIXME I'm just enabling the MSM5232 Noise Output for now. Proper emulation
 	// of the analog circuitry should be done instead.
-//  if (data & ~state->ay_port_b & 0x08)   cymbal hit trigger
-//  if (data & ~state->ay_port_b & 0x04)   hi-hat hit trigger
+//  if (data & ~state->m_ay_port_b & 0x08)   cymbal hit trigger
+//  if (data & ~state->m_ay_port_b & 0x04)   hi-hat hit trigger
 //  data & 3   cymbal volume
 //  data & 0x40  hi-hat enable
 
-	if (data & ~state->ay_port_b & 0x08)
-		state->cymvol = 1.0f;
+	if (data & ~state->m_ay_port_b & 0x08)
+		state->m_cymvol = 1.0f;
 
-	if (data & ~state->ay_port_b & 0x04)
-		state->hihatvol = 0.8f;
+	if (data & ~state->m_ay_port_b & 0x04)
+		state->m_hihatvol = 0.8f;
 
 	if (~data & 0x40)
-		state->hihatvol = 0.0f;
+		state->m_hihatvol = 0.0f;
 
-	state->ay_port_b = data;
+	state->m_ay_port_b = data;
 
 #if POPDRUMKIT
-popmessage("HH %d(%d) CYM %d(%d)",state->hihat,BIT(state->ay_port_b,6),state->cymbal,state->ay_port_b & 3);
+popmessage("HH %d(%d) CYM %d(%d)",state->m_hihat,BIT(state->m_ay_port_b,6),state->m_cymbal,state->m_ay_port_b & 3);
 #endif
 }
 
 static WRITE8_HANDLER(equites_cymbal_ctrl_w)
 {
-	equites_state *state = space->machine->driver_data<equites_state>();
-	state->eq_cymbal_ctrl++;
+	equites_state *state = space->machine().driver_data<equites_state>();
+	state->m_eq_cymbal_ctrl++;
 }
 
 
-static void equites_update_dac( running_machine *machine )
+static void equites_update_dac( running_machine &machine )
 {
-	equites_state *state = machine->driver_data<equites_state>();
+	equites_state *state = machine.driver_data<equites_state>();
 
 	// there is only one latch, which is used to drive two DAC channels.
 	// When the channel is enabled in the 4066, it goes to a series of
@@ -543,25 +547,25 @@ static void equites_update_dac( running_machine *machine )
 	// then it's disabled again.
 	// Note that PB0 goes through three filters while PB1 only goes through one.
 
-	if (state->eq8155_port_b & 1)
-		dac_signed_data_w(state->dac_1, state->dac_latch);
+	if (state->m_eq8155_port_b & 1)
+		dac_signed_data_w(state->m_dac_1, state->m_dac_latch);
 
-	if (state->eq8155_port_b & 2)
-		dac_signed_data_w(state->dac_2, state->dac_latch);
+	if (state->m_eq8155_port_b & 2)
+		dac_signed_data_w(state->m_dac_2, state->m_dac_latch);
 }
 
 static WRITE8_HANDLER( equites_dac_latch_w )
 {
-	equites_state *state = space->machine->driver_data<equites_state>();
-	state->dac_latch = data << 2;
-	equites_update_dac(space->machine);
+	equites_state *state = space->machine().driver_data<equites_state>();
+	state->m_dac_latch = data << 2;
+	equites_update_dac(space->machine());
 }
 
 static WRITE8_HANDLER( equites_8155_portb_w )
 {
-	equites_state *state = space->machine->driver_data<equites_state>();
-	state->eq8155_port_b = data;
-	equites_update_dac(space->machine);
+	equites_state *state = space->machine().driver_data<equites_state>();
+	state->m_eq8155_port_b = data;
+	equites_update_dac(space->machine());
 }
 
 static void equites_msm5232_gate( device_t *device, int state )
@@ -575,53 +579,67 @@ static void equites_msm5232_gate( device_t *device, int state )
 // Interrupt Handlers
 
 // Equites Hardware
-static INTERRUPT_GEN( equites_interrupt )
+static TIMER_DEVICE_CALLBACK( equites_scanline )
 {
-	if (cpu_getiloops(device))
-		cpu_set_input_line(device, 2, HOLD_LINE);
-	else
-		cpu_set_input_line(device, 1, HOLD_LINE);
+	int scanline = param;
+
+	if(scanline == 232) // vblank-out irq
+		cputag_set_input_line(timer.machine(), "maincpu", 1, HOLD_LINE);
+
+	if(scanline == 24) // vblank-in irq
+		cputag_set_input_line(timer.machine(), "maincpu", 2, HOLD_LINE);
+}
+
+static TIMER_DEVICE_CALLBACK( splndrbt_scanline )
+{
+	int scanline = param;
+
+	if(scanline == 224) // vblank-out irq
+		cputag_set_input_line(timer.machine(), "maincpu", 1, HOLD_LINE);
+
+	if(scanline == 32) // vblank-in irq
+		cputag_set_input_line(timer.machine(), "maincpu", 2, HOLD_LINE);
 }
 
 static WRITE8_HANDLER(equites_8155_w)
 {
-	equites_state *state = space->machine->driver_data<equites_state>();
+	equites_state *state = space->machine().driver_data<equites_state>();
 
 	// FIXME proper 8155 emulation must be implemented
 	switch( offset )
 	{
 		case 0: //logerror( "8155 Command register write %x, timer command = %x, interrupt enable = %x, ports = %x\n", data, (data >> 6) & 3, (data >> 4) & 3, data & 0xf );
 			if (((data >> 6) & 3) == 3)
-				timer_adjust_periodic(state->nmi_timer, ATTOTIME_IN_HZ(XTAL_6_144MHz/2 / state->timer_count), 0, ATTOTIME_IN_HZ(XTAL_6_144MHz/2 / state->timer_count));
+				state->m_nmi_timer->adjust(attotime::from_hz(XTAL_6_144MHz/2 / state->m_timer_count), 0, attotime::from_hz(XTAL_6_144MHz/2 / state->m_timer_count));
 			break;
 		case 1: //logerror( "8155 I/O Port A write %x\n", data );
-			state->eq8155_port_a = data;
-			sound_set_output_gain(state->msm, 0, (data >> 4) / 15.0);	/* group1 from msm5232 */
-			sound_set_output_gain(state->msm, 1, (data >> 4) / 15.0);	/* group1 from msm5232 */
-			sound_set_output_gain(state->msm, 2, (data >> 4) / 15.0);	/* group1 from msm5232 */
-			sound_set_output_gain(state->msm, 3, (data >> 4) / 15.0);	/* group1 from msm5232 */
-			sound_set_output_gain(state->msm, 4, (data & 0x0f) / 15.0);	/* group2 from msm5232 */
-			sound_set_output_gain(state->msm, 5, (data & 0x0f) / 15.0);	/* group2 from msm5232 */
-			sound_set_output_gain(state->msm, 6, (data & 0x0f) / 15.0);	/* group2 from msm5232 */
-			sound_set_output_gain(state->msm, 7, (data & 0x0f) / 15.0);	/* group2 from msm5232 */
+			state->m_eq8155_port_a = data;
+			state->m_msm->set_output_gain(0, (data >> 4) / 15.0);	/* group1 from msm5232 */
+			state->m_msm->set_output_gain(1, (data >> 4) / 15.0);	/* group1 from msm5232 */
+			state->m_msm->set_output_gain(2, (data >> 4) / 15.0);	/* group1 from msm5232 */
+			state->m_msm->set_output_gain(3, (data >> 4) / 15.0);	/* group1 from msm5232 */
+			state->m_msm->set_output_gain(4, (data & 0x0f) / 15.0);	/* group2 from msm5232 */
+			state->m_msm->set_output_gain(5, (data & 0x0f) / 15.0);	/* group2 from msm5232 */
+			state->m_msm->set_output_gain(6, (data & 0x0f) / 15.0);	/* group2 from msm5232 */
+			state->m_msm->set_output_gain(7, (data & 0x0f) / 15.0);	/* group2 from msm5232 */
 			break;
 		case 2: //logerror( "8155 I/O Port B write %x\n", data );
 			equites_8155_portb_w(space, 0, data);
 			break;
 		case 3: //logerror( "8155 I/O Port C (or control) write %x\n", data );
-			state->eq8155_port_c = data;
-			sound_set_output_gain(state->msm, 8, (data & 0x0f) / 15.0);	/* SOLO  8' from msm5232 */
+			state->m_eq8155_port_c = data;
+			state->m_msm->set_output_gain(8, (data & 0x0f) / 15.0);	/* SOLO  8' from msm5232 */
 			if (data & 0x20)
-				sound_set_output_gain(state->msm, 9, (data & 0x0f) / 15.0);	/* SOLO 16' from msm5232 */
+				state->m_msm->set_output_gain(9, (data & 0x0f) / 15.0);	/* SOLO 16' from msm5232 */
 			else
-				sound_set_output_gain(state->msm, 9, 0);	/* SOLO 16' from msm5232 */
+				state->m_msm->set_output_gain(9, 0);	/* SOLO 16' from msm5232 */
 
 			break;
 		case 4: //logerror( "8155 Timer low 8 bits write %x\n", data );
-			state->timer_count = (state->timer_count & 0xff00) | data;
+			state->m_timer_count = (state->m_timer_count & 0xff00) | data;
 			break;
 		case 5: //logerror( "8155 Timer high 6 bits write %x, timer mode %x\n", data & 0x3f, (data >> 6) & 3);
-			state->timer_count = (state->timer_count & 0x00ff) | ((data & 0x3f) << 8);
+			state->m_timer_count = (state->m_timer_count & 0x00ff) | ((data & 0x3f) << 8);
 			break;
 	}
 }
@@ -632,27 +650,27 @@ static WRITE8_HANDLER(equites_8155_w)
 #if HVOLTAGE_DEBUG
 static READ16_HANDLER(hvoltage_debug_r)
 {
-	return(input_port_read(space->machine, "FAKE"));
+	return(input_port_read(space->machine(), "FAKE"));
 }
 #endif
 
 
 static CUSTOM_INPUT( gekisou_unknown_status )
 {
-	equites_state *state = field->port->machine->driver_data<equites_state>();
-	return state->unknown_bit;
+	equites_state *state = field.machine().driver_data<equites_state>();
+	return state->m_unknown_bit;
 }
 
 static WRITE16_HANDLER( gekisou_unknown_0_w )
 {
-	equites_state *state = space->machine->driver_data<equites_state>();
-	state->unknown_bit = 0;
+	equites_state *state = space->machine().driver_data<equites_state>();
+	state->m_unknown_bit = 0;
 }
 
 static WRITE16_HANDLER( gekisou_unknown_1_w )
 {
-	equites_state *state = space->machine->driver_data<equites_state>();
-	state->unknown_bit = 1;
+	equites_state *state = space->machine().driver_data<equites_state>();
+	state->m_unknown_bit = 1;
 }
 
 /******************************************************************************/
@@ -661,48 +679,48 @@ static WRITE16_HANDLER( gekisou_unknown_1_w )
 
 static READ16_HANDLER(equites_spriteram_kludge_r)
 {
-	equites_state *state = space->machine->driver_data<equites_state>();
-	if (state->spriteram[0] == 0x5555)
+	equites_state *state = space->machine().driver_data<equites_state>();
+	if (state->m_spriteram[0] == 0x5555)
 		return 0;
 	else
-		return state->spriteram[0];
+		return state->m_spriteram[0];
 }
 
 static READ16_HANDLER(mcu_r)
 {
-	equites_state *state = space->machine->driver_data<equites_state>();
-	return 0xff00 | state->mcu_ram[offset];
+	equites_state *state = space->machine().driver_data<equites_state>();
+	return 0xff00 | state->m_mcu_ram[offset];
 }
 
 static WRITE16_HANDLER(mcu_w)
 {
-	equites_state *state = space->machine->driver_data<equites_state>();
+	equites_state *state = space->machine().driver_data<equites_state>();
 	if (ACCESSING_BITS_0_7)
-		state->mcu_ram[offset] = data & 0xff;
+		state->m_mcu_ram[offset] = data & 0xff;
 }
 
 static WRITE16_HANDLER( mcu_halt_assert_w )
 {
-	equites_state *state = space->machine->driver_data<equites_state>();
-	cpu_set_input_line(state->mcu, INPUT_LINE_HALT, ASSERT_LINE);
+	equites_state *state = space->machine().driver_data<equites_state>();
+	device_set_input_line(state->m_mcu, INPUT_LINE_HALT, ASSERT_LINE);
 }
 
 static WRITE16_HANDLER( mcu_halt_clear_w )
 {
-	equites_state *state = space->machine->driver_data<equites_state>();
-	cpu_set_input_line(state->mcu, INPUT_LINE_HALT, CLEAR_LINE);
+	equites_state *state = space->machine().driver_data<equites_state>();
+	device_set_input_line(state->m_mcu, INPUT_LINE_HALT, CLEAR_LINE);
 }
 
 
 
-static ADDRESS_MAP_START( equites_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( equites_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x00ffff) AM_ROM	// ROM area is written several times (dev system?)
 	AM_RANGE(0x040000, 0x040fff) AM_RAM AM_SHARE("nvram")	// nvram is for gekisou only
 	AM_RANGE(0x080000, 0x080fff) AM_READWRITE(equites_fg_videoram_r, equites_fg_videoram_w)	// 8-bit
-	AM_RANGE(0x0c0000, 0x0c01ff) AM_RAM_WRITE(equites_bg_videoram_w) AM_BASE_MEMBER(equites_state, bg_videoram)
+	AM_RANGE(0x0c0000, 0x0c01ff) AM_RAM_WRITE(equites_bg_videoram_w) AM_BASE_MEMBER(equites_state, m_bg_videoram)
 	AM_RANGE(0x0c0200, 0x0c0fff) AM_RAM
 	AM_RANGE(0x100000, 0x100001) AM_READ(equites_spriteram_kludge_r)
-	AM_RANGE(0x100000, 0x1001ff) AM_RAM AM_BASE_MEMBER(equites_state, spriteram)
+	AM_RANGE(0x100000, 0x1001ff) AM_RAM AM_BASE_MEMBER(equites_state, m_spriteram)
 	AM_RANGE(0x140000, 0x1407ff) AM_READWRITE(mcu_r, mcu_w)	// 8-bit
 	AM_RANGE(0x180000, 0x180001) AM_READ_PORT("IN1") AM_WRITE(soundlatch_word_w) // LSB: sound latch
 	AM_RANGE(0x184000, 0x184001) AM_WRITE(equites_flip0_w)
@@ -718,9 +736,9 @@ static ADDRESS_MAP_START( equites_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x780000, 0x780001) AM_WRITE(watchdog_reset16_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( splndrbt_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( splndrbt_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x00ffff) AM_ROM
-	AM_RANGE(0x040000, 0x040fff) AM_RAM AM_BASE_MEMBER(equites_state, workram) // work RAM
+	AM_RANGE(0x040000, 0x040fff) AM_RAM AM_BASE_MEMBER(equites_state, m_workram) // work RAM
 	AM_RANGE(0x080000, 0x080001) AM_READ_PORT("IN0") // joyport [2211]
 	AM_RANGE(0x0c0000, 0x0c0001) AM_READ_PORT("IN1") AM_WRITE(splndrbt_flip0_w) // [MMLL] MM: bg color register, LL: normal screen
 	AM_RANGE(0x0c4000, 0x0c4001) AM_WRITE(mcu_halt_clear_w) // 8404 control port1
@@ -735,13 +753,13 @@ static ADDRESS_MAP_START( splndrbt_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x1c0000, 0x1c0001) AM_WRITE(splndrbt_bg_scrolly_w)
 	AM_RANGE(0x180000, 0x1807ff) AM_READWRITE(mcu_r, mcu_w)	// 8-bit
 	AM_RANGE(0x200000, 0x200fff) AM_MIRROR(0x1000) AM_READWRITE(equites_fg_videoram_r, equites_fg_videoram_w)	// 8-bit
-	AM_RANGE(0x400000, 0x4007ff) AM_RAM_WRITE(equites_bg_videoram_w) AM_BASE_MEMBER(equites_state, bg_videoram)
+	AM_RANGE(0x400000, 0x4007ff) AM_RAM_WRITE(equites_bg_videoram_w) AM_BASE_MEMBER(equites_state, m_bg_videoram)
 	AM_RANGE(0x400800, 0x400fff) AM_RAM
-	AM_RANGE(0x600000, 0x6000ff) AM_RAM AM_BASE_MEMBER(equites_state, spriteram)	// sprite RAM 0,1
-	AM_RANGE(0x600100, 0x6001ff) AM_RAM AM_BASE_MEMBER(equites_state, spriteram_2)	// sprite RAM 2 (8-bit)
+	AM_RANGE(0x600000, 0x6000ff) AM_RAM AM_BASE_MEMBER(equites_state, m_spriteram)	// sprite RAM 0,1
+	AM_RANGE(0x600100, 0x6001ff) AM_RAM AM_BASE_MEMBER(equites_state, m_spriteram_2)	// sprite RAM 2 (8-bit)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xc000) AM_READ(soundlatch_r)
 	AM_RANGE(0xc080, 0xc08d) AM_DEVWRITE("msm", msm5232_w)
@@ -754,13 +772,13 @@ static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xe000, 0xe0ff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_portmap, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( sound_portmap, AS_IO, 8 )
 	AM_RANGE(0x00e0, 0x00e5) AM_WRITE(equites_8155_w)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( mcu_map, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x03ff) AM_RAM AM_BASE_MEMBER(equites_state, mcu_ram) /* main CPU shared RAM */
+static ADDRESS_MAP_START( mcu_map, AS_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x03ff) AM_RAM AM_BASE_MEMBER(equites_state, m_mcu_ram) /* main CPU shared RAM */
 ADDRESS_MAP_END
 
 /******************************************************************************/
@@ -820,7 +838,7 @@ static INPUT_PORTS_START( equites )
 
 	/* this is actually a variable resistor */
 	PORT_START(FRQ_ADJUSTER_TAG)
-	PORT_ADJUSTER(50, "MSM5232 Clock")
+	PORT_ADJUSTER(25, "MSM5232 Clock")
 INPUT_PORTS_END
 
 /******************************************************************************/
@@ -846,7 +864,7 @@ static INPUT_PORTS_START( gekisou )
 
 	/* this is actually a variable resistor */
 	PORT_START(FRQ_ADJUSTER_TAG)
-	PORT_ADJUSTER(50, "MSM5232 Clock")
+	PORT_ADJUSTER(24, "MSM5232 Clock")
 INPUT_PORTS_END
 
 /******************************************************************************/
@@ -882,7 +900,7 @@ static INPUT_PORTS_START( bullfgtr )
 
 	/* this is actually a variable resistor */
 	PORT_START(FRQ_ADJUSTER_TAG)
-	PORT_ADJUSTER(50, "MSM5232 Clock")
+	PORT_ADJUSTER(33, "MSM5232 Clock")
 INPUT_PORTS_END
 
 /******************************************************************************/
@@ -919,7 +937,7 @@ static INPUT_PORTS_START( kouyakyu )
 
 	/* this is actually a variable resistor */
 	PORT_START(FRQ_ADJUSTER_TAG)
-	PORT_ADJUSTER(50, "MSM5232 Clock")
+	PORT_ADJUSTER(33, "MSM5232 Clock")
 INPUT_PORTS_END
 
 /******************************************************************************/
@@ -955,7 +973,7 @@ static INPUT_PORTS_START( splndrbt )
 
 	/* this is actually a variable resistor */
 	PORT_START(FRQ_ADJUSTER_TAG)
-	PORT_ADJUSTER(50, "MSM5232 Clock")
+	PORT_ADJUSTER(28, "MSM5232 Clock")
 INPUT_PORTS_END
 
 /******************************************************************************/
@@ -1024,7 +1042,7 @@ static INPUT_PORTS_START( hvoltage )
 
 	/* this is actually a variable resistor */
 	PORT_START(FRQ_ADJUSTER_TAG)
-	PORT_ADJUSTER(50, "MSM5232 Clock")
+	PORT_ADJUSTER(27, "MSM5232 Clock")
 INPUT_PORTS_END
 
 /******************************************************************************/
@@ -1184,60 +1202,60 @@ MACHINE_CONFIG_END
 
 static MACHINE_START( equites )
 {
-	equites_state *state = machine->driver_data<equites_state>();
+	equites_state *state = machine.driver_data<equites_state>();
 
-	state->mcu = machine->device("mcu");
-	state->audio_cpu = machine->device("audiocpu");
-	state->msm = machine->device("msm");
-	state->dac_1 = machine->device("dac1");
-	state->dac_2 = machine->device("dac2");
+	state->m_mcu = machine.device("mcu");
+	state->m_audio_cpu = machine.device("audiocpu");
+	state->m_msm = machine.device<msm5232_device>("msm");
+	state->m_dac_1 = machine.device("dac1");
+	state->m_dac_2 = machine.device("dac2");
 
-	state_save_register_global(machine, state->fg_char_bank);
-	state_save_register_global(machine, state->bgcolor);
-	state_save_register_global(machine, state->splndrbt_bg_scrollx);
-	state_save_register_global(machine, state->splndrbt_bg_scrolly);
-	state_save_register_global(machine, state->sound_prom_address);
-	state_save_register_global(machine, state->dac_latch);
-	state_save_register_global(machine, state->eq8155_port_b);
-	state_save_register_global(machine, state->eq8155_port_a);
-	state_save_register_global(machine, state->eq8155_port_c);
-	state_save_register_global(machine, state->ay_port_a);
-	state_save_register_global(machine, state->ay_port_b);
-	state_save_register_global(machine, state->eq_cymbal_ctrl);
-	state_save_register_global(machine, state->cymvol);
-	state_save_register_global(machine, state->hihatvol);
-	state_save_register_global(machine, state->timer_count);
-	state_save_register_global(machine, state->unknown_bit);
+	state->save_item(NAME(state->m_fg_char_bank));
+	state->save_item(NAME(state->m_bgcolor));
+	state->save_item(NAME(state->m_splndrbt_bg_scrollx));
+	state->save_item(NAME(state->m_splndrbt_bg_scrolly));
+	state->save_item(NAME(state->m_sound_prom_address));
+	state->save_item(NAME(state->m_dac_latch));
+	state->save_item(NAME(state->m_eq8155_port_b));
+	state->save_item(NAME(state->m_eq8155_port_a));
+	state->save_item(NAME(state->m_eq8155_port_c));
+	state->save_item(NAME(state->m_ay_port_a));
+	state->save_item(NAME(state->m_ay_port_b));
+	state->save_item(NAME(state->m_eq_cymbal_ctrl));
+	state->save_item(NAME(state->m_cymvol));
+	state->save_item(NAME(state->m_hihatvol));
+	state->save_item(NAME(state->m_timer_count));
+	state->save_item(NAME(state->m_unknown_bit));
 #if POPDRUMKIT
-	state_save_register_global(machine, state->hihat);
-	state_save_register_global(machine, state->cymbal);
+	state->save_item(NAME(state->m_hihat));
+	state->save_item(NAME(state->m_cymbal));
 #endif
 }
 
 static MACHINE_RESET( equites )
 {
-	equites_state *state = machine->driver_data<equites_state>();
+	equites_state *state = machine.driver_data<equites_state>();
 
 	flip_screen_set(machine, 0);
 
-	state->fg_char_bank = 0;
-	state->bgcolor = 0;
-	state->splndrbt_bg_scrollx = 0;
-	state->splndrbt_bg_scrolly = 0;
-	state->sound_prom_address = 0;
-	state->dac_latch = 0;
-	state->eq8155_port_b = 0;
-	state->eq8155_port_a = 0;
-	state->eq8155_port_c = 0;
-	state->ay_port_a = 0;
-	state->ay_port_b = 0;
-	state->eq_cymbal_ctrl = 0;
-	state->cymvol = 0.0;
-	state->hihatvol = 0.0;
-	state->timer_count = 0;
-	state->unknown_bit = 0;
+	state->m_fg_char_bank = 0;
+	state->m_bgcolor = 0;
+	state->m_splndrbt_bg_scrollx = 0;
+	state->m_splndrbt_bg_scrolly = 0;
+	state->m_sound_prom_address = 0;
+	state->m_dac_latch = 0;
+	state->m_eq8155_port_b = 0;
+	state->m_eq8155_port_a = 0;
+	state->m_eq8155_port_c = 0;
+	state->m_ay_port_a = 0;
+	state->m_ay_port_b = 0;
+	state->m_eq_cymbal_ctrl = 0;
+	state->m_cymvol = 0.0;
+	state->m_hihatvol = 0.0;
+	state->m_timer_count = 0;
+	state->m_unknown_bit = 0;
 #if POPDRUMKIT
-	state->hihat = state->cymbal = 0;
+	state->m_hihat = state->m_cymbal = 0;
 #endif
 }
 
@@ -1247,7 +1265,7 @@ static MACHINE_CONFIG_START( equites, equites_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M68000, XTAL_12MHz/4) /* 68000P8 running at 3mhz! verified on pcb */
 	MCFG_CPU_PROGRAM_MAP(equites_map)
-	MCFG_CPU_VBLANK_INT_HACK(equites_interrupt, 2)
+	MCFG_TIMER_ADD_SCANLINE("scantimer", equites_scanline, "screen", 0, 1)
 
 	MCFG_FRAGMENT_ADD(common_sound)
 
@@ -1260,12 +1278,12 @@ static MACHINE_CONFIG_START( equites, equites_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 3*8, 29*8-1)
+	MCFG_SCREEN_UPDATE(equites)
 
 	MCFG_GFXDECODE(equites)
 	MCFG_PALETTE_LENGTH(0x180)
 	MCFG_PALETTE_INIT(equites)
 	MCFG_VIDEO_START(equites)
-	MCFG_VIDEO_UPDATE(equites)
 
 	MCFG_MACHINE_START(equites)
 	MCFG_MACHINE_RESET(equites)
@@ -1285,7 +1303,7 @@ static MACHINE_CONFIG_START( splndrbt, equites_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M68000, XTAL_24MHz/4) /* 68000P8 running at 6mhz, verified on pcb */
 	MCFG_CPU_PROGRAM_MAP(splndrbt_map)
-	MCFG_CPU_VBLANK_INT_HACK(equites_interrupt, 2)
+	MCFG_TIMER_ADD_SCANLINE("scantimer", splndrbt_scanline, "screen", 0, 1)
 
 	MCFG_FRAGMENT_ADD(common_sound)
 
@@ -1298,12 +1316,12 @@ static MACHINE_CONFIG_START( splndrbt, equites_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 28*8-1)
+	MCFG_SCREEN_UPDATE(splndrbt)
 
 	MCFG_GFXDECODE(splndrbt)
 	MCFG_PALETTE_LENGTH(0x280)
 	MCFG_PALETTE_INIT(splndrbt)
 	MCFG_VIDEO_START(splndrbt)
-	MCFG_VIDEO_UPDATE(splndrbt)
 
 	MCFG_MACHINE_START(equites)
 	MCFG_MACHINE_RESET(equites)
@@ -1851,9 +1869,9 @@ ROM_END
 /******************************************************************************/
 // Initializations
 
-static void unpack_block( running_machine *machine, const char *region, int offset, int size )
+static void unpack_block( running_machine &machine, const char *region, int offset, int size )
 {
-	UINT8 *rom = machine->region(region)->base();
+	UINT8 *rom = machine.region(region)->base();
 	int i;
 
 	for (i = 0; i < size; ++i)
@@ -1863,7 +1881,7 @@ static void unpack_block( running_machine *machine, const char *region, int offs
 	}
 }
 
-static void unpack_region( running_machine *machine, const char *region )
+static void unpack_region( running_machine &machine, const char *region )
 {
 	unpack_block(machine, region, 0x0000, 0x2000);
 	unpack_block(machine, region, 0x4000, 0x2000);
@@ -1894,8 +1912,8 @@ static DRIVER_INIT( gekisou )
 	unpack_region(machine, "gfx3");
 
 	// install special handlers for unknown device (protection?)
-	memory_install_write16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x580000, 0x580001, 0, 0, gekisou_unknown_0_w);
-	memory_install_write16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x5a0000, 0x5a0001, 0, 0, gekisou_unknown_1_w);
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0x580000, 0x580001, FUNC(gekisou_unknown_0_w));
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0x5a0000, 0x5a0001, FUNC(gekisou_unknown_1_w));
 }
 
 static DRIVER_INIT( splndrbt )
@@ -1908,7 +1926,7 @@ static DRIVER_INIT( hvoltage )
 	unpack_region(machine, "gfx3");
 
 #if HVOLTAGE_DEBUG
-	memory_install_read16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x000038, 0x000039, 0, 0, hvoltage_debug_r);
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x000038, 0x000039, FUNC(hvoltage_debug_r));
 #endif
 }
 
