@@ -28,96 +28,110 @@ Notes:
 #include "cpu/z80/z80.h"
 #include "sound/ay8910.h"
 #include "machine/nvram.h"
+#include "video/resnet.h"
 
-/* it uses the same palette layout as in naughtyb */
-PALETTE_INIT( naughtyb );
 
-static int palreg = 0;
-static int gfx_bank = 0;
-static int question_bank = 0;
+class ettrivia_state : public driver_device
+{
+public:
+	ettrivia_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-static int b000_val = 0;
-static int b000_ret = 0;
-static int b800_prev = 0;
+	int m_palreg;
+	int m_gfx_bank;
+	int m_question_bank;
+	int m_b000_val;
+	int m_b000_ret;
+	int m_b800_prev;
+	UINT8 *m_bg_videoram;
+	UINT8 *m_fg_videoram;
+	tilemap_t *m_bg_tilemap;
+	tilemap_t *m_fg_tilemap;
+};
 
-static UINT8 *bg_videoram, *fg_videoram;
-static tilemap_t *bg_tilemap, *fg_tilemap;
 
 static WRITE8_HANDLER( ettrivia_fg_w )
 {
-	fg_videoram[offset] = data;
-	tilemap_mark_tile_dirty(fg_tilemap,offset);
+	ettrivia_state *state = space->machine().driver_data<ettrivia_state>();
+	state->m_fg_videoram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_fg_tilemap,offset);
 }
 
 static WRITE8_HANDLER( ettrivia_bg_w )
 {
-	bg_videoram[offset] = data;
-	tilemap_mark_tile_dirty(bg_tilemap,offset);
+	ettrivia_state *state = space->machine().driver_data<ettrivia_state>();
+	state->m_bg_videoram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_bg_tilemap,offset);
 }
 
 static WRITE8_HANDLER( ettrivia_control_w )
 {
-	tilemap_mark_all_tiles_dirty_all(space->machine);
+	ettrivia_state *state = space->machine().driver_data<ettrivia_state>();
+	tilemap_mark_all_tiles_dirty_all(space->machine());
 
-	palreg  = (data >> 1) & 3;
-	gfx_bank = (data >> 2) & 1;
+	state->m_palreg  = (data >> 1) & 3;
+	state->m_gfx_bank = (data >> 2) & 1;
 
-	question_bank = (data >> 3) & 3;
+	state->m_question_bank = (data >> 3) & 3;
 
-	coin_counter_w(space->machine, 0, data & 0x80);
+	coin_counter_w(space->machine(), 0, data & 0x80);
 
-	flip_screen_set(space->machine, data & 1);
+	flip_screen_set(space->machine(), data & 1);
 }
 
 static READ8_HANDLER( ettrivia_question_r )
 {
-	UINT8 *QUESTIONS = space->machine->region("user1")->base();
-	return QUESTIONS[offset + 0x10000 * question_bank];
+	ettrivia_state *state = space->machine().driver_data<ettrivia_state>();
+	UINT8 *QUESTIONS = space->machine().region("user1")->base();
+	return QUESTIONS[offset + 0x10000 * state->m_question_bank];
 }
 
 static WRITE8_HANDLER( b000_w )
 {
-	b000_val = data;
+	ettrivia_state *state = space->machine().driver_data<ettrivia_state>();
+	state->m_b000_val = data;
 }
 
 static READ8_HANDLER( b000_r )
 {
-	if(b800_prev)
-		return b000_ret;
+	ettrivia_state *state = space->machine().driver_data<ettrivia_state>();
+	if(state->m_b800_prev)
+		return state->m_b000_ret;
 	else
-		return b000_val;
+		return state->m_b000_val;
 }
 
 static WRITE8_HANDLER( b800_w )
 {
+	ettrivia_state *state = space->machine().driver_data<ettrivia_state>();
 	switch(data)
 	{
 		/* special case to return the value written to 0xb000 */
 		/* does it reset the chips too ? */
 		case 0:	break;
-		case 0xc4: b000_ret = ay8910_r(space->machine->device("ay1"), 0);	break;
-		case 0x94: b000_ret = ay8910_r(space->machine->device("ay2"), 0);	break;
-		case 0x86: b000_ret = ay8910_r(space->machine->device("ay3"), 0);	break;
+		case 0xc4: state->m_b000_ret = ay8910_r(space->machine().device("ay1"), 0);	break;
+		case 0x94: state->m_b000_ret = ay8910_r(space->machine().device("ay2"), 0);	break;
+		case 0x86: state->m_b000_ret = ay8910_r(space->machine().device("ay3"), 0);	break;
 
 		case 0x80:
-			switch(b800_prev)
+			switch(state->m_b800_prev)
 			{
-				case 0xe0: ay8910_address_w(space->machine->device("ay1"),0,b000_val);	break;
-				case 0x98: ay8910_address_w(space->machine->device("ay2"),0,b000_val);	break;
-				case 0x83: ay8910_address_w(space->machine->device("ay3"),0,b000_val);	break;
+				case 0xe0: ay8910_address_w(space->machine().device("ay1"),0,state->m_b000_val);	break;
+				case 0x98: ay8910_address_w(space->machine().device("ay2"),0,state->m_b000_val);	break;
+				case 0x83: ay8910_address_w(space->machine().device("ay3"),0,state->m_b000_val);	break;
 
-				case 0xa0: ay8910_data_w(space->machine->device("ay1"),0,b000_val);	break;
-				case 0x88: ay8910_data_w(space->machine->device("ay2"),0,b000_val);	break;
-				case 0x81: ay8910_data_w(space->machine->device("ay3"),0,b000_val);	break;
+				case 0xa0: ay8910_data_w(space->machine().device("ay1"),0,state->m_b000_val);	break;
+				case 0x88: ay8910_data_w(space->machine().device("ay2"),0,state->m_b000_val);	break;
+				case 0x81: ay8910_data_w(space->machine().device("ay3"),0,state->m_b000_val);	break;
 
 			}
 		break;
 	}
 
-	b800_prev = data;
+	state->m_b800_prev = data;
 }
 
-static ADDRESS_MAP_START( cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( cpu_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0x87ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x9000, 0x9000) AM_WRITE(ettrivia_control_w)
@@ -125,11 +139,11 @@ static ADDRESS_MAP_START( cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xa000, 0xa000) AM_WRITENOP
 	AM_RANGE(0xb000, 0xb000) AM_READ(b000_r) AM_WRITE(b000_w)
 	AM_RANGE(0xb800, 0xb800) AM_WRITE(b800_w)
-	AM_RANGE(0xc000, 0xc7ff) AM_RAM_WRITE(ettrivia_fg_w) AM_BASE(&fg_videoram)
-	AM_RANGE(0xe000, 0xe7ff) AM_RAM_WRITE(ettrivia_bg_w) AM_BASE(&bg_videoram)
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM_WRITE(ettrivia_fg_w) AM_BASE_MEMBER(ettrivia_state, m_fg_videoram)
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM_WRITE(ettrivia_bg_w) AM_BASE_MEMBER(ettrivia_state, m_bg_videoram)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( io_map, AS_IO, 8 )
 	AM_RANGE(0x0000, 0xffff) AM_READ(ettrivia_question_r)
 ADDRESS_MAP_END
 
@@ -174,38 +188,79 @@ static GFXDECODE_START( ettrivia )
 	GFXDECODE_ENTRY( "gfx2", 0, charlayout, 32*4, 32 )
 GFXDECODE_END
 
-INLINE void get_tile_info(running_machine *machine, tile_data *tileinfo, int tile_index, UINT8 *vidram, int gfx_code)
+INLINE void get_tile_info(running_machine &machine, tile_data *tileinfo, int tile_index, UINT8 *vidram, int gfx_code)
 {
+	ettrivia_state *state = machine.driver_data<ettrivia_state>();
 	int code = vidram[tile_index];
-	int color = (code >> 5) + 8 * palreg;
+	int color = (code >> 5) + 8 * state->m_palreg;
 
-	code += gfx_bank * 0x100;
+	code += state->m_gfx_bank * 0x100;
 
 	SET_TILE_INFO(gfx_code,code,color,0);
 }
 
 static TILE_GET_INFO( get_tile_info_bg )
 {
-	get_tile_info(machine, tileinfo, tile_index, bg_videoram, 0);
+	ettrivia_state *state = machine.driver_data<ettrivia_state>();
+	get_tile_info(machine, tileinfo, tile_index, state->m_bg_videoram, 0);
 }
 
 static TILE_GET_INFO( get_tile_info_fg )
 {
-	get_tile_info(machine, tileinfo, tile_index, fg_videoram, 1);
+	ettrivia_state *state = machine.driver_data<ettrivia_state>();
+	get_tile_info(machine, tileinfo, tile_index, state->m_fg_videoram, 1);
+}
+
+static PALETTE_INIT( ettrivia )
+{
+	static const int resistances[2] = { 270, 130 };
+	double weights[2];
+	int i;
+
+	/* compute the color output resistor weights */
+	compute_resistor_weights(0, 255, -1.0,
+			2, resistances, weights, 0, 0,
+			2, resistances, weights, 0, 0,
+			0, 0, 0, 0, 0);
+
+	for (i = 0;i < machine.total_colors(); i++)
+	{
+		int bit0, bit1;
+		int r, g, b;
+
+		/* red component */
+		bit0 = (color_prom[i] >> 0) & 0x01;
+		bit1 = (color_prom[i+0x100] >> 0) & 0x01;
+		r = combine_2_weights(weights, bit0, bit1);
+
+		/* green component */
+		bit0 = (color_prom[i] >> 2) & 0x01;
+		bit1 = (color_prom[i+0x100] >> 2) & 0x01;
+		g = combine_2_weights(weights, bit0, bit1);
+
+		/* blue component */
+		bit0 = (color_prom[i] >> 1) & 0x01;
+		bit1 = (color_prom[i+0x100] >> 1) & 0x01;
+		b = combine_2_weights(weights, bit0, bit1);
+
+		palette_set_color(machine, BITSWAP8(i,5,7,6,2,1,0,4,3), MAKE_RGB(r, g, b));
+	}
 }
 
 static VIDEO_START( ettrivia )
 {
-	bg_tilemap = tilemap_create( machine, get_tile_info_bg,tilemap_scan_rows,8,8,64,32 );
-	fg_tilemap = tilemap_create( machine, get_tile_info_fg,tilemap_scan_rows,8,8,64,32 );
+	ettrivia_state *state = machine.driver_data<ettrivia_state>();
+	state->m_bg_tilemap = tilemap_create( machine, get_tile_info_bg,tilemap_scan_rows,8,8,64,32 );
+	state->m_fg_tilemap = tilemap_create( machine, get_tile_info_fg,tilemap_scan_rows,8,8,64,32 );
 
-	tilemap_set_transparent_pen(fg_tilemap,0);
+	tilemap_set_transparent_pen(state->m_fg_tilemap,0);
 }
 
-static VIDEO_UPDATE( ettrivia )
+static SCREEN_UPDATE( ettrivia )
 {
-	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
-	tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
+	ettrivia_state *state = screen->machine().driver_data<ettrivia_state>();
+	tilemap_draw(bitmap,cliprect,state->m_bg_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,state->m_fg_tilemap,0,0);
 	return 0;
 }
 
@@ -232,13 +287,13 @@ static const ay8910_interface ay8912_interface_3 =
 
 static INTERRUPT_GEN( ettrivia_interrupt )
 {
-	if( input_port_read(device->machine, "COIN") & 0x01 )
-		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
+	if( input_port_read(device->machine(), "COIN") & 0x01 )
+		device_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 	else
-		cpu_set_input_line(device, 0, HOLD_LINE);
+		device_set_input_line(device, 0, HOLD_LINE);
 }
 
-static MACHINE_CONFIG_START( ettrivia, driver_device )
+static MACHINE_CONFIG_START( ettrivia, ettrivia_state )
 	MCFG_CPU_ADD("maincpu", Z80,12000000/4-48000) //should be ok, it gives the 300 interrupts expected
 	MCFG_CPU_PROGRAM_MAP(cpu_map)
 	MCFG_CPU_IO_MAP(io_map)
@@ -253,13 +308,13 @@ static MACHINE_CONFIG_START( ettrivia, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 28*8-1)
+	MCFG_SCREEN_UPDATE(ettrivia)
 
 	MCFG_GFXDECODE(ettrivia)
 	MCFG_PALETTE_LENGTH(256)
 
-	MCFG_PALETTE_INIT(naughtyb)
+	MCFG_PALETTE_INIT(ettrivia)
 	MCFG_VIDEO_START(ettrivia)
-	MCFG_VIDEO_UPDATE(ettrivia)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
