@@ -65,26 +65,11 @@
 #include "cpu/m6502/m6502.h"
 #include "sound/dac.h"
 #include "sound/2151intf.h"
+#include "machine/nvram.h"
 #include "includes/exterm.h"
 
 
 
-/*************************************
- *
- *  Globals
- *
- *************************************/
-
-static UINT8 aimpos[2];
-static UINT8 trackball_old[2];
-
-static UINT8 master_sound_latch;
-static UINT8 slave_sound_latch;
-static UINT8 sound_control;
-static UINT8 dac_value[2];
-
-
-
 /*************************************
  *
  *  Master/slave communications
@@ -93,13 +78,13 @@ static UINT8 dac_value[2];
 
 static WRITE16_HANDLER( exterm_host_data_w )
 {
-	tms34010_host_w(space->machine->device("slave"), offset / TOWORD(0x00100000), data);
+	tms34010_host_w(space->machine().device("slave"), offset / TOWORD(0x00100000), data);
 }
 
 
 static READ16_HANDLER( exterm_host_data_r )
 {
-	return tms34010_host_r(space->machine->device("slave"), offset / TOWORD(0x00100000));
+	return tms34010_host_r(space->machine().device("slave"), offset / TOWORD(0x00100000));
 }
 
 
@@ -110,30 +95,31 @@ static READ16_HANDLER( exterm_host_data_r )
  *
  *************************************/
 
-static UINT16 exterm_trackball_port_r(const address_space *space, int which, UINT16 mem_mask)
+static UINT16 exterm_trackball_port_r(address_space *space, int which, UINT16 mem_mask)
 {
+	exterm_state *state = space->machine().driver_data<exterm_state>();
 	UINT16 port;
 
 	/* Read the fake input port */
-	UINT8 trackball_pos = input_port_read(space->machine, which ? "DIAL1" : "DIAL0");
+	UINT8 trackball_pos = input_port_read(space->machine(), which ? "DIAL1" : "DIAL0");
 
 	/* Calculate the change from the last position. */
-	UINT8 trackball_diff = trackball_old[which] - trackball_pos;
+	UINT8 trackball_diff = state->m_trackball_old[which] - trackball_pos;
 
 	/* Store the new position for the next comparision. */
-	trackball_old[which] = trackball_pos;
+	state->m_trackball_old[which] = trackball_pos;
 
 	/* Move the sign bit to the high bit of the 6-bit trackball count. */
 	if (trackball_diff & 0x80)
 		trackball_diff |= 0x20;
 
 	/* Keep adding the changes.  The counters will be reset later by a hardware write. */
-	aimpos[which] = (aimpos[which] + trackball_diff) & 0x3f;
+	state->m_aimpos[which] = (state->m_aimpos[which] + trackball_diff) & 0x3f;
 
 	/* Combine it with the standard input bits */
-	port = which ? input_port_read(space->machine, "P2") : input_port_read(space->machine, "P1");
+	port = which ? input_port_read(space->machine(), "P2") : input_port_read(space->machine(), "P1");
 
-	return (port & 0xc0ff) | (aimpos[which] << 8);
+	return (port & 0xc0ff) | (state->m_aimpos[which] << 8);
 }
 
 
@@ -158,37 +144,38 @@ static READ16_HANDLER( exterm_input_port_1_r )
 
 static WRITE16_HANDLER( exterm_output_port_0_w )
 {
+	exterm_state *state = space->machine().driver_data<exterm_state>();
 	/* All the outputs are activated on the rising edge */
-	static UINT16 last = 0;
 
 	if (ACCESSING_BITS_0_7)
 	{
 		/* Bit 0-1= Resets analog controls */
-		if ((data & 0x0001) && !(last & 0x0001))
-			aimpos[0] = 0;
-		if ((data & 0x0002) && !(last & 0x0002))
-			aimpos[1] = 0;
+		if ((data & 0x0001) && !(state->m_last & 0x0001))
+			state->m_aimpos[0] = 0;
+		if ((data & 0x0002) && !(state->m_last & 0x0002))
+			state->m_aimpos[1] = 0;
 	}
 
 	if (ACCESSING_BITS_8_15)
 	{
 		/* Bit 13 = Resets the slave CPU */
-		if ((data & 0x2000) && !(last & 0x2000))
-			cputag_set_input_line(space->machine, "slave", INPUT_LINE_RESET, PULSE_LINE);
+		if ((data & 0x2000) && !(state->m_last & 0x2000))
+			cputag_set_input_line(space->machine(), "slave", INPUT_LINE_RESET, PULSE_LINE);
 
 		/* Bits 14-15 = Coin counters */
-		coin_counter_w(space->machine, 0, data & 0x8000);
-		coin_counter_w(space->machine, 1, data & 0x4000);
+		coin_counter_w(space->machine(), 0, data & 0x8000);
+		coin_counter_w(space->machine(), 1, data & 0x4000);
 	}
 
-	COMBINE_DATA(&last);
+	COMBINE_DATA(&state->m_last);
 }
 
 
 static TIMER_CALLBACK( sound_delayed_w )
 {
+	exterm_state *state = machine.driver_data<exterm_state>();
 	/* data is latched independently for both sound CPUs */
-	master_sound_latch = slave_sound_latch = param;
+	state->m_master_sound_latch = state->m_slave_sound_latch = param;
 	cputag_set_input_line(machine, "audiocpu", M6502_IRQ_LINE, ASSERT_LINE);
 	cputag_set_input_line(machine, "audioslave", M6502_IRQ_LINE, ASSERT_LINE);
 }
@@ -197,7 +184,7 @@ static TIMER_CALLBACK( sound_delayed_w )
 static WRITE16_HANDLER( sound_latch_w )
 {
 	if (ACCESSING_BITS_0_7)
-		timer_call_after_resynch(space->machine, NULL, data & 0xff, sound_delayed_w);
+		space->machine().scheduler().synchronize(FUNC(sound_delayed_w), data & 0xff);
 }
 
 
@@ -210,16 +197,18 @@ static WRITE16_HANDLER( sound_latch_w )
 
 static TIMER_DEVICE_CALLBACK( master_sound_nmi_callback )
 {
+	exterm_state *state = timer.machine().driver_data<exterm_state>();
 	/* bit 0 of the sound control determines if the NMI is actually delivered */
-	if (sound_control & 0x01)
-		cputag_set_input_line(timer.machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
+	if (state->m_sound_control & 0x01)
+		cputag_set_input_line(timer.machine(), "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
 }
 
 
 static WRITE8_DEVICE_HANDLER( ym2151_data_latch_w )
 {
+	exterm_state *state = device->machine().driver_data<exterm_state>();
 	/* bit 7 of the sound control selects which port */
-	ym2151_w(device, sound_control >> 7, data);
+	ym2151_w(device, state->m_sound_control >> 7, data);
 }
 
 
@@ -228,46 +217,50 @@ static WRITE8_HANDLER( sound_nmi_rate_w )
 	/* rate is controlled by the value written here */
 	/* this value is latched into up-counters, which are clocked at the */
 	/* input clock / 256 */
-	attotime nmi_rate = attotime_mul(ATTOTIME_IN_HZ(4000000), 4096 * (256 - data));
-	timer_device *nmi_timer = space->machine->device<timer_device>("snd_nmi_timer");
+	attotime nmi_rate = attotime::from_hz(4000000) * (4096 * (256 - data));
+	timer_device *nmi_timer = space->machine().device<timer_device>("snd_nmi_timer");
 	nmi_timer->adjust(nmi_rate, 0, nmi_rate);
 }
 
 
 static READ8_HANDLER( sound_master_latch_r )
 {
+	exterm_state *state = space->machine().driver_data<exterm_state>();
 	/* read latch and clear interrupt */
-	cputag_set_input_line(space->machine, "audiocpu", M6502_IRQ_LINE, CLEAR_LINE);
-	return master_sound_latch;
+	cputag_set_input_line(space->machine(), "audiocpu", M6502_IRQ_LINE, CLEAR_LINE);
+	return state->m_master_sound_latch;
 }
 
 
 static READ8_HANDLER( sound_slave_latch_r )
 {
+	exterm_state *state = space->machine().driver_data<exterm_state>();
 	/* read latch and clear interrupt */
-	cputag_set_input_line(space->machine, "audioslave", M6502_IRQ_LINE, CLEAR_LINE);
-	return slave_sound_latch;
+	cputag_set_input_line(space->machine(), "audioslave", M6502_IRQ_LINE, CLEAR_LINE);
+	return state->m_slave_sound_latch;
 }
 
 
 static WRITE8_DEVICE_HANDLER( sound_slave_dac_w )
 {
+	exterm_state *state = device->machine().driver_data<exterm_state>();
 	/* DAC A is used to modulate DAC B */
-	dac_value[offset & 1] = data;
-	dac_data_16_w(device, (dac_value[0] ^ 0xff) * dac_value[1]);
+	state->m_dac_value[offset & 1] = data;
+	dac_data_16_w(device, (state->m_dac_value[0] ^ 0xff) * state->m_dac_value[1]);
 }
 
 
 static READ8_HANDLER( sound_nmi_to_slave_r )
 {
 	/* a read from here triggers an NMI pulse to the slave */
-	cputag_set_input_line(space->machine, "audioslave", INPUT_LINE_NMI, PULSE_LINE);
+	cputag_set_input_line(space->machine(), "audioslave", INPUT_LINE_NMI, PULSE_LINE);
 	return 0xff;
 }
 
 
 static WRITE8_HANDLER( sound_control_w )
 {
+	exterm_state *state = space->machine().driver_data<exterm_state>();
 /*
     D7 = to S4-15
     D6 = to S4-12
@@ -275,7 +268,7 @@ static WRITE8_HANDLER( sound_control_w )
     D1 = to LED
     D0 = enable NMI timer
 */
-	sound_control = data;
+	state->m_sound_control = data;
 }
 
 
@@ -286,9 +279,9 @@ static WRITE8_HANDLER( sound_control_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( master_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( master_map, AS_PROGRAM, 16 )
 	AM_RANGE(0xc0000000, 0xc00001ff) AM_READWRITE(tms34010_io_register_r, tms34010_io_register_w)
-	AM_RANGE(0x00000000, 0x000fffff) AM_MIRROR(0xfc700000) AM_RAM AM_BASE(&exterm_master_videoram)
+	AM_RANGE(0x00000000, 0x000fffff) AM_MIRROR(0xfc700000) AM_RAM AM_BASE_MEMBER(exterm_state, m_master_videoram)
 	AM_RANGE(0x00800000, 0x00bfffff) AM_MIRROR(0xfc400000) AM_RAM
 	AM_RANGE(0x01000000, 0x013fffff) AM_MIRROR(0xfc000000) AM_READWRITE(exterm_host_data_r, exterm_host_data_w)
 	AM_RANGE(0x01400000, 0x0143ffff) AM_MIRROR(0xfc000000) AM_READ(exterm_input_port_0_r)
@@ -298,14 +291,14 @@ static ADDRESS_MAP_START( master_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x01580000, 0x015bffff) AM_MIRROR(0xfc000000) AM_WRITE(sound_latch_w)
 	AM_RANGE(0x015c0000, 0x015fffff) AM_MIRROR(0xfc000000) AM_WRITE(watchdog_reset16_w)
 	AM_RANGE(0x01800000, 0x01807fff) AM_MIRROR(0xfc7f8000) AM_RAM_WRITE(paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0x02800000, 0x02807fff) AM_MIRROR(0xfc7f8000) AM_RAM AM_BASE_SIZE_GENERIC(nvram)
+	AM_RANGE(0x02800000, 0x02807fff) AM_MIRROR(0xfc7f8000) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x03000000, 0x03ffffff) AM_MIRROR(0xfc000000) AM_ROM AM_REGION("user1", 0)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( slave_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( slave_map, AS_PROGRAM, 16 )
 	AM_RANGE(0xc0000000, 0xc00001ff) AM_READWRITE(tms34010_io_register_r, tms34010_io_register_w)
-	AM_RANGE(0x00000000, 0x000fffff) AM_MIRROR(0xfbf00000) AM_RAM AM_BASE(&exterm_slave_videoram)
+	AM_RANGE(0x00000000, 0x000fffff) AM_MIRROR(0xfbf00000) AM_RAM AM_BASE_MEMBER(exterm_state, m_slave_videoram)
 	AM_RANGE(0x04000000, 0x047fffff) AM_MIRROR(0xfb800000) AM_RAM
 ADDRESS_MAP_END
 
@@ -317,7 +310,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( sound_master_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_master_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_MIRROR(0x1800) AM_RAM
 	AM_RANGE(0x4000, 0x5fff) AM_DEVWRITE("ymsnd", ym2151_data_latch_w)
 	AM_RANGE(0x6000, 0x67ff) AM_WRITE(sound_nmi_rate_w)
@@ -329,7 +322,7 @@ static ADDRESS_MAP_START( sound_master_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( sound_slave_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_slave_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_MIRROR(0x3800) AM_RAM
 	AM_RANGE(0x4000, 0x5fff) AM_READ(sound_slave_latch_r)
 	AM_RANGE(0x8000, 0xbfff) AM_DEVWRITE("dac", sound_slave_dac_w)
@@ -446,48 +439,48 @@ static const tms34010_config slave_config =
  *
  *************************************/
 
-static MACHINE_DRIVER_START( exterm )
+static MACHINE_CONFIG_START( exterm, exterm_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", TMS34010, 40000000)
-	MDRV_CPU_CONFIG(master_config)
-	MDRV_CPU_PROGRAM_MAP(master_map)
+	MCFG_CPU_ADD("maincpu", TMS34010, 40000000)
+	MCFG_CPU_CONFIG(master_config)
+	MCFG_CPU_PROGRAM_MAP(master_map)
 
-	MDRV_CPU_ADD("slave", TMS34010, 40000000)
-	MDRV_CPU_CONFIG(slave_config)
-	MDRV_CPU_PROGRAM_MAP(slave_map)
+	MCFG_CPU_ADD("slave", TMS34010, 40000000)
+	MCFG_CPU_CONFIG(slave_config)
+	MCFG_CPU_PROGRAM_MAP(slave_map)
 
-	MDRV_CPU_ADD("audiocpu", M6502, 2000000)
-	MDRV_CPU_PROGRAM_MAP(sound_master_map)
+	MCFG_CPU_ADD("audiocpu", M6502, 2000000)
+	MCFG_CPU_PROGRAM_MAP(sound_master_map)
 
-	MDRV_CPU_ADD("audioslave", M6502, 2000000)
-	MDRV_CPU_PROGRAM_MAP(sound_slave_map)
+	MCFG_CPU_ADD("audioslave", M6502, 2000000)
+	MCFG_CPU_PROGRAM_MAP(sound_slave_map)
 
-	MDRV_QUANTUM_TIME(HZ(6000))
+	MCFG_QUANTUM_TIME(attotime::from_hz(6000))
 
-	MDRV_NVRAM_HANDLER(generic_0fill)
+	MCFG_NVRAM_ADD_0FILL("nvram")
 
-	MDRV_TIMER_ADD("snd_nmi_timer", master_sound_nmi_callback)
+	MCFG_TIMER_ADD("snd_nmi_timer", master_sound_nmi_callback)
 
 	/* video hardware */
-	MDRV_PALETTE_LENGTH(2048+32768)
+	MCFG_PALETTE_LENGTH(2048+32768)
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_RAW_PARAMS(40000000/8, 318, 0, 256, 264, 0, 240)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_RAW_PARAMS(40000000/8, 318, 0, 256, 264, 0, 240)
+	MCFG_SCREEN_UPDATE(tms340x0)
 
-	MDRV_PALETTE_INIT(exterm)
-	MDRV_VIDEO_UPDATE(tms340x0)
+	MCFG_PALETTE_INIT(exterm)
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("dac", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
+	MCFG_SOUND_ADD("dac", DAC, 0)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
-	MDRV_SOUND_ADD("ymsnd", YM2151, 4000000)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("ymsnd", YM2151, 4000000)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_CONFIG_END
 
 
 
