@@ -36,10 +36,10 @@ inputs + notes by stephh
 
 static INPUT_CHANGED( coin_inserted )
 {
-	fcombat_state *state = field->port->machine->driver_data<fcombat_state>();
+	fcombat_state *state = field.machine().driver_data<fcombat_state>();
 
 	/* coin insertion causes an NMI */
-	cpu_set_input_line(state->maincpu, INPUT_LINE_NMI, newval ? CLEAR_LINE : ASSERT_LINE);
+	device_set_input_line(state->m_maincpu, INPUT_LINE_NMI, newval ? CLEAR_LINE : ASSERT_LINE);
 }
 
 
@@ -61,9 +61,9 @@ static READ8_HANDLER( fcombat_protection_r )
 
 static READ8_HANDLER( fcombat_port01_r )
 {
-	fcombat_state *state = space->machine->driver_data<fcombat_state>();
+	fcombat_state *state = space->machine().driver_data<fcombat_state>();
 	/* the cocktail flip bit muxes between ports 0 and 1 */
-	return state->cocktail_flip ? input_port_read(space->machine, "IN1") : input_port_read(space->machine, "IN0");
+	return state->m_cocktail_flip ? input_port_read(space->machine(), "IN1") : input_port_read(space->machine(), "IN0");
 }
 
 
@@ -71,20 +71,20 @@ static READ8_HANDLER( fcombat_port01_r )
 
 static WRITE8_HANDLER(e900_w)
 {
-	fcombat_state *state = space->machine->driver_data<fcombat_state>();
-	state->fcombat_sh = data;
+	fcombat_state *state = space->machine().driver_data<fcombat_state>();
+	state->m_fcombat_sh = data;
 }
 
 static WRITE8_HANDLER(ea00_w)
 {
-	fcombat_state *state = space->machine->driver_data<fcombat_state>();
-	state->fcombat_sv = (state->fcombat_sv & 0xff00) | data;
+	fcombat_state *state = space->machine().driver_data<fcombat_state>();
+	state->m_fcombat_sv = (state->m_fcombat_sv & 0xff00) | data;
 }
 
 static WRITE8_HANDLER(eb00_w)
 {
-	fcombat_state *state = space->machine->driver_data<fcombat_state>();
-	state->fcombat_sv = (state->fcombat_sv & 0xff) | (data << 8);
+	fcombat_state *state = space->machine().driver_data<fcombat_state>();
+	state->m_fcombat_sv = (state->m_fcombat_sv & 0xff) | (data << 8);
 }
 
 
@@ -92,23 +92,23 @@ static WRITE8_HANDLER(eb00_w)
 
 static WRITE8_HANDLER(ec00_w)
 {
-	fcombat_state *state = space->machine->driver_data<fcombat_state>();
-	state->tx = data;
+	fcombat_state *state = space->machine().driver_data<fcombat_state>();
+	state->m_tx = data;
 }
 
 static WRITE8_HANDLER(ed00_w)
 {
-	fcombat_state *state = space->machine->driver_data<fcombat_state>();
-	state->ty = data;
+	fcombat_state *state = space->machine().driver_data<fcombat_state>();
+	state->m_ty = data;
 }
 
 static READ8_HANDLER(e300_r)
 {
-	fcombat_state *state = space->machine->driver_data<fcombat_state>();
-	int wx = (state->tx + state->fcombat_sh) / 16;
-	int wy = (state->ty * 2 + state->fcombat_sv) / 16;
+	fcombat_state *state = space->machine().driver_data<fcombat_state>();
+	int wx = (state->m_tx + state->m_fcombat_sh) / 16;
+	int wy = (state->m_ty * 2 + state->m_fcombat_sv) / 16;
 
-	return space->machine->region("user2")->base()[wx * 32 * 16 + wy];
+	return space->machine().region("user2")->base()[wx * 32 * 16 + wy];
 }
 
 static WRITE8_HANDLER(ee00_w)
@@ -116,11 +116,11 @@ static WRITE8_HANDLER(ee00_w)
 
 }
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0xc000, 0xc7ff) AM_RAM
-	AM_RANGE(0xd000, 0xd7ff) AM_RAM AM_BASE_SIZE_MEMBER(fcombat_state, videoram, videoram_size)
-	AM_RANGE(0xd800, 0xd8ff) AM_RAM AM_BASE_SIZE_MEMBER(fcombat_state, spriteram, spriteram_size)
+	AM_RANGE(0xd000, 0xd7ff) AM_RAM AM_BASE_SIZE_MEMBER(fcombat_state, m_videoram, m_videoram_size)
+	AM_RANGE(0xd800, 0xd8ff) AM_RAM AM_BASE_SIZE_MEMBER(fcombat_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0xe000, 0xe000) AM_READ(fcombat_port01_r)
 	AM_RANGE(0xe100, 0xe100) AM_READ_PORT("DSW0")
 	AM_RANGE(0xe200, 0xe200) AM_READ_PORT("DSW1")
@@ -137,7 +137,7 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( audio_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( audio_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x47ff) AM_RAM
 	AM_RANGE(0x6000, 0x6000) AM_READ(soundlatch_r)
@@ -267,32 +267,32 @@ GFXDECODE_END
 
 static MACHINE_START( fcombat )
 {
-	fcombat_state *state = machine->driver_data<fcombat_state>();
+	fcombat_state *state = machine.driver_data<fcombat_state>();
 
-	state->maincpu = machine->device("maincpu");
+	state->m_maincpu = machine.device("maincpu");
 
-	state_save_register_global(machine, state->cocktail_flip);
-	state_save_register_global(machine, state->char_palette);
-	state_save_register_global(machine, state->sprite_palette);
-	state_save_register_global(machine, state->char_bank);
-	state_save_register_global(machine, state->fcombat_sh);
-	state_save_register_global(machine, state->fcombat_sv);
-	state_save_register_global(machine, state->tx);
-	state_save_register_global(machine, state->ty);
+	state->save_item(NAME(state->m_cocktail_flip));
+	state->save_item(NAME(state->m_char_palette));
+	state->save_item(NAME(state->m_sprite_palette));
+	state->save_item(NAME(state->m_char_bank));
+	state->save_item(NAME(state->m_fcombat_sh));
+	state->save_item(NAME(state->m_fcombat_sv));
+	state->save_item(NAME(state->m_tx));
+	state->save_item(NAME(state->m_ty));
 }
 
 static MACHINE_RESET( fcombat )
 {
-	fcombat_state *state = machine->driver_data<fcombat_state>();
+	fcombat_state *state = machine.driver_data<fcombat_state>();
 
-	state->cocktail_flip = 0;
-	state->char_palette = 0;
-	state->sprite_palette = 0;
-	state->char_bank = 0;
-	state->fcombat_sh = 0;
-	state->fcombat_sv = 0;
-	state->tx = 0;
-	state->ty = 0;
+	state->m_cocktail_flip = 0;
+	state->m_char_palette = 0;
+	state->m_sprite_palette = 0;
+	state->m_char_bank = 0;
+	state->m_fcombat_sh = 0;
+	state->m_fcombat_sv = 0;
+	state->m_tx = 0;
+	state->m_ty = 0;
 }
 
 static MACHINE_CONFIG_START( fcombat, fcombat_state )
@@ -311,13 +311,13 @@ static MACHINE_CONFIG_START( fcombat, fcombat_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_RAW_PARAMS(FCOMBAT_PIXEL_CLOCK, FCOMBAT_HTOTAL, FCOMBAT_HBEND, FCOMBAT_HBSTART, FCOMBAT_VTOTAL, FCOMBAT_VBEND, FCOMBAT_VBSTART)
+	MCFG_SCREEN_UPDATE(fcombat)
 
 	MCFG_GFXDECODE(fcombat)
 	MCFG_PALETTE_LENGTH(256*3)
 
 	MCFG_PALETTE_INIT(fcombat)
 	MCFG_VIDEO_START(fcombat)
-	MCFG_VIDEO_UPDATE(fcombat)
 
 	/* audio hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -348,8 +348,8 @@ static DRIVER_INIT( fcombat )
 
 	/* make a temporary copy of the character data */
 	src = temp;
-	dst = machine->region("gfx1")->base();
-	length = machine->region("gfx1")->bytes();
+	dst = machine.region("gfx1")->base();
+	length = machine.region("gfx1")->bytes();
 	memcpy(src, dst, length);
 
 	/* decode the characters */
@@ -366,8 +366,8 @@ static DRIVER_INIT( fcombat )
 
 	/* make a temporary copy of the sprite data */
 	src = temp;
-	dst = machine->region("gfx2")->base();
-	length = machine->region("gfx2")->bytes();
+	dst = machine.region("gfx2")->base();
+	length = machine.region("gfx2")->bytes();
 	memcpy(src, dst, length);
 
 	/* decode the sprites */
@@ -387,8 +387,8 @@ static DRIVER_INIT( fcombat )
 
 	/* make a temporary copy of the character data */
 	src = temp;
-	dst = machine->region("gfx3")->base();
-	length = machine->region("gfx3")->bytes();
+	dst = machine.region("gfx3")->base();
+	length = machine.region("gfx3")->bytes();
 	memcpy(src, dst, length);
 
 	/* decode the characters */
@@ -406,8 +406,8 @@ static DRIVER_INIT( fcombat )
 	}
 
 	src = temp;
-	dst = machine->region("user1")->base();
-	length = machine->region("user1")->bytes();
+	dst = machine.region("user1")->base();
+	length = machine.region("user1")->bytes();
 	memcpy(src, dst, length);
 
 	for (oldaddr = 0; oldaddr < 32; oldaddr++)
@@ -418,8 +418,8 @@ static DRIVER_INIT( fcombat )
 
 
 	src = temp;
-	dst = machine->region("user2")->base();
-	length = machine->region("user2")->bytes();
+	dst = machine.region("user2")->base();
+	length = machine.region("user2")->bytes();
 	memcpy(src, dst, length);
 
 	for (oldaddr = 0; oldaddr < 32; oldaddr++)
