@@ -35,6 +35,31 @@ but requires a special level III player for proper control. Video: CAV. Audio: A
 #include "machine/x2212.h"
 
 
+class firefox_state : public driver_device
+{
+public:
+	firefox_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	device_t *m_laserdisc;
+	int m_n_disc_lock;
+	int m_n_disc_data;
+	int m_n_disc_read_data;
+	unsigned char *m_tileram;
+	unsigned char *m_tile_palette;
+	unsigned char *m_sprite_palette;
+	x2212_device *m_nvram_1c;
+	x2212_device *m_nvram_1d;
+	tilemap_t *m_bgtiles;
+	int m_control_num;
+	UINT8 m_sound_to_main_flag;
+	UINT8 m_main_to_sound_flag;
+	int m_sprite_bank;
+	UINT8 *m_spriteram;
+};
+
+
+
 #define MASTER_XTAL		XTAL_14_31818MHz
 
 
@@ -57,10 +82,6 @@ fffe=reset e7cc
 /* FXXXXX for first field
    AXXXXX for second field */
 
-static device_t *laserdisc;
-static int m_n_disc_lock;
-static int m_n_disc_data;
-static int m_n_disc_read_data;
 
 /* 20 = DISKOPR - Active low
    40 = DISKFULL - Active low
@@ -68,12 +89,13 @@ static int m_n_disc_read_data;
    */
 static READ8_HANDLER( firefox_disc_status_r )
 {
+	firefox_state *state = space->machine().driver_data<firefox_state>();
 	UINT8 result = 0xff;
 
 	result ^= 0x20;
-	if (!laserdisc_line_r(laserdisc, LASERDISC_LINE_READY))
+	if (!laserdisc_line_r(state->m_laserdisc, LASERDISC_LINE_READY))
 		result ^= 0x40;
-	if (laserdisc_line_r(laserdisc, LASERDISC_LINE_DATA_AVAIL))
+	if (laserdisc_line_r(state->m_laserdisc, LASERDISC_LINE_DATA_AVAIL))
 		result ^= 0x80;
 
 	return result;
@@ -83,56 +105,52 @@ static READ8_HANDLER( firefox_disc_status_r )
 /* this reset RDDSK (&DSKRD) */
 static READ8_HANDLER( firefox_disc_data_r )
 {
-	return m_n_disc_read_data;
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	return state->m_n_disc_read_data;
 }
 
 /* DISK READ ENABLE */
 /* 4218 - DSKREAD, set RDDSK */
 static WRITE8_HANDLER( firefox_disc_read_w )
 {
-	m_n_disc_read_data = laserdisc_data_r(laserdisc);
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_n_disc_read_data = laserdisc_data_r(state->m_laserdisc);
 }
 
 static WRITE8_HANDLER( firefox_disc_lock_w )
 {
-	m_n_disc_lock = data & 0x80;
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_n_disc_lock = data & 0x80;
 }
 
 static WRITE8_HANDLER( audio_enable_w )
 {
-	sound_set_output_gain(space->machine->device("ldsound"), ~offset & 1, (data & 0x80) ? 1.0 : 0.0);
+	space->machine().device<laserdisc_sound_device>("ldsound")->set_output_gain(~offset & 1, (data & 0x80) ? 1.0 : 0.0);
 }
 
 static WRITE8_HANDLER( firefox_disc_reset_w )
 {
-	laserdisc_line_w(laserdisc, LASERDISC_LINE_RESET, (data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	laserdisc_line_w(state->m_laserdisc, LASERDISC_LINE_RESET, (data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
 }
 
 /* active low on dbb7 */
 static WRITE8_HANDLER( firefox_disc_write_w )
 {
+	firefox_state *state = space->machine().driver_data<firefox_state>();
 	if ( ( data & 0x80 ) == 0 )
-		laserdisc_data_w(laserdisc, m_n_disc_data);
+		laserdisc_data_w(state->m_laserdisc, state->m_n_disc_data);
 }
 
 /* latch the data */
 static WRITE8_HANDLER( firefox_disc_data_w )
 {
-	m_n_disc_data = data;
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_n_disc_data = data;
 }
 
 
-static unsigned char *tileram;
-static unsigned char *tile_palette;
-static unsigned char *sprite_palette;
-static x2212_device *nvram_1c;
-static x2212_device *nvram_1d;
-static tilemap_t *bgtiles;
 
-static int control_num;
-static UINT8 sound_to_main_flag;
-static UINT8 main_to_sound_flag;
-static int sprite_bank;
 
 /*************************************
  *
@@ -142,35 +160,39 @@ static int sprite_bank;
 
 static TILE_GET_INFO( bgtile_get_info )
 {
-	SET_TILE_INFO(0, tileram[tile_index], 0, 0);
+	firefox_state *state = machine.driver_data<firefox_state>();
+	SET_TILE_INFO(0, state->m_tileram[tile_index], 0, 0);
 }
 
 
 static WRITE8_HANDLER( tileram_w )
 {
-	tileram[offset] = data;
-	tilemap_mark_tile_dirty(bgtiles, offset);
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_tileram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_bgtiles, offset);
 }
 
 
 static VIDEO_START( firefox )
 {
-	bgtiles = tilemap_create(machine, bgtile_get_info, tilemap_scan_rows, 8,8, 64,64);
-	tilemap_set_transparent_pen(bgtiles, 0);
-	tilemap_set_scrolldy(bgtiles, machine->primary_screen->visible_area().min_y, 0);
+	firefox_state *state = machine.driver_data<firefox_state>();
+	state->m_bgtiles = tilemap_create(machine, bgtile_get_info, tilemap_scan_rows, 8,8, 64,64);
+	tilemap_set_transparent_pen(state->m_bgtiles, 0);
+	tilemap_set_scrolldy(state->m_bgtiles, machine.primary_screen->visible_area().min_y, 0);
 }
 
 
-static VIDEO_UPDATE( firefox )
+static SCREEN_UPDATE( firefox )
 {
+	firefox_state *state = screen->machine().driver_data<firefox_state>();
 	int sprite;
 	int gfxtop = screen->visible_area().min_y;
 
-	bitmap_fill( bitmap, cliprect, palette_get_color(screen->machine, 256) );
+	bitmap_fill( bitmap, cliprect, palette_get_color(screen->machine(), 256) );
 
 	for( sprite = 0; sprite < 32; sprite++ )
 	{
-		UINT8 *sprite_data = screen->machine->generic.spriteram.u8 + ( 0x200 * sprite_bank ) + ( sprite * 16 );
+		UINT8 *sprite_data = state->m_spriteram + ( 0x200 * state->m_sprite_bank ) + ( sprite * 16 );
 		int flags = sprite_data[ 0 ];
 		int y = sprite_data[ 1 ] + ( 256 * ( ( flags >> 0 ) & 1 ) );
 		int x = sprite_data[ 2 ] + ( 256 * ( ( flags >> 1 ) & 1 ) );
@@ -186,24 +208,24 @@ static VIDEO_UPDATE( firefox )
 				int flipx = flags & 0x20;
 				int code = sprite_data[ 15 - row ] + ( 256 * ( ( flags >> 6 ) & 3 ) );
 
-				drawgfx_transpen( bitmap, cliprect, screen->machine->gfx[ 1 ], code, color, flipx, flipy, x + 8, gfxtop + 500 - y - ( row * 16 ), 0 );
+				drawgfx_transpen( bitmap, cliprect, screen->machine().gfx[ 1 ], code, color, flipx, flipy, x + 8, gfxtop + 500 - y - ( row * 16 ), 0 );
 			}
 		}
 	}
 
-	tilemap_draw( bitmap, cliprect, bgtiles, 0, 0 );
+	tilemap_draw( bitmap, cliprect, state->m_bgtiles, 0, 0 );
 
 	return 0;
 }
 
 static TIMER_DEVICE_CALLBACK( video_timer_callback )
 {
-	timer.machine->primary_screen->update_now();
+	timer.machine().primary_screen->update_now();
 
-	cputag_set_input_line( timer.machine, "maincpu", M6809_IRQ_LINE, ASSERT_LINE );
+	cputag_set_input_line( timer.machine(), "maincpu", M6809_IRQ_LINE, ASSERT_LINE );
 }
 
-static void set_rgba( running_machine *machine, int start, int index, unsigned char *palette_ram )
+static void set_rgba( running_machine &machine, int start, int index, unsigned char *palette_ram )
 {
 	int r = palette_ram[ index ];
 	int g = palette_ram[ index + 256 ];
@@ -215,19 +237,22 @@ static void set_rgba( running_machine *machine, int start, int index, unsigned c
 
 static WRITE8_HANDLER( tile_palette_w )
 {
-	tile_palette[ offset ] = data;
-	set_rgba( space->machine, 0, offset & 0xff, tile_palette );
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_tile_palette[ offset ] = data;
+	set_rgba( space->machine(), 0, offset & 0xff, state->m_tile_palette );
 }
 
 static WRITE8_HANDLER( sprite_palette_w )
 {
-	sprite_palette[ offset ] = data;
-	set_rgba( space->machine, 256, offset & 0xff, sprite_palette );
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_sprite_palette[ offset ] = data;
+	set_rgba( space->machine(), 256, offset & 0xff, state->m_sprite_palette );
 }
 
 static WRITE8_HANDLER( firefox_objram_bank_w )
 {
-	sprite_bank = data & 0x03;
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_sprite_bank = data & 0x03;
 }
 
 
@@ -240,43 +265,50 @@ static WRITE8_HANDLER( firefox_objram_bank_w )
 
 static CUSTOM_INPUT( mainflag_r )
 {
-	return main_to_sound_flag;
+	firefox_state *state = field.machine().driver_data<firefox_state>();
+	return state->m_main_to_sound_flag;
 }
 
 static CUSTOM_INPUT( soundflag_r )
 {
-	return sound_to_main_flag;
+	firefox_state *state = field.machine().driver_data<firefox_state>();
+	return state->m_sound_to_main_flag;
 }
 
 static READ8_HANDLER( sound_to_main_r )
 {
-	sound_to_main_flag = 0;
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_sound_to_main_flag = 0;
 	return soundlatch2_r(space, 0);
 }
 
 static WRITE8_HANDLER( main_to_sound_w )
 {
-	main_to_sound_flag = 1;
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_main_to_sound_flag = 1;
 	soundlatch_w(space, 0, data);
-	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
+	cputag_set_input_line(space->machine(), "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static WRITE8_HANDLER( sound_reset_w )
 {
-	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_RESET, (data & 0x80) ? ASSERT_LINE : CLEAR_LINE);
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	cputag_set_input_line(space->machine(), "audiocpu", INPUT_LINE_RESET, (data & 0x80) ? ASSERT_LINE : CLEAR_LINE);
 	if ((data & 0x80) != 0)
-		sound_to_main_flag = main_to_sound_flag = 0;
+		state->m_sound_to_main_flag = state->m_main_to_sound_flag = 0;
 }
 
 static READ8_HANDLER( main_to_sound_r )
 {
-	main_to_sound_flag = 0;
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_main_to_sound_flag = 0;
 	return soundlatch_r(space, 0);
 }
 
 static WRITE8_HANDLER( sound_to_main_w )
 {
-	sound_to_main_flag = 1;
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_sound_to_main_flag = 1;
 	soundlatch2_w(space, 0, data);
 }
 
@@ -290,6 +322,7 @@ static WRITE8_HANDLER( sound_to_main_w )
 
 static READ8_DEVICE_HANDLER( riot_porta_r )
 {
+	firefox_state *state = device->machine().driver_data<firefox_state>();
 	/* bit 7 = MAINFLAG */
 	/* bit 6 = SOUNDFLAG */
 	/* bit 5 = PA5 */
@@ -299,12 +332,12 @@ static READ8_DEVICE_HANDLER( riot_porta_r )
 	/* bit 1 = TMS /read */
 	/* bit 0 = TMS /write */
 
-	return (main_to_sound_flag << 7) | (sound_to_main_flag << 6) | 0x10 | (tms5220_readyq_r(device) << 2);
+	return (state->m_main_to_sound_flag << 7) | (state->m_sound_to_main_flag << 6) | 0x10 | (tms5220_readyq_r(device) << 2);
 }
 
 static WRITE8_DEVICE_HANDLER( riot_porta_w )
 {
-	device_t *tms = device->machine->device("tms");
+	device_t *tms = device->machine().device("tms");
 
 	/* handle 5220 read */
 	tms5220_rsq_w(tms, (data>>1) & 1);
@@ -315,7 +348,7 @@ static WRITE8_DEVICE_HANDLER( riot_porta_w )
 
 static WRITE_LINE_DEVICE_HANDLER( riot_irq )
 {
-	cputag_set_input_line(device->machine, "audiocpu", M6502_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine(), "audiocpu", M6502_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -328,17 +361,19 @@ static WRITE_LINE_DEVICE_HANDLER( riot_irq )
 
 static READ8_HANDLER( adc_r )
 {
-	if( control_num == 0 )
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	if( state->m_control_num == 0 )
 	{
-		return input_port_read( space->machine, "PITCH" );
+		return input_port_read( space->machine(), "PITCH" );
 	}
 
-	return input_port_read( space->machine, "YAW" );
+	return input_port_read( space->machine(), "YAW" );
 }
 
 static WRITE8_HANDLER( adc_select_w )
 {
-	control_num = offset;
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_control_num = offset;
 }
 
 
@@ -351,25 +386,29 @@ static WRITE8_HANDLER( adc_select_w )
 
 static WRITE8_HANDLER( nvram_w )
 {
-	nvram_1c->write(*space, offset, data >> 4);
-	nvram_1d->write(*space, offset, data & 0xf);
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_nvram_1c->write(*space, offset, data >> 4);
+	state->m_nvram_1d->write(*space, offset, data & 0xf);
 }
 
 static READ8_HANDLER( nvram_r )
 {
-	return (nvram_1c->read(*space, offset) << 4) | (nvram_1d->read(*space, offset) & 0x0f);
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	return (state->m_nvram_1c->read(*space, offset) << 4) | (state->m_nvram_1d->read(*space, offset) & 0x0f);
 }
 
 static WRITE8_HANDLER( novram_recall_w )
 {
-	nvram_1c->recall(data & 0x80);
-	nvram_1d->recall(data & 0x80);
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_nvram_1c->recall(data & 0x80);
+	state->m_nvram_1d->recall(data & 0x80);
 }
 
 static WRITE8_HANDLER( novram_store_w )
 {
-	nvram_1c->store(data & 0x80);
-	nvram_1d->store(data & 0x80);
+	firefox_state *state = space->machine().driver_data<firefox_state>();
+	state->m_nvram_1c->store(data & 0x80);
+	state->m_nvram_1d->store(data & 0x80);
 }
 
 
@@ -382,22 +421,22 @@ static WRITE8_HANDLER( novram_store_w )
 
 static WRITE8_HANDLER( rom_bank_w )
 {
-	memory_set_bank(space->machine, "bank1", data & 0x1f);
+	memory_set_bank(space->machine(), "bank1", data & 0x1f);
 }
 
 static WRITE8_HANDLER( main_irq_clear_w )
 {
-    cputag_set_input_line( space->machine, "maincpu", M6809_IRQ_LINE, CLEAR_LINE );
+    cputag_set_input_line( space->machine(), "maincpu", M6809_IRQ_LINE, CLEAR_LINE );
 }
 
 static WRITE8_HANDLER( main_firq_clear_w )
 {
-    cputag_set_input_line( space->machine, "maincpu", M6809_FIRQ_LINE, CLEAR_LINE );
+    cputag_set_input_line( space->machine(), "maincpu", M6809_FIRQ_LINE, CLEAR_LINE );
 }
 
 static WRITE8_HANDLER( self_reset_w )
 {
-	cputag_set_input_line( space->machine, "maincpu", INPUT_LINE_RESET, PULSE_LINE );
+	cputag_set_input_line( space->machine(), "maincpu", INPUT_LINE_RESET, PULSE_LINE );
 }
 
 
@@ -410,12 +449,12 @@ static WRITE8_HANDLER( self_reset_w )
 
 static WRITE8_HANDLER( led_w )
 {
-    set_led_status( space->machine, offset, ( data & 0x80 ) == 0 );
+    set_led_status( space->machine(), offset, ( data & 0x80 ) == 0 );
 }
 
 static WRITE8_HANDLER( firefox_coin_counter_w )
 {
-	coin_counter_w( space->machine, offset, data & 0x80 );
+	coin_counter_w( space->machine(), offset, data & 0x80 );
 }
 
 
@@ -423,21 +462,22 @@ static WRITE8_HANDLER( firefox_coin_counter_w )
 static void firq_gen(device_t *device, int state)
 {
 	if (state)
-	    cputag_set_input_line( device->machine, "maincpu", M6809_FIRQ_LINE, ASSERT_LINE );
+	    cputag_set_input_line( device->machine(), "maincpu", M6809_FIRQ_LINE, ASSERT_LINE );
 }
 
 
 static MACHINE_START( firefox )
 {
-	memory_configure_bank(machine, "bank1", 0, 32, machine->region("maincpu")->base() + 0x10000, 0x1000);
-	nvram_1c = machine->device<x2212_device>("nvram_1c");
-	nvram_1d = machine->device<x2212_device>("nvram_1d");
+	firefox_state *state = machine.driver_data<firefox_state>();
+	memory_configure_bank(machine, "bank1", 0, 32, machine.region("maincpu")->base() + 0x10000, 0x1000);
+	state->m_nvram_1c = machine.device<x2212_device>("nvram_1c");
+	state->m_nvram_1d = machine.device<x2212_device>("nvram_1d");
 
-	laserdisc = machine->device("laserdisc");
-	vp931_set_data_ready_callback(laserdisc, firq_gen);
+	state->m_laserdisc = machine.device("laserdisc");
+	vp931_set_data_ready_callback(state->m_laserdisc, firq_gen);
 
-	control_num = 0;
-	sprite_bank = 0;
+	state->m_control_num = 0;
+	state->m_sprite_bank = 0;
 }
 
 
@@ -447,13 +487,13 @@ static MACHINE_START( firefox )
  *
  *************************************/
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8)
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8)
 	AM_RANGE(0x0000, 0x0fff) AM_RAM
-	AM_RANGE(0x1000, 0x1fff) AM_RAM_WRITE(tileram_w) AM_BASE(&tileram)
-	AM_RANGE(0x2000, 0x27ff) AM_RAM AM_BASE_GENERIC(spriteram)
-	AM_RANGE(0x2800, 0x2aff) AM_RAM_WRITE(sprite_palette_w) AM_BASE(&sprite_palette)
+	AM_RANGE(0x1000, 0x1fff) AM_RAM_WRITE(tileram_w) AM_BASE_MEMBER(firefox_state, m_tileram)
+	AM_RANGE(0x2000, 0x27ff) AM_RAM AM_BASE_MEMBER(firefox_state, m_spriteram)
+	AM_RANGE(0x2800, 0x2aff) AM_RAM_WRITE(sprite_palette_w) AM_BASE_MEMBER(firefox_state, m_sprite_palette)
 	AM_RANGE(0x2b00, 0x2b00) AM_MIRROR(0x04ff) AM_WRITE(firefox_objram_bank_w)
-	AM_RANGE(0x2c00, 0x2eff) AM_RAM_WRITE(tile_palette_w) AM_BASE(&tile_palette)
+	AM_RANGE(0x2c00, 0x2eff) AM_RAM_WRITE(tile_palette_w) AM_BASE_MEMBER(firefox_state, m_tile_palette)
 	AM_RANGE(0x3000, 0x3fff) AM_ROMBANK("bank1")
 	AM_RANGE(0x4000, 0x40ff) AM_READWRITE(nvram_r, nvram_w)						/* NOVRAM */
 	AM_RANGE(0x4100, 0x4100) AM_MIRROR(0x00f8) AM_READ_PORT("rdin0")			/* RDIN0 */
@@ -493,7 +533,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( audio_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( audio_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_RAM
 	AM_RANGE(0x0800, 0x087f) AM_MIRROR(0x0700) AM_RAM /* RIOT ram */
 	AM_RANGE(0x0880, 0x089f) AM_MIRROR(0x07e0) AM_DEVREADWRITE("riot",riot6532_r, riot6532_w)
@@ -641,7 +681,7 @@ static const riot6532_interface riot_intf =
 };
 
 
-static MACHINE_CONFIG_START( firefox, driver_device )
+static MACHINE_CONFIG_START( firefox, firefox_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M6809E, MASTER_XTAL/2)
@@ -652,10 +692,10 @@ static MACHINE_CONFIG_START( firefox, driver_device )
 	MCFG_CPU_ADD("audiocpu", M6502, MASTER_XTAL/8)
 	MCFG_CPU_PROGRAM_MAP(audio_map)
 
-	MCFG_QUANTUM_TIME(HZ(60000))
+	MCFG_QUANTUM_TIME(attotime::from_hz(60000))
 
 	MCFG_MACHINE_START(firefox)
-	MCFG_WATCHDOG_TIME_INIT(HZ((double)MASTER_XTAL/8/16/16/16/16))
+	MCFG_WATCHDOG_TIME_INIT(attotime::from_hz((double)MASTER_XTAL/8/16/16/16/16))
 
 	/* video hardware */
 	MCFG_LASERDISC_SCREEN_ADD_NTSC("screen", BITMAP_FORMAT_RGB32)
