@@ -179,13 +179,13 @@ Stephh's notes (based on the games Z80 code and some tests) :
 
 static WRITE8_HANDLER( firetrap_nmi_disable_w )
 {
-	firetrap_state *state = space->machine->driver_data<firetrap_state>();
-	state->nmi_enable = ~data & 1;
+	firetrap_state *state = space->machine().driver_data<firetrap_state>();
+	state->m_nmi_enable = ~data & 1;
 }
 
 static WRITE8_HANDLER( firetrap_bankselect_w )
 {
-	memory_set_bank(space->machine, "bank1", data & 0x03);
+	memory_set_bank(space->machine(), "bank1", data & 0x03);
 }
 
 static READ8_HANDLER( firetrap_8751_bootleg_r )
@@ -193,12 +193,12 @@ static READ8_HANDLER( firetrap_8751_bootleg_r )
 	/* Check for coin insertion */
 	/* the following only works in the bootleg version, which doesn't have an */
 	/* 8751 - the real thing is much more complicated than that. */
-	firetrap_state *state = space->machine->driver_data<firetrap_state>();
+	firetrap_state *state = space->machine().driver_data<firetrap_state>();
 	UINT8 coin = 0;
-	UINT8 port = input_port_read(space->machine, "IN2") & 0x70;
+	UINT8 port = input_port_read(space->machine(), "IN2") & 0x70;
 
-	if (cpu_get_pc(space->cpu) == 0x1188)
-		return ~state->coin_command_pending;
+	if (cpu_get_pc(&space->device()) == 0x1188)
+		return ~state->m_coin_command_pending;
 
 	if (port != 0x70)
 	{
@@ -208,7 +208,7 @@ static READ8_HANDLER( firetrap_8751_bootleg_r )
 			coin = 2;
 		if (!(port & 0x10)) /* SERVICE1 */
 			coin = 3;
-		state->coin_command_pending = coin;
+		state->m_coin_command_pending = coin;
 		return 0xff;
 	}
 
@@ -217,9 +217,9 @@ static READ8_HANDLER( firetrap_8751_bootleg_r )
 
 static READ8_HANDLER( firetrap_8751_r )
 {
-	firetrap_state *state = space->machine->driver_data<firetrap_state>();
-	//logerror("PC:%04x read from 8751\n",cpu_get_pc(space->cpu));
-	return state->i8751_return;
+	firetrap_state *state = space->machine().driver_data<firetrap_state>();
+	//logerror("PC:%04x read from 8751\n",cpu_get_pc(&space->device()));
+	return state->m_i8751_return;
 }
 
 static WRITE8_HANDLER( firetrap_8751_w )
@@ -244,119 +244,119 @@ static WRITE8_HANDLER( firetrap_8751_w )
 	};
 	static const int i8751_coin_data[]={ 0x00, 0xb7 };
 	static const int i8751_36_data[]={ 0x00, 0xbc };
-	firetrap_state *state = space->machine->driver_data<firetrap_state>();
+	firetrap_state *state = space->machine().driver_data<firetrap_state>();
 
 	/* End of command - important to note, as coin input is supressed while commands are pending */
 	if (data == 0x26)
 	{
-		state->i8751_current_command = 0;
-		state->i8751_return = 0xff; /* This value is XOR'd and must equal 0 */
-		cpu_set_input_line_and_vector(state->maincpu, 0, HOLD_LINE, 0xff);
+		state->m_i8751_current_command = 0;
+		state->m_i8751_return = 0xff; /* This value is XOR'd and must equal 0 */
+		device_set_input_line_and_vector(state->m_maincpu, 0, HOLD_LINE, 0xff);
 		return;
 	}
 
 	/* Init sequence command (0x13 : US - 0xf5 : Japan) */
 	else if ((data == 0x13) || (data == 0xf5))
 	{
-		if (!state->i8751_current_command)
-			state->i8751_init_ptr = 0;
-		state->i8751_return = i8751_init_data[state->i8751_init_ptr++];
+		if (!state->m_i8751_current_command)
+			state->m_i8751_init_ptr = 0;
+		state->m_i8751_return = i8751_init_data[state->m_i8751_init_ptr++];
 	}
 
 	/* Used to calculate a jump address when coins are inserted */
 	else if (data == 0xbd)
 	{
-		if (!state->i8751_current_command)
-			state->i8751_init_ptr = 0;
-		state->i8751_return = i8751_coin_data[state->i8751_init_ptr++];
+		if (!state->m_i8751_current_command)
+			state->m_i8751_init_ptr = 0;
+		state->m_i8751_return = i8751_coin_data[state->m_i8751_init_ptr++];
 	}
 
 	else if (data == 0x36)
 	{
-		if (!state->i8751_current_command)
-			state->i8751_init_ptr = 0;
-		state->i8751_return = i8751_36_data[state->i8751_init_ptr++];
+		if (!state->m_i8751_current_command)
+			state->m_i8751_init_ptr = 0;
+		state->m_i8751_return = i8751_36_data[state->m_i8751_init_ptr++];
 	}
 
 	/* Static value commands */
 	else if (data == 0x14)
-		state->i8751_return = 1;
+		state->m_i8751_return = 1;
 	else if (data == 0x02)
-		state->i8751_return = 0;
+		state->m_i8751_return = 0;
 	else if (data == 0x72)
-		state->i8751_return = 3;
+		state->m_i8751_return = 3;
 	else if (data == 0x69)
-		state->i8751_return = 2;
+		state->m_i8751_return = 2;
 	else if (data == 0xcb)
-		state->i8751_return = 0;
+		state->m_i8751_return = 0;
 	else if (data == 0x49)
-		state->i8751_return = 1;
+		state->m_i8751_return = 1;
 	else if (data == 0x17)
-		state->i8751_return = 2;
+		state->m_i8751_return = 2;
 	else if (data == 0x88)
-		state->i8751_return = 3;
+		state->m_i8751_return = 3;
 	else
 	{
-		state->i8751_return = 0xff;
-		logerror("%04x: Unknown i8751 command %02x!\n",cpu_get_pc(space->cpu),data);
+		state->m_i8751_return = 0xff;
+		logerror("%04x: Unknown i8751 command %02x!\n",cpu_get_pc(&space->device()),data);
 	}
 
 	/* Signal main cpu task is complete */
-	cpu_set_input_line_and_vector(state->maincpu, 0, HOLD_LINE, 0xff);
-	state->i8751_current_command=data;
+	device_set_input_line_and_vector(state->m_maincpu, 0, HOLD_LINE, 0xff);
+	state->m_i8751_current_command=data;
 }
 
 static WRITE8_HANDLER( firetrap_sound_command_w )
 {
-	firetrap_state *state = space->machine->driver_data<firetrap_state>();
+	firetrap_state *state = space->machine().driver_data<firetrap_state>();
 	soundlatch_w(space, offset, data);
-	cpu_set_input_line(state->audiocpu, INPUT_LINE_NMI, PULSE_LINE);
+	device_set_input_line(state->m_audiocpu, INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static WRITE8_HANDLER( firetrap_sound_2400_w )
 {
-	firetrap_state *state = space->machine->driver_data<firetrap_state>();
-	msm5205_reset_w(state->msm, ~data & 0x01);
-	state->irq_enable = data & 0x02;
+	firetrap_state *state = space->machine().driver_data<firetrap_state>();
+	msm5205_reset_w(state->m_msm, ~data & 0x01);
+	state->m_irq_enable = data & 0x02;
 }
 
 static WRITE8_HANDLER( firetrap_sound_bankselect_w )
 {
-	memory_set_bank(space->machine, "bank2", data & 0x01);
+	memory_set_bank(space->machine(), "bank2", data & 0x01);
 }
 
 static void firetrap_adpcm_int( device_t *device )
 {
-	firetrap_state *state = device->machine->driver_data<firetrap_state>();
+	firetrap_state *state = device->machine().driver_data<firetrap_state>();
 
-	msm5205_data_w(device, state->msm5205next >> 4);
-	state->msm5205next <<= 4;
+	msm5205_data_w(device, state->m_msm5205next >> 4);
+	state->m_msm5205next <<= 4;
 
-	state->adpcm_toggle ^= 1;
-	if (state->irq_enable && state->adpcm_toggle)
-		cpu_set_input_line(state->audiocpu, M6502_IRQ_LINE, HOLD_LINE);
+	state->m_adpcm_toggle ^= 1;
+	if (state->m_irq_enable && state->m_adpcm_toggle)
+		device_set_input_line(state->m_audiocpu, M6502_IRQ_LINE, HOLD_LINE);
 }
 
 static WRITE8_HANDLER( firetrap_adpcm_data_w )
 {
-	firetrap_state *state = space->machine->driver_data<firetrap_state>();
-	state->msm5205next = data;
+	firetrap_state *state = space->machine().driver_data<firetrap_state>();
+	state->m_msm5205next = data;
 }
 
 static WRITE8_HANDLER( flip_screen_w )
 {
-	flip_screen_set(space->machine, data);
+	flip_screen_set(space->machine(), data);
 }
 
 
-static ADDRESS_MAP_START( firetrap_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( firetrap_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK("bank1")
 	AM_RANGE(0xc000, 0xcfff) AM_RAM
-	AM_RANGE(0xd000, 0xd7ff) AM_RAM_WRITE(firetrap_bg1videoram_w) AM_BASE_MEMBER(firetrap_state, bg1videoram)
-	AM_RANGE(0xd800, 0xdfff) AM_RAM_WRITE(firetrap_bg2videoram_w) AM_BASE_MEMBER(firetrap_state, bg2videoram)
-	AM_RANGE(0xe000, 0xe7ff) AM_RAM_WRITE(firetrap_fgvideoram_w) AM_BASE_MEMBER(firetrap_state, fgvideoram)
-	AM_RANGE(0xe800, 0xe97f) AM_RAM AM_BASE_SIZE_MEMBER(firetrap_state, spriteram, spriteram_size)
+	AM_RANGE(0xd000, 0xd7ff) AM_RAM_WRITE(firetrap_bg1videoram_w) AM_BASE_MEMBER(firetrap_state, m_bg1videoram)
+	AM_RANGE(0xd800, 0xdfff) AM_RAM_WRITE(firetrap_bg2videoram_w) AM_BASE_MEMBER(firetrap_state, m_bg2videoram)
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM_WRITE(firetrap_fgvideoram_w) AM_BASE_MEMBER(firetrap_state, m_fgvideoram)
+	AM_RANGE(0xe800, 0xe97f) AM_RAM AM_BASE_SIZE_MEMBER(firetrap_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0xf000, 0xf000) AM_WRITENOP	/* IRQ acknowledge */
 	AM_RANGE(0xf001, 0xf001) AM_WRITE(firetrap_sound_command_w)
 	AM_RANGE(0xf002, 0xf002) AM_WRITE(firetrap_bankselect_w)
@@ -375,14 +375,14 @@ static ADDRESS_MAP_START( firetrap_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf016, 0xf016) AM_READ(firetrap_8751_r)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( firetrap_bootleg_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( firetrap_bootleg_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK("bank1")
 	AM_RANGE(0xc000, 0xcfff) AM_RAM
-	AM_RANGE(0xd000, 0xd7ff) AM_RAM_WRITE(firetrap_bg1videoram_w) AM_BASE_MEMBER(firetrap_state, bg1videoram)
-	AM_RANGE(0xd800, 0xdfff) AM_RAM_WRITE(firetrap_bg2videoram_w) AM_BASE_MEMBER(firetrap_state, bg2videoram)
-	AM_RANGE(0xe000, 0xe7ff) AM_RAM_WRITE(firetrap_fgvideoram_w) AM_BASE_MEMBER(firetrap_state, fgvideoram)
-	AM_RANGE(0xe800, 0xe97f) AM_RAM AM_BASE_SIZE_MEMBER(firetrap_state, spriteram, spriteram_size)
+	AM_RANGE(0xd000, 0xd7ff) AM_RAM_WRITE(firetrap_bg1videoram_w) AM_BASE_MEMBER(firetrap_state, m_bg1videoram)
+	AM_RANGE(0xd800, 0xdfff) AM_RAM_WRITE(firetrap_bg2videoram_w) AM_BASE_MEMBER(firetrap_state, m_bg2videoram)
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM_WRITE(firetrap_fgvideoram_w) AM_BASE_MEMBER(firetrap_state, m_fgvideoram)
+	AM_RANGE(0xe800, 0xe97f) AM_RAM AM_BASE_SIZE_MEMBER(firetrap_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0xf000, 0xf000) AM_WRITENOP	/* IRQ acknowledge */
 	AM_RANGE(0xf001, 0xf001) AM_WRITE(firetrap_sound_command_w)
 	AM_RANGE(0xf002, 0xf002) AM_WRITE(firetrap_bankselect_w)
@@ -402,7 +402,7 @@ static ADDRESS_MAP_START( firetrap_bootleg_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf800, 0xf8ff) AM_ROM /* extra ROM in the bootleg with unprotection code */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_RAM
 	AM_RANGE(0x1000, 0x1001) AM_DEVWRITE("ymsnd", ym3526_w)
 	AM_RANGE(0x2000, 0x2000) AM_WRITE(firetrap_adpcm_data_w)	/* ADPCM data for the MSM5205 chip */
@@ -574,16 +574,16 @@ static const msm5205_interface msm5205_config =
 	MSM5205_S48_4B		/* 7.8125kHz          */
 };
 
-static INTERRUPT_GEN( firetrap )
+static INTERRUPT_GEN( firetrap_irq )
 {
-	firetrap_state *state = device->machine->driver_data<firetrap_state>();
+	firetrap_state *state = device->machine().driver_data<firetrap_state>();
 	UINT8 coin = 0;
-	UINT8 port = input_port_read(device->machine, "COIN") & 0x07;
+	UINT8 port = input_port_read(device->machine(), "COIN") & 0x07; /* TODO: remove me */
 
 	/* Check for coin IRQ */
 	if (cpu_getiloops(device))
 	{
-		if (port != 0x07 && !state->int_latch)
+		if (port != 0x07 && !state->m_int_latch)
 		{
 			if (!(port & 0x01)) /* COIN1 */
 				coin = 1;
@@ -591,85 +591,85 @@ static INTERRUPT_GEN( firetrap )
 				coin = 2;
 			if (!(port & 0x04)) /* SERVICE1 */
 				coin = 3;
-			state->coin_command_pending = coin;
-			state->int_latch = 1;
+			state->m_coin_command_pending = coin;
+			state->m_int_latch = 1;
 		}
 		if (port == 0x07)
-			state->int_latch = 0;
+			state->m_int_latch = 0;
 
 		/* Make sure coin IRQ's aren't generated when another command is pending, the main cpu
             definitely doesn't expect them as it locks out the coin routine */
-		if (state->coin_command_pending && !state->i8751_current_command)
+		if (state->m_coin_command_pending && !state->m_i8751_current_command)
 		{
-			state->i8751_return = state->coin_command_pending;
-			cpu_set_input_line_and_vector(device, 0, HOLD_LINE, 0xff);
-			state->coin_command_pending = 0;
+			state->m_i8751_return = state->m_coin_command_pending;
+			device_set_input_line_and_vector(device, 0, HOLD_LINE, 0xff);
+			state->m_coin_command_pending = 0;
 		}
 	}
 
-	if (state->nmi_enable && !cpu_getiloops(device))
-		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
+	if (state->m_nmi_enable && !cpu_getiloops(device))
+		device_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 }
 
-static INTERRUPT_GEN( bootleg )
+static INTERRUPT_GEN( bootleg_irq )
 {
-	firetrap_state *state = device->machine->driver_data<firetrap_state>();
+	firetrap_state *state = device->machine().driver_data<firetrap_state>();
 
-	if (state->nmi_enable)
-		cpu_set_input_line (device, INPUT_LINE_NMI, PULSE_LINE);
+	if (state->m_nmi_enable)
+		device_set_input_line (device, INPUT_LINE_NMI, PULSE_LINE);
 }
 
 
 static MACHINE_START( firetrap )
 {
-	firetrap_state *state = machine->driver_data<firetrap_state>();
-	UINT8 *MAIN = machine->region("maincpu")->base();
-	UINT8 *SOUND = machine->region("audiocpu")->base();
+	firetrap_state *state = machine.driver_data<firetrap_state>();
+	UINT8 *MAIN = machine.region("maincpu")->base();
+	UINT8 *SOUND = machine.region("audiocpu")->base();
 
-	state->maincpu = machine->device("maincpu");
-	state->audiocpu = machine->device("audiocpu");
-	state->msm = machine->device("msm");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_audiocpu = machine.device("audiocpu");
+	state->m_msm = machine.device("msm");
 
 	memory_configure_bank(machine, "bank1", 0, 4, &MAIN[0x10000], 0x4000);
 	memory_configure_bank(machine, "bank2", 0, 2, &SOUND[0x10000], 0x4000);
 
-	state_save_register_global(machine, state->i8751_current_command);
-	state_save_register_global(machine, state->irq_enable);
-	state_save_register_global(machine, state->nmi_enable);
-	state_save_register_global(machine, state->i8751_return);
-	state_save_register_global(machine, state->i8751_init_ptr);
-	state_save_register_global(machine, state->msm5205next);
-	state_save_register_global(machine, state->adpcm_toggle);
-	state_save_register_global(machine, state->int_latch);
-	state_save_register_global(machine, state->coin_command_pending);
-	state_save_register_global_array(machine, state->scroll1_x);
-	state_save_register_global_array(machine, state->scroll1_y);
-	state_save_register_global_array(machine, state->scroll2_x);
-	state_save_register_global_array(machine, state->scroll2_y);
+	state->save_item(NAME(state->m_i8751_current_command));
+	state->save_item(NAME(state->m_irq_enable));
+	state->save_item(NAME(state->m_nmi_enable));
+	state->save_item(NAME(state->m_i8751_return));
+	state->save_item(NAME(state->m_i8751_init_ptr));
+	state->save_item(NAME(state->m_msm5205next));
+	state->save_item(NAME(state->m_adpcm_toggle));
+	state->save_item(NAME(state->m_int_latch));
+	state->save_item(NAME(state->m_coin_command_pending));
+	state->save_item(NAME(state->m_scroll1_x));
+	state->save_item(NAME(state->m_scroll1_y));
+	state->save_item(NAME(state->m_scroll2_x));
+	state->save_item(NAME(state->m_scroll2_y));
 }
 
 static MACHINE_RESET( firetrap )
 {
-	firetrap_state *state = machine->driver_data<firetrap_state>();
+	firetrap_state *state = machine.driver_data<firetrap_state>();
 	int i;
 
 	for (i = 0; i < 2; i++)
 	{
-		state->scroll1_x[i] = 0;
-		state->scroll1_y[i] = 0;
-		state->scroll2_x[i] = 0;
-		state->scroll2_y[i] = 0;
+		state->m_scroll1_x[i] = 0;
+		state->m_scroll1_y[i] = 0;
+		state->m_scroll2_x[i] = 0;
+		state->m_scroll2_y[i] = 0;
 	}
 
-	state->i8751_current_command = 0;
-	state->irq_enable = 0;
-	state->nmi_enable = 0;
-	state->i8751_return = 0;
-	state->i8751_init_ptr = 0;
-	state->msm5205next = 0xff;
-	state->adpcm_toggle = 0;
-	state->int_latch = 0;
-	state->coin_command_pending = 0;
+	state->m_i8751_current_command = 0;
+	state->m_irq_enable = 0;
+	state->m_nmi_enable = 0;
+	state->m_i8751_return = 0;
+	state->m_i8751_init_ptr = 0;
+	state->m_msm5205next = 0xff;
+	state->m_adpcm_toggle = 0;
+	state->m_int_latch = 0;
+	state->m_coin_command_pending = 0;
 }
 
 static MACHINE_CONFIG_START( firetrap, firetrap_state )
@@ -677,7 +677,7 @@ static MACHINE_CONFIG_START( firetrap, firetrap_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80, FIRETRAP_XTAL/2)		// 6 MHz
 	MCFG_CPU_PROGRAM_MAP(firetrap_map)
-	MCFG_CPU_VBLANK_INT_HACK(firetrap,2)
+	MCFG_CPU_VBLANK_INT_HACK(firetrap_irq,2)
 
 	MCFG_CPU_ADD("audiocpu", M6502, FIRETRAP_XTAL/8)	// 1.5 MHz
 	MCFG_CPU_PROGRAM_MAP(sound_map)
@@ -694,13 +694,13 @@ static MACHINE_CONFIG_START( firetrap, firetrap_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_UPDATE(firetrap)
 
 	MCFG_GFXDECODE(firetrap)
 	MCFG_PALETTE_LENGTH(256)
 
 	MCFG_PALETTE_INIT(firetrap)
 	MCFG_VIDEO_START(firetrap)
-	MCFG_VIDEO_UPDATE(firetrap)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -718,7 +718,7 @@ static MACHINE_CONFIG_START( firetrapbl, firetrap_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80, FIRETRAP_XTAL/2)		// 6 MHz
 	MCFG_CPU_PROGRAM_MAP(firetrap_bootleg_map)
-	MCFG_CPU_VBLANK_INT("screen", bootleg)
+	MCFG_CPU_VBLANK_INT("screen", bootleg_irq)
 
 	MCFG_CPU_ADD("audiocpu", M6502, FIRETRAP_XTAL/8)	// 1.5 MHz
 	MCFG_CPU_PROGRAM_MAP(sound_map)
@@ -741,7 +741,7 @@ static MACHINE_CONFIG_START( firetrapbl, firetrap_state )
 
 	MCFG_PALETTE_INIT(firetrap)
 	MCFG_VIDEO_START(firetrap)
-	MCFG_VIDEO_UPDATE(firetrap)
+	MCFG_SCREEN_UPDATE(firetrap)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
