@@ -25,14 +25,24 @@ found/dumped yet. */
 #include "video/tms9928a.h"
 #include "sound/ay8910.h"
 
-static UINT8 forte2_input_mask;
 
-static ADDRESS_MAP_START( program_mem, ADDRESS_SPACE_PROGRAM, 8 )
+class forte2_state : public driver_device
+{
+public:
+	forte2_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 m_input_mask;
+};
+
+
+
+static ADDRESS_MAP_START( program_mem, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( io_mem, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( io_mem, AS_IO, 8 )
 	ADDRESS_MAP_UNMAP_HIGH
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x98, 0x98) AM_READWRITE( TMS9928A_vram_r, TMS9928A_vram_w )
@@ -61,13 +71,15 @@ INPUT_PORTS_END
 
 static READ8_DEVICE_HANDLER(forte2_ay8910_read_input)
 {
-	return input_port_read(device->machine, "IN0") | (forte2_input_mask&0x3f);
+	forte2_state *state = device->machine().driver_data<forte2_state>();
+	return input_port_read(device->machine(), "IN0") | (state->m_input_mask&0x3f);
 }
 
 static WRITE8_DEVICE_HANDLER( forte2_ay8910_set_input_mask )
 {
+	forte2_state *state = device->machine().driver_data<forte2_state>();
 	/* PSG reg 15, writes 0 at coin insert, 0xff at boot and game over */
-	forte2_input_mask = data;
+	state->m_input_mask = data;
 }
 
 static const ay8910_interface forte2_ay8910_interface =
@@ -81,7 +93,7 @@ static const ay8910_interface forte2_ay8910_interface =
 };
 
 
-static void vdp_interrupt(running_machine *machine, int i)
+static void vdp_interrupt(running_machine &machine, int i)
 {
 	cputag_set_input_line(machine, "maincpu", 0, (i ? HOLD_LINE : CLEAR_LINE));
 }
@@ -94,20 +106,16 @@ static const TMS9928a_interface tms9928a_interface =
 	vdp_interrupt
 };
 
-static STATE_POSTLOAD ( forte2 )
-{
-	TMS9928A_post_load(machine);
-}
-
 static MACHINE_START( forte2 )
 {
+	forte2_state *state = machine.driver_data<forte2_state>();
 	TMS9928A_configure(&tms9928a_interface);
 
-	forte2_input_mask = 0xff;
+	state->m_input_mask = 0xff;
 
 	/* register for save states */
-	state_save_register_global(machine, forte2_input_mask);
-	state_save_register_postload(machine, forte2, NULL);
+	state_save_register_global(machine, state->m_input_mask);
+	machine.save().register_postload(save_prepost_delegate(FUNC(TMS9928A_post_load), &machine));
 }
 
 static MACHINE_RESET( forte2 )
@@ -117,11 +125,11 @@ static MACHINE_RESET( forte2 )
 
 static INTERRUPT_GEN( pesadelo_interrupt )
 {
-	TMS9928A_interrupt(device->machine);
+	TMS9928A_interrupt(device->machine());
 }
 
 
-static MACHINE_CONFIG_START( pesadelo, driver_device )
+static MACHINE_CONFIG_START( pesadelo, forte2_state )
 
 	MCFG_CPU_ADD("maincpu", Z80, 3579545)		  /* 3.579545 Mhz */
 	MCFG_CPU_PROGRAM_MAP(program_mem)
@@ -148,8 +156,8 @@ MACHINE_CONFIG_END
 static DRIVER_INIT(pesadelo)
 {
 	int i;
-	UINT8 *mem = machine->region("maincpu")->base();
-	int memsize = machine->region("maincpu")->bytes();
+	UINT8 *mem = machine.region("maincpu")->base();
+	int memsize = machine.region("maincpu")->bytes();
 	UINT8 *buf;
 
 	// data swap
