@@ -15,10 +15,13 @@
     gberetb is a bootleg hacked to run on different hardware.
 
     TODO
+        - Original Green Beret is currently running too fast so it was downgraded to an unlikely
+          refresh rate (30 Hz). Possible causes ranges from irq sources not understood (there's a custom
+          IC that controls irq timings) or even waitstates (see MT #3600).
         - Dump Green Beret Bootleg proms.  Bootleg has four proms while the original has three
           and correct the locations.
         - Dump Green Beret Bootleg PAL
-        - Green Beret boolteg xtal is 20.000 MHz
+        - Green Beret bootleg xtal is 20.000 MHz
 
 ****************************************************************************
 
@@ -73,7 +76,6 @@
 
 #include "emu.h"
 #include "cpu/z80/z80.h"
-#include "deprecat.h"
 #include "sound/sn76496.h"
 #include "includes/konamipt.h"
 #include "includes/gberet.h"
@@ -86,19 +88,37 @@
  *
  *************************************/
 
-static INTERRUPT_GEN( gberet_interrupt )
+static TIMER_DEVICE_CALLBACK( gberet_scanline )
 {
-	gberet_state *state = device->machine->driver_data<gberet_state>();
-	if (cpu_getiloops(device) == 0)
-	{
-		if (state->irq_enable)
-			cpu_set_input_line(device, 0, HOLD_LINE);
-	}
+	gberet_state *state = timer.machine().driver_data<gberet_state>();
+	int scanline = param;
 
-	if (cpu_getiloops(device) % 2)
+	if(scanline == 240)
 	{
-		if (state->nmi_enable)
-			cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
+		if (state->m_irq_enable)
+			cputag_set_input_line(timer.machine(), "maincpu", 0, HOLD_LINE);
+	}
+	else if ((scanline % 16) == 0)
+	{
+		if (state->m_nmi_enable)
+			cputag_set_input_line(timer.machine(), "maincpu", INPUT_LINE_NMI, PULSE_LINE);
+	}
+}
+
+static TIMER_DEVICE_CALLBACK( mrgoemon_scanline )
+{
+	gberet_state *state = timer.machine().driver_data<gberet_state>();
+	int scanline = param;
+
+	if(scanline == 240)
+	{
+		if (state->m_irq_enable)
+			cputag_set_input_line(timer.machine(), "maincpu", 0, HOLD_LINE);
+	}
+	else if ((scanline % 32) == 0)
+	{
+		if (state->m_nmi_enable)
+			cputag_set_input_line(timer.machine(), "maincpu", INPUT_LINE_NMI, PULSE_LINE);
 	}
 }
 
@@ -112,36 +132,36 @@ static INTERRUPT_GEN( gberet_interrupt )
 static WRITE8_HANDLER( gberet_coin_counter_w )
 {
 	/* bits 0/1 = coin counters */
-	coin_counter_w(space->machine, 0, data & 0x01);
-	coin_counter_w(space->machine, 1, data & 0x02);
+	coin_counter_w(space->machine(), 0, data & 0x01);
+	coin_counter_w(space->machine(), 1, data & 0x02);
 }
 
 static WRITE8_HANDLER( gberet_flipscreen_w )
 {
-	gberet_state *state = space->machine->driver_data<gberet_state>();
-	state->nmi_enable = data & 0x01;
-	state->irq_enable = data & 0x04;
+	gberet_state *state = space->machine().driver_data<gberet_state>();
+	state->m_nmi_enable = data & 0x01;
+	state->m_irq_enable = data & 0x04;
 
-	flip_screen_set(space->machine, data & 0x08);
+	flip_screen_set(space->machine(), data & 0x08);
 }
 
 static WRITE8_HANDLER( mrgoemon_coin_counter_w )
 {
 	/* bits 0/1 = coin counters */
-	coin_counter_w(space->machine, 0, data & 0x01);
-	coin_counter_w(space->machine, 1, data & 0x02);
+	coin_counter_w(space->machine(), 0, data & 0x01);
+	coin_counter_w(space->machine(), 1, data & 0x02);
 
 	/* bits 5-7 = ROM bank select */
-	memory_set_bank(space->machine, "bank1", ((data & 0xe0) >> 5));
+	memory_set_bank(space->machine(), "bank1", ((data & 0xe0) >> 5));
 }
 
 static WRITE8_HANDLER( mrgoemon_flipscreen_w )
 {
-	gberet_state *state = space->machine->driver_data<gberet_state>();
-	state->nmi_enable = data & 0x01;
-	state->irq_enable = data & 0x02;
+	gberet_state *state = space->machine().driver_data<gberet_state>();
+	state->m_nmi_enable = data & 0x01;
+	state->m_irq_enable = data & 0x02;
 
-	flip_screen_set(space->machine, data & 0x08);
+	flip_screen_set(space->machine(), data & 0x08);
 }
 
 /*************************************
@@ -150,14 +170,14 @@ static WRITE8_HANDLER( mrgoemon_flipscreen_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( gberet_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( gberet_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
-	AM_RANGE(0xc000, 0xc7ff) AM_RAM_WRITE(gberet_colorram_w) AM_BASE_MEMBER(gberet_state, colorram)
-	AM_RANGE(0xc800, 0xcfff) AM_RAM_WRITE(gberet_videoram_w) AM_BASE_MEMBER(gberet_state, videoram)
-	AM_RANGE(0xd000, 0xd0ff) AM_RAM AM_BASE_MEMBER(gberet_state, spriteram2)
-	AM_RANGE(0xd100, 0xd1ff) AM_RAM AM_BASE_MEMBER(gberet_state, spriteram)
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM_WRITE(gberet_colorram_w) AM_BASE_MEMBER(gberet_state, m_colorram)
+	AM_RANGE(0xc800, 0xcfff) AM_RAM_WRITE(gberet_videoram_w) AM_BASE_MEMBER(gberet_state, m_videoram)
+	AM_RANGE(0xd000, 0xd0ff) AM_RAM AM_BASE_MEMBER(gberet_state, m_spriteram2)
+	AM_RANGE(0xd100, 0xd1ff) AM_RAM AM_BASE_MEMBER(gberet_state, m_spriteram)
 	AM_RANGE(0xd200, 0xdfff) AM_RAM
-	AM_RANGE(0xe000, 0xe03f) AM_RAM_WRITE(gberet_scroll_w) AM_BASE_MEMBER(gberet_state, scrollram)
+	AM_RANGE(0xe000, 0xe03f) AM_RAM_WRITE(gberet_scroll_w) AM_BASE_MEMBER(gberet_state, m_scrollram)
 	AM_RANGE(0xe040, 0xe042) AM_WRITENOP // ???
 	AM_RANGE(0xe043, 0xe043) AM_WRITE(gberet_sprite_bank_w)
 	AM_RANGE(0xe044, 0xe044) AM_WRITE(gberet_flipscreen_w)
@@ -171,16 +191,16 @@ static ADDRESS_MAP_START( gberet_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf600, 0xf600) AM_WRITE(watchdog_reset_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( gberetb_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( gberetb_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
-	AM_RANGE(0xc000, 0xc7ff) AM_RAM_WRITE(gberet_colorram_w) AM_BASE_MEMBER(gberet_state, colorram)
-	AM_RANGE(0xc800, 0xcfff) AM_RAM_WRITE(gberet_videoram_w) AM_BASE_MEMBER(gberet_state, videoram)
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM_WRITE(gberet_colorram_w) AM_BASE_MEMBER(gberet_state, m_colorram)
+	AM_RANGE(0xc800, 0xcfff) AM_RAM_WRITE(gberet_videoram_w) AM_BASE_MEMBER(gberet_state, m_videoram)
 	AM_RANGE(0xd000, 0xdfff) AM_RAM
 	AM_RANGE(0xe000, 0xe03f) AM_RAM
 	AM_RANGE(0xe040, 0xe043) AM_WRITENOP // ???
 	AM_RANGE(0xe044, 0xe044) AM_WRITE(gberet_flipscreen_w)
 	AM_RANGE(0xe800, 0xe8ff) AM_RAM
-	AM_RANGE(0xe900, 0xe9ff) AM_RAM AM_BASE_SIZE_MEMBER(gberet_state, spriteram, spriteram_size)
+	AM_RANGE(0xe900, 0xe9ff) AM_RAM AM_BASE_SIZE_MEMBER(gberet_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0xf000, 0xf000) AM_WRITENOP				// coin counter not supported
 	AM_RANGE(0xf200, 0xf200) AM_READ_PORT("DSW2")
 	AM_RANGE(0xf400, 0xf400) AM_DEVWRITE("snsnd", sn76496_w)
@@ -192,14 +212,14 @@ static ADDRESS_MAP_START( gberetb_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf900, 0xf901) AM_WRITE(gberetb_scroll_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( mrgoemon_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( mrgoemon_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
-	AM_RANGE(0xc000, 0xc7ff) AM_RAM_WRITE(gberet_colorram_w) AM_BASE_MEMBER(gberet_state, colorram)
-	AM_RANGE(0xc800, 0xcfff) AM_RAM_WRITE(gberet_videoram_w) AM_BASE_MEMBER(gberet_state, videoram)
-	AM_RANGE(0xd000, 0xd0ff) AM_RAM AM_BASE_MEMBER(gberet_state, spriteram2)
-	AM_RANGE(0xd100, 0xd1ff) AM_RAM AM_BASE_MEMBER(gberet_state, spriteram)
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM_WRITE(gberet_colorram_w) AM_BASE_MEMBER(gberet_state, m_colorram)
+	AM_RANGE(0xc800, 0xcfff) AM_RAM_WRITE(gberet_videoram_w) AM_BASE_MEMBER(gberet_state, m_videoram)
+	AM_RANGE(0xd000, 0xd0ff) AM_RAM AM_BASE_MEMBER(gberet_state, m_spriteram2)
+	AM_RANGE(0xd100, 0xd1ff) AM_RAM AM_BASE_MEMBER(gberet_state, m_spriteram)
 	AM_RANGE(0xd200, 0xdfff) AM_RAM
-	AM_RANGE(0xe000, 0xe03f) AM_RAM_WRITE(gberet_scroll_w) AM_BASE_MEMBER(gberet_state, scrollram)
+	AM_RANGE(0xe000, 0xe03f) AM_RAM_WRITE(gberet_scroll_w) AM_BASE_MEMBER(gberet_state, m_scrollram)
 	AM_RANGE(0xe040, 0xe042) AM_WRITENOP // ???
 	AM_RANGE(0xe043, 0xe043) AM_WRITE(gberet_sprite_bank_w)
 	AM_RANGE(0xe044, 0xe044) AM_WRITE(mrgoemon_flipscreen_w)
@@ -371,20 +391,20 @@ GFXDECODE_END
 
 static MACHINE_START( gberet )
 {
-	gberet_state *state = machine->driver_data<gberet_state>();
+	gberet_state *state = machine.driver_data<gberet_state>();
 
-	state_save_register_global(machine, state->irq_enable);
-	state_save_register_global(machine, state->nmi_enable);
-	state_save_register_global(machine, state->spritebank);
+	state->save_item(NAME(state->m_irq_enable));
+	state->save_item(NAME(state->m_nmi_enable));
+	state->save_item(NAME(state->m_spritebank));
 }
 
 static MACHINE_RESET( gberet )
 {
-	gberet_state *state = machine->driver_data<gberet_state>();
+	gberet_state *state = machine.driver_data<gberet_state>();
 
-	state->irq_enable = 0;
-	state->nmi_enable = 0;
-	state->spritebank = 0;
+	state->m_irq_enable = 0;
+	state->m_nmi_enable = 0;
+	state->m_spritebank = 0;
 }
 
 static MACHINE_CONFIG_START( gberet, gberet_state )
@@ -392,7 +412,7 @@ static MACHINE_CONFIG_START( gberet, gberet_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80, MASTER_CLOCK/6)	// X1S (generated by a custom IC)
 	MCFG_CPU_PROGRAM_MAP(gberet_map)
-	MCFG_CPU_VBLANK_INT_HACK(gberet_interrupt, 32)	// 1 IRQ + 16 NMI (generated by a custom IC)
+	MCFG_TIMER_ADD_SCANLINE("scantimer", gberet_scanline, "screen", 0, 1)
 
 	MCFG_MACHINE_START(gberet)
 	MCFG_MACHINE_RESET(gberet)
@@ -404,13 +424,13 @@ static MACHINE_CONFIG_START( gberet, gberet_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(gberet)
 
 	MCFG_GFXDECODE(gberet)
 	MCFG_PALETTE_LENGTH(2*16*16)
 
 	MCFG_PALETTE_INIT(gberet)
 	MCFG_VIDEO_START(gberet)
-	MCFG_VIDEO_UPDATE(gberet)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -424,16 +444,15 @@ static MACHINE_CONFIG_DERIVED( gberetb, gberet )
 	/* basic machine hardware */
 	MCFG_CPU_MODIFY("maincpu")
 	MCFG_CPU_PROGRAM_MAP(gberetb_map)
-	MCFG_CPU_VBLANK_INT_HACK(gberet_interrupt, 16)	// 1 IRQ + 8 NMI
+	MCFG_TIMER_MODIFY("scantimer")//, mrgoemon_scanline, "screen", 0, 1)
+	MCFG_TIMER_CALLBACK(mrgoemon_scanline)
 
 	/* video hardware */
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_UPDATE(gberetb)
 
 	MCFG_GFXDECODE(gberetb)
-
-	MCFG_VIDEO_UPDATE(gberetb)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( mrgoemon, gberet )
@@ -441,12 +460,11 @@ static MACHINE_CONFIG_DERIVED( mrgoemon, gberet )
 	/* basic machine hardware */
 	MCFG_CPU_MODIFY("maincpu")
 	MCFG_CPU_PROGRAM_MAP(mrgoemon_map)
-	MCFG_CPU_VBLANK_INT_HACK(gberet_interrupt, 16)	// 1 IRQ + 8 NMI
+	MCFG_TIMER_MODIFY("scantimer")//, mrgoemon_scanline, "screen", 0, 1)
+	MCFG_TIMER_CALLBACK(mrgoemon_scanline)
 
-	/* video hardware */
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_REFRESH_RATE(60)
-	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 MACHINE_CONFIG_END
 
 /*************************************
@@ -548,7 +566,7 @@ ROM_END
 
 static DRIVER_INIT( mrgoemon )
 {
-	UINT8 *ROM = machine->region("maincpu")->base();
+	UINT8 *ROM = machine.region("maincpu")->base();
 	memory_configure_bank(machine, "bank1", 0, 8, &ROM[0x10000], 0x800);
 }
 
