@@ -72,36 +72,50 @@ U.S.A. Trivia              New Sports                 General Facts
 #include "machine/nvram.h"
 #include "sound/dac.h"
 
-static UINT8 drawctrl[3];
-static UINT8 color[8];
+
+class gei_state : public driver_device
+{
+public:
+	gei_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 m_drawctrl[3];
+	UINT8 m_color[8];
+	int m_prevoffset;
+	int m_yadd;
+	int m_signature_answer;
+	int m_signature_pos;
+};
+
 
 static WRITE8_HANDLER( gei_drawctrl_w )
 {
-	drawctrl[offset] = data;
+	gei_state *state = space->machine().driver_data<gei_state>();
+	state->m_drawctrl[offset] = data;
 	if (offset == 2)
 	{
 		int i;
 		for (i = 0; i < 8; i++)
-			if (BIT(drawctrl[1],i)) color[i] = drawctrl[0] & 7;
+			if (BIT(state->m_drawctrl[1],i)) state->m_color[i] = state->m_drawctrl[0] & 7;
 	}
 }
 
 static WRITE8_HANDLER( gei_bitmap_w )
 {
+	gei_state *state = space->machine().driver_data<gei_state>();
 	int sx,sy;
-	static int prevoffset, yadd;
 	int i;
 
-	yadd = (offset==prevoffset) ? (yadd+1):0;
-	prevoffset = offset;
+	state->m_yadd = (offset==state->m_prevoffset) ? (state->m_yadd+1):0;
+	state->m_prevoffset = offset;
 
 	sx = 8 * (offset % 64);
 	sy = offset / 64;
-	sy = (sy + yadd) & 0xff;
+	sy = (sy + state->m_yadd) & 0xff;
 
 
 	for (i = 0; i < 8; i++)
-		*BITMAP_ADDR16(space->machine->generic.tmpbitmap, sy, sx+i) = color[8-i-1];
+		*BITMAP_ADDR16(space->machine().generic.tmpbitmap, sy, sx+i) = state->m_color[8-i-1];
 }
 
 static PALETTE_INIT(gei)
@@ -127,66 +141,66 @@ static PALETTE_INIT(quizvid)
 static WRITE8_DEVICE_HANDLER( lamps_w )
 {
 	/* 5 button lamps */
-	set_led_status(device->machine, 0,data & 0x01);
-	set_led_status(device->machine, 1,data & 0x02);
-	set_led_status(device->machine, 2,data & 0x04);
-	set_led_status(device->machine, 3,data & 0x08);
-	set_led_status(device->machine, 4,data & 0x10);
+	set_led_status(device->machine(), 0,data & 0x01);
+	set_led_status(device->machine(), 1,data & 0x02);
+	set_led_status(device->machine(), 2,data & 0x04);
+	set_led_status(device->machine(), 3,data & 0x08);
+	set_led_status(device->machine(), 4,data & 0x10);
 
 	/* 3 button lamps for deal, cancel, stand in poker games;
     lamp order verified in poker and selection self tests */
-	set_led_status(device->machine, 7,data & 0x20);
-	set_led_status(device->machine, 5,data & 0x40);
-	set_led_status(device->machine, 6,data & 0x80);
+	set_led_status(device->machine(), 7,data & 0x20);
+	set_led_status(device->machine(), 5,data & 0x40);
+	set_led_status(device->machine(), 6,data & 0x80);
 }
 
 static WRITE8_DEVICE_HANDLER( sound_w )
 {
-	address_space *space = cputag_get_address_space(device->machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = device->machine().device("maincpu")->memory().space(AS_PROGRAM);
 
 	/* bit 3 - coin lockout, lamp10 in poker / lamp6 in trivia test modes */
-	coin_lockout_global_w(device->machine, ~data & 0x08);
-	set_led_status(device->machine, 9,data & 0x08);
+	coin_lockout_global_w(device->machine(), ~data & 0x08);
+	set_led_status(device->machine(), 9,data & 0x08);
 
 	/* bit 5 - ticket out in trivia games */
-	ticket_dispenser_w(device->machine->device("ticket"), 0, (data & 0x20)<< 2);
+	ticket_dispenser_w(device->machine().device("ticket"), 0, (data & 0x20)<< 2);
 
 	/* bit 6 enables NMI */
 	interrupt_enable_w(space, 0, data & 0x40);
 
 	/* bit 7 goes directly to the sound amplifier */
-	dac_data_w(device->machine->device("dac"), ((data & 0x80) >> 7) * 255);
+	dac_data_w(device->machine().device("dac"), ((data & 0x80) >> 7) * 255);
 }
 
 static WRITE8_DEVICE_HANDLER( sound2_w )
 {
 	/* bit 3,6 - coin lockout, lamp10+11 in selection test mode */
-	coin_lockout_w(device->machine, 0, ~data & 0x08);
-	coin_lockout_w(device->machine, 1, ~data & 0x40);
-	set_led_status(device->machine, 9,data & 0x08);
-	set_led_status(device->machine, 10,data & 0x40);
+	coin_lockout_w(device->machine(), 0, ~data & 0x08);
+	coin_lockout_w(device->machine(), 1, ~data & 0x40);
+	set_led_status(device->machine(), 9,data & 0x08);
+	set_led_status(device->machine(), 10,data & 0x40);
 
 	/* bit 4,5 - lamps 12, 13 in selection test mode;
     12 lights up if dsw maximum bet = 30 an bet > 15 or if dsw maximum bet = 10 an bet = 10 */
-	set_led_status(device->machine, 11,data & 0x10);
-	set_led_status(device->machine, 12,data & 0x20);
+	set_led_status(device->machine(), 11,data & 0x10);
+	set_led_status(device->machine(), 12,data & 0x20);
 
 	/* bit 7 goes directly to the sound amplifier */
-	dac_data_w(device->machine->device("dac"), ((data & 0x80) >> 7) * 255);
+	dac_data_w(device->machine().device("dac"), ((data & 0x80) >> 7) * 255);
 }
 
 static WRITE8_DEVICE_HANDLER( lamps2_w )
 {
 	/* bit 4 - play/raise button lamp, lamp 9 in poker test mode  */
-	set_led_status(device->machine, 8,data & 0x10);
+	set_led_status(device->machine(), 8,data & 0x10);
 }
 
 static WRITE8_DEVICE_HANDLER( nmi_w )
 {
-	address_space *space = cputag_get_address_space(device->machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = device->machine().device("maincpu")->memory().space(AS_PROGRAM);
 
 	/* bit 4 - play/raise button lamp, lamp 9 in selection test mode  */
-	set_led_status(device->machine, 8,data & 0x10);
+	set_led_status(device->machine(), 8,data & 0x10);
 
 	/* bit 6 enables NMI */
 	interrupt_enable_w(space, 0, data & 0x40);
@@ -194,7 +208,7 @@ static WRITE8_DEVICE_HANDLER( nmi_w )
 
 static READ8_HANDLER( catchall )
 {
-	int pc = cpu_get_pc(space->cpu);
+	int pc = cpu_get_pc(&space->device());
 
 	if (pc != 0x3c74 && pc != 0x0364 && pc != 0x036d)	/* weed out spurious blit reads */
 		logerror("%04x: unmapped memory read from %04x\n",pc,offset);
@@ -209,68 +223,68 @@ static READ8_DEVICE_HANDLER( portC_r )
 
 static WRITE8_HANDLER( banksel_main_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x8000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x8000);
 }
 static WRITE8_HANDLER( banksel_1_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x10000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x10000);
 }
 static WRITE8_HANDLER( banksel_2_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x18000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x18000);
 }
 static WRITE8_HANDLER( banksel_3_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x20000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x20000);
 }
 static WRITE8_HANDLER( banksel_4_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x28000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x28000);
 }
 static WRITE8_HANDLER( banksel_5_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x30000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x30000);
 }
 
 static WRITE8_HANDLER( banksel_1_1_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x10000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x10000);
 }
 static WRITE8_HANDLER( banksel_2_1_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x14000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x14000);
 }
 static WRITE8_HANDLER( banksel_3_1_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x18000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x18000);
 }
 static WRITE8_HANDLER( banksel_4_1_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x1c000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x1c000);
 }
 static WRITE8_HANDLER( banksel_5_1_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x20000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x20000);
 }
 static WRITE8_HANDLER( banksel_1_2_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x12000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x12000);
 }
 static WRITE8_HANDLER( banksel_2_2_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x16000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x16000);
 }
 static WRITE8_HANDLER( banksel_3_2_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x1a000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x1a000);
 }
 static WRITE8_HANDLER( banksel_4_2_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x1e000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x1e000);
 }
 static WRITE8_HANDLER( banksel_5_2_w )
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x22000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x22000);
 }
 
 static WRITE8_HANDLER(geimulti_bank_w)
@@ -298,74 +312,76 @@ static WRITE8_HANDLER(geimulti_bank_w)
 	}
 
 	if (bank != -1)
-		memory_set_bankptr(space->machine, "bank1", space->machine->region("bank")->base() + bank*0x8000);
+		memory_set_bankptr(space->machine(), "bank1", space->machine().region("bank")->base() + bank*0x8000);
 }
 
 static READ8_HANDLER(banksel_1_r)
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x10000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x10000);
 	return 0x03;
 };
 
 static READ8_HANDLER(banksel_2_r)
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x18000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x18000);
 	return 0x03;
 }
 
 static READ8_HANDLER(banksel_3_r)
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x20000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x20000);
 	return 0x03;
 }
 
 static READ8_HANDLER(banksel_4_r)
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x28000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x28000);
 	return 0x03;
 }
 
 static READ8_HANDLER(banksel_5_r)
 {
-	memory_set_bankptr(space->machine, "bank1",space->machine->region("maincpu")->base() + 0x30000);
+	memory_set_bankptr(space->machine(), "bank1",space->machine().region("maincpu")->base() + 0x30000);
 	return 0x03;
 }
 
 /* This signature is used to validate the ROMs in sportauth. Simple protection check? */
-static int signature_answer,signature_pos;
 
 static READ8_HANDLER( signature_r )
 {
-	return signature_answer;
+	gei_state *state = space->machine().driver_data<gei_state>();
+	return state->m_signature_answer;
 }
 
 static WRITE8_HANDLER( signature_w )
 {
-	if (data == 0) signature_pos = 0;
+	gei_state *state = space->machine().driver_data<gei_state>();
+	if (data == 0) state->m_signature_pos = 0;
 	else
 	{
 		static const UINT8 signature[8] = { 0xff, 0x01, 0xfd, 0x05, 0xf5, 0x15, 0xd5, 0x55 };
 
-		signature_answer = signature[signature_pos++];
+		state->m_signature_answer = signature[state->m_signature_pos++];
 
-		signature_pos &= 7;	/* safety; shouldn't happen */
+		state->m_signature_pos &= 7;	/* safety; shouldn't happen */
 	}
 }
 
 static WRITE8_HANDLER( signature2_w )
 {
-	if (data == 0) signature_pos = 0;
+	gei_state *state = space->machine().driver_data<gei_state>();
+	if (data == 0) state->m_signature_pos = 0;
 	else
 	{
 		static const UINT8 signature[8] = { 0xff, 0x01, 0xf7, 0x11, 0xd7, 0x51, 0x57, 0x51 };
 
-		signature_answer = signature[signature_pos++];
+		state->m_signature_answer = signature[state->m_signature_pos++];
 
-		signature_pos &= 7;	/* safety; shouldn't happen */
+		state->m_signature_pos &= 7;	/* safety; shouldn't happen */
 	}
 }
 
-static ADDRESS_MAP_START( getrivia_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( getrivia_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x3fff) AM_ROMBANK("bank1")
 	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_SHARE("nvram")
@@ -387,7 +403,7 @@ static ADDRESS_MAP_START( getrivia_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xffff) AM_RAM_WRITE(gei_bitmap_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( gselect_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( gselect_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x3fff) AM_ROMBANK("bank1")
 	AM_RANGE(0x4000, 0x40ff) AM_RAM AM_SHARE("nvram")
@@ -402,7 +418,7 @@ static ADDRESS_MAP_START( gselect_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 // TODO: where are mapped the lower 0x2000 bytes of the banks?
-static ADDRESS_MAP_START( amuse_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( amuse_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x3fff) AM_ROMBANK("bank1")
 	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_SHARE("nvram")
@@ -418,7 +434,7 @@ static ADDRESS_MAP_START( amuse_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xffff) AM_RAM_WRITE(gei_bitmap_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( gepoker_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( gepoker_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x3fff) AM_ROMBANK("bank1")
 	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_SHARE("nvram")
@@ -435,7 +451,7 @@ static ADDRESS_MAP_START( gepoker_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xffff) AM_RAM_WRITE(gei_bitmap_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( amuse1_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( amuse1_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x3fff) AM_ROMBANK("bank1")
 	AM_RANGE(0x4000, 0x43ff) AM_RAM AM_SHARE("nvram")
@@ -452,7 +468,7 @@ static ADDRESS_MAP_START( amuse1_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xffff) AM_RAM_WRITE(gei_bitmap_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( findout_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( findout_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x4800, 0x4803) AM_DEVREADWRITE("ppi8255_0", ppi8255_r,ppi8255_w)
@@ -473,7 +489,7 @@ static ADDRESS_MAP_START( findout_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xffff) AM_READ(catchall)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( quizvid_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( quizvid_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x4800, 0x4803) AM_DEVREADWRITE("ppi8255_0", ppi8255_r,ppi8255_w)
@@ -491,7 +507,7 @@ static ADDRESS_MAP_START( quizvid_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xffff) AM_READ(catchall)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( suprpokr_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( suprpokr_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x4800, 0x4803) AM_DEVREADWRITE("ppi8255_0", ppi8255_r, ppi8255_w)
@@ -503,7 +519,7 @@ static ADDRESS_MAP_START( suprpokr_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( geimulti_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( geimulti_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x4800, 0x4803) AM_DEVREADWRITE("ppi8255_0", ppi8255_r, ppi8255_w)
@@ -516,7 +532,7 @@ static ADDRESS_MAP_START( geimulti_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xffff) AM_RAM_WRITE(gei_bitmap_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sprtauth_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sprtauth_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x4800, 0x4803) AM_DEVREADWRITE("ppi8255_0", ppi8255_r, ppi8255_w)
@@ -1047,7 +1063,7 @@ static const ppi8255_interface findout_ppi8255_intf[2] =
 	}
 };
 
-static MACHINE_CONFIG_START( getrivia, driver_device )
+static MACHINE_CONFIG_START( getrivia, gei_state )
 	MCFG_CPU_ADD("maincpu",Z80,4000000) /* 4 MHz */
 	MCFG_CPU_PROGRAM_MAP(getrivia_map)
 	MCFG_CPU_VBLANK_INT("screen", nmi_line_pulse)
@@ -1059,6 +1075,7 @@ static MACHINE_CONFIG_START( getrivia, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(512, 256)
 	MCFG_SCREEN_VISIBLE_AREA(48, 511-48, 16, 255-16)
+	MCFG_SCREEN_UPDATE(generic_bitmapped)
 
 	MCFG_PALETTE_LENGTH(8)
 	MCFG_PALETTE_INIT(gei)
@@ -1066,7 +1083,6 @@ static MACHINE_CONFIG_START( getrivia, driver_device )
 	MCFG_NVRAM_ADD_0FILL("nvram")
 
 	MCFG_VIDEO_START(generic_bitmapped)
-	MCFG_VIDEO_UPDATE(generic_bitmapped)
 
 	MCFG_PPI8255_ADD( "ppi8255_0", getrivia_ppi8255_intf[0] )
 	MCFG_PPI8255_ADD( "ppi8255_1", getrivia_ppi8255_intf[1] )
@@ -1808,12 +1824,12 @@ ROM_END
 
 static DRIVER_INIT( setbank )
 {
-	memory_set_bankptr(machine, "bank1",machine->region("maincpu")->base() + 0x2000);
+	memory_set_bankptr(machine, "bank1",machine.region("maincpu")->base() + 0x2000);
 }
 
 static DRIVER_INIT( geimulti )
 {
-	memory_set_bankptr(machine, "bank1",machine->region("bank")->base() + 0x0000);
+	memory_set_bankptr(machine, "bank1",machine.region("bank")->base() + 0x0000);
 }
 
 GAME( 1982, jokpoker, 0,        gselect,  gselect,  setbank, ROT0, "Greyhound Electronics", "Joker Poker (Version 16.03B)",            GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
@@ -1853,15 +1869,15 @@ GAME( 1984, gt103asx, gtsers8,  findout,  gt103a,   0,       ROT0, "Greyhound El
 GAME( 1985, sextriv1, 0,        getrivia, sextriv1, 0,       ROT0, "Kinky Kit and Game Co.", "Sexual Trivia (Version 1.02SB, set 1)",  GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
 GAME( 1985, sextriv2, sextriv1, getrivia, sextriv1, 0,       ROT0, "Kinky Kit and Game Co.", "Sexual Trivia (Version 1.02SB, set 2)",  GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
 
-GAME( 1986, gt507uk,  0,        findout,  gt507uk,  0,       ROT0, "Greyhound Electronics", "Trivia (UK Version 5.07)",                GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
-GAME( 1986, gt5,      0,        findout,  gt103,    0,       ROT0, "Greyhound Electronics", "Trivia (Version 5.06)",                   GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
+GAME( 1986, gt507uk,  0,        findout,  gt507uk,  0,       ROT0, "Grayhound Electronics", "Trivia (UK Version 5.07)",                GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
+GAME( 1986, gt5,      0,        findout,  gt103,    0,       ROT0, "Grayhound Electronics", "Trivia (Version 5.06)",                   GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
 
 GAME( 1986, quiz,     0,        findout,  quiz,     0,       ROT0, "bootleg",               "Quiz (Revision 2)",                       GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
 
 GAME( 1986, quizvid,  0,        quizvid,  quiz,     0,       ROT0, "bootleg",               "Video Quiz",                              GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
 
-GAME( 1986, reelfun,  0,        findout,  reelfun,  0,       ROT0, "Greyhound Electronics", "Reel Fun (Version 7.03)",                 GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
-GAME( 1986, reelfun1, reelfun,  findout,  reelfun,  0,       ROT0, "Greyhound Electronics", "Reel Fun (Version 7.01)",                 GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
+GAME( 1986, reelfun,  0,        findout,  reelfun,  0,       ROT0, "Grayhound Electronics", "Reel Fun (Version 7.03)",                 GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
+GAME( 1986, reelfun1, reelfun,  findout,  reelfun,  0,       ROT0, "Grayhound Electronics", "Reel Fun (Version 7.01)",                 GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
 GAME( 1987, findout,  0,        findout,  findout,  0,       ROT0, "Elettronolo",           "Find Out (Version 4.04)",                 GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
 
 GAME( 1986, suprpokr, 0,        suprpokr, suprpokr, 0,       ROT0, "Grayhound Electronics", "Super Poker (Version 10.19S)",            GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
@@ -1869,5 +1885,5 @@ GAME( 1986, suprpkr1, suprpokr, suprpokr, suprpokr, 0,       ROT0, "Grayhound El
 
 GAME( 1991, quiz211,  0,        findout,  quiz,     0,       ROT0, "Elettronolo",           "Quiz (Revision 2.11)",                    GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
 
-GAME( 1992, geimulti, 0,        geimulti, geimulti, geimulti,ROT0, "Greyhound Electronics",  "GEI Multi Game",                         GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
-GAME( 1992, sprtauth, 0,        sprtauth, sprtauth, geimulti,ROT0, "Classic Games",          "Sports Authority",                       GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
+GAME( 1992, geimulti, 0,        geimulti, geimulti, geimulti,ROT0, "Grayhound Electronics", "GEI Multi Game",                          GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
+GAME( 1992, sprtauth, 0,        sprtauth, sprtauth, geimulti,ROT0, "Classic Games",         "Sports Authority",                        GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND )
