@@ -44,17 +44,23 @@ f5d6    print 7 digit BCD number: d0.l to (a1)+ color $3000
                                 To Do
                                 -----
 
-- The sound section will benefit from proper MC6840 and YM8950 emulation
+- game doesn't init paletteram / tilemaps properly, ending up with MAME
+  palette defaults at start-up and missing text layer if you coin it up
+  too soon.
 
 ***************************************************************************/
 
 #include "emu.h"
-#include "cpu/m6809/m6809.h"
 #include "cpu/m68000/m68000.h"
-#include "deprecat.h"
+#include "cpu/m6809/m6809.h"
 #include "sound/ay8910.h"
 #include "sound/8950intf.h"
 #include "includes/ginganin.h"
+#include "machine/6840ptm.h"
+
+
+#define MAIN_CLOCK XTAL_6MHz
+#define SOUND_CLOCK XTAL_3_579545MHz
 
 
 /*
@@ -64,15 +70,15 @@ f5d6    print 7 digit BCD number: d0.l to (a1)+ color $3000
 */
 
 
-static ADDRESS_MAP_START( ginganin_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( ginganin_map, AS_PROGRAM, 16 )
 /* The ROM area: 10000-13fff is written with: 0000 0000 0000 0001, at startup only. Why? */
 	AM_RANGE(0x000000, 0x01ffff) AM_ROM
 	AM_RANGE(0x020000, 0x023fff) AM_RAM
-	AM_RANGE(0x030000, 0x0307ff) AM_RAM_WRITE(ginganin_txtram16_w) AM_BASE_MEMBER(ginganin_state, txtram)
-	AM_RANGE(0x040000, 0x0407ff) AM_RAM AM_BASE_SIZE_MEMBER(ginganin_state, spriteram, spriteram_size)
+	AM_RANGE(0x030000, 0x0307ff) AM_RAM_WRITE(ginganin_txtram16_w) AM_BASE_MEMBER(ginganin_state, m_txtram)
+	AM_RANGE(0x040000, 0x0407ff) AM_RAM AM_BASE_SIZE_MEMBER(ginganin_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x050000, 0x0507ff) AM_RAM_WRITE(paletteram16_RRRRGGGGBBBBxxxx_word_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0x060000, 0x06000f) AM_RAM_WRITE(ginganin_vregs16_w) AM_BASE_MEMBER(ginganin_state, vregs)
-	AM_RANGE(0x068000, 0x06bfff) AM_RAM_WRITE(ginganin_fgram16_w) AM_BASE_MEMBER(ginganin_state, fgram)
+	AM_RANGE(0x060000, 0x06000f) AM_RAM_WRITE(ginganin_vregs16_w) AM_BASE_MEMBER(ginganin_state, m_vregs)
+	AM_RANGE(0x068000, 0x06bfff) AM_RAM_WRITE(ginganin_fgram16_w) AM_BASE_MEMBER(ginganin_state, m_fgram)
 	AM_RANGE(0x070000, 0x070001) AM_READ_PORT("P1_P2")
 	AM_RANGE(0x070002, 0x070003) AM_READ_PORT("DSW")
 ADDRESS_MAP_END
@@ -84,66 +90,9 @@ ADDRESS_MAP_END
 **
 */
 
-static WRITE8_HANDLER( MC6840_control_port_0_w )
-{
-	/* MC6840 Emulation by Takahiro Nogi. 1999/09/27
-    (This routine hasn't been completed yet.) */
-
-	ginganin_state *state = space->machine->driver_data<ginganin_state>();
-	state->MC6840_index0 = data;
-
-	if (state->MC6840_index0 & 0x80)	/* enable timer output */
-	{
-		if ((state->MC6840_register0 != state->S_TEMPO) && (state->MC6840_register0 != 0))
-		{
-			state->S_TEMPO = state->MC6840_register0;
-#ifdef MAME_DEBUG
-			popmessage("I0:0x%02X R0:0x%02X I1:0x%02X R1:0x%02X", state->MC6840_index0, state->MC6840_register0, state->MC6840_index1, state->MC6840_register1);
-#endif
-		}
-		state->MC6809_FLAG = 1;
-	}
-	else
-		state->MC6809_FLAG = 0;
-
-#ifdef MAME_DEBUG
-	logerror("MC6840 Write:(0x%02X)0x%02X\n", state->MC6840_register0,  data);
-#endif
-}
-
-static WRITE8_HANDLER( MC6840_control_port_1_w )
-{
-	/* MC6840 Emulation by Takahiro Nogi. 1999/09/27
-    (This routine hasn't been completed yet.) */
-
-	ginganin_state *state = space->machine->driver_data<ginganin_state>();
-	state->MC6840_index1 = data;
-}
-
-static WRITE8_HANDLER( MC6840_write_port_0_w )
-{
-	/* MC6840 Emulation by Takahiro Nogi. 1999/09/27
-    (This routine hasn't been completed yet.) */
-
-	ginganin_state *state = space->machine->driver_data<ginganin_state>();
-	state->MC6840_register0 = data;
-}
-
-static WRITE8_HANDLER( MC6840_write_port_1_w )
-{
-	/* MC6840 Emulation by Takahiro Nogi. 1999/09/27
-    (This routine hasn't been completed yet.) */
-
-	ginganin_state *state = space->machine->driver_data<ginganin_state>();
-	state->MC6840_register1 = data;
-}
-
-static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_RAM
-	AM_RANGE(0x0800, 0x0800) AM_WRITE(MC6840_control_port_0_w)	/* Takahiro Nogi. 1999/09/27 */
-	AM_RANGE(0x0801, 0x0801) AM_WRITE(MC6840_control_port_1_w)	/* Takahiro Nogi. 1999/09/27 */
-	AM_RANGE(0x0802, 0x0802) AM_WRITE(MC6840_write_port_0_w)		/* Takahiro Nogi. 1999/09/27 */
-	AM_RANGE(0x0803, 0x0803) AM_WRITE(MC6840_write_port_1_w)		/* Takahiro Nogi. 1999/09/27 */
+	AM_RANGE(0x0800, 0x0807) AM_DEVREADWRITE_MODERN("6840ptm", ptm6840_device, read, write)
 	AM_RANGE(0x1800, 0x1800) AM_READ(soundlatch_r)
 	AM_RANGE(0x2000, 0x2001) AM_DEVWRITE("ymsnd", y8950_w)
 	AM_RANGE(0x2800, 0x2801) AM_DEVWRITE("aysnd", ay8910_address_data_w)
@@ -218,7 +167,7 @@ static INPUT_PORTS_START( ginganin )
 	PORT_DIPNAME( 0x4000, 0x4000, DEF_STR( Flip_Screen ) )
 	PORT_DIPSETTING(	  0x4000, DEF_STR( Off ) )
 	PORT_DIPSETTING(	  0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x8000, 0x8000, "Freeze (Cheat)")
+	PORT_DIPNAME( 0x8000, 0x8000, "Freeze" )
 	PORT_DIPSETTING(	  0x8000, DEF_STR( Off ) )
 	PORT_DIPSETTING(	  0x0000, DEF_STR( On ) )
 INPUT_PORTS_END
@@ -272,31 +221,6 @@ GFXDECODE_END
 
 
 
-/* Modified by Takahiro Nogi. 1999/09/27 */
-static INTERRUPT_GEN( ginganin_sound_interrupt )
-{
-	/* MC6840 Emulation by Takahiro Nogi. 1999/09/27
-    (This routine hasn't been completed yet.) */
-
-	ginganin_state *state = device->machine->driver_data<ginganin_state>();
-
-	if (state->S_TEMPO_OLD != state->S_TEMPO)
-	{
-		state->S_TEMPO_OLD = state->S_TEMPO;
-		state->MC6809_CTR = 0;
-	}
-
-	if (state->MC6809_FLAG != 0)
-	{
-		if (state->MC6809_CTR > state->S_TEMPO)
-		{
-			state->MC6809_CTR = 0;
-			cpu_set_input_line(device, 0, HOLD_LINE);
-		}
-		else
-			state->MC6809_CTR++;
-	}
-}
 
 
 
@@ -304,53 +228,51 @@ static INTERRUPT_GEN( ginganin_sound_interrupt )
 
 static MACHINE_START( ginganin )
 {
-	ginganin_state *state = machine->driver_data<ginganin_state>();
+	ginganin_state *state = machine.driver_data<ginganin_state>();
 
-	state->audiocpu = machine->device("audiocpu");
+	state->m_audiocpu = machine.device("audiocpu");
 
-	state_save_register_global(machine, state->layers_ctrl);
-	state_save_register_global(machine, state->flipscreen);
-	state_save_register_global(machine, state->MC6840_index0);
-	state_save_register_global(machine, state->MC6840_register0);
-	state_save_register_global(machine, state->MC6840_index1);
-	state_save_register_global(machine, state->MC6840_register1);
-	state_save_register_global(machine, state->S_TEMPO);
-	state_save_register_global(machine, state->S_TEMPO_OLD);
-	state_save_register_global(machine, state->MC6809_CTR);
-	state_save_register_global(machine, state->MC6809_FLAG);
+	state->save_item(NAME(state->m_layers_ctrl));
+	state->save_item(NAME(state->m_flipscreen));
 }
 
 static MACHINE_RESET( ginganin )
 {
-	ginganin_state *state = machine->driver_data<ginganin_state>();
+	ginganin_state *state = machine.driver_data<ginganin_state>();
 
-	state->layers_ctrl = 0;
-	state->flipscreen = 0;
-	state->MC6840_index0 = 0;
-	state->MC6840_register0 = 0;
-	state->MC6840_index1 = 0;
-	state->MC6840_register1 = 0;
-	state->S_TEMPO = 0;
-	state->S_TEMPO_OLD = 0;
-	state->MC6809_CTR = 0;
-	state->MC6809_FLAG = 0;
+	state->m_layers_ctrl = 0;
+	state->m_flipscreen = 0;
 }
 
 
+static WRITE8_DEVICE_HANDLER( ptm_irq )
+{
+	cputag_set_input_line(device->machine(), "audiocpu", 0, (data & 1) ? ASSERT_LINE : CLEAR_LINE);
+}
+
+static const ptm6840_interface ptm_intf =
+{
+	SOUND_CLOCK/2,
+	{ 0, 0, 0 },
+	{ DEVCB_HANDLER(ptm_irq), DEVCB_NULL, DEVCB_NULL },
+	DEVCB_NULL
+};
+
 static MACHINE_CONFIG_START( ginganin, ginganin_state )
 
 	/* basic machine hardware */
-	MCFG_CPU_ADD("maincpu", M68000, 6000000)	/* ? */
+	MCFG_CPU_ADD("maincpu", M68000, MAIN_CLOCK)
 	MCFG_CPU_PROGRAM_MAP(ginganin_map)
 	MCFG_CPU_VBLANK_INT("screen", irq1_line_hold) /* ? (vectors 1-7 cointain the same address) */
 
-	MCFG_CPU_ADD("audiocpu", M6809, 1000000)
+	MCFG_CPU_ADD("audiocpu", M6809, SOUND_CLOCK)
 	MCFG_CPU_PROGRAM_MAP(sound_map)
-	MCFG_CPU_VBLANK_INT_HACK(ginganin_sound_interrupt,60)	/* Takahiro Nogi. 1999/09/27 (1 -> 60) */
 
 	MCFG_MACHINE_START(ginganin)
 	MCFG_MACHINE_RESET(ginganin)
 
+	MCFG_PTM6840_ADD("6840ptm", ptm_intf)
+
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
@@ -358,20 +280,20 @@ static MACHINE_CONFIG_START( ginganin, ginganin_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 255, 0 + 16 , 255 - 16)
+	MCFG_SCREEN_UPDATE(ginganin)
 
 	MCFG_GFXDECODE(ginganin)
 	MCFG_PALETTE_LENGTH(1024)
 
 	MCFG_VIDEO_START(ginganin)
-	MCFG_VIDEO_UPDATE(ginganin)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MCFG_SOUND_ADD("aysnd", AY8910, 3579545 / 2)
+	MCFG_SOUND_ADD("aysnd", AY8910, SOUND_CLOCK / 2)
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
-	MCFG_SOUND_ADD("ymsnd", Y8950, 3579545)	/* The Y8950 is basically a YM3526 with ADPCM built in */
+	MCFG_SOUND_ADD("ymsnd", Y8950, SOUND_CLOCK)	/* The Y8950 is basically a YM3526 with ADPCM built in */
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_CONFIG_END
 
@@ -459,7 +381,7 @@ static DRIVER_INIT( ginganin )
 	UINT16 *rom;
 
 	/* main cpu patches */
-	rom = (UINT16 *)machine->region("maincpu")->base();
+	rom = (UINT16 *)machine.region("maincpu")->base();
 	/* avoid writes to rom getting to the log */
 	rom[0x408 / 2] = 0x6000;
 	rom[0x40a / 2] = 0x001c;
@@ -467,7 +389,7 @@ static DRIVER_INIT( ginganin )
 
 	/* sound cpu patches */
 	/* let's clear the RAM: ROM starts at 0x4000 */
-	memset(machine->region("audiocpu")->base(), 0, 0x800);
+	memset(machine.region("audiocpu")->base(), 0, 0x800);
 }
 
 
