@@ -38,47 +38,48 @@ voice.rom - VOICE ROM
 class good_state : public driver_device
 {
 public:
-	good_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	good_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT16 *  bg_tilemapram;
-	UINT16 *  fg_tilemapram;
-	UINT16 *  sprites;
-//  UINT16 *  paletteram;   // currently this uses generic palette handling
+	UINT16 *  m_bg_tilemapram;
+	UINT16 *  m_fg_tilemapram;
+	UINT16 *  m_sprites;
+//  UINT16 *  m_paletteram;   // currently this uses generic palette handling
 
 	/* video-related */
-	tilemap_t  *bg_tilemap,*fg_tilemap;
+	tilemap_t  *m_bg_tilemap;
+	tilemap_t  *m_fg_tilemap;
 };
 
 
 static WRITE16_HANDLER( fg_tilemapram_w )
 {
-	good_state *state = space->machine->driver_data<good_state>();
-	COMBINE_DATA(&state->fg_tilemapram[offset]);
-	tilemap_mark_tile_dirty(state->fg_tilemap, offset / 2);
+	good_state *state = space->machine().driver_data<good_state>();
+	COMBINE_DATA(&state->m_fg_tilemapram[offset]);
+	tilemap_mark_tile_dirty(state->m_fg_tilemap, offset / 2);
 }
 
 static TILE_GET_INFO( get_fg_tile_info )
 {
-	good_state *state = machine->driver_data<good_state>();
-	int tileno = state->fg_tilemapram[tile_index * 2];
-	int attr = state->fg_tilemapram[tile_index * 2 + 1] & 0xf;
+	good_state *state = machine.driver_data<good_state>();
+	int tileno = state->m_fg_tilemapram[tile_index * 2];
+	int attr = state->m_fg_tilemapram[tile_index * 2 + 1] & 0xf;
 	SET_TILE_INFO(0, tileno, attr, 0);
 }
 
 static WRITE16_HANDLER( bg_tilemapram_w )
 {
-	good_state *state = space->machine->driver_data<good_state>();
-	COMBINE_DATA(&state->bg_tilemapram[offset]);
-	tilemap_mark_tile_dirty(state->bg_tilemap, offset / 2);
+	good_state *state = space->machine().driver_data<good_state>();
+	COMBINE_DATA(&state->m_bg_tilemapram[offset]);
+	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset / 2);
 }
 
 static TILE_GET_INFO( get_bg_tile_info )
 {
-	good_state *state = machine->driver_data<good_state>();
-	int tileno = state->bg_tilemapram[tile_index * 2];
-	int attr = state->bg_tilemapram[tile_index * 2 + 1] & 0xf;
+	good_state *state = machine.driver_data<good_state>();
+	int tileno = state->m_bg_tilemapram[tile_index * 2];
+	int attr = state->m_bg_tilemapram[tile_index * 2 + 1] & 0xf;
 	SET_TILE_INFO(1, tileno, attr, 0);
 }
 
@@ -86,21 +87,21 @@ static TILE_GET_INFO( get_bg_tile_info )
 
 static VIDEO_START( good )
 {
-	good_state *state = machine->driver_data<good_state>();
-	state->bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows, 16, 16, 32, 32);
-	state->fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_rows, 16, 16, 32, 32);
-	tilemap_set_transparent_pen(state->fg_tilemap, 0xf);
+	good_state *state = machine.driver_data<good_state>();
+	state->m_bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows, 16, 16, 32, 32);
+	state->m_fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_rows, 16, 16, 32, 32);
+	tilemap_set_transparent_pen(state->m_fg_tilemap, 0xf);
 }
 
-static VIDEO_UPDATE( good )
+static SCREEN_UPDATE( good )
 {
-	good_state *state = screen->machine->driver_data<good_state>();
-	tilemap_draw(bitmap, cliprect, state->bg_tilemap, 0, 0);
-	tilemap_draw(bitmap, cliprect, state->fg_tilemap, 0, 0);
+	good_state *state = screen->machine().driver_data<good_state>();
+	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
+	tilemap_draw(bitmap, cliprect, state->m_fg_tilemap, 0, 0);
 	return 0;
 }
 
-static ADDRESS_MAP_START( good_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( good_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x01ffff) AM_ROM
 
 	//AM_RANGE(0x270000, 0x270007) AM_RAM // scroll?
@@ -112,8 +113,8 @@ static ADDRESS_MAP_START( good_map, ADDRESS_SPACE_PROGRAM, 16 )
 
 	AM_RANGE(0x800000, 0x8007ff) AM_RAM_WRITE(paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE_GENERIC(paletteram)
 
-	AM_RANGE(0x820000, 0x820fff) AM_RAM_WRITE(fg_tilemapram_w) AM_BASE_MEMBER(good_state, fg_tilemapram)
-	AM_RANGE(0x822000, 0x822fff) AM_RAM_WRITE(bg_tilemapram_w) AM_BASE_MEMBER(good_state, bg_tilemapram)
+	AM_RANGE(0x820000, 0x820fff) AM_RAM_WRITE(fg_tilemapram_w) AM_BASE_MEMBER(good_state, m_fg_tilemapram)
+	AM_RANGE(0x822000, 0x822fff) AM_RAM_WRITE(bg_tilemapram_w) AM_BASE_MEMBER(good_state, m_bg_tilemapram)
 
 	AM_RANGE(0xff0000, 0xffefff) AM_RAM
 ADDRESS_MAP_END
@@ -286,11 +287,11 @@ static MACHINE_CONFIG_START( good, good_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*16, 32*16)
 	MCFG_SCREEN_VISIBLE_AREA(1*16, 23*16-1, 0*16, 14*16-1)
+	MCFG_SCREEN_UPDATE(good)
 
 	MCFG_PALETTE_LENGTH(0x400)
 
 	MCFG_VIDEO_START(good)
-	MCFG_VIDEO_UPDATE(good)
 
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
