@@ -56,14 +56,21 @@ Notes:
 #include "sound/3812intf.h"
 #include "includes/sei_crtc.h"
 
+
+class goodejan_state : public driver_device
+{
+public:
+	goodejan_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT16 m_mux_data;
+};
+
+
 #define GOODEJAN_MHZ1 7159090
 #define GOODEJAN_MHZ2 16000000
 #define GOODEJAN_MHZ3 12000000
 
-extern UINT16 *seibucrtc_sc0vram,*seibucrtc_sc1vram,*seibucrtc_sc2vram,*seibucrtc_sc3vram;
-extern UINT16 *seibucrtc_vregs;
-extern UINT16 seibucrtc_sc0bank;
-static UINT16 goodejan_mux_data;
 
 static WRITE16_HANDLER( goodejan_gfxbank_w )
 {
@@ -73,16 +80,17 @@ static WRITE16_HANDLER( goodejan_gfxbank_w )
 /* Multiplexer device for the mahjong panel */
 static READ16_HANDLER( mahjong_panel_r )
 {
+	goodejan_state *state = space->machine().driver_data<goodejan_state>();
 	UINT16 ret;
 	ret = 0xffff;
 
-	switch(goodejan_mux_data)
+	switch(state->m_mux_data)
 	{
-		case 1:    ret = input_port_read(space->machine, "KEY0"); break;
-		case 2:    ret = input_port_read(space->machine, "KEY1"); break;
-		case 4:    ret = input_port_read(space->machine, "KEY2"); break;
-		case 8:    ret = input_port_read(space->machine, "KEY3"); break;
-		case 0x10: ret = input_port_read(space->machine, "KEY4"); break;
+		case 1:    ret = input_port_read(space->machine(), "KEY0"); break;
+		case 2:    ret = input_port_read(space->machine(), "KEY1"); break;
+		case 4:    ret = input_port_read(space->machine(), "KEY2"); break;
+		case 8:    ret = input_port_read(space->machine(), "KEY3"); break;
+		case 0x10: ret = input_port_read(space->machine(), "KEY4"); break;
 	}
 
 	return ret;
@@ -90,10 +98,11 @@ static READ16_HANDLER( mahjong_panel_r )
 
 static WRITE16_HANDLER( mahjong_panel_w )
 {
-	goodejan_mux_data = data;
+	goodejan_state *state = space->machine().driver_data<goodejan_state>();
+	state->m_mux_data = data;
 }
 
-static ADDRESS_MAP_START( goodejan_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( goodejan_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x00000, 0x0afff) AM_RAM
 	AM_RANGE(0x0c000, 0x0c7ff) AM_RAM_WRITE(seibucrtc_sc0vram_w) AM_BASE(&seibucrtc_sc0vram)
 	AM_RANGE(0x0c800, 0x0cfff) AM_RAM_WRITE(seibucrtc_sc3vram_w) AM_BASE(&seibucrtc_sc3vram)
@@ -101,12 +110,12 @@ static ADDRESS_MAP_START( goodejan_map, ADDRESS_SPACE_PROGRAM, 16 )
 	/*Guess: these two aren't used/initialized at all.*/
 	AM_RANGE(0x0e000, 0x0e7ff) AM_RAM_WRITE(seibucrtc_sc1vram_w) AM_BASE(&seibucrtc_sc1vram)
 	AM_RANGE(0x0e800, 0x0efff) AM_RAM_WRITE(seibucrtc_sc2vram_w) AM_BASE(&seibucrtc_sc2vram)
-	AM_RANGE(0x0f800, 0x0ffff) AM_RAM AM_BASE_GENERIC(spriteram)
+	AM_RANGE(0x0f800, 0x0ffff) AM_RAM AM_SHARE("spriteram")
 	AM_RANGE(0xc0000, 0xfffff) AM_ROM
 ADDRESS_MAP_END
 
 /*totmejan CRT is at 8000-804f,goodejan is at 8040-807f(808f but not tested)*/
-static ADDRESS_MAP_START( common_io_map, ADDRESS_SPACE_IO, 16 )
+static ADDRESS_MAP_START( common_io_map, AS_IO, 16 )
 	AM_RANGE(0x9000, 0x9001) AM_WRITE(goodejan_gfxbank_w)
 	AM_RANGE(0xb000, 0xb003) AM_WRITENOP
 	AM_RANGE(0xb004, 0xb005) AM_WRITE(mahjong_panel_w)
@@ -117,12 +126,12 @@ static ADDRESS_MAP_START( common_io_map, ADDRESS_SPACE_IO, 16 )
 	AM_RANGE(0xd000, 0xd00f) AM_READWRITE(seibu_main_word_r, seibu_main_word_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( totmejan_io_map, ADDRESS_SPACE_IO, 16 )
+static ADDRESS_MAP_START( totmejan_io_map, AS_IO, 16 )
 	AM_RANGE(0x8000, 0x804f) AM_RAM_WRITE(seibucrtc_vregs_w) AM_BASE(&seibucrtc_vregs)
 	AM_IMPORT_FROM(common_io_map)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( goodejan_io_map, ADDRESS_SPACE_IO, 16 )
+static ADDRESS_MAP_START( goodejan_io_map, AS_IO, 16 )
 	AM_RANGE(0x8040, 0x807f) AM_RAM_WRITE(seibucrtc_vregs_w) AM_BASE(&seibucrtc_vregs)
 	AM_IMPORT_FROM(common_io_map)
 ADDRESS_MAP_END
@@ -321,45 +330,44 @@ GFXDECODE_END
 
 static INTERRUPT_GEN( goodejan_irq )
 {
-	cpu_set_input_line_and_vector(device,0,HOLD_LINE,0x208/4);
+	device_set_input_line_and_vector(device,0,HOLD_LINE,0x208/4);
 /* vector 0x00c is just a reti */
 }
 
-static MACHINE_DRIVER_START( goodejan )
+static MACHINE_CONFIG_START( goodejan, goodejan_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", V30, GOODEJAN_MHZ2/2)
-	MDRV_CPU_PROGRAM_MAP(goodejan_map)
-	MDRV_CPU_IO_MAP(goodejan_io_map)
-	MDRV_CPU_VBLANK_INT("screen",goodejan_irq)
+	MCFG_CPU_ADD("maincpu", V30, GOODEJAN_MHZ2/2)
+	MCFG_CPU_PROGRAM_MAP(goodejan_map)
+	MCFG_CPU_IO_MAP(goodejan_io_map)
+	MCFG_CPU_VBLANK_INT("screen",goodejan_irq)
 
 	SEIBU_SOUND_SYSTEM_CPU(GOODEJAN_MHZ1/2)
 
-	MDRV_MACHINE_RESET(seibu_sound)
+	MCFG_MACHINE_RESET(seibu_sound)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1) //TODO: dynamic resolution
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1) //TODO: dynamic resolution
+	MCFG_SCREEN_UPDATE(seibu_crtc)
 
-	MDRV_GFXDECODE(goodejan)
-	MDRV_PALETTE_LENGTH(0x1000)
+	MCFG_GFXDECODE(goodejan)
+	MCFG_PALETTE_LENGTH(0x1000)
 
-	MDRV_VIDEO_START(seibu_crtc)
-	MDRV_VIDEO_UPDATE(seibu_crtc)
+	MCFG_VIDEO_START(seibu_crtc)
 
 	/* sound hardware */
 	SEIBU_SOUND_SYSTEM_YM3812_INTERFACE(GOODEJAN_MHZ1/2,GOODEJAN_MHZ2/16)
-MACHINE_DRIVER_END
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( totmejan )
-	MDRV_IMPORT_FROM( goodejan )
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_IO_MAP(totmejan_io_map)
-MACHINE_DRIVER_END
+static MACHINE_CONFIG_DERIVED( totmejan, goodejan )
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_IO_MAP(totmejan_io_map)
+MACHINE_CONFIG_END
 
 ROM_START( totmejan )
 	ROM_REGION( 0x100000, "maincpu", 0 ) /* V30 code */
