@@ -30,21 +30,21 @@
 
 static TILE_GET_INFO( get_hitme_tile_info )
 {
-	hitme_state *state = machine->driver_data<hitme_state>();
+	hitme_state *state = machine.driver_data<hitme_state>();
 
 	/* the code is the low 6 bits */
-	UINT8 code = state->videoram[tile_index] & 0x3f;
+	UINT8 code = state->m_videoram[tile_index] & 0x3f;
 	SET_TILE_INFO(0, code, 0, 0);
 }
 
 
 static WRITE8_HANDLER( hitme_vidram_w )
 {
-	hitme_state *state = space->machine->driver_data<hitme_state>();
+	hitme_state *state = space->machine().driver_data<hitme_state>();
 
 	/* mark this tile dirty */
-	state->videoram[offset] = data;
-	tilemap_mark_tile_dirty(state->tilemap, offset);
+	state->m_videoram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_tilemap, offset);
 }
 
 
@@ -57,23 +57,23 @@ static WRITE8_HANDLER( hitme_vidram_w )
 
 static VIDEO_START( hitme )
 {
-	hitme_state *state = machine->driver_data<hitme_state>();
-	state->tilemap = tilemap_create(machine, get_hitme_tile_info, tilemap_scan_rows, 8, 10, 40, 19);
+	hitme_state *state = machine.driver_data<hitme_state>();
+	state->m_tilemap = tilemap_create(machine, get_hitme_tile_info, tilemap_scan_rows, 8, 10, 40, 19);
 }
 
 
 static VIDEO_START( barricad )
 {
-	hitme_state *state = machine->driver_data<hitme_state>();
-	state->tilemap = tilemap_create(machine, get_hitme_tile_info, tilemap_scan_rows, 8, 8, 32, 24);
+	hitme_state *state = machine.driver_data<hitme_state>();
+	state->m_tilemap = tilemap_create(machine, get_hitme_tile_info, tilemap_scan_rows, 8, 8, 32, 24);
 }
 
 
-static VIDEO_UPDATE( hitme )
+static SCREEN_UPDATE( hitme )
 {
-	hitme_state *state = screen->machine->driver_data<hitme_state>();
+	hitme_state *state = screen->machine().driver_data<hitme_state>();
 	/* the card width resistor comes from an input port, scaled to the range 0-25 kOhms */
-	double width_resist = input_port_read(screen->machine, "WIDTH") * 25000 / 100;
+	double width_resist = input_port_read(screen->machine(), "WIDTH") * 25000 / 100;
 	/* this triggers a oneshot for the following length of time */
 	double width_duration = 0.45 * 1000e-12 * width_resist;
 	/* the dot clock runs at the standard horizontal frequency * 320+16 clocks per scanline */
@@ -84,7 +84,7 @@ static VIDEO_UPDATE( hitme )
 	offs_t offs = 0;
 
 	/* start by drawing the tilemap */
-	tilemap_draw(bitmap, cliprect, state->tilemap, 0, 0);
+	tilemap_draw(bitmap, cliprect, state->m_tilemap, 0, 0);
 
 	/* now loop over and invert anything */
 	for (y = 0; y < 19; y++)
@@ -93,7 +93,7 @@ static VIDEO_UPDATE( hitme )
 		for (inv = x = 0; x < 40; x++, offs++)
 		{
 			/* if the high bit is set, reset the oneshot */
-			if (state->videoram[y * 40 + x] & 0x80)
+			if (state->m_videoram[y * 40 + x] & 0x80)
 				inv = width_pixels;
 
 			/* invert pixels until we run out */
@@ -117,10 +117,10 @@ static VIDEO_UPDATE( hitme )
 }
 
 
-static VIDEO_UPDATE( barricad )
+static SCREEN_UPDATE( barricad )
 {
-	hitme_state *state = screen->machine->driver_data<hitme_state>();
-	tilemap_draw(bitmap, cliprect, state->tilemap, 0, 0);
+	hitme_state *state = screen->machine().driver_data<hitme_state>();
+	tilemap_draw(bitmap, cliprect, state->m_tilemap, 0, 0);
 	return 0;
 }
 
@@ -132,22 +132,22 @@ static VIDEO_UPDATE( barricad )
  *
  *************************************/
 
-static UINT8 read_port_and_t0( running_machine *machine, int port )
+static UINT8 read_port_and_t0( running_machine &machine, int port )
 {
-	hitme_state *state = machine->driver_data<hitme_state>();
+	hitme_state *state = machine.driver_data<hitme_state>();
 	static const char *const portnames[] = { "IN0", "IN1", "IN2", "IN3" };
 
 	UINT8 val = input_port_read(machine, portnames[port]);
-	if (attotime_compare(timer_get_time(machine), state->timeout_time) > 0)
+	if (machine.time() > state->m_timeout_time)
 		val ^= 0x80;
 	return val;
 }
 
 
-static UINT8 read_port_and_t0_and_hblank( running_machine *machine, int port )
+static UINT8 read_port_and_t0_and_hblank( running_machine &machine, int port )
 {
 	UINT8 val = read_port_and_t0(machine, port);
-	if (machine->primary_screen->hpos() < (machine->primary_screen->width() * 9 / 10))
+	if (machine.primary_screen->hpos() < (machine.primary_screen->width() * 9 / 10))
 		val ^= 0x04;
 	return val;
 }
@@ -155,25 +155,25 @@ static UINT8 read_port_and_t0_and_hblank( running_machine *machine, int port )
 
 static READ8_HANDLER( hitme_port_0_r )
 {
-	return read_port_and_t0_and_hblank(space->machine, 0);
+	return read_port_and_t0_and_hblank(space->machine(), 0);
 }
 
 
 static READ8_HANDLER( hitme_port_1_r )
 {
-	return read_port_and_t0(space->machine, 1);
+	return read_port_and_t0(space->machine(), 1);
 }
 
 
 static READ8_HANDLER( hitme_port_2_r )
 {
-	return read_port_and_t0_and_hblank(space->machine, 2);
+	return read_port_and_t0_and_hblank(space->machine(), 2);
 }
 
 
 static READ8_HANDLER( hitme_port_3_r )
 {
-	return read_port_and_t0(space->machine, 3);
+	return read_port_and_t0(space->machine(), 3);
 }
 
 
@@ -192,11 +192,11 @@ static WRITE8_DEVICE_HANDLER( output_port_0_w )
         In fact, it is very important that our timing calculation timeout AFTER the sound
         system's equivalent computation, or else we will hang notes.
     */
-	hitme_state *state = device->machine->driver_data<hitme_state>();
-	UINT8 raw_game_speed = input_port_read(device->machine, "R3");
+	hitme_state *state = device->machine().driver_data<hitme_state>();
+	UINT8 raw_game_speed = input_port_read(device->machine(), "R3");
 	double resistance = raw_game_speed * 25000 / 100;
-	attotime duration = attotime_make(0, ATTOSECONDS_PER_SECOND * 0.45 * 6.8e-6 * resistance * (data + 1));
-	state->timeout_time = attotime_add(timer_get_time(device->machine), duration);
+	attotime duration = attotime(0, ATTOSECONDS_PER_SECOND * 0.45 * 6.8e-6 * resistance * (data + 1));
+	state->m_timeout_time = device->machine().time() + duration;
 
 	discrete_sound_w(device, HITME_DOWNCOUNT_VAL, data);
 	discrete_sound_w(device, HITME_OUT0, 1);
@@ -224,10 +224,10 @@ static WRITE8_DEVICE_HANDLER( output_port_1_w )
     upper 8 bits.
 */
 
-static ADDRESS_MAP_START( hitme_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( hitme_map, AS_PROGRAM, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0x1fff)
 	AM_RANGE(0x0000, 0x09ff) AM_ROM
-	AM_RANGE(0x0c00, 0x0eff) AM_RAM_WRITE(hitme_vidram_w) AM_BASE_MEMBER(hitme_state, videoram)
+	AM_RANGE(0x0c00, 0x0eff) AM_RAM_WRITE(hitme_vidram_w) AM_BASE_MEMBER(hitme_state, m_videoram)
 	AM_RANGE(0x1000, 0x10ff) AM_MIRROR(0x300) AM_RAM
 	AM_RANGE(0x1400, 0x14ff) AM_READ(hitme_port_0_r)
 	AM_RANGE(0x1500, 0x15ff) AM_READ(hitme_port_1_r)
@@ -240,7 +240,7 @@ static ADDRESS_MAP_START( hitme_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( hitme_portmap, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( hitme_portmap, AS_IO, 8 )
 	AM_RANGE(0x14, 0x14) AM_READ(hitme_port_0_r)
 	AM_RANGE(0x15, 0x15) AM_READ(hitme_port_1_r)
 	AM_RANGE(0x16, 0x16) AM_READ(hitme_port_2_r)
@@ -311,9 +311,9 @@ static MACHINE_START( hitme )
 
 static MACHINE_RESET( hitme )
 {
-	hitme_state *state = machine->driver_data<hitme_state>();
+	hitme_state *state = machine.driver_data<hitme_state>();
 
-	state->timeout_time = attotime_zero;
+	state->m_timeout_time = attotime::zero;
 }
 
 static MACHINE_CONFIG_START( hitme, hitme_state )
@@ -333,13 +333,13 @@ static MACHINE_CONFIG_START( hitme, hitme_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(40*8, 19*10)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 19*10-1)
+	MCFG_SCREEN_UPDATE(hitme)
 
 	MCFG_GFXDECODE(hitme)
 	MCFG_PALETTE_LENGTH(2)
 
 	MCFG_PALETTE_INIT(black_and_white)
 	MCFG_VIDEO_START(hitme)
-	MCFG_VIDEO_UPDATE(hitme)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -363,11 +363,11 @@ static MACHINE_CONFIG_DERIVED( barricad, hitme )
 	MCFG_SCREEN_MODIFY("screen")
 	MCFG_SCREEN_SIZE(32*8, 24*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 24*8-1)
+	MCFG_SCREEN_UPDATE(barricad)
 
 	MCFG_GFXDECODE(barricad)
 
 	MCFG_VIDEO_START(barricad)
-	MCFG_VIDEO_UPDATE(barricad)
 MACHINE_CONFIG_END
 
 
@@ -414,7 +414,7 @@ static INPUT_PORTS_START( hitme )
 	PORT_START("IN3")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )				/* Time out counter (TOC1) */
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNUSED )					/* Always high */
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNUSED )					/* Aux 2 dipswitch - Unused*/
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNUSED )					/* Aux 2 dipswitch - Unused */
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNUSED )					/* Always high */
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(4)	/* P4 Stand button */
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(4)	/* P4 Hit button */
@@ -454,6 +454,61 @@ static INPUT_PORTS_START( hitme )
 	PORT_ADJUSTER(50, "Card Width")
 INPUT_PORTS_END
 
+static INPUT_PORTS_START( super21 )
+	PORT_START("IN0")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN4 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SPECIAL )				/* Hblank */
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )				/* Always high */
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(4)	/* P4 Stand button */
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(4)	/* P4 Hit button */
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(4)	/* P4 Ante button */
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SPECIAL )				/* Time out counter (*TO) */
+
+	PORT_START("IN1")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN3 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )				/* Aux 2 dipswitch? */
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(3)	/* P3 Stand button */
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(3)	/* P3 Hit button */
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(3)	/* P3 Ante button */
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SPECIAL )				/* Time out counter (*TO) */
+
+	PORT_START("IN2")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )				/* Aux 1 dipswitch? */
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SPECIAL )				/* Hblank */
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)	/* P2 Stand button */
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)	/* P2 Hit button */
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)	/* P2 Ante button */
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SPECIAL )				/* Time out counter (*TO) */
+
+	PORT_START("IN3")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )				/* Time out counter (TOC1) */
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )				/* Aux 2 dipswitch? */
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)	/* P1 Stand button */
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)	/* P1 Hit button */
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)	/* P1 Ante button */
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SPECIAL )				/* Time out counter (*TO) */
+
+	PORT_START("IN4")
+	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+
+	PORT_START("IN5") // bit 2 is chip/bet related, but also causes gfx glitches when set
+	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+
+	/* this is actually a variable resistor */
+	PORT_START("R3")
+	PORT_ADJUSTER(30, "Game Speed")
+
+	/* this is actually a variable resistor */
+	PORT_START("WIDTH")
+	PORT_ADJUSTER(50, "Card Width")
+INPUT_PORTS_END
 
 static INPUT_PORTS_START( barricad )
 	PORT_START("IN0")
@@ -489,7 +544,7 @@ static INPUT_PORTS_START( barricad )
 	PORT_START("IN3")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )						/* Time out counter (TOC1) */
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )						/* Always high */
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )						/* Aux 2 dipswitch - Unused*/
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )						/* Aux 2 dipswitch - Unused */
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  ) PORT_PLAYER(2)
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT  ) PORT_PLAYER(2)
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  ) PORT_PLAYER(2)
@@ -571,7 +626,7 @@ All chips we read as 82s141 - guessed becuase of 24 pin pinout and 512x8 rom acc
 ROM_START( hitme )
 	ROM_REGION( 0x2000, "maincpu", ROMREGION_INVERT )
 	ROM_LOAD( "hm2-0.b7", 0x0000, 0x0200, CRC(1b94caad) SHA1(30987e5cb0d55f3666dd63f04132a0e65988caea) )
-	ROM_LOAD( "hm-2-2.c7", 0x0200, 0x0200, CRC(fa7e8c33) SHA1(2d04635cee32d49cccd9a9a855b3a2be4295c2a5) )
+	ROM_LOAD( "hm-2-2.c7",0x0200, 0x0200, CRC(fa7e8c33) SHA1(2d04635cee32d49cccd9a9a855b3a2be4295c2a5) )
 	ROM_LOAD( "hm1-4.d7", 0x0400, 0x0200, CRC(10dd4581) SHA1(eaa7c9e75f79befc8abf0bd0913bbf15dd04230e) )
 	ROM_LOAD( "hm1-6.e7", 0x0600, 0x0200, CRC(18e4c83c) SHA1(bce987da371b7946262d7dff65f61ff2fcb55bf6) )
 	ROM_LOAD( "hm2-8.f7", 0x0800, 0x0200, CRC(f28983f8) SHA1(89167cf41ba71d90cd6133751158bb99bfc5e829) )
@@ -591,7 +646,6 @@ ROM_START( hitme1 )
 	ROM_LOAD( "hmcg.h7", 0x0000, 0x0200, CRC(818f5fbe) SHA1(e2b3349e51ba57d14f3388ba93891bc6274b7a14) )
 ROM_END
 
-
 ROM_START( m21 )
 	ROM_REGION( 0x2000, "maincpu", ROMREGION_INVERT )
 	ROM_LOAD( "mirco1.bin", 0x0000, 0x0200, CRC(aa796ad7) SHA1(2908bdb4ab17a2f5bc4da2f957906bf2b57afa50) )
@@ -603,6 +657,17 @@ ROM_START( m21 )
 	ROM_LOAD( "hmcg.h7", 0x0000, 0x0200, CRC(818f5fbe) SHA1(e2b3349e51ba57d14f3388ba93891bc6274b7a14) )
 ROM_END
 
+ROM_START( super21 )
+	ROM_REGION( 0x2000, "maincpu", ROMREGION_INVERT )
+	ROM_LOAD( "1.h1", 0x0000, 0x0200, CRC(cecf2224) SHA1(794d7b9f2533f7c00bbe1c7b3d37eb08c25a09bb) )
+	ROM_LOAD( "3.h2", 0x0200, 0x0200, CRC(eb62ea5f) SHA1(e4b9fafe2cab5a31549504ce430eadc230e3da39) )
+	ROM_LOAD( "2.j1", 0x0400, 0x0200, CRC(fea88bf2) SHA1(a18081cecd29c7929e589c5fda7ba1033ef8e7c3) )
+	ROM_LOAD( "4.j2", 0x0600, 0x0200, CRC(63238ddb) SHA1(7197640e758d7ef93c659eeea098424d3aa50314) )
+	ROM_LOAD( "5.k2", 0x0800, 0x0200, CRC(89983131) SHA1(c22c02a3bff0a61c5f341f1c2b3b37150ad2c1e3) )
+
+	ROM_REGION( 0x0400, "gfx1", ROMREGION_ERASE00 )
+	ROM_LOAD( "7.h6", 0x0000, 0x0200, CRC(818f5fbe) SHA1(e2b3349e51ba57d14f3388ba93891bc6274b7a14) )
+ROM_END
 
 ROM_START( barricad )
    ROM_REGION( 0x2000, "maincpu", ROMREGION_INVERT )
@@ -615,7 +680,6 @@ ROM_START( barricad )
    ROM_LOAD( "550805.7h",   0x0000, 0x0200, CRC(35197599) SHA1(3c49af89b1bc1d495e1d6265ff3feaf33c56facb) )
 ROM_END
 
-
 ROM_START( brickyrd )
    ROM_REGION( 0x2000, "maincpu", ROMREGION_INVERT )
    ROM_LOAD( "550806.7b",   0x0000, 0x0200, CRC(ea7f5da7) SHA1(c0ad37a0ffdb0500e8adc8fb9c4369e461307f84) )
@@ -635,8 +699,9 @@ ROM_END
  *
  *************************************/
 
-GAME( 1976, hitme,    0,        hitme,    hitme,    0, ROT0, "RamTek", "Hit Me (set 1)",  GAME_SUPPORTS_SAVE )
+GAME( 1976, hitme,    0,        hitme,    hitme,    0, ROT0, "RamTek", "Hit Me (set 1)",  GAME_SUPPORTS_SAVE )	// 05/1976
 GAME( 1976, hitme1,   hitme,    hitme,    hitme,    0, ROT0, "RamTek", "Hit Me (set 2)",  GAME_SUPPORTS_SAVE )
-GAME( 1976, m21,      hitme,    hitme,    hitme,    0, ROT0, "Mirco",  "21 (Mirco)", GAME_SUPPORTS_SAVE )
+GAME( 1976, m21,      hitme,    hitme,    hitme,    0, ROT0, "Mirco Games",  "21 (Mirco)", GAME_SUPPORTS_SAVE )	// 08/1976, licensed?
+GAME( 1978, super21,  0,        hitme,    super21,  0, ROT0, "Mirco Games",  "Super Twenty One", GAME_SUPPORTS_SAVE )
 GAME( 1976, barricad, 0,        barricad, barricad, 0, ROT0, "RamTek", "Barricade",  GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
 GAME( 1976, brickyrd, barricad, barricad, barricad, 0, ROT0, "RamTek", "Brickyard",  GAME_IMPERFECT_SOUND | GAME_SUPPORTS_SAVE )
