@@ -6,6 +6,9 @@ Ikki (c) 1985 Sun Electronics
 
     20/Jun/2001 -
 
+TODO:
+- understand proper CPU communications and irq firing;
+
 *****************************************************************************/
 
 #include "emu.h"
@@ -25,15 +28,15 @@ static READ8_HANDLER( ikki_e000_r )
 {
 /* bit1: interrupt type?, bit0: CPU2 busack? */
 
-	if (cpu_getiloops(space->cpu) == 0)
+	if (cpu_getiloops(&space->device()) == 0)
 		return 0;
 	return 2;
 }
 
 static WRITE8_HANDLER( ikki_coin_counters )
 {
-	coin_counter_w(space->machine, 0, data & 0x01);
-	coin_counter_w(space->machine, 1, data & 0x02);
+	coin_counter_w(space->machine(), 0, data & 0x01);
+	coin_counter_w(space->machine(), 1, data & 0x02);
 }
 
 /*************************************
@@ -42,11 +45,11 @@ static WRITE8_HANDLER( ikki_coin_counters )
  *
  *************************************/
 
-static ADDRESS_MAP_START( ikki_cpu1, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( ikki_cpu1, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x9fff) AM_ROM
 	AM_RANGE(0xc000, 0xc7ff) AM_RAM
 	AM_RANGE(0xc800, 0xcfff) AM_RAM AM_SHARE("share1")
-	AM_RANGE(0xd000, 0xd7ff) AM_RAM AM_BASE_SIZE_MEMBER(ikki_state, videoram, videoram_size)
+	AM_RANGE(0xd000, 0xd7ff) AM_RAM AM_BASE_SIZE_MEMBER(ikki_state, m_videoram, m_videoram_size)
 	AM_RANGE(0xe000, 0xe000) AM_READ(ikki_e000_r)
 	AM_RANGE(0xe001, 0xe001) AM_READ_PORT("DSW1")
 	AM_RANGE(0xe002, 0xe002) AM_READ_PORT("DSW2")
@@ -55,12 +58,12 @@ static ADDRESS_MAP_START( ikki_cpu1, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xe005, 0xe005) AM_READ_PORT("P2")
 	AM_RANGE(0xe008, 0xe008) AM_WRITE(ikki_scrn_ctrl_w)
 	AM_RANGE(0xe009, 0xe009) AM_WRITE(ikki_coin_counters)
-	AM_RANGE(0xe00a, 0xe00b) AM_WRITEONLY AM_BASE_MEMBER(ikki_state, scroll)
+	AM_RANGE(0xe00a, 0xe00b) AM_WRITEONLY AM_BASE_MEMBER(ikki_state, m_scroll)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( ikki_cpu2, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( ikki_cpu2, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
-	AM_RANGE(0xc000, 0xc7ff) AM_RAM AM_BASE_SIZE_MEMBER(ikki_state, spriteram, spriteram_size)
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM AM_BASE_SIZE_MEMBER(ikki_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0xc800, 0xcfff) AM_RAM AM_SHARE("share1")
 	AM_RANGE(0xd801, 0xd801) AM_DEVWRITE("sn1", sn76496_w)
 	AM_RANGE(0xd802, 0xd802) AM_DEVWRITE("sn2", sn76496_w)
@@ -208,17 +211,17 @@ GFXDECODE_END
 
 static MACHINE_START( ikki )
 {
-	ikki_state *state = machine->driver_data<ikki_state>();
+	ikki_state *state = machine.driver_data<ikki_state>();
 
-	state_save_register_global(machine, state->flipscreen);
-	state_save_register_global(machine, state->punch_through_pen);
+	state->save_item(NAME(state->m_flipscreen));
+	state->save_item(NAME(state->m_punch_through_pen));
 }
 
 static MACHINE_RESET( ikki )
 {
-	ikki_state *state = machine->driver_data<ikki_state>();
+	ikki_state *state = machine.driver_data<ikki_state>();
 
-	state->flipscreen = 0;
+	state->m_flipscreen = 0;
 }
 
 static MACHINE_CONFIG_START( ikki, ikki_state )
@@ -232,7 +235,7 @@ static MACHINE_CONFIG_START( ikki, ikki_state )
 	MCFG_CPU_PROGRAM_MAP(ikki_cpu2)
 	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,2)
 
-	MCFG_QUANTUM_TIME(HZ(600))
+	MCFG_QUANTUM_TIME(attotime::from_hz(600))
 
 	MCFG_MACHINE_START(ikki)
 	MCFG_MACHINE_RESET(ikki)
@@ -244,13 +247,13 @@ static MACHINE_CONFIG_START( ikki, ikki_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(ikki)
 
 	MCFG_GFXDECODE(ikki)
 	MCFG_PALETTE_LENGTH(1024)
 
 	MCFG_PALETTE_INIT(ikki)
 	MCFG_VIDEO_START(ikki)
-	MCFG_VIDEO_UPDATE(ikki)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
