@@ -170,49 +170,53 @@ there are 9 PALS on the pcb (not dumped)
 #include "emu.h"
 #include "cpu/m68000/m68000.h"
 #include "deprecat.h"
+#include "machine/nvram.h"
 #include "sound/ymz280b.h"
-#include "includes/suprnova.h"
 #include "includes/kaneko16.h"
+#include "video/sknsspr.h"
 
-static bitmap_t *sprite_bitmap_1;
-static bitmap_t *sprite_bitmap_2;
+class jchan_state : public kaneko16_state
+{
+public:
+	jchan_state(const machine_config &mconfig, device_type type, const char *tag)
+		: kaneko16_state(mconfig, type, tag) { }
 
-static UINT32* jchan_sprite_ram32_1;
-static UINT32* jchan_sprite_ram32_2;
-static UINT32* jchan_sprite_regs32_1;
-static UINT32* jchan_sprite_regs32_2;
+	bitmap_t *m_sprite_bitmap_1;
+	bitmap_t *m_sprite_bitmap_2;
+	UINT32* m_sprite_ram32_1;
+	UINT32* m_sprite_ram32_2;
+	UINT32* m_sprite_regs32_1;
+	UINT32* m_sprite_regs32_2;
+	int m_irq_sub_enable;
+	UINT16 *m_spriteram_1;
+	UINT16* m_sprregs_1;
+	UINT16 *m_spriteram_2;
+	UINT16* m_sprregs_2;
+	UINT16 *m_mainsub_shared_ram;
+	UINT8 m_nvram_data[128];
+	UINT16 *m_mcu_ram;
+	UINT16 m_mcu_com[4];
+	UINT16 *m_ctrl;
 
-static int jchan_irq_sub_enable;
+	sknsspr_device* m_spritegen1;
+	sknsspr_device* m_spritegen2;
+};
 
-static UINT16 *jchan_spriteram_1;
-static UINT16* jchan_sprregs_1;
-static UINT16 *jchan_spriteram_2;
-static UINT16* jchan_sprregs_2;
-
-static UINT16 *mainsub_shared_ram;
 
 /***************************************************************************
 
                             MCU Code Simulation
-                (follows the implementation of kaneko16.c)
-
-Provided we find a working PCB, trojan code will help:
-- to get this game working (but there are many #4 sub-commands!)
-- to have more patterns and eventualy defeat the MCU 'encryption'
-- decapping and manually recovering the interal ROM is being persued
-
-This will benefit galpani3 and other kaneko16 games with TOYBOX MCU.
 
 ***************************************************************************/
-static UINT16 *mcu_ram, jchan_mcu_com[4];
 
-static void jchan_mcu_run(running_machine *machine)
+static void jchan_mcu_run(running_machine &machine)
 {
-	UINT16 mcu_command = mcu_ram[0x0010/2];		/* command nb */
-	UINT16 mcu_offset  = mcu_ram[0x0012/2] / 2;	/* offset in shared RAM where MCU will write */
-	UINT16 mcu_subcmd  = mcu_ram[0x0014/2];		/* sub-command parameter, happens only for command #4 */
+	jchan_state *state = machine.driver_data<jchan_state>();
+	UINT16 mcu_command = state->m_mcu_ram[0x0010/2];		/* command nb */
+	UINT16 mcu_offset  = state->m_mcu_ram[0x0012/2] / 2;	/* offset in shared RAM where MCU will write */
+	UINT16 mcu_subcmd  = state->m_mcu_ram[0x0014/2];		/* sub-command parameter, happens only for command #4 */
 
-	logerror("%s : MCU executed command: %04X %04X %04X ",cpuexec_describe_context(machine),mcu_command,mcu_offset*2,mcu_subcmd);
+	logerror("%s : MCU executed command: %04X %04X %04X ",machine.describe_context(),mcu_command,mcu_offset*2,mcu_subcmd);
 
 /*
     the only MCU commands found in program code are:
@@ -226,37 +230,27 @@ static void jchan_mcu_run(running_machine *machine)
 	{
 		case 0x04: /* Protection: during self-test for mcu_subcmd = 0x3d, 0x3e, 0x3f */
 		{
-			 toxboy_handle_04_subcommand(machine,mcu_subcmd,mcu_ram);
+			 toxboy_handle_04_subcommand(machine,mcu_subcmd,state->m_mcu_ram);
 		}
 		break;
 
 		case 0x03:	// DSW
 		{
-			mcu_ram[mcu_offset] = input_port_read(machine, "DSW");
-			logerror("%s : MCU executed command: %04X %04X (read DSW)\n",cpuexec_describe_context(machine),mcu_command,mcu_offset*2);
+			state->m_mcu_ram[mcu_offset] = input_port_read(machine, "DSW");
+			logerror("%s : MCU executed command: %04X %04X (read DSW)\n",machine.describe_context(),mcu_command,mcu_offset*2);
 		}
 		break;
 
 		case 0x02: /* load game settings from 93C46 EEPROM ($1090-$10dc) */
 		{
-			mame_file *f;
-			if ((f = nvram_fopen(machine, OPEN_FLAG_READ)) != 0)
-			{
-				mame_fread(f,&mcu_ram[mcu_offset], 128);
-				mame_fclose(f);
-			}
+			memcpy(&state->m_mcu_ram[mcu_offset], state->m_nvram_data, sizeof(state->m_nvram_data));
 			logerror("(load NVRAM settings)\n");
 		}
 		break;
 
 		case 0x42: /* save game settings to 93C46 EEPROM ($50d4) */
 		{
-			mame_file *f;
-			if ((f = nvram_fopen(machine, OPEN_FLAG_WRITE | OPEN_FLAG_CREATE | OPEN_FLAG_CREATE_PATHS)) != 0)
-			{
-				mame_fwrite(f,&mcu_ram[mcu_offset], 128);
-				mame_fclose(f);
-			}
+			memcpy(state->m_nvram_data, &state->m_mcu_ram[mcu_offset], sizeof(state->m_nvram_data));
 			logerror("(save NVRAM settings)\n");
 		}
 		break;
@@ -266,27 +260,27 @@ static void jchan_mcu_run(running_machine *machine)
 	}
 }
 
-#define JCHAN_MCU_COM_W(_n_) \
-static WRITE16_HANDLER( jchan_mcu_com##_n_##_w ) \
-{ \
-	COMBINE_DATA(&jchan_mcu_com[_n_]); \
-	if (jchan_mcu_com[0] != 0xFFFF)	return; \
-	if (jchan_mcu_com[1] != 0xFFFF)	return; \
-	if (jchan_mcu_com[2] != 0xFFFF)	return; \
-	if (jchan_mcu_com[3] != 0xFFFF)	return; \
-\
-	memset(jchan_mcu_com, 0, 4 * sizeof( UINT16 ) ); \
-	jchan_mcu_run(space->machine); \
+INLINE void jchan_mcu_com_w(address_space *space, offs_t offset, UINT16 data, UINT16 mem_mask, int _n_)
+{
+	jchan_state *state = space->machine().driver_data<jchan_state>();
+	COMBINE_DATA(&state->m_mcu_com[_n_]);
+	if (state->m_mcu_com[0] != 0xFFFF)	return;
+	if (state->m_mcu_com[1] != 0xFFFF)	return;
+	if (state->m_mcu_com[2] != 0xFFFF)	return;
+	if (state->m_mcu_com[3] != 0xFFFF)	return;
+
+	memset(state->m_mcu_com, 0, 4 * sizeof( UINT16 ) );
+	jchan_mcu_run(space->machine());
 }
 
-JCHAN_MCU_COM_W(0)
-JCHAN_MCU_COM_W(1)
-JCHAN_MCU_COM_W(2)
-JCHAN_MCU_COM_W(3)
+static WRITE16_HANDLER( jchan_mcu_com0_w ) { jchan_mcu_com_w(space, offset, data, mem_mask, 0); }
+static WRITE16_HANDLER( jchan_mcu_com1_w ) { jchan_mcu_com_w(space, offset, data, mem_mask, 1); }
+static WRITE16_HANDLER( jchan_mcu_com2_w ) { jchan_mcu_com_w(space, offset, data, mem_mask, 2); }
+static WRITE16_HANDLER( jchan_mcu_com3_w ) { jchan_mcu_com_w(space, offset, data, mem_mask, 3); }
 
 static READ16_HANDLER( jchan_mcu_status_r )
 {
-	logerror("cpu '%s' (PC=%06X): read mcu status\n", space->cpu->tag(), cpu_get_previouspc(space->cpu));
+	logerror("cpu '%s' (PC=%06X): read mcu status\n", space->device().tag(), cpu_get_previouspc(&space->device()));
 	return 0;
 }
 
@@ -305,35 +299,36 @@ static READ16_HANDLER( jchan_mcu_status_r )
 //  move was performed
 static INTERRUPT_GEN( jchan_vblank )
 {
+	jchan_state *state = device->machine().driver_data<jchan_state>();
 	int i = cpu_getiloops(device);
 	switch (i)
 	{
 
 		case 0:
-			cpu_set_input_line(device, 1, HOLD_LINE);
+			device_set_input_line(device, 1, HOLD_LINE);
 			break;
 
 		case 100:
-			cpu_set_input_line(device, 2, HOLD_LINE);
+			device_set_input_line(device, 2, HOLD_LINE);
 			break;
 
 	}
 
-	if (jchan_irq_sub_enable)
+	if (state->m_irq_sub_enable)
 	{
 		switch (i)
 		{
 
 			case 0:
-				cputag_set_input_line(device->machine, "sub", 1, HOLD_LINE);
+				cputag_set_input_line(device->machine(), "sub", 1, HOLD_LINE);
 				break;
 
 			case 220:
-				cputag_set_input_line(device->machine, "sub", 2, HOLD_LINE);
+				cputag_set_input_line(device->machine(), "sub", 2, HOLD_LINE);
 				break;
 
 			case 100:
-				cputag_set_input_line(device->machine, "sub", 3, HOLD_LINE);
+				cputag_set_input_line(device->machine(), "sub", 3, HOLD_LINE);
 				break;
 
 		}
@@ -345,18 +340,24 @@ static INTERRUPT_GEN( jchan_vblank )
 
 static VIDEO_START(jchan)
 {
+	jchan_state *state = machine.driver_data<jchan_state>();
 	/* so we can use suprnova.c */
-	jchan_sprite_ram32_1 = auto_alloc_array(machine, UINT32, 0x4000/4);
-	jchan_sprite_ram32_2 = auto_alloc_array(machine, UINT32, 0x4000/4);
+	state->m_sprite_ram32_1 = auto_alloc_array(machine, UINT32, 0x4000/4);
+	state->m_sprite_ram32_2 = auto_alloc_array(machine, UINT32, 0x4000/4);
 
-	machine->generic.spriteram_size = 0x4000;
-	jchan_sprite_regs32_1 = auto_alloc_array(machine, UINT32, 0x40/4);
-	jchan_sprite_regs32_2 = auto_alloc_array(machine, UINT32, 0x40/4);
+	machine.generic.spriteram_size = 0x4000;
+	state->m_sprite_regs32_1 = auto_alloc_array(machine, UINT32, 0x40/4);
+	state->m_sprite_regs32_2 = auto_alloc_array(machine, UINT32, 0x40/4);
 
-	sprite_bitmap_1 = auto_bitmap_alloc(machine,1024,1024,BITMAP_FORMAT_INDEXED16);
-	sprite_bitmap_2 = auto_bitmap_alloc(machine,1024,1024,BITMAP_FORMAT_INDEXED16);
+	state->m_sprite_bitmap_1 = auto_bitmap_alloc(machine,1024,1024,BITMAP_FORMAT_INDEXED16);
+	state->m_sprite_bitmap_2 = auto_bitmap_alloc(machine,1024,1024,BITMAP_FORMAT_INDEXED16);
 
-	suprnova_alt_enable_sprites = 1;
+	state->m_spritegen1 = machine.device<sknsspr_device>("spritegen1");
+	state->m_spritegen2 = machine.device<sknsspr_device>("spritegen2");
+
+
+	state->m_spritegen1->skns_sprite_kludge(0,0);
+	state->m_spritegen2->skns_sprite_kludge(0,0);
 
 	VIDEO_START_CALL( kaneko16_1xVIEW2_tilemaps );
 }
@@ -367,8 +368,9 @@ static VIDEO_START(jchan)
 
 
 
-static VIDEO_UPDATE(jchan)
+static SCREEN_UPDATE(jchan)
 {
+	jchan_state *state = screen->machine().driver_data<jchan_state>();
 	int x,y;
 	UINT16* src1;
 	UINT16* src2;
@@ -376,21 +378,21 @@ static VIDEO_UPDATE(jchan)
 	UINT16 pixdata1;
 	UINT16 pixdata2;
 
-	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine()));
 
-	VIDEO_UPDATE_CALL(jchan_view2);
+	SCREEN_UPDATE_CALL(jchan_view2);
 
-	bitmap_fill(sprite_bitmap_1, cliprect, 0x0000);
-	bitmap_fill(sprite_bitmap_2, cliprect, 0x0000);
+	bitmap_fill(state->m_sprite_bitmap_1, cliprect, 0x0000);
+	bitmap_fill(state->m_sprite_bitmap_2, cliprect, 0x0000);
 
-	skns_draw_sprites(screen->machine, sprite_bitmap_1, cliprect, jchan_sprite_ram32_1, 0x4000, screen->machine->region("gfx1")->base(), screen->machine->region ("gfx1")->bytes(), jchan_sprite_regs32_1 );
-	skns_draw_sprites(screen->machine, sprite_bitmap_2, cliprect, jchan_sprite_ram32_2, 0x4000, screen->machine->region("gfx2")->base(), screen->machine->region ("gfx2")->bytes(), jchan_sprite_regs32_2 );
+	state->m_spritegen1->skns_draw_sprites(screen->machine(), state->m_sprite_bitmap_1, cliprect, state->m_sprite_ram32_1, 0x4000, screen->machine().region("gfx1")->base(), screen->machine().region ("gfx1")->bytes(), state->m_sprite_regs32_1 );
+	state->m_spritegen2->skns_draw_sprites(screen->machine(), state->m_sprite_bitmap_2, cliprect, state->m_sprite_ram32_2, 0x4000, screen->machine().region("gfx2")->base(), screen->machine().region ("gfx2")->bytes(), state->m_sprite_regs32_2 );
 
 	// ignoring priority bits for now - might use alpha too, check 0x8000 of palette writes
 	for (y=0;y<240;y++)
 	{
-		src1 = BITMAP_ADDR16(sprite_bitmap_1, y, 0);
-		src2 = BITMAP_ADDR16(sprite_bitmap_2, y, 0);
+		src1 = BITMAP_ADDR16(state->m_sprite_bitmap_1, y, 0);
+		src2 = BITMAP_ADDR16(state->m_sprite_bitmap_2, y, 0);
 		dst =  BITMAP_ADDR16(bitmap, y, 0);
 
 		for (x=0;x<320;x++)
@@ -424,24 +426,25 @@ static VIDEO_UPDATE(jchan)
     $f00006 is read and impacts controls 'decoding'
     $f00000 is the only location also written
 */
-static UINT16 *jchan_ctrl;
 
 static WRITE16_HANDLER( jchan_ctrl_w )
 {
-	jchan_irq_sub_enable = data & 0x8000; // hack / guess!
+	jchan_state *state = space->machine().driver_data<jchan_state>();
+	state->m_irq_sub_enable = data & 0x8000; // hack / guess!
 }
 
 static READ16_HANDLER ( jchan_ctrl_r )
 {
+	jchan_state *state = space->machine().driver_data<jchan_state>();
 	switch(offset)
 	{
-		case 0/2: return input_port_read(space->machine, "P1");
-		case 2/2: return input_port_read(space->machine, "P2");
-		case 4/2: return input_port_read(space->machine, "SYSTEM");
-		case 6/2: return input_port_read(space->machine, "EXTRA");
+		case 0/2: return input_port_read(space->machine(), "P1");
+		case 2/2: return input_port_read(space->machine(), "P2");
+		case 4/2: return input_port_read(space->machine(), "SYSTEM");
+		case 6/2: return input_port_read(space->machine(), "EXTRA");
 		default: logerror("jchan_ctrl_r unknown!"); break;
 	}
-	return jchan_ctrl[offset];
+	return state->m_ctrl[offset];
 }
 
 /***************************************************************************
@@ -453,88 +456,94 @@ static READ16_HANDLER ( jchan_ctrl_r )
 /* communications - hacky! */
 static WRITE16_HANDLER( main2sub_cmd_w )
 {
-	COMBINE_DATA(&mainsub_shared_ram[0x03ffe/2]);
-	cputag_set_input_line(space->machine, "sub", 4, HOLD_LINE);
+	jchan_state *state = space->machine().driver_data<jchan_state>();
+	COMBINE_DATA(&state->m_mainsub_shared_ram[0x03ffe/2]);
+	cputag_set_input_line(space->machine(), "sub", 4, HOLD_LINE);
 }
 
 // is this called?
 static WRITE16_HANDLER( sub2main_cmd_w )
 {
-	COMBINE_DATA(&mainsub_shared_ram[0x0000/2]);
-	cputag_set_input_line(space->machine, "maincpu", 3, HOLD_LINE);
+	jchan_state *state = space->machine().driver_data<jchan_state>();
+	COMBINE_DATA(&state->m_mainsub_shared_ram[0x0000/2]);
+	cputag_set_input_line(space->machine(), "maincpu", 3, HOLD_LINE);
 }
 
 /* ram convert for suprnova (requires 32-bit stuff) */
 static WRITE16_HANDLER( jchan_suprnova_sprite32_1_w )
 {
-	COMBINE_DATA(&jchan_spriteram_1[offset]);
+	jchan_state *state = space->machine().driver_data<jchan_state>();
+	COMBINE_DATA(&state->m_spriteram_1[offset]);
 	offset>>=1;
-	jchan_sprite_ram32_1[offset]=(jchan_spriteram_1[offset*2+1]<<16) | (jchan_spriteram_1[offset*2]);
+	state->m_sprite_ram32_1[offset]=(state->m_spriteram_1[offset*2+1]<<16) | (state->m_spriteram_1[offset*2]);
 }
 
 static WRITE16_HANDLER( jchan_suprnova_sprite32regs_1_w )
 {
-	COMBINE_DATA(&jchan_sprregs_1[offset]);
+	jchan_state *state = space->machine().driver_data<jchan_state>();
+	COMBINE_DATA(&state->m_sprregs_1[offset]);
 	offset>>=1;
-	jchan_sprite_regs32_1[offset]=(jchan_sprregs_1[offset*2+1]<<16) | (jchan_sprregs_1[offset*2]);
+	state->m_sprite_regs32_1[offset]=(state->m_sprregs_1[offset*2+1]<<16) | (state->m_sprregs_1[offset*2]);
 }
 
 static WRITE16_HANDLER( jchan_suprnova_sprite32_2_w )
 {
-	COMBINE_DATA(&jchan_spriteram_2[offset]);
+	jchan_state *state = space->machine().driver_data<jchan_state>();
+	COMBINE_DATA(&state->m_spriteram_2[offset]);
 	offset>>=1;
-	jchan_sprite_ram32_2[offset]=(jchan_spriteram_2[offset*2+1]<<16) | (jchan_spriteram_2[offset*2]);
+	state->m_sprite_ram32_2[offset]=(state->m_spriteram_2[offset*2+1]<<16) | (state->m_spriteram_2[offset*2]);
 }
 
 static WRITE16_HANDLER( jchan_suprnova_sprite32regs_2_w )
 {
-	COMBINE_DATA(&jchan_sprregs_2[offset]);
+	jchan_state *state = space->machine().driver_data<jchan_state>();
+	COMBINE_DATA(&state->m_sprregs_2[offset]);
 	offset>>=1;
-	jchan_sprite_regs32_2[offset]=(jchan_sprregs_2[offset*2+1]<<16) | (jchan_sprregs_2[offset*2]);
+	state->m_sprite_regs32_2[offset]=(state->m_sprregs_2[offset*2+1]<<16) | (state->m_sprregs_2[offset*2]);
 }
 
 
-static ADDRESS_MAP_START( jchan_main, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( jchan_main, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x1fffff) AM_ROM
 	AM_RANGE(0x200000, 0x20ffff) AM_RAM // Work RAM - [A] grid tested, cleared ($9d6-$a54)
 
-	AM_RANGE(0x300000, 0x30ffff) AM_RAM AM_BASE(&mcu_ram)	// MCU [G] grid tested, cleared ($a5a-$ad8)
+	AM_RANGE(0x300000, 0x30ffff) AM_RAM AM_BASE_MEMBER(jchan_state, m_mcu_ram)	// MCU [G] grid tested, cleared ($a5a-$ad8)
 	AM_RANGE(0x330000, 0x330001) AM_WRITE(jchan_mcu_com0_w)	// _[ these 2 are set to 0xFFFF
 	AM_RANGE(0x340000, 0x340001) AM_WRITE(jchan_mcu_com1_w)	//  [ to trigger mcu to run cmd ?
 	AM_RANGE(0x350000, 0x350001) AM_WRITE(jchan_mcu_com2_w)	// _[ these 2 are set to 0xFFFF
 	AM_RANGE(0x360000, 0x360001) AM_WRITE(jchan_mcu_com3_w)	//  [ for mcu to return its status ?
 	AM_RANGE(0x370000, 0x370001) AM_READ(jchan_mcu_status_r)
 
-	AM_RANGE(0x400000, 0x403fff) AM_RAM AM_BASE(&mainsub_shared_ram) AM_SHARE("share1")
+	AM_RANGE(0x400000, 0x403fff) AM_RAM AM_BASE_MEMBER(jchan_state, m_mainsub_shared_ram) AM_SHARE("share1")
 
 	/* 1st sprite layer */
-	AM_RANGE(0x500000, 0x503fff) AM_RAM_WRITE(jchan_suprnova_sprite32_1_w) AM_BASE(&jchan_spriteram_1)
-	AM_RANGE(0x600000, 0x60003f) AM_RAM_WRITE(jchan_suprnova_sprite32regs_1_w) AM_BASE(&jchan_sprregs_1)
+	AM_RANGE(0x500000, 0x503fff) AM_RAM_WRITE(jchan_suprnova_sprite32_1_w) AM_BASE_MEMBER(jchan_state, m_spriteram_1)
+	AM_RANGE(0x600000, 0x60003f) AM_RAM_WRITE(jchan_suprnova_sprite32regs_1_w) AM_BASE_MEMBER(jchan_state, m_sprregs_1)
 
 	AM_RANGE(0x700000, 0x70ffff) AM_RAM_WRITE(paletteram16_xGGGGGRRRRRBBBBB_word_w) AM_BASE_GENERIC(paletteram) // palette for sprites?
 
-	AM_RANGE(0xf00000, 0xf00007) AM_READWRITE(jchan_ctrl_r, jchan_ctrl_w) AM_BASE(&jchan_ctrl)
+	AM_RANGE(0xf00000, 0xf00007) AM_READWRITE(jchan_ctrl_r, jchan_ctrl_w) AM_BASE_MEMBER(jchan_state, m_ctrl)
 
 	AM_RANGE(0xf80000, 0xf80001) AM_READWRITE(watchdog_reset16_r, watchdog_reset16_w)	// watchdog
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( jchan_sub, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( jchan_sub, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x100000, 0x10ffff) AM_RAM // Work RAM - grid tested, cleared ($612-$6dc)
 
-	AM_RANGE(0x400000, 0x403fff) AM_RAM AM_BASE(&mainsub_shared_ram) AM_SHARE("share1")
+	AM_RANGE(0x400000, 0x403fff) AM_RAM AM_BASE_MEMBER(jchan_state, m_mainsub_shared_ram) AM_SHARE("share1")
 
 	/* VIEW2 Tilemap - [D] grid tested, cleared ($1d84), also cleared at startup ($810-$826) */
-	AM_RANGE(0x500000, 0x500fff) AM_RAM_WRITE(kaneko16_vram_1_w) AM_BASE(&kaneko16_vram_1)	// Layers 0
-	AM_RANGE(0x501000, 0x501fff) AM_RAM_WRITE(kaneko16_vram_0_w) AM_BASE(&kaneko16_vram_0)	//
-	AM_RANGE(0x502000, 0x502fff) AM_RAM AM_BASE(&kaneko16_vscroll_1)									//
-	AM_RANGE(0x503000, 0x503fff) AM_RAM AM_BASE(&kaneko16_vscroll_0)									//
-	AM_RANGE(0x600000, 0x60001f) AM_RAM_WRITE(kaneko16_layers_0_regs_w) AM_BASE(&kaneko16_layers_0_regs)	// Layers 0 Regs
+	AM_RANGE(0x500000, 0x500fff) AM_RAM_WRITE(kaneko16_vram_1_w) AM_BASE_MEMBER(jchan_state, m_vram[1])	// Layers 0
+	AM_RANGE(0x501000, 0x501fff) AM_RAM_WRITE(kaneko16_vram_0_w) AM_BASE_MEMBER(jchan_state, m_vram[0])	//
+	AM_RANGE(0x502000, 0x502fff) AM_RAM AM_BASE_MEMBER(jchan_state, m_vscroll[1])									//
+	AM_RANGE(0x503000, 0x503fff) AM_RAM AM_BASE_MEMBER(jchan_state, m_vscroll[0])									//
+	AM_RANGE(0x600000, 0x60001f) AM_RAM_WRITE(kaneko16_layers_0_regs_w) AM_BASE_MEMBER(jchan_state, m_layers_0_regs)	// Layers 0 Regs
 
 	/* background prites */
-	AM_RANGE(0x700000, 0x703fff) AM_RAM_WRITE(jchan_suprnova_sprite32_2_w) AM_BASE(&jchan_spriteram_2)
-	AM_RANGE(0x780000, 0x78003f) AM_RAM_WRITE(jchan_suprnova_sprite32regs_2_w) AM_BASE(&jchan_sprregs_2)
+	AM_RANGE(0x700000, 0x703fff) AM_RAM_WRITE(jchan_suprnova_sprite32_2_w) AM_BASE_MEMBER(jchan_state, m_spriteram_2)
+	AM_RANGE(0x780000, 0x78003f) AM_RAM_WRITE(jchan_suprnova_sprite32regs_2_w) AM_BASE_MEMBER(jchan_state, m_sprregs_2)
 
 	AM_RANGE(0x800000, 0x800003) AM_DEVWRITE8("ymz", ymz280b_w, 0x00ff) // sound
 
@@ -612,26 +621,26 @@ static INPUT_PORTS_START( jchan )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START("DSW")		/* provided by the MCU - $200098.b <- $300200 */
-	PORT_SERVICE( 0x0100, IP_ACTIVE_LOW )
-	PORT_DIPNAME( 0x0200, 0x0200, DEF_STR( Flip_Screen ) )
+	PORT_SERVICE_DIPLOC(  0x0100, IP_ACTIVE_LOW, "SW1:1" )
+	PORT_DIPNAME( 0x0200, 0x0200, DEF_STR( Flip_Screen ) )		PORT_DIPLOCATION("SW1:2")
 	PORT_DIPSETTING(      0x0200, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0400, 0x0000, DEF_STR( Demo_Sounds ) )
+	PORT_DIPNAME( 0x0400, 0x0000, DEF_STR( Demo_Sounds ) )		PORT_DIPLOCATION("SW1:3")
 	PORT_DIPSETTING(      0x0400, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0800, 0x0800, "Sound" )
+	PORT_DIPNAME( 0x0800, 0x0800, "Sound" )				PORT_DIPLOCATION("SW1:4")
 	PORT_DIPSETTING(      0x0000, DEF_STR( Mono ) )
 	PORT_DIPSETTING(      0x0800, DEF_STR( Stereo ) )
-	PORT_DIPNAME( 0x1000, 0x1000, DEF_STR( Free_Play ) )
+	PORT_DIPNAME( 0x1000, 0x1000, DEF_STR( Free_Play ) )		PORT_DIPLOCATION("SW1:5")
 	PORT_DIPSETTING(      0x1000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x2000, 0x0000, "Blood Mode" )
+	PORT_DIPNAME( 0x2000, 0x0000, "Blood Mode" )			PORT_DIPLOCATION("SW1:6")
 	PORT_DIPSETTING(      0x2000, DEF_STR( Normal ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( High ) )
-	PORT_DIPNAME( 0x4000, 0x4000, "Special Prize Available" )    /* impacts $200008.l many times -> see high-score tables - WTF is it ? */
+	PORT_DIPNAME( 0x4000, 0x4000, "Special Prize Available" )	PORT_DIPLOCATION("SW1:7")	/* impacts $200008.l many times -> see high-score tables - WTF is it ? */
 	PORT_DIPSETTING(      0x4000, DEF_STR( No ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Yes ) )
-	PORT_DIPNAME( 0x8000, 0x8000, "Buttons Layout" )             /* impacts $200116.l once! -> impacts reading of controls at 0x00021e2a */
+	PORT_DIPNAME( 0x8000, 0x8000, "Buttons Layout" )		PORT_DIPLOCATION("SW1:8")	/* impacts $200116.l once! -> impacts reading of controls at 0x00021e2a */
 	PORT_DIPSETTING(      0x8000, "3+1" )
 	PORT_DIPSETTING(      0x0000, "2+2" )
 INPUT_PORTS_END
@@ -655,7 +664,7 @@ static const ymz280b_interface ymz280b_intf =
 
 /* machine driver */
 
-static MACHINE_CONFIG_START( jchan, driver_device )
+static MACHINE_CONFIG_START( jchan, jchan_state )
 
 	MCFG_CPU_ADD("maincpu", M68000, 16000000)
 	MCFG_CPU_PROGRAM_MAP(jchan_main)
@@ -673,11 +682,16 @@ static MACHINE_CONFIG_START( jchan, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(jchan)
 
 	MCFG_PALETTE_LENGTH(0x10000)
 
 	MCFG_VIDEO_START(jchan)
-	MCFG_VIDEO_UPDATE(jchan)
+
+	MCFG_DEVICE_ADD("spritegen1", SKNS_SPRITE, 0)
+	MCFG_DEVICE_ADD("spritegen2", SKNS_SPRITE, 0)
+
+	MCFG_NVRAM_ADD_0FILL("nvram")
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
@@ -771,13 +785,16 @@ ROM_END
 
 static DRIVER_INIT( jchan )
 {
+	jchan_state *state = machine.driver_data<jchan_state>();
 	DRIVER_INIT_CALL( decrypt_toybox_rom );
 	// install these here, putting them in the memory map causes issues
-	memory_install_write16_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x403ffe, 0x403fff, 0, 0, main2sub_cmd_w );
-	memory_install_write16_handler(cputag_get_address_space(machine, "sub", ADDRESS_SPACE_PROGRAM), 0x400000, 0x400001, 0, 0, sub2main_cmd_w );
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0x403ffe, 0x403fff, FUNC(main2sub_cmd_w) );
+	machine.device("sub")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0x400000, 0x400001, FUNC(sub2main_cmd_w) );
 
 
-	memset(jchan_mcu_com, 0, 4 * sizeof( UINT16 ) );
+	memset(state->m_mcu_com, 0, 4 * sizeof( UINT16 ) );
+
+	machine.device<nvram_device>("nvram")->set_base(state->m_nvram_data, sizeof(state->m_nvram_data));
 }
 
 
