@@ -23,6 +23,7 @@
     There is another Karnov rom set - a bootleg version of the Japanese roms with
     the Data East copyright removed - not supported because the original Japanese
     roms work fine.
+    ^^ This should be added (DH, 30/03/11)
 
     One of the two color PROMs for chelnov and chelnoj is different; one is most
     likely a bad read, but I don't know which one.
@@ -81,7 +82,7 @@ Stephh's notes (based on the games M68000 code and some tests) :
 #include "sound/2203intf.h"
 #include "sound/3526intf.h"
 #include "includes/karnov.h"
-
+#include "video/deckarn.h"
 
 /*************************************
  *
@@ -90,62 +91,62 @@ Stephh's notes (based on the games M68000 code and some tests) :
  *************************************/
 
 /* Emulation of the protected microcontroller - for coins & general protection */
-static void karnov_i8751_w( running_machine *machine, int data )
+static void karnov_i8751_w( running_machine &machine, int data )
 {
-	karnov_state *state = machine->driver_data<karnov_state>();
+	karnov_state *state = machine.driver_data<karnov_state>();
 
 	/* Pending coin operations may cause protection commands to be queued */
-	if (state->i8751_needs_ack)
+	if (state->m_i8751_needs_ack)
 	{
-		state->i8751_command_queue = data;
+		state->m_i8751_command_queue = data;
 		return;
 	}
 
-	state->i8751_return = 0;
+	state->m_i8751_return = 0;
 
-	if (data == 0x100 && state->microcontroller_id == KARNOV)	/* USA version */
-		state->i8751_return = 0x56b;
+	if (data == 0x100 && state->m_microcontroller_id == KARNOV)	/* USA version */
+		state->m_i8751_return = 0x56b;
 
-	if (data == 0x100 && state->microcontroller_id == KARNOVJ)	/* Japan version */
-		state->i8751_return = 0x56a;
+	if (data == 0x100 && state->m_microcontroller_id == KARNOVJ)	/* Japan version */
+		state->m_i8751_return = 0x56a;
 
 	if ((data & 0xf00) == 0x300)
-		state->i8751_return = (data & 0xff) * 0x12; /* Player sprite mapping */
+		state->m_i8751_return = (data & 0xff) * 0x12; /* Player sprite mapping */
 
 	/* I'm not sure the ones marked ^ appear in the right order */
-	if (data == 0x400) state->i8751_return = 0x4000; /* Get The Map... */
-	if (data == 0x402) state->i8751_return = 0x40a6; /* Ancient Ruins */
-	if (data == 0x403) state->i8751_return = 0x4054; /* Forest... */
-	if (data == 0x404) state->i8751_return = 0x40de; /* ^Rocky hills */
-	if (data == 0x405) state->i8751_return = 0x4182; /* Sea */
-	if (data == 0x406) state->i8751_return = 0x41ca; /* Town */
-	if (data == 0x407) state->i8751_return = 0x421e; /* Desert */
-	if (data == 0x401) state->i8751_return = 0x4138; /* ^Whistling wind */
-	if (data == 0x408) state->i8751_return = 0x4276; /* ^Heavy Gates */
+	if (data == 0x400) state->m_i8751_return = 0x4000; /* Get The Map... */
+	if (data == 0x402) state->m_i8751_return = 0x40a6; /* Ancient Ruins */
+	if (data == 0x403) state->m_i8751_return = 0x4054; /* Forest... */
+	if (data == 0x404) state->m_i8751_return = 0x40de; /* ^Rocky hills */
+	if (data == 0x405) state->m_i8751_return = 0x4182; /* Sea */
+	if (data == 0x406) state->m_i8751_return = 0x41ca; /* Town */
+	if (data == 0x407) state->m_i8751_return = 0x421e; /* Desert */
+	if (data == 0x401) state->m_i8751_return = 0x4138; /* ^Whistling wind */
+	if (data == 0x408) state->m_i8751_return = 0x4276; /* ^Heavy Gates */
 
-//  if (!state->i8751_return && data != 0x300) logerror("%s - Unknown Write %02x intel\n", cpuexec_describe_context(machine), data);
+//  if (!state->m_i8751_return && data != 0x300) logerror("%s - Unknown Write %02x intel\n", machine.describe_context(), data);
 
-	cpu_set_input_line(state->maincpu, 6, HOLD_LINE); /* Signal main cpu task is complete */
-	state->i8751_needs_ack = 1;
+	device_set_input_line(state->m_maincpu, 6, HOLD_LINE); /* Signal main cpu task is complete */
+	state->m_i8751_needs_ack = 1;
 }
 
-static void wndrplnt_i8751_w( running_machine *machine, int data )
+static void wndrplnt_i8751_w( running_machine &machine, int data )
 {
-	karnov_state *state = machine->driver_data<karnov_state>();
+	karnov_state *state = machine.driver_data<karnov_state>();
 
 	/* The last command hasn't been ACK'd (probably a conflict with coin command) */
-	if (state->i8751_needs_ack)
+	if (state->m_i8751_needs_ack)
 	{
-		state->i8751_command_queue = data;
+		state->m_i8751_command_queue = data;
 		return;
 	}
 
-	state->i8751_return=0;
+	state->m_i8751_return=0;
 
-	if (data == 0x100) state->i8751_return = 0x67a;
-	if (data == 0x200) state->i8751_return = 0x214;
-	if (data == 0x300) state->i8751_return = 0x17; /* Copyright text on title screen */
-//  if (data == 0x300) state->i8751_return = 0x1; /* (USA) Copyright text on title screen */
+	if (data == 0x100) state->m_i8751_return = 0x67a;
+	if (data == 0x200) state->m_i8751_return = 0x214;
+	if (data == 0x300) state->m_i8751_return = 0x17; /* Copyright text on title screen */
+//  if (data == 0x300) state->m_i8751_return = 0x1; /* (USA) Copyright text on title screen */
 
 	/* The game writes many values in the 0x600 range, but only a specific mask
     matters for the return value */
@@ -153,172 +154,172 @@ static void wndrplnt_i8751_w( running_machine *machine, int data )
 	{
 		switch (data & 0x18)
 		{
-			case 0x00:	state->i8751_return = 0x4d53; break;
-			case 0x08:	state->i8751_return = 0x4b54; break;
-			case 0x10:	state->i8751_return = 0x5453; break;
-			case 0x18:	state->i8751_return = 0x5341; break;
+			case 0x00:	state->m_i8751_return = 0x4d53; break;
+			case 0x08:	state->m_i8751_return = 0x4b54; break;
+			case 0x10:	state->m_i8751_return = 0x5453; break;
+			case 0x18:	state->m_i8751_return = 0x5341; break;
 		}
 	}
-//  else logerror("%s - Unknown Write %02x intel\n", cpuexec_describe_context(machine), data);
+//  else logerror("%s - Unknown Write %02x intel\n", machine.describe_context(), data);
 
 	/* These are 68k function call addresses - different address for each power-up */
-	if (data == 0x400) state->i8751_return = 0x594;
-	if (data == 0x401) state->i8751_return = 0x5ea;
-	if (data == 0x402) state->i8751_return = 0x628;
-	if (data == 0x403) state->i8751_return = 0x66c;
-	if (data == 0x404) state->i8751_return = 0x6a4;
-	if (data == 0x405) state->i8751_return = 0x6a4;
-	if (data == 0x406) state->i8751_return = 0x6a4;
+	if (data == 0x400) state->m_i8751_return = 0x594;
+	if (data == 0x401) state->m_i8751_return = 0x5ea;
+	if (data == 0x402) state->m_i8751_return = 0x628;
+	if (data == 0x403) state->m_i8751_return = 0x66c;
+	if (data == 0x404) state->m_i8751_return = 0x6a4;
+	if (data == 0x405) state->m_i8751_return = 0x6a4;
+	if (data == 0x406) state->m_i8751_return = 0x6a4;
 
 	/* This is 68k program code which is executed every frame */
-	if (data == 0x50c) state->i8751_return = 0x13fc;
-	if (data == 0x50b) state->i8751_return = 0x00ff;
-	if (data == 0x50a) state->i8751_return = 0x0006;
-	if (data == 0x509) state->i8751_return = 0x0000;
-	if (data == 0x508) state->i8751_return = 0x4a39;
-	if (data == 0x507) state->i8751_return = 0x0006;
-	if (data == 0x506) state->i8751_return = 0x0000;
-	if (data == 0x505) state->i8751_return = 0x66f8;
-	if (data == 0x504) state->i8751_return = 0x4a39;
-	if (data == 0x503) state->i8751_return = 0x000c;
-	if (data == 0x502) state->i8751_return = 0x0003;
-	if (data == 0x501) state->i8751_return = 0x6bf8;
-	if (data == 0x500) state->i8751_return = 0x4e75;
+	if (data == 0x50c) state->m_i8751_return = 0x13fc;
+	if (data == 0x50b) state->m_i8751_return = 0x00ff;
+	if (data == 0x50a) state->m_i8751_return = 0x0006;
+	if (data == 0x509) state->m_i8751_return = 0x0000;
+	if (data == 0x508) state->m_i8751_return = 0x4a39;
+	if (data == 0x507) state->m_i8751_return = 0x0006;
+	if (data == 0x506) state->m_i8751_return = 0x0000;
+	if (data == 0x505) state->m_i8751_return = 0x66f8;
+	if (data == 0x504) state->m_i8751_return = 0x4a39;
+	if (data == 0x503) state->m_i8751_return = 0x000c;
+	if (data == 0x502) state->m_i8751_return = 0x0003;
+	if (data == 0x501) state->m_i8751_return = 0x6bf8;
+	if (data == 0x500) state->m_i8751_return = 0x4e75;
 
-	cpu_set_input_line(state->maincpu, 6, HOLD_LINE); /* Signal main cpu task is complete */
-	state->i8751_needs_ack = 1;
+	device_set_input_line(state->m_maincpu, 6, HOLD_LINE); /* Signal main cpu task is complete */
+	state->m_i8751_needs_ack = 1;
 }
 
-static void chelnov_i8751_w( running_machine *machine, int data )
+static void chelnov_i8751_w( running_machine &machine, int data )
 {
-	karnov_state *state = machine->driver_data<karnov_state>();
+	karnov_state *state = machine.driver_data<karnov_state>();
 
 	/* Pending coin operations may cause protection commands to be queued */
-	if (state->i8751_needs_ack)
+	if (state->m_i8751_needs_ack)
 	{
-		state->i8751_command_queue = data;
+		state->m_i8751_command_queue = data;
 		return;
 	}
 
-	state->i8751_return = 0;
+	state->m_i8751_return = 0;
 
-	if (data == 0x200 && state->microcontroller_id == CHELNOV)	/* World version */
-		state->i8751_return = 0x7736;
+	if (data == 0x200 && state->m_microcontroller_id == CHELNOV)	/* World version */
+		state->m_i8751_return = 0x7736;
 
-	if (data == 0x200 && state->microcontroller_id == CHELNOVU)	/* USA version */
-		state->i8751_return = 0x783e;
+	if (data == 0x200 && state->m_microcontroller_id == CHELNOVU)	/* USA version */
+		state->m_i8751_return = 0x783e;
 
-	if (data == 0x200 && state->microcontroller_id == CHELNOVJ)	/* Japan version */
-		state->i8751_return = 0x7734;
+	if (data == 0x200 && state->m_microcontroller_id == CHELNOVJ)	/* Japan version */
+		state->m_i8751_return = 0x7734;
 
-	if (data == 0x100 && state->microcontroller_id == CHELNOV)	/* World version */
-		state->i8751_return = 0x71c;
+	if (data == 0x100 && state->m_microcontroller_id == CHELNOV)	/* World version */
+		state->m_i8751_return = 0x71c;
 
-	if (data == 0x100 && state->microcontroller_id == CHELNOVU)	/* USA version */
-		state->i8751_return = 0x71b;
+	if (data == 0x100 && state->m_microcontroller_id == CHELNOVU)	/* USA version */
+		state->m_i8751_return = 0x71b;
 
-	if (data == 0x100 && state->microcontroller_id == CHELNOVJ)	/* Japan version */
-		state->i8751_return = 0x71a;
+	if (data == 0x100 && state->m_microcontroller_id == CHELNOVJ)	/* Japan version */
+		state->m_i8751_return = 0x71a;
 
 	if (data >= 0x6000 && data < 0x8000)
-		state->i8751_return = 1;  /* patched */
+		state->m_i8751_return = 1;  /* patched */
 
-	if ((data & 0xf000) == 0x1000) state->i8751_level = 1;		/* Level 1 */
-	if ((data & 0xf000) == 0x2000) state->i8751_level++;		/* Level Increment */
+	if ((data & 0xf000) == 0x1000) state->m_i8751_level = 1;		/* Level 1 */
+	if ((data & 0xf000) == 0x2000) state->m_i8751_level++;		/* Level Increment */
 
 	if ((data & 0xf000) == 0x3000)
 	{
 		/* Sprite table mapping */
 		int b = data & 0xff;
-		switch (state->i8751_level)
+		switch (state->m_i8751_level)
 		{
 			case 1: /* Level 1, Sprite mapping tables */
-				if (state->microcontroller_id == CHELNOVU) /* USA */
+				if (state->m_microcontroller_id == CHELNOVU) /* USA */
 				{
-					if (b < 2) state->i8751_return = 0;
-					else if (b < 6) state->i8751_return = 1;
-					else if (b < 0xb) state->i8751_return = 2;
-					else if (b < 0xf) state->i8751_return = 3;
-					else if (b < 0x13) state->i8751_return = 4;
-					else state->i8751_return = 5;
+					if (b < 2) state->m_i8751_return = 0;
+					else if (b < 6) state->m_i8751_return = 1;
+					else if (b < 0xb) state->m_i8751_return = 2;
+					else if (b < 0xf) state->m_i8751_return = 3;
+					else if (b < 0x13) state->m_i8751_return = 4;
+					else state->m_i8751_return = 5;
 				}
 				else	/* Japan, World */
 				{
-					if (b < 3) state->i8751_return = 0;
-					else if (b < 8) state->i8751_return = 1;
-					else if (b < 0xc) state->i8751_return = 2;
-					else if (b < 0x10) state->i8751_return = 3;
-					else if (b < 0x19) state->i8751_return = 4;
-					else if (b < 0x1b) state->i8751_return = 5;
-					else if (b < 0x22) state->i8751_return = 6;
-					else if (b < 0x28) state->i8751_return = 7;
-					else state->i8751_return = 8;
+					if (b < 3) state->m_i8751_return = 0;
+					else if (b < 8) state->m_i8751_return = 1;
+					else if (b < 0xc) state->m_i8751_return = 2;
+					else if (b < 0x10) state->m_i8751_return = 3;
+					else if (b < 0x19) state->m_i8751_return = 4;
+					else if (b < 0x1b) state->m_i8751_return = 5;
+					else if (b < 0x22) state->m_i8751_return = 6;
+					else if (b < 0x28) state->m_i8751_return = 7;
+					else state->m_i8751_return = 8;
 				}
 				break;
 			case 2: /* Level 2, Sprite mapping tables, all sets are the same */
-				if (b < 3) state->i8751_return = 0;
-				else if (b < 9) state->i8751_return = 1;
-				else if (b < 0x11) state->i8751_return = 2;
-				else if (b < 0x1b) state->i8751_return = 3;
-				else if (b < 0x21) state->i8751_return = 4;
-				else if (b < 0x28) state->i8751_return = 5;
-				else state->i8751_return = 6;
+				if (b < 3) state->m_i8751_return = 0;
+				else if (b < 9) state->m_i8751_return = 1;
+				else if (b < 0x11) state->m_i8751_return = 2;
+				else if (b < 0x1b) state->m_i8751_return = 3;
+				else if (b < 0x21) state->m_i8751_return = 4;
+				else if (b < 0x28) state->m_i8751_return = 5;
+				else state->m_i8751_return = 6;
 				break;
 			case 3: /* Level 3, Sprite mapping tables, all sets are the same */
-				if (b < 5) state->i8751_return = 0;
-				else if (b < 9) state->i8751_return = 1;
-				else if (b < 0xd) state->i8751_return = 2;
-				else if (b < 0x11) state->i8751_return = 3;
-				else if (b < 0x1b) state->i8751_return = 4;
-				else if (b < 0x1c) state->i8751_return = 5;
-				else if (b < 0x22) state->i8751_return = 6;
-				else if (b < 0x27) state->i8751_return = 7;
-				else state->i8751_return = 8;
+				if (b < 5) state->m_i8751_return = 0;
+				else if (b < 9) state->m_i8751_return = 1;
+				else if (b < 0xd) state->m_i8751_return = 2;
+				else if (b < 0x11) state->m_i8751_return = 3;
+				else if (b < 0x1b) state->m_i8751_return = 4;
+				else if (b < 0x1c) state->m_i8751_return = 5;
+				else if (b < 0x22) state->m_i8751_return = 6;
+				else if (b < 0x27) state->m_i8751_return = 7;
+				else state->m_i8751_return = 8;
 				break;
 			case 4: /* Level 4, Sprite mapping tables, all sets are the same */
-				if (b < 4) state->i8751_return = 0;
-				else if (b < 0xc) state->i8751_return = 1;
-				else if (b < 0xf) state->i8751_return = 2;
-				else if (b < 0x19) state->i8751_return = 3;
-				else if (b < 0x1c) state->i8751_return = 4;
-				else if (b < 0x22) state->i8751_return = 5;
-				else if (b < 0x29) state->i8751_return = 6;
-				else state->i8751_return = 7;
+				if (b < 4) state->m_i8751_return = 0;
+				else if (b < 0xc) state->m_i8751_return = 1;
+				else if (b < 0xf) state->m_i8751_return = 2;
+				else if (b < 0x19) state->m_i8751_return = 3;
+				else if (b < 0x1c) state->m_i8751_return = 4;
+				else if (b < 0x22) state->m_i8751_return = 5;
+				else if (b < 0x29) state->m_i8751_return = 6;
+				else state->m_i8751_return = 7;
 				break;
 			case 5: /* Level 5, Sprite mapping tables, all sets are the same  */
-				if (b < 7) state->i8751_return = 0;
-				else if (b < 0xe) state->i8751_return = 1;
-				else if (b < 0x14) state->i8751_return = 2;
-				else if (b < 0x1a) state->i8751_return = 3;
-				else if (b < 0x23) state->i8751_return = 4;
-				else if (b < 0x27) state->i8751_return = 5;
-				else state->i8751_return = 6;
+				if (b < 7) state->m_i8751_return = 0;
+				else if (b < 0xe) state->m_i8751_return = 1;
+				else if (b < 0x14) state->m_i8751_return = 2;
+				else if (b < 0x1a) state->m_i8751_return = 3;
+				else if (b < 0x23) state->m_i8751_return = 4;
+				else if (b < 0x27) state->m_i8751_return = 5;
+				else state->m_i8751_return = 6;
 				break;
 			case 6: /* Level 6, Sprite mapping tables, all sets are the same  */
-				if (b < 3) state->i8751_return = 0;
-				else if (b < 0xb) state->i8751_return = 1;
-				else if (b < 0x11) state->i8751_return = 2;
-				else if (b < 0x17) state->i8751_return = 3;
-				else if (b < 0x1d) state->i8751_return = 4;
-				else if (b < 0x24) state->i8751_return = 5;
-				else state->i8751_return = 6;
+				if (b < 3) state->m_i8751_return = 0;
+				else if (b < 0xb) state->m_i8751_return = 1;
+				else if (b < 0x11) state->m_i8751_return = 2;
+				else if (b < 0x17) state->m_i8751_return = 3;
+				else if (b < 0x1d) state->m_i8751_return = 4;
+				else if (b < 0x24) state->m_i8751_return = 5;
+				else state->m_i8751_return = 6;
 				break;
 			case 7: /* Level 7, Sprite mapping tables, all sets are the same  */
-				if (b < 5) state->i8751_return = 0;
-				else if (b < 0xb) state->i8751_return = 1;
-				else if (b < 0x11) state->i8751_return = 2;
-				else if (b < 0x1a) state->i8751_return = 3;
-				else if (b < 0x21) state->i8751_return = 4;
-				else if (b < 0x27) state->i8751_return = 5;
-				else state->i8751_return = 6;
+				if (b < 5) state->m_i8751_return = 0;
+				else if (b < 0xb) state->m_i8751_return = 1;
+				else if (b < 0x11) state->m_i8751_return = 2;
+				else if (b < 0x1a) state->m_i8751_return = 3;
+				else if (b < 0x21) state->m_i8751_return = 4;
+				else if (b < 0x27) state->m_i8751_return = 5;
+				else state->m_i8751_return = 6;
 				break;
 		}
 	}
 
-	//  logerror("%s - Unknown Write %02x intel\n", cpuexec_describe_context(machine), data);
+	//  logerror("%s - Unknown Write %02x intel\n", machine.describe_context(), data);
 
-	cpu_set_input_line(state->maincpu, 6, HOLD_LINE); /* Signal main cpu task is complete */
-	state->i8751_needs_ack = 1;
+	device_set_input_line(state->m_maincpu, 6, HOLD_LINE); /* Signal main cpu task is complete */
+	state->m_i8751_needs_ack = 1;
 }
 
 /*************************************
@@ -329,40 +330,40 @@ static void chelnov_i8751_w( running_machine *machine, int data )
 
 static WRITE16_HANDLER( karnov_control_w )
 {
-	karnov_state *state = space->machine->driver_data<karnov_state>();
+	karnov_state *state = space->machine().driver_data<karnov_state>();
 
 	/* Mnemonics filled in from the schematics, brackets are my comments */
 	switch (offset << 1)
 	{
 		case 0: /* SECLR (Interrupt ack for Level 6 i8751 interrupt) */
-			cpu_set_input_line(state->maincpu, 6, CLEAR_LINE);
+			device_set_input_line(state->m_maincpu, 6, CLEAR_LINE);
 
-			if (state->i8751_needs_ack)
+			if (state->m_i8751_needs_ack)
 			{
 				/* If a command and coin insert happen at once, then the i8751 will queue the coin command until the previous command is ACK'd */
-				if (state->i8751_coin_pending)
+				if (state->m_i8751_coin_pending)
 				{
-					state->i8751_return = state->i8751_coin_pending;
-					cpu_set_input_line(state->maincpu, 6, HOLD_LINE);
-					state->i8751_coin_pending = 0;
+					state->m_i8751_return = state->m_i8751_coin_pending;
+					device_set_input_line(state->m_maincpu, 6, HOLD_LINE);
+					state->m_i8751_coin_pending = 0;
 				}
-				else if (state->i8751_command_queue)
+				else if (state->m_i8751_command_queue)
 				{
 					/* Pending control command - just write it back as SECREQ */
-					state->i8751_needs_ack = 0;
-					karnov_control_w(space, 3, state->i8751_command_queue, 0xffff);
-					state->i8751_command_queue = 0;
+					state->m_i8751_needs_ack = 0;
+					karnov_control_w(space, 3, state->m_i8751_command_queue, 0xffff);
+					state->m_i8751_command_queue = 0;
 				}
 				else
 				{
-					state->i8751_needs_ack = 0;
+					state->m_i8751_needs_ack = 0;
 				}
 			}
 			return;
 
 		case 2: /* SONREQ (Sound CPU byte) */
 			soundlatch_w(space, 0, data & 0xff);
-			cpu_set_input_line(state->audiocpu, INPUT_LINE_NMI, PULSE_LINE);
+			device_set_input_line(state->m_audiocpu, INPUT_LINE_NMI, PULSE_LINE);
 			break;
 
 		case 4: /* DM (DMA to buffer spriteram) */
@@ -370,51 +371,51 @@ static WRITE16_HANDLER( karnov_control_w )
 			break;
 
 		case 6: /* SECREQ (Interrupt & Data to i8751) */
-			if (state->microcontroller_id == KARNOV || state->microcontroller_id == KARNOVJ)
-				karnov_i8751_w(space->machine, data);
-			if (state->microcontroller_id == CHELNOV || state->microcontroller_id == CHELNOVU || state->microcontroller_id == CHELNOVJ)
-				chelnov_i8751_w(space->machine, data);
-			if (state->microcontroller_id == WNDRPLNT)
-				wndrplnt_i8751_w(space->machine, data);
+			if (state->m_microcontroller_id == KARNOV || state->m_microcontroller_id == KARNOVJ)
+				karnov_i8751_w(space->machine(), data);
+			if (state->m_microcontroller_id == CHELNOV || state->m_microcontroller_id == CHELNOVU || state->m_microcontroller_id == CHELNOVJ)
+				chelnov_i8751_w(space->machine(), data);
+			if (state->m_microcontroller_id == WNDRPLNT)
+				wndrplnt_i8751_w(space->machine(), data);
 			break;
 
 		case 8: /* HSHIFT (9 bits) - Top bit indicates video flip */
-			COMBINE_DATA(&state->scroll[0]);
-			karnov_flipscreen_w(space->machine, data >> 15);
+			COMBINE_DATA(&state->m_scroll[0]);
+			karnov_flipscreen_w(space->machine(), data >> 15);
 			break;
 
 		case 0xa: /* VSHIFT */
-			COMBINE_DATA(&state->scroll[1]);
+			COMBINE_DATA(&state->m_scroll[1]);
 			break;
 
 		case 0xc: /* SECR (Reset i8751) */
 			logerror("Reset i8751\n");
-			state->i8751_needs_ack = 0;
-			state->i8751_coin_pending = 0;
-			state->i8751_command_queue = 0;
-			state->i8751_return = 0;
+			state->m_i8751_needs_ack = 0;
+			state->m_i8751_coin_pending = 0;
+			state->m_i8751_command_queue = 0;
+			state->m_i8751_return = 0;
 			break;
 
 		case 0xe: /* INTCLR (Interrupt ack for Level 7 vbl interrupt) */
-			cpu_set_input_line(state->maincpu, 7, CLEAR_LINE);
+			device_set_input_line(state->m_maincpu, 7, CLEAR_LINE);
 			break;
 	}
 }
 
 static READ16_HANDLER( karnov_control_r )
 {
-	karnov_state *state = space->machine->driver_data<karnov_state>();
+	karnov_state *state = space->machine().driver_data<karnov_state>();
 
 	switch (offset << 1)
 	{
 		case 0:
-			return input_port_read(space->machine, "P1_P2");
+			return input_port_read(space->machine(), "P1_P2");
 		case 2: /* Start buttons & VBL */
-			return input_port_read(space->machine, "SYSTEM");
+			return input_port_read(space->machine(), "SYSTEM");
 		case 4:
-			return input_port_read(space->machine, "DSW");
+			return input_port_read(space->machine(), "DSW");
 		case 6: /* i8751 return values */
-			return state->i8751_return;
+			return state->m_i8751_return;
 	}
 
 	return ~0;
@@ -426,20 +427,20 @@ static READ16_HANDLER( karnov_control_r )
  *
  *************************************/
 
-static ADDRESS_MAP_START( karnov_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( karnov_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x05ffff) AM_ROM
-	AM_RANGE(0x060000, 0x063fff) AM_RAM AM_BASE_MEMBER(karnov_state, ram)
+	AM_RANGE(0x060000, 0x063fff) AM_RAM AM_BASE_MEMBER(karnov_state, m_ram)
 	AM_RANGE(0x080000, 0x080fff) AM_RAM AM_BASE_SIZE_GENERIC(spriteram)
-	AM_RANGE(0x0a0000, 0x0a07ff) AM_RAM_WRITE(karnov_videoram_w) AM_BASE_MEMBER(karnov_state, videoram)
+	AM_RANGE(0x0a0000, 0x0a07ff) AM_RAM_WRITE(karnov_videoram_w) AM_BASE_MEMBER(karnov_state, m_videoram)
 	AM_RANGE(0x0a0800, 0x0a0fff) AM_WRITE(karnov_videoram_w) /* Wndrplnt Mirror */
-	AM_RANGE(0x0a1000, 0x0a17ff) AM_WRITEONLY AM_BASE_MEMBER(karnov_state, pf_data)
+	AM_RANGE(0x0a1000, 0x0a17ff) AM_WRITEONLY AM_BASE_MEMBER(karnov_state, m_pf_data)
 	AM_RANGE(0x0a1800, 0x0a1fff) AM_WRITE(karnov_playfield_swap_w)
 	AM_RANGE(0x0c0000, 0x0c0007) AM_READ(karnov_control_r)
 	AM_RANGE(0x0c0000, 0x0c000f) AM_WRITE(karnov_control_w)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( karnov_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( karnov_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x05ff) AM_RAM
 	AM_RANGE(0x0800, 0x0800) AM_READ(soundlatch_r)
 	AM_RANGE(0x1000, 0x1001) AM_DEVWRITE("ym1", ym2203_w)
@@ -728,37 +729,37 @@ GFXDECODE_END
 
 static INTERRUPT_GEN( karnov_interrupt )
 {
-	karnov_state *state = device->machine->driver_data<karnov_state>();
-	UINT8 port = input_port_read(device->machine, "FAKE");
+	karnov_state *state = device->machine().driver_data<karnov_state>();
+	UINT8 port = input_port_read(device->machine(), "FAKE");
 
 	/* Coin input to the i8751 generates an interrupt to the main cpu */
-	if (port == state->coin_mask)
-		state->latch = 1;
+	if (port == state->m_coin_mask)
+		state->m_latch = 1;
 
-	if (port != state->coin_mask && state->latch)
+	if (port != state->m_coin_mask && state->m_latch)
 	{
-		if (state->i8751_needs_ack)
+		if (state->m_i8751_needs_ack)
 		{
 			/* i8751 is busy - queue the command */
-			state->i8751_coin_pending = port | 0x8000;
+			state->m_i8751_coin_pending = port | 0x8000;
 		}
 		else
 		{
-			state->i8751_return = port | 0x8000;
-			cpu_set_input_line(device, 6, HOLD_LINE);
-			state->i8751_needs_ack = 1;
+			state->m_i8751_return = port | 0x8000;
+			device_set_input_line(device, 6, HOLD_LINE);
+			state->m_i8751_needs_ack = 1;
 		}
 
-		state->latch = 0;
+		state->m_latch = 0;
 	}
 
-	cpu_set_input_line(device, 7, HOLD_LINE);	/* VBL */
+	device_set_input_line(device, 7, HOLD_LINE);	/* VBL */
 }
 
 static void sound_irq( device_t *device, int linestate )
 {
-	karnov_state *state = device->machine->driver_data<karnov_state>();
-	cpu_set_input_line(state->audiocpu, 0, linestate); /* IRQ */
+	karnov_state *state = device->machine().driver_data<karnov_state>();
+	device_set_input_line(state->m_audiocpu, 0, linestate); /* IRQ */
 }
 
 static const ym3526_interface ym3526_config =
@@ -774,39 +775,39 @@ static const ym3526_interface ym3526_config =
 
 static MACHINE_START( karnov )
 {
-	karnov_state *state = machine->driver_data<karnov_state>();
+	karnov_state *state = machine.driver_data<karnov_state>();
 
-	state->maincpu = machine->device("maincpu");
-	state->audiocpu = machine->device("audiocpu");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_audiocpu = machine.device("audiocpu");
 
-	state_save_register_global(machine, state->flipscreen);
-	state_save_register_global_array(machine, state->scroll);
+	state->save_item(NAME(state->m_flipscreen));
+	state->save_item(NAME(state->m_scroll));
 
-	state_save_register_global(machine, state->i8751_return);
-	state_save_register_global(machine, state->i8751_needs_ack);
-	state_save_register_global(machine, state->i8751_coin_pending);
-	state_save_register_global(machine, state->i8751_command_queue);
-	state_save_register_global(machine, state->i8751_level);
-	state_save_register_global(machine, state->latch);
+	state->save_item(NAME(state->m_i8751_return));
+	state->save_item(NAME(state->m_i8751_needs_ack));
+	state->save_item(NAME(state->m_i8751_coin_pending));
+	state->save_item(NAME(state->m_i8751_command_queue));
+	state->save_item(NAME(state->m_i8751_level));
+	state->save_item(NAME(state->m_latch));
 
 }
 
 static MACHINE_RESET( karnov )
 {
-	karnov_state *state = machine->driver_data<karnov_state>();
+	karnov_state *state = machine.driver_data<karnov_state>();
 
-	memset(state->ram, 0, 0x4000 / 2); /* Chelnov likes ram clear on reset.. */
+	memset(state->m_ram, 0, 0x4000 / 2); /* Chelnov likes ram clear on reset.. */
 
-	state->i8751_return = 0;
-	state->i8751_needs_ack = 0;
-	state->i8751_coin_pending = 0;
-	state->i8751_command_queue = 0;
-	state->i8751_level = 0;
-//  state->latch = 0;
+	state->m_i8751_return = 0;
+	state->m_i8751_needs_ack = 0;
+	state->m_i8751_coin_pending = 0;
+	state->m_i8751_command_queue = 0;
+	state->m_i8751_level = 0;
+//  state->m_latch = 0;
 
-	state->flipscreen = 0;
-	state->scroll[0] = 0;
-	state->scroll[0] = 0;
+	state->m_flipscreen = 0;
+	state->m_scroll[0] = 0;
+	state->m_scroll[0] = 0;
 }
 
 
@@ -832,13 +833,16 @@ static MACHINE_CONFIG_START( karnov, karnov_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_UPDATE(karnov)
 
 	MCFG_GFXDECODE(karnov)
 	MCFG_PALETTE_LENGTH(1024)
 
+	MCFG_DEVICE_ADD("spritegen", DECO_KARNOVSPRITES, 0)
+	deco_karnovsprites_device::set_gfx_region(*device, 2);
+
 	MCFG_PALETTE_INIT(karnov)
 	MCFG_VIDEO_START(karnov)
-	MCFG_VIDEO_UPDATE(karnov)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -874,13 +878,16 @@ static MACHINE_CONFIG_START( wndrplnt, karnov_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_UPDATE(karnov)
 
 	MCFG_GFXDECODE(karnov)
 	MCFG_PALETTE_LENGTH(1024)
 
+	MCFG_DEVICE_ADD("spritegen", DECO_KARNOVSPRITES, 0)
+	deco_karnovsprites_device::set_gfx_region(*device, 2);
+
 	MCFG_PALETTE_INIT(karnov)
 	MCFG_VIDEO_START(wndrplnt)
-	MCFG_VIDEO_UPDATE(karnov)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -912,6 +919,9 @@ ROM_START( karnov )
 	ROM_REGION( 0x10000, "audiocpu", 0 ) /* 6502 Sound CPU */
 	ROM_LOAD( "dn05-5",       0x8000, 0x8000, CRC(fa1a31a8) SHA1(5007a625be03c546d2a78444d72c28761b10cdb0) )
 
+	ROM_REGION( 0x1000, "mcu", 0 )    /* i8751 MCU */
+	ROM_LOAD( "karnov_i8751", 0x0000, 0x1000, NO_DUMP )
+
 	ROM_REGION( 0x08000, "gfx1", 0 )
 	ROM_LOAD( "dn00-",        0x00000, 0x08000, CRC(0ed77c6d) SHA1(4ec86ac56c01c158a580dc13dea3e5cbdf90d0e9) )	/* Characters */
 
@@ -948,6 +958,9 @@ ROM_START( karnovj )
 	ROM_REGION( 0x10000, "audiocpu", 0 ) /* 6502 Sound CPU */
 	ROM_LOAD( "kar5",         0x8000, 0x8000, CRC(7c9158f1) SHA1(dfba7b3abd6b8d6991f0207cd252ee652a6050c2) )
 
+	ROM_REGION( 0x1000, "mcu", 0 )    /* i8751 MCU */
+	ROM_LOAD( "karnovj_i8751", 0x0000, 0x1000, NO_DUMP )
+
 	ROM_REGION( 0x08000, "gfx1", 0 )
 	ROM_LOAD( "dn00-",        0x00000, 0x08000, CRC(0ed77c6d) SHA1(4ec86ac56c01c158a580dc13dea3e5cbdf90d0e9) )	/* Characters */
 
@@ -984,6 +997,9 @@ ROM_START( wndrplnt )
 	ROM_REGION( 0x10000, "audiocpu", 0 )	/* 6502 Sound CPU */
 	ROM_LOAD( "ea05.bin",     0x8000, 0x8000, CRC(8dbb6231) SHA1(342faa020448ce916e820b3df18d44191983f7a6) )
 
+	ROM_REGION( 0x1000, "mcu", 0 )    /* i8751 MCU */
+	ROM_LOAD( "wndrplnt_i8751", 0x0000, 0x1000, NO_DUMP )
+
 	ROM_REGION( 0x08000, "gfx1", 0 )
 	ROM_LOAD( "ea00.bin",    0x00000, 0x08000, CRC(9f3cac4c) SHA1(af8a275ff531029dbada3c820c9f660fef383100) )	/* Characters */
 
@@ -1020,6 +1036,9 @@ ROM_START( chelnov )
 	ROM_REGION( 0x10000, "audiocpu", 0 )	/* 6502 Sound CPU */
 	ROM_LOAD( "ee05-.f3",     0x8000, 0x8000, CRC(6a8936b4) SHA1(2b72cb749e6bddb67c2bd3d27b3a92511f9ef016) )
 
+	ROM_REGION( 0x1000, "mcu", 0 )    /* i8751 MCU */
+	ROM_LOAD( "chelnov_i8751", 0x0000, 0x1000, NO_DUMP )
+
 	ROM_REGION( 0x08000, "gfx1", 0 )
 	ROM_LOAD( "ee00-e.c5",    0x00000, 0x08000, CRC(e06e5c6b) SHA1(70166257da5be428cb8404d8e1063c59c7722365) )	/* Characters */
 
@@ -1053,6 +1072,9 @@ ROM_START( chelnovu )
 	ROM_REGION( 0x10000, "audiocpu", 0 )	/* 6502 Sound CPU */
 	ROM_LOAD( "ee05-.f3",     0x8000, 0x8000, CRC(6a8936b4) SHA1(2b72cb749e6bddb67c2bd3d27b3a92511f9ef016) )
 
+	ROM_REGION( 0x1000, "mcu", 0 )    /* i8751 MCU */
+	ROM_LOAD( "chelnovu_i8751", 0x0000, 0x1000, NO_DUMP )
+
 	ROM_REGION( 0x08000, "gfx1", 0 )
 	ROM_LOAD( "ee00-e.c5",    0x00000, 0x08000, CRC(e06e5c6b) SHA1(70166257da5be428cb8404d8e1063c59c7722365) )	/* Characters */
 
@@ -1086,6 +1108,9 @@ ROM_START( chelnovj )
 	ROM_REGION( 0x10000, "audiocpu", 0 )	/* 6502 Sound CPU */
 	ROM_LOAD( "ee05-.f3",     0x8000, 0x8000, CRC(6a8936b4) SHA1(2b72cb749e6bddb67c2bd3d27b3a92511f9ef016) )
 
+	ROM_REGION( 0x1000, "mcu", 0 )    /* i8751 MCU */
+	ROM_LOAD( "chelnovj_i8751", 0x0000, 0x1000, NO_DUMP )
+
 	ROM_REGION( 0x08000, "gfx1", 0 )
 	ROM_LOAD( "a-c5.bin",     0x00000, 0x08000, CRC(1abf2c6d) SHA1(86d625ae94cd9ea69e4e613895410640efb175b3) )	/* Characters */
 
@@ -1116,54 +1141,54 @@ ROM_END
 
 static DRIVER_INIT( karnov )
 {
-	karnov_state *state = machine->driver_data<karnov_state>();
-	state->microcontroller_id = KARNOV;
-	state->coin_mask = 0x07;
+	karnov_state *state = machine.driver_data<karnov_state>();
+	state->m_microcontroller_id = KARNOV;
+	state->m_coin_mask = 0x07;
 }
 
 static DRIVER_INIT( karnovj )
 {
-	karnov_state *state = machine->driver_data<karnov_state>();
-	state->microcontroller_id = KARNOVJ;
-	state->coin_mask = 0x07;
+	karnov_state *state = machine.driver_data<karnov_state>();
+	state->m_microcontroller_id = KARNOVJ;
+	state->m_coin_mask = 0x07;
 }
 
 static DRIVER_INIT( wndrplnt )
 {
-	karnov_state *state = machine->driver_data<karnov_state>();
-	state->microcontroller_id = WNDRPLNT;
-	state->coin_mask = 0x00;
+	karnov_state *state = machine.driver_data<karnov_state>();
+	state->m_microcontroller_id = WNDRPLNT;
+	state->m_coin_mask = 0x00;
 }
 
 static DRIVER_INIT( chelnov )
 {
-	karnov_state *state = machine->driver_data<karnov_state>();
-	UINT16 *RAM = (UINT16 *)machine->region("maincpu")->base();
+	karnov_state *state = machine.driver_data<karnov_state>();
+	UINT16 *RAM = (UINT16 *)machine.region("maincpu")->base();
 
-	state->microcontroller_id = CHELNOV;
-	state->coin_mask = 0xe0;
+	state->m_microcontroller_id = CHELNOV;
+	state->m_coin_mask = 0xe0;
 	RAM[0x0a26/2] = 0x4e71;  /* removes a protection lookup table */
 	RAM[0x062a/2] = 0x4e71;  /* hangs waiting on i8751 int */
 }
 
 static DRIVER_INIT( chelnovu )
 {
-	karnov_state *state = machine->driver_data<karnov_state>();
-	UINT16 *RAM = (UINT16 *)machine->region("maincpu")->base();
+	karnov_state *state = machine.driver_data<karnov_state>();
+	UINT16 *RAM = (UINT16 *)machine.region("maincpu")->base();
 
-	state->microcontroller_id = CHELNOVU;
-	state->coin_mask = 0xe0;
+	state->m_microcontroller_id = CHELNOVU;
+	state->m_coin_mask = 0xe0;
 	RAM[0x0a26/2] = 0x4e71;  /* removes a protection lookup table */
 	RAM[0x062a/2] = 0x4e71;  /* hangs waiting on i8751 int */
 }
 
 static DRIVER_INIT( chelnovj )
 {
-	karnov_state *state = machine->driver_data<karnov_state>();
-	UINT16 *RAM = (UINT16 *)machine->region("maincpu")->base();
+	karnov_state *state = machine.driver_data<karnov_state>();
+	UINT16 *RAM = (UINT16 *)machine.region("maincpu")->base();
 
-	state->microcontroller_id = CHELNOVJ;
-	state->coin_mask = 0xe0;
+	state->m_microcontroller_id = CHELNOVJ;
+	state->m_coin_mask = 0xe0;
 	RAM[0x0a2e/2] = 0x4e71;  /* removes a protection lookup table */
 	RAM[0x062a/2] = 0x4e71;  /* hangs waiting on i8751 int */
 }
