@@ -190,31 +190,63 @@ Notes:
 #include "cdrom.h"
 #include "cpu/powerpc/ppc.h"
 
-static UINT64 *main_ram;
 
-static UINT32 vdl0_address;
-static UINT32 vdl1_address;
+typedef struct
+{
+	UINT32 dst_addr;
+	int length;
+	UINT32 next_dst_addr;
+	int next_length;
+	int dma_done;
+} CDE_DMA;
+
+class konamim2_state : public driver_device
+{
+public:
+	konamim2_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT64 *m_main_ram;
+	UINT32 m_vdl0_address;
+	UINT32 m_vdl1_address;
+	UINT32 m_irq_enable;
+	UINT32 m_irq_active;
+	UINT64 m_unk3;
+	UINT32 m_unk20004;
+	int m_counter1;
+	int m_cde_num_status_bytes;
+	UINT32 m_cde_status_bytes[16];
+	int m_cde_status_byte_ptr;
+	UINT32 m_cde_command_bytes[16];
+	int m_cde_command_byte_ptr;
+	int m_cde_response;
+	int m_cde_drive_state;
+	int m_cde_enable_qchannel_reports;
+	int m_cde_enable_seek_reports;
+	int m_cde_qchannel_offset;
+	cdrom_toc m_cde_toc;
+	CDE_DMA m_cde_dma[2];
+};
 
-static UINT32 irq_enable;
-static UINT32 irq_active;
 
 static VIDEO_START( m2 )
 {
 }
 
-static VIDEO_UPDATE( m2 )
+static SCREEN_UPDATE( m2 )
 {
+	konamim2_state *state = screen->machine().driver_data<konamim2_state>();
 	int i, j;
 
 	UINT32 fb_start = 0xffffffff;
-	if (vdl0_address != 0)
+	if (state->m_vdl0_address != 0)
 	{
-		fb_start = *(UINT32*)&main_ram[(vdl0_address - 0x40000000) / 8] - 0x40000000;
+		fb_start = *(UINT32*)&state->m_main_ram[(state->m_vdl0_address - 0x40000000) / 8] - 0x40000000;
 	}
 
 	if (fb_start <= 0x800000)
 	{
-		UINT16 *frame = (UINT16*)&main_ram[fb_start/8];
+		UINT16 *frame = (UINT16*)&state->m_main_ram[fb_start/8];
 		for (j=0; j < 384; j++)
 		{
 			UINT16 *fb = &frame[(j*512)];
@@ -234,11 +266,12 @@ static VIDEO_UPDATE( m2 )
 
 static READ64_HANDLER(irq_enable_r)
 {
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
 	UINT64 r = 0;
 
 	if (ACCESSING_BITS_32_63)
 	{
-		r |= (UINT64)(irq_enable) << 32;
+		r |= (UINT64)(state->m_irq_enable) << 32;
 	}
 
 	return r;
@@ -246,19 +279,21 @@ static READ64_HANDLER(irq_enable_r)
 
 static WRITE64_HANDLER(irq_enable_w)
 {
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
 	if (ACCESSING_BITS_32_63)
 	{
-		irq_enable |= (UINT32)(data >> 32);
+		state->m_irq_enable |= (UINT32)(data >> 32);
 	}
 }
 
 static READ64_HANDLER(irq_active_r)
 {
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
 	UINT64 r = 0;
 
 	if (ACCESSING_BITS_32_63)
 	{
-		r |= (UINT64)(irq_active) << 32;
+		r |= (UINT64)(state->m_irq_active) << 32;
 	}
 
 	return r;
@@ -283,18 +318,18 @@ static READ64_HANDLER(unk2_r)
 }
 #endif
 
-static UINT64 unk3;
 static READ64_HANDLER(unk3_r)
 {
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
 	//return U64(0xffffffffffffffff);
-	return unk3;
+	return state->m_unk3;
 }
 
-static UINT32 unk20004 = 0;
 static READ64_HANDLER(unk4_r)
 {
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
 	UINT64 r = 0;
-//  logerror("unk4_r: %08X, %08X%08X at %08X\n", offset, (UINT32)(mem_mask>>32), (UINT32)(mem_mask), cpu_get_pc(space->cpu));
+//  logerror("unk4_r: %08X, %08X%08X at %08X\n", offset, (UINT32)(mem_mask>>32), (UINT32)(mem_mask), cpu_get_pc(&space->device()));
 
 	if (ACCESSING_BITS_32_63)
 	{
@@ -303,34 +338,35 @@ static READ64_HANDLER(unk4_r)
 	}
 	if (ACCESSING_BITS_0_31)
 	{
-		r |= unk20004 & ~0x800000;
+		r |= state->m_unk20004 & ~0x800000;
 	}
 	return r;
 }
 
 static WRITE64_HANDLER(unk4_w)
 {
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
 //  logerror("unk4_w: %08X%08X, %08X, %08X%08X at %08X\n", (UINT32)(data >> 32), (UINT32)(data),
-//      offset, (UINT32)(mem_mask>>32), (UINT32)(mem_mask), cpu_get_pc(space->cpu));
+//      offset, (UINT32)(mem_mask>>32), (UINT32)(mem_mask), cpu_get_pc(&space->device()));
 
 	if (ACCESSING_BITS_0_31)
 	{
 		if (data & 0x800000)
 		{
-			mame_printf_debug("CPU '%s': CPU1 IRQ at %08X\n", space->cpu->tag(), cpu_get_pc(space->cpu));
-			cputag_set_input_line(space->machine, "sub", INPUT_LINE_IRQ0, ASSERT_LINE);
+//          mame_printf_debug("CPU '%s': CPU1 IRQ at %08X\n", space->device().tag(), cpu_get_pc(&space->device()));
+			cputag_set_input_line(space->machine(), "sub", INPUT_LINE_IRQ0, ASSERT_LINE);
 		}
 
-		unk20004 = (UINT32)(data);
+		state->m_unk20004 = (UINT32)(data);
 		return;
 	}
 }
 
-static int counter1 = 0;
 static READ64_HANDLER(unk30000_r)
 {
-	counter1++;
-	return (UINT64)(counter1 & 0x7f) << 32;
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
+	state->m_counter1++;
+	return (UINT64)(state->m_counter1 & 0x7f) << 32;
 }
 
 static READ64_HANDLER(unk30030_r)
@@ -344,23 +380,25 @@ static READ64_HANDLER(unk30030_r)
 
 static WRITE64_HANDLER(video_w)
 {
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
 	if (ACCESSING_BITS_32_63)
 	{
-		vdl0_address = (UINT32)(data >> 32);
+		state->m_vdl0_address = (UINT32)(data >> 32);
 	}
 	if (ACCESSING_BITS_0_31)
 	{
-		vdl1_address = (UINT32)(data);
+		state->m_vdl1_address = (UINT32)(data);
 	}
 }
 
 static WRITE64_HANDLER(video_irq_ack_w)
 {
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
 	if (ACCESSING_BITS_32_63)
 	{
 		if ((data >> 32) & 0x8000)
 		{
-			irq_active &= ~0x800000;
+			state->m_irq_active &= ~0x800000;
 		}
 	}
 }
@@ -395,11 +433,11 @@ static WRITE64_HANDLER(unk4000010_w)
 {
 	if ((data & 0xff) == 0xd)
 	{
-		mame_printf_debug("\n");
+//      mame_printf_debug("\n");
 	}
 	else
 	{
-		mame_printf_debug("%c", (UINT8)(data & 0xff));
+//      mame_printf_debug("%c", (UINT8)(data & 0xff));
 	}
 }
 
@@ -409,12 +447,13 @@ static WRITE64_HANDLER(unk4000418_w)
 
 static WRITE64_HANDLER(reset_w)
 {
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
 	if (ACCESSING_BITS_32_63)
 	{
 		if (data & U64(0x100000000))
 		{
-			cputag_set_input_line(space->machine, "maincpu", INPUT_LINE_RESET, PULSE_LINE);
-			unk3 = 0;
+			cputag_set_input_line(space->machine(), "maincpu", INPUT_LINE_RESET, PULSE_LINE);
+			state->m_unk3 = 0;
 		}
 	}
 }
@@ -423,46 +462,26 @@ static WRITE64_HANDLER(reset_w)
 /*****************************************************************************/
 /* CDE */
 
-typedef struct
-{
-	UINT32 dst_addr;
-	int length;
-	UINT32 next_dst_addr;
-	int next_length;
-	int dma_done;
-} CDE_DMA;
-
 #define CDE_DRIVE_STATE_PAUSED			0x02
 #define CDE_DRIVE_STATE_SEEK_DONE		0x03
 
-static int cde_num_status_bytes = 0;
-static UINT32 cde_status_bytes[16];
-static int cde_status_byte_ptr = 0;
-
-static UINT32 cde_command_bytes[16];
-static int cde_command_byte_ptr = 0;
-
-static int cde_response = 0;
-static int cde_drive_state = 0;
-
-static int cde_enable_qchannel_reports = 0;
-static int cde_enable_seek_reports = 0;
-
-static int cde_qchannel_offset = 0;
-
-static cdrom_toc cde_toc;
-
-static CDE_DMA cde_dma[2];
 
 
-static void cde_init(running_machine *machine)
+
+
+
+
+
+
+static void cde_init(running_machine &machine)
 {
+	konamim2_state *state = machine.driver_data<konamim2_state>();
 	cdrom_file *cd = cdrom_open(get_disk_handle(machine, "cdrom"));
 	const cdrom_toc *toc = cdrom_get_toc(cd);
 
 	if (cd)
 	{
-		memcpy(&cde_toc, toc, sizeof(cdrom_toc));
+		memcpy(&state->m_cde_toc, toc, sizeof(cdrom_toc));
 	}
 
 	/*
@@ -480,306 +499,308 @@ static void cde_init(running_machine *machine)
 		cdrom_close(cd);
 	}
 
-	cde_drive_state = CDE_DRIVE_STATE_PAUSED;
+	state->m_cde_drive_state = CDE_DRIVE_STATE_PAUSED;
 
-	cde_num_status_bytes = 0;
-	cde_status_byte_ptr = 0;
-	cde_command_byte_ptr = 0;
+	state->m_cde_num_status_bytes = 0;
+	state->m_cde_status_byte_ptr = 0;
+	state->m_cde_command_byte_ptr = 0;
 
-	cde_response = 0;
+	state->m_cde_response = 0;
 
-	cde_enable_qchannel_reports = 0;
-	cde_enable_seek_reports = 0;
+	state->m_cde_enable_qchannel_reports = 0;
+	state->m_cde_enable_seek_reports = 0;
 
-	cde_qchannel_offset = 0;
+	state->m_cde_qchannel_offset = 0;
 }
 
-static void cde_handle_command(void)
+static void cde_handle_command(running_machine &machine)
 {
-	switch (cde_command_bytes[0])
+	konamim2_state *state = machine.driver_data<konamim2_state>();
+	switch (state->m_cde_command_bytes[0])
 	{
 		case 0x04:		// Set Speed
 		{
-			cde_num_status_bytes = 1;
+			state->m_cde_num_status_bytes = 1;
 
-			cde_status_bytes[0] = 0x04;
-			cde_status_byte_ptr = 0;
+			state->m_cde_status_bytes[0] = 0x04;
+			state->m_cde_status_byte_ptr = 0;
 
-			mame_printf_debug("CDE: SET SPEED %02X, %02X\n", cde_command_bytes[1], cde_command_bytes[2]);
+//          mame_printf_debug("CDE: SET SPEED %02X, %02X\n", state->m_cde_command_bytes[1], state->m_cde_command_bytes[2]);
 			break;
 		}
 		case 0x06:		// Audio Format / Data Format
 		{
-			cde_num_status_bytes = 1;
+			state->m_cde_num_status_bytes = 1;
 
-			cde_status_bytes[0] = 0x06;
-			cde_status_byte_ptr = 0;
+			state->m_cde_status_bytes[0] = 0x06;
+			state->m_cde_status_byte_ptr = 0;
 
-			if (cde_command_bytes[1] == 0x00)		// Audio Format
+			if (state->m_cde_command_bytes[1] == 0x00)		// Audio Format
 			{
-				mame_printf_debug("CDE: AUDIO FORMAT\n");
+//              mame_printf_debug("CDE: AUDIO FORMAT\n");
 			}
-			else if (cde_command_bytes[1] == 0x78)	// Data Format
+			else if (state->m_cde_command_bytes[1] == 0x78)	// Data Format
 			{
-				mame_printf_debug("CDE: DATA FORMAT\n");
+//              mame_printf_debug("CDE: DATA FORMAT\n");
 			}
 			else
 			{
-				fatalerror("CDE: unknown command %02X, %02X\n", cde_command_bytes[0], cde_command_bytes[1]);
+				fatalerror("CDE: unknown command %02X, %02X\n", state->m_cde_command_bytes[0], state->m_cde_command_bytes[1]);
 			}
 			break;
 		}
 		case 0x08:		// Pause / Eject / Play
 		{
-			cde_num_status_bytes = 1;
+			state->m_cde_num_status_bytes = 1;
 
-			cde_status_bytes[0] = 0x08;
-			cde_status_byte_ptr = 0;
+			state->m_cde_status_bytes[0] = 0x08;
+			state->m_cde_status_byte_ptr = 0;
 
-			if (cde_command_bytes[1] == 0x00)		// Eject
+			if (state->m_cde_command_bytes[1] == 0x00)		// Eject
 			{
-				mame_printf_debug("CDE: EJECT command\n");
+//              mame_printf_debug("CDE: EJECT command\n");
 			}
-			else if (cde_command_bytes[1] == 0x02)	// Pause
+			else if (state->m_cde_command_bytes[1] == 0x02)	// Pause
 			{
-				mame_printf_debug("CDE: PAUSE command\n");
-				cde_drive_state = CDE_DRIVE_STATE_PAUSED;
+//              mame_printf_debug("CDE: PAUSE command\n");
+				state->m_cde_drive_state = CDE_DRIVE_STATE_PAUSED;
 			}
-			else if (cde_command_bytes[1] == 0x03)	// Play
+			else if (state->m_cde_command_bytes[1] == 0x03)	// Play
 			{
-				mame_printf_debug("CDE: PLAY command\n");
+//              mame_printf_debug("CDE: PLAY command\n");
 			}
 			else
 			{
-				fatalerror("CDE: unknown command %02X, %02X\n", cde_command_bytes[0], cde_command_bytes[1]);
+				fatalerror("CDE: unknown command %02X, %02X\n", state->m_cde_command_bytes[0], state->m_cde_command_bytes[1]);
 			}
 			break;
 		}
 		case 0x09:		// Seek
 		{
-			cde_num_status_bytes = 1;
+			state->m_cde_num_status_bytes = 1;
 
-			cde_status_bytes[0] = 0x1b;
-			cde_status_byte_ptr = 0;
+			state->m_cde_status_bytes[0] = 0x1b;
+			state->m_cde_status_byte_ptr = 0;
 
-			cde_drive_state = CDE_DRIVE_STATE_SEEK_DONE;
+			state->m_cde_drive_state = CDE_DRIVE_STATE_SEEK_DONE;
 
-			mame_printf_debug("CDE: SEEK %08X\n", (cde_command_bytes[1] << 16) | (cde_command_bytes[2] << 8) | (cde_command_bytes[3]));
+//          mame_printf_debug("CDE: SEEK %08X\n", (state->m_cde_command_bytes[1] << 16) | (state->m_cde_command_bytes[2] << 8) | (state->m_cde_command_bytes[3]));
 			break;
 		}
 		case 0x0b:		// Get Drive State
 		{
-			cde_num_status_bytes = 0x3;
+			state->m_cde_num_status_bytes = 0x3;
 
-			cde_status_bytes[0] = 0x0b;
-			cde_status_bytes[1] = 0x1b;
-			cde_status_bytes[2] = cde_drive_state;
-			cde_status_byte_ptr = 0;
+			state->m_cde_status_bytes[0] = 0x0b;
+			state->m_cde_status_bytes[1] = 0x1b;
+			state->m_cde_status_bytes[2] = state->m_cde_drive_state;
+			state->m_cde_status_byte_ptr = 0;
 
-			if (cde_command_bytes[1] & 0x02)
+			if (state->m_cde_command_bytes[1] & 0x02)
 			{
-				cde_enable_seek_reports = 1;
+				state->m_cde_enable_seek_reports = 1;
 			}
 			else
 			{
-				cde_enable_seek_reports = 0;
+				state->m_cde_enable_seek_reports = 0;
 			}
 
-			mame_printf_debug("CDE: GET DRIVE STATE %02X\n", cde_command_bytes[1]);
+//          mame_printf_debug("CDE: GET DRIVE STATE %02X\n", state->m_cde_command_bytes[1]);
 			break;
 		}
 		case 0x0c:		// ?
 		{
-			cde_num_status_bytes = 1;
+			state->m_cde_num_status_bytes = 1;
 
-			cde_status_bytes[0] = 0x0c;
-			cde_status_byte_ptr = 0;
+			state->m_cde_status_bytes[0] = 0x0c;
+			state->m_cde_status_byte_ptr = 0;
 
-			if (cde_command_bytes[1] == 0x02)
+			if (state->m_cde_command_bytes[1] == 0x02)
 			{
-				cde_enable_qchannel_reports = 1;
-				cde_drive_state = CDE_DRIVE_STATE_PAUSED;
+				state->m_cde_enable_qchannel_reports = 1;
+				state->m_cde_drive_state = CDE_DRIVE_STATE_PAUSED;
 			}
-			else if (cde_command_bytes[0] == 0x00)
+			else if (state->m_cde_command_bytes[0] == 0x00)
 			{
-				cde_enable_qchannel_reports = 0;
+				state->m_cde_enable_qchannel_reports = 0;
 			}
 
-			mame_printf_debug("CDE: UNKNOWN CMD 0x0c %02X\n", cde_command_bytes[1]);
+//          mame_printf_debug("CDE: UNKNOWN CMD 0x0c %02X\n", state->m_cde_command_bytes[1]);
 			break;
 		}
 		case 0x0d:		// Get Switch State
 		{
-			cde_num_status_bytes = 0x4;
+			state->m_cde_num_status_bytes = 0x4;
 
-			cde_status_bytes[0] = 0x0d;
-			cde_status_bytes[1] = 0x1d;
-			cde_status_bytes[2] = 0x02;
-			cde_status_byte_ptr = 0;
+			state->m_cde_status_bytes[0] = 0x0d;
+			state->m_cde_status_bytes[1] = 0x1d;
+			state->m_cde_status_bytes[2] = 0x02;
+			state->m_cde_status_byte_ptr = 0;
 
-			mame_printf_debug("CDE: GET SWITCH STATE %02X\n", cde_command_bytes[1]);
+//          mame_printf_debug("CDE: GET SWITCH STATE %02X\n", state->m_cde_command_bytes[1]);
 			break;
 		}
 		case 0x21:		// Mech type
 		{
-			cde_num_status_bytes = 0x8;
+			state->m_cde_num_status_bytes = 0x8;
 
-			cde_status_bytes[0] = 0x21;
-			cde_status_bytes[1] = 0xff;
-			cde_status_bytes[2] = 0x08;		// Max Speed
-			cde_status_bytes[3] = 0xff;
-			cde_status_bytes[4] = 0xff;
-			cde_status_bytes[5] = 0xff;
-			cde_status_bytes[6] = 0xff;
-			cde_status_bytes[7] = 0xff;
+			state->m_cde_status_bytes[0] = 0x21;
+			state->m_cde_status_bytes[1] = 0xff;
+			state->m_cde_status_bytes[2] = 0x08;		// Max Speed
+			state->m_cde_status_bytes[3] = 0xff;
+			state->m_cde_status_bytes[4] = 0xff;
+			state->m_cde_status_bytes[5] = 0xff;
+			state->m_cde_status_bytes[6] = 0xff;
+			state->m_cde_status_bytes[7] = 0xff;
 
-			cde_status_byte_ptr = 0;
+			state->m_cde_status_byte_ptr = 0;
 
-			mame_printf_debug("CDE: MECH TYPE %02X, %02X, %02X\n", cde_command_bytes[1], cde_command_bytes[2], cde_command_bytes[3]);
+//          mame_printf_debug("CDE: MECH TYPE %02X, %02X, %02X\n", state->m_cde_command_bytes[1], state->m_cde_command_bytes[2], state->m_cde_command_bytes[3]);
 			break;
 		}
 		case 0x83:		// Read ID
 		{
-			cde_num_status_bytes = 0xc;
+			state->m_cde_num_status_bytes = 0xc;
 
-			cde_status_bytes[0] = 0x03;
-			cde_status_bytes[1] = 0xff;
-			cde_status_bytes[2] = 0xff;
-			cde_status_bytes[3] = 0xff;
-			cde_status_bytes[4] = 0xff;
-			cde_status_bytes[5] = 0xff;
-			cde_status_bytes[6] = 0xff;
-			cde_status_bytes[7] = 0xff;
-			cde_status_bytes[8] = 0xff;
-			cde_status_bytes[9] = 0xff;
-			cde_status_bytes[10] = 0xff;
-			cde_status_bytes[11] = 0xff;
+			state->m_cde_status_bytes[0] = 0x03;
+			state->m_cde_status_bytes[1] = 0xff;
+			state->m_cde_status_bytes[2] = 0xff;
+			state->m_cde_status_bytes[3] = 0xff;
+			state->m_cde_status_bytes[4] = 0xff;
+			state->m_cde_status_bytes[5] = 0xff;
+			state->m_cde_status_bytes[6] = 0xff;
+			state->m_cde_status_bytes[7] = 0xff;
+			state->m_cde_status_bytes[8] = 0xff;
+			state->m_cde_status_bytes[9] = 0xff;
+			state->m_cde_status_bytes[10] = 0xff;
+			state->m_cde_status_bytes[11] = 0xff;
 
-			cde_status_byte_ptr = 0;
+			state->m_cde_status_byte_ptr = 0;
 
-			mame_printf_debug("CDE: READ ID\n");
+//          mame_printf_debug("CDE: READ ID\n");
 			break;
 		}
 		default:
 		{
-			fatalerror("CDE: unknown command %08X\n", cde_command_bytes[0]);
+			fatalerror("CDE: unknown command %08X\n", state->m_cde_command_bytes[0]);
 			break;
 		}
 	}
 }
 
-static void cde_handle_reports(void)
+static void cde_handle_reports(running_machine &machine)
 {
-	switch (cde_command_bytes[0])
+	konamim2_state *state = machine.driver_data<konamim2_state>();
+	switch (state->m_cde_command_bytes[0])
 	{
 		case 0x09:
 		{
-			if (cde_enable_seek_reports)
+			if (state->m_cde_enable_seek_reports)
 			{
-				cde_num_status_bytes = 0x2;
-				cde_status_bytes[0] = 0x02;
+				state->m_cde_num_status_bytes = 0x2;
+				state->m_cde_status_bytes[0] = 0x02;
 
-				cde_status_byte_ptr = 0;
+				state->m_cde_status_byte_ptr = 0;
 
-				cde_command_bytes[0] = 0x0c;
+				state->m_cde_command_bytes[0] = 0x0c;
 
-				mame_printf_debug("CDE: SEEK REPORT\n");
+//              mame_printf_debug("CDE: SEEK REPORT\n");
 			}
 			break;
 		}
 
 		case 0x0b:
 		{
-			if (cde_enable_qchannel_reports)
+			if (state->m_cde_enable_qchannel_reports)
 			{
 				int track, num_tracks;
 
-				num_tracks = cde_toc.numtrks;
-				track = cde_qchannel_offset % (num_tracks+3);
+				num_tracks = state->m_cde_toc.numtrks;
+				track = state->m_cde_qchannel_offset % (num_tracks+3);
 
-				cde_num_status_bytes = 0xb;
-				cde_status_bytes[0] = 0x1c;
+				state->m_cde_num_status_bytes = 0xb;
+				state->m_cde_status_bytes[0] = 0x1c;
 
 				/*
-                cde_status_bytes[1] = 0x0;      // q-Mode
-                cde_status_bytes[2] = 0x0;      // TNO
-                cde_status_bytes[3] = 0x0;      // Index / Pointer
-                cde_status_bytes[4] = 0x0;      // Min
-                cde_status_bytes[5] = 0x0;      // Sec
-                cde_status_bytes[6] = 0x0;      // Frac
-                cde_status_bytes[7] = 0x0;      // Zero
-                cde_status_bytes[8] = 0x0;      // A-Min
-                cde_status_bytes[9] = 0x0;      // A-Sec
-                cde_status_bytes[10] = 0x0;     // A-Frac
+                state->m_cde_status_bytes[1] = 0x0;      // q-Mode
+                state->m_cde_status_bytes[2] = 0x0;      // TNO
+                state->m_cde_status_bytes[3] = 0x0;      // Index / Pointer
+                state->m_cde_status_bytes[4] = 0x0;      // Min
+                state->m_cde_status_bytes[5] = 0x0;      // Sec
+                state->m_cde_status_bytes[6] = 0x0;      // Frac
+                state->m_cde_status_bytes[7] = 0x0;      // Zero
+                state->m_cde_status_bytes[8] = 0x0;      // A-Min
+                state->m_cde_status_bytes[9] = 0x0;      // A-Sec
+                state->m_cde_status_bytes[10] = 0x0;     // A-Frac
                 */
 
 				if (track < num_tracks)
 				{
-					int time = lba_to_msf(cde_toc.tracks[track].physframeofs);
+					int time = lba_to_msf(state->m_cde_toc.tracks[track].physframeofs);
 
-					cde_status_bytes[1] = 0x41;					// q-Mode
-					cde_status_bytes[2] = 0x0;					// TNO (Lead-in track)
-					cde_status_bytes[3] = track+1;				// Pointer
-					cde_status_bytes[4] = 0x0;					// Min
-					cde_status_bytes[5] = 0x0;					// Sec
-					cde_status_bytes[6] = 0x0;					// Frac
-					cde_status_bytes[7] = 0x0;					// Zero
-					cde_status_bytes[8] = (time >> 16) & 0xff;	// P-Min
-					cde_status_bytes[9] = (time >>  8) & 0xff;	// P-Sec
-					cde_status_bytes[10] = time & 0xff;			// P-Frac
+					state->m_cde_status_bytes[1] = 0x41;					// q-Mode
+					state->m_cde_status_bytes[2] = 0x0;					// TNO (Lead-in track)
+					state->m_cde_status_bytes[3] = track+1;				// Pointer
+					state->m_cde_status_bytes[4] = 0x0;					// Min
+					state->m_cde_status_bytes[5] = 0x0;					// Sec
+					state->m_cde_status_bytes[6] = 0x0;					// Frac
+					state->m_cde_status_bytes[7] = 0x0;					// Zero
+					state->m_cde_status_bytes[8] = (time >> 16) & 0xff;	// P-Min
+					state->m_cde_status_bytes[9] = (time >>  8) & 0xff;	// P-Sec
+					state->m_cde_status_bytes[10] = time & 0xff;			// P-Frac
 				}
 				else
 				{
 					if (track == num_tracks+0)
 					{
-						cde_status_bytes[1] = 0x41;					// q-Mode / Control
-						cde_status_bytes[2] = 0x0;					// TNO (Lead-in track)
-						cde_status_bytes[3] = 0xa0;					// Pointer
-						cde_status_bytes[4] = 0x0;					// Min
-						cde_status_bytes[5] = 0x0;					// Sec
-						cde_status_bytes[6] = 0x0;					// Frac
-						cde_status_bytes[7] = 0x0;					// Zero
-						cde_status_bytes[8] = 1;					// P-Min
-						cde_status_bytes[9] = 0x0;					// P-Sec
-						cde_status_bytes[10] = 0x0;					// P-Frac
+						state->m_cde_status_bytes[1] = 0x41;					// q-Mode / Control
+						state->m_cde_status_bytes[2] = 0x0;					// TNO (Lead-in track)
+						state->m_cde_status_bytes[3] = 0xa0;					// Pointer
+						state->m_cde_status_bytes[4] = 0x0;					// Min
+						state->m_cde_status_bytes[5] = 0x0;					// Sec
+						state->m_cde_status_bytes[6] = 0x0;					// Frac
+						state->m_cde_status_bytes[7] = 0x0;					// Zero
+						state->m_cde_status_bytes[8] = 1;					// P-Min
+						state->m_cde_status_bytes[9] = 0x0;					// P-Sec
+						state->m_cde_status_bytes[10] = 0x0;					// P-Frac
 					}
 					else if (track == num_tracks+1)
 					{
-						cde_status_bytes[1] = 0x41;					// q-Mode / Control
-						cde_status_bytes[2] = 0x0;					// TNO (Lead-in track)
-						cde_status_bytes[3] = 0xa1;					// Pointer
-						cde_status_bytes[4] = 0x0;					// Min
-						cde_status_bytes[5] = 0x0;					// Sec
-						cde_status_bytes[6] = 0x0;					// Frac
-						cde_status_bytes[7] = 0x0;					// Zero
-						cde_status_bytes[8] = num_tracks;			// P-Min
-						cde_status_bytes[9] = 0x0;					// P-Sec
-						cde_status_bytes[10] = 0x0;					// P-Frac
+						state->m_cde_status_bytes[1] = 0x41;					// q-Mode / Control
+						state->m_cde_status_bytes[2] = 0x0;					// TNO (Lead-in track)
+						state->m_cde_status_bytes[3] = 0xa1;					// Pointer
+						state->m_cde_status_bytes[4] = 0x0;					// Min
+						state->m_cde_status_bytes[5] = 0x0;					// Sec
+						state->m_cde_status_bytes[6] = 0x0;					// Frac
+						state->m_cde_status_bytes[7] = 0x0;					// Zero
+						state->m_cde_status_bytes[8] = num_tracks;			// P-Min
+						state->m_cde_status_bytes[9] = 0x0;					// P-Sec
+						state->m_cde_status_bytes[10] = 0x0;					// P-Frac
 					}
 					else
 					{
-						int leadout_lba = cde_toc.tracks[num_tracks-1].physframeofs + cde_toc.tracks[num_tracks-1].frames;
+						int leadout_lba = state->m_cde_toc.tracks[num_tracks-1].physframeofs + state->m_cde_toc.tracks[num_tracks-1].frames;
 						int leadout_time = lba_to_msf(leadout_lba);
 
-						cde_status_bytes[1] = 0x41;					// q-Mode / Control
-						cde_status_bytes[2] = 0x0;					// TNO (Lead-in track)
-						cde_status_bytes[3] = 0xa2;					// Pointer
-						cde_status_bytes[4] = 0x0;					// Min
-						cde_status_bytes[5] = 0x0;					// Sec
-						cde_status_bytes[6] = 0x0;					// Frac
-						cde_status_bytes[7] = 0x0;					// Zero
-						cde_status_bytes[8] = (leadout_time >> 16) & 0xff;	// P-Min
-						cde_status_bytes[9] = (leadout_time >>  8) & 0xff;	// P-Sec
-						cde_status_bytes[10] = leadout_time & 0xff;			// P-Frac
+						state->m_cde_status_bytes[1] = 0x41;					// q-Mode / Control
+						state->m_cde_status_bytes[2] = 0x0;					// TNO (Lead-in track)
+						state->m_cde_status_bytes[3] = 0xa2;					// Pointer
+						state->m_cde_status_bytes[4] = 0x0;					// Min
+						state->m_cde_status_bytes[5] = 0x0;					// Sec
+						state->m_cde_status_bytes[6] = 0x0;					// Frac
+						state->m_cde_status_bytes[7] = 0x0;					// Zero
+						state->m_cde_status_bytes[8] = (leadout_time >> 16) & 0xff;	// P-Min
+						state->m_cde_status_bytes[9] = (leadout_time >>  8) & 0xff;	// P-Sec
+						state->m_cde_status_bytes[10] = leadout_time & 0xff;			// P-Frac
 					}
 				}
 
-				cde_qchannel_offset++;
+				state->m_cde_qchannel_offset++;
 
-				cde_status_byte_ptr = 0;
-				cde_command_bytes[0] = 0x0c;
+				state->m_cde_status_byte_ptr = 0;
+				state->m_cde_command_bytes[0] = 0x0c;
 
-				mame_printf_debug("CDE: QCHANNEL REPORT\n");
+//              mame_printf_debug("CDE: QCHANNEL REPORT\n");
 				break;
 			}
 		}
@@ -788,22 +809,23 @@ static void cde_handle_reports(void)
 
 static void cde_dma_transfer(address_space *space, int channel, int next)
 {
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
 	UINT32 address;
 	//int length;
 	int i;
 
 	if (next)
 	{
-		address = cde_dma[channel].next_dst_addr;
-		//length = cde_dma[channel].next_length;
+		address = state->m_cde_dma[channel].next_dst_addr;
+		//length = state->m_cde_dma[channel].next_length;
 	}
 	else
 	{
-		address = cde_dma[channel].dst_addr;
-		//length = cde_dma[channel].length;
+		address = state->m_cde_dma[channel].dst_addr;
+		//length = state->m_cde_dma[channel].length;
 	}
 
-	for (i=0; i < cde_dma[channel].next_length; i++)
+	for (i=0; i < state->m_cde_dma[channel].next_length; i++)
 	{
 		space->write_byte(address, 0xff);		// TODO: do the real transfer...
 		address++;
@@ -812,6 +834,7 @@ static void cde_dma_transfer(address_space *space, int channel, int next)
 
 static READ64_HANDLER(cde_r)
 {
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
 	UINT32 r = 0;
 	int reg = offset * 2;
 
@@ -829,36 +852,36 @@ static READ64_HANDLER(cde_r)
 		{
 			r = 0x100038;
 
-			r |= cde_dma[0].dma_done ? 0x400 : 0;
-			r |= cde_dma[1].dma_done ? 0x800 : 0;
+			r |= state->m_cde_dma[0].dma_done ? 0x400 : 0;
+			r |= state->m_cde_dma[1].dma_done ? 0x800 : 0;
 			break;
 		}
 		case 0x02c/4:
 		{
-			r = cde_status_bytes[cde_status_byte_ptr++];
+			r = state->m_cde_status_bytes[state->m_cde_status_byte_ptr++];
 
-			if (cde_status_byte_ptr <= cde_num_status_bytes)
+			if (state->m_cde_status_byte_ptr <= state->m_cde_num_status_bytes)
 			{
 				r |= 0x100;
 			}
 			else
 			{
 				//if (cde_enable_reports &&
-				//  !cde_response &&
-				//  cde_command_bytes[0] != ((cde_report_type >> 8) & 0xff))
+				//  !state->m_cde_response &&
+				//  state->m_cde_command_bytes[0] != ((cde_report_type >> 8) & 0xff))
 
-				if (!cde_response)
+				if (!state->m_cde_response)
 				{
-					cde_handle_reports();
+					cde_handle_reports(space->machine());
 
-			//      cde_command_byte_ptr = 0;
-			//      cde_command_bytes[cde_command_byte_ptr++] = 0x1c;
+			//      state->m_cde_command_byte_ptr = 0;
+			//      state->m_cde_command_bytes[state->m_cde_command_byte_ptr++] = 0x1c;
 
-			//      cde_response = 1;
+			//      state->m_cde_response = 1;
 				}
 			}
 
-	//      printf("status byte %d\n", cde_status_byte_ptr);
+	//      printf("status byte %d\n", state->m_cde_status_byte_ptr);
 			break;
 		}
 
@@ -870,7 +893,7 @@ static READ64_HANDLER(cde_r)
 
 		default:
 		{
-	//      mame_printf_debug("cde_r: %08X at %08X\n", reg*4, cpu_get_pc(space->cpu));
+//                      mame_printf_debug("cde_r: %08X at %08X\n", reg*4, cpu_get_pc(&space->device()));
 			break;
 		}
 	}
@@ -887,6 +910,7 @@ static READ64_HANDLER(cde_r)
 
 static WRITE64_HANDLER(cde_w)
 {
+	konamim2_state *state = space->machine().driver_data<konamim2_state>();
 	int reg = offset * 2;
 	UINT32 d;
 
@@ -904,32 +928,32 @@ static WRITE64_HANDLER(cde_w)
 	{
 		case 0x028/4:		// Command write
 		{
-			//printf("cde_w: %08X, %08X at %08X\n", d, reg*4, cpu_get_pc(space->cpu));
+			//printf("cde_w: %08X, %08X at %08X\n", d, reg*4, cpu_get_pc(&space->device()));
 
 			if (d == 0x0180)
 			{
-				if (cde_response)
+				if (state->m_cde_response)
 				{
-					cde_handle_command();
+					cde_handle_command(space->machine());
 
-					cde_response = 0;
+					state->m_cde_response = 0;
 				}
 
-				cde_command_byte_ptr = 0;
+				state->m_cde_command_byte_ptr = 0;
 			}
-			else if (cde_command_byte_ptr == 0)
+			else if (state->m_cde_command_byte_ptr == 0)
 			{
-				cde_num_status_bytes = 1;
+				state->m_cde_num_status_bytes = 1;
 
-				cde_status_bytes[0] = d & 0xff;
-				cde_status_byte_ptr = 0;
+				state->m_cde_status_bytes[0] = d & 0xff;
+				state->m_cde_status_byte_ptr = 0;
 
-				cde_response = 1;
+				state->m_cde_response = 1;
 			}
 
 			if (d != 0x180)
 			{
-				cde_command_bytes[cde_command_byte_ptr++] = d;
+				state->m_cde_command_bytes[state->m_cde_command_byte_ptr++] = d;
 			}
 
 			break;
@@ -937,17 +961,17 @@ static WRITE64_HANDLER(cde_w)
 
 		case 0x300/4:		// DMA Channel 0 enable
 		{
-			mame_printf_debug("CDE: DMA0 enable %08X\n", d);
+//          mame_printf_debug("CDE: DMA0 enable %08X\n", d);
 
 			if (d & 0x20)
 			{
-				cde_dma[0].dma_done = 1;
+				state->m_cde_dma[0].dma_done = 1;
 
 				cde_dma_transfer(space, 0, 0);
 			}
 			if (d & 0x40)
 			{
-				cde_dma[0].dma_done = 1;
+				state->m_cde_dma[0].dma_done = 1;
 
 				cde_dma_transfer(space, 0, 1);
 			}
@@ -955,64 +979,64 @@ static WRITE64_HANDLER(cde_w)
 		}
 		case 0x308/4:		// DMA Channel 0 destination address
 		{
-			mame_printf_debug("CDE: DMA0 dst addr %08X\n", d);
+//          mame_printf_debug("CDE: DMA0 dst addr %08X\n", d);
 
-			cde_dma[0].dst_addr = d;
+			state->m_cde_dma[0].dst_addr = d;
 			break;
 		}
 		case 0x30c/4:		// DMA Channel 0 length?
 		{
-			mame_printf_debug("CDE: DMA0 length %08X\n", d);
+//          mame_printf_debug("CDE: DMA0 length %08X\n", d);
 
-			cde_dma[0].length = d;
+			state->m_cde_dma[0].length = d;
 			break;
 		}
 		case 0x318/4:		// DMA Channel 0 next destination address
 		{
-			mame_printf_debug("CDE: DMA0 next dst addr %08X\n", d);
+//          mame_printf_debug("CDE: DMA0 next dst addr %08X\n", d);
 
-			cde_dma[0].next_dst_addr = d;
+			state->m_cde_dma[0].next_dst_addr = d;
 			break;
 		}
 		case 0x31c/4:		// DMA Channel 0 next length?
 		{
-			mame_printf_debug("CDE: DMA0 next length %08X\n", d);
+//          mame_printf_debug("CDE: DMA0 next length %08X\n", d);
 
-			cde_dma[0].next_length = d;
+			state->m_cde_dma[0].next_length = d;
 			break;
 		}
 
 		case 0x320/4:		// DMA Channel 1 enable
 		{
-			mame_printf_debug("CDE: DMA1 enable %08X\n", d);
+//          mame_printf_debug("CDE: DMA1 enable %08X\n", d);
 			break;
 		}
 		case 0x328/4:		// DMA Channel 1 destination address
 		{
-			mame_printf_debug("CDE: DMA1 dst addr %08X\n", d);
+//          mame_printf_debug("CDE: DMA1 dst addr %08X\n", d);
 
-			cde_dma[1].dst_addr = d;
+			state->m_cde_dma[1].dst_addr = d;
 			break;
 		}
 		case 0x32c/4:		// DMA Channel 1 length?
 		{
-			mame_printf_debug("CDE: DMA1 length %08X\n", d);
+//          mame_printf_debug("CDE: DMA1 length %08X\n", d);
 
-			cde_dma[1].length = d;
+			state->m_cde_dma[1].length = d;
 			break;
 		}
 		case 0x338/4:		// DMA Channel 1 next destination address
 		{
-			mame_printf_debug("CDE: DMA1 next dst addr %08X\n", d);
+//          mame_printf_debug("CDE: DMA1 next dst addr %08X\n", d);
 
-			cde_dma[1].next_dst_addr = d;
+			state->m_cde_dma[1].next_dst_addr = d;
 			break;
 		}
 		case 0x33c/4:		// DMA Channel 1 next length?
 		{
-			mame_printf_debug("CDE: DMA1 next length %08X\n", d);
+//          mame_printf_debug("CDE: DMA1 next length %08X\n", d);
 
-			cde_dma[1].next_length = d;
+			state->m_cde_dma[1].next_length = d;
 			break;
 		}
 
@@ -1020,19 +1044,19 @@ static WRITE64_HANDLER(cde_w)
 		{
 			if (d & 0x80000000)
 			{
-				irq_active &= ~0x8;
+				state->m_irq_active &= ~0x8;
 			}
 			if (d & 0x60000000)
 			{
-				cde_dma[0].dma_done = 0;
-				cde_dma[1].dma_done = 0;
+				state->m_cde_dma[0].dma_done = 0;
+				state->m_cde_dma[1].dma_done = 0;
 			}
 			break;
 		}
 
 		default:
 		{
-	//      mame_printf_debug("cde_w: %08X, %08X at %08X\n", d, reg*4, cpu_get_pc(space->cpu));
+//                      mame_printf_debug("cde_w: %08X, %08X at %08X\n", d, reg*4, cpu_get_pc(&space->device()));
 			break;
 		}
 	}
@@ -1075,7 +1099,7 @@ static READ64_HANDLER(cpu_r)
 
 	if (ACCESSING_BITS_32_63)
 	{
-		r = (UINT64)((space->cpu != space->machine->device("maincpu")) ? 0x80000000 : 0);
+		r = (UINT64)((&space->device() != space->machine().device("maincpu")) ? 0x80000000 : 0);
 		//r |= 0x40000000;  // sets Video-LowRes !?
 		return r << 32;
 	}
@@ -1083,7 +1107,7 @@ static READ64_HANDLER(cpu_r)
 	return 0;
 }
 
-static ADDRESS_MAP_START( m2_main, ADDRESS_SPACE_PROGRAM, 64 )
+static ADDRESS_MAP_START( m2_main, AS_PROGRAM, 64 )
 	AM_RANGE(0x00010040, 0x00010047) AM_READWRITE(irq_enable_r, irq_enable_w)
 	AM_RANGE(0x00010050, 0x00010057) AM_READ(irq_active_r)
 	AM_RANGE(0x00020000, 0x00020007) AM_READWRITE(unk4_r, unk4_w)
@@ -1102,7 +1126,7 @@ static ADDRESS_MAP_START( m2_main, ADDRESS_SPACE_PROGRAM, 64 )
 	AM_RANGE(0x10000000, 0x10000007) AM_READ(cpu_r)
 	AM_RANGE(0x10000008, 0x10001007) AM_NOP		// ???
 	AM_RANGE(0x20000000, 0x201fffff) AM_ROM AM_SHARE("share2")
-	AM_RANGE(0x40000000, 0x407fffff) AM_RAM AM_SHARE("share3") AM_BASE(&main_ram)
+	AM_RANGE(0x40000000, 0x407fffff) AM_RAM AM_SHARE("share3") AM_BASE_MEMBER(konamim2_state, m_main_ram)
 	AM_RANGE(0xfff00000, 0xffffffff) AM_ROM AM_REGION("boot", 0) AM_SHARE("share2")
 ADDRESS_MAP_END
 
@@ -1117,20 +1141,21 @@ static const powerpc_config ppc602_config =
 
 static INTERRUPT_GEN(m2)
 {
-	if (irq_enable & 0x800000)
+	konamim2_state *state = device->machine().driver_data<konamim2_state>();
+	if (state->m_irq_enable & 0x800000)
 	{
-		irq_active |= 0x800000;
+		state->m_irq_active |= 0x800000;
 	}
 
-	/*if (irq_enable & 0x8)
+	/*if (state->m_irq_enable & 0x8)
     {
-        irq_active |= 0x8;
+        state->m_irq_active |= 0x8;
     }*/
 
-	cpu_set_input_line(device, INPUT_LINE_IRQ0, ASSERT_LINE);
+	device_set_input_line(device, INPUT_LINE_IRQ0, ASSERT_LINE);
 }
 
-static MACHINE_CONFIG_START( m2, driver_device )
+static MACHINE_CONFIG_START( m2, konamim2_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", PPC602, 33000000)	/* actually PPC602, 66MHz */
@@ -1149,12 +1174,12 @@ static MACHINE_CONFIG_START( m2, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(640, 480)
 	MCFG_SCREEN_VISIBLE_AREA(0, 511, 0, 383)
+	MCFG_SCREEN_UPDATE(m2)
 
 	MCFG_PALETTE_LENGTH(32768)
 	MCFG_PALETTE_INIT(RRRRR_GGGGG_BBBBB)
 
 	MCFG_VIDEO_START(m2)
-	MCFG_VIDEO_UPDATE(m2)
 
 MACHINE_CONFIG_END
 
@@ -1193,6 +1218,23 @@ ROM_START( evilngt )
 	ROM_REGION64_BE( 0x200000, "boot", 0 )
 	ROM_LOAD16_WORD( "636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b) )
 
+	ROM_REGION( 0x2000, "timekeep", 0 ) /* timekeeper SRAM */
+	ROM_LOAD( "m48t58y.9n",   0x000000, 0x002000, CRC(e887ca1f) SHA1(54205f01b1ceba1d5f4d979fc30be1add8116e90) )
+
+	ROM_REGION( 0x400000, "ymz", 0 ) /* YMZ280B sound rom on sub board */
+	ROM_LOAD( "810a03.16h",  0x000000, 0x400000, CRC(4cd79d98) SHA1(12fea41cfc5c1b883ffbeda7e428dd1d1bf54d7f) )
+
+	ROM_REGION( 0x80, "eeprom", 0 )	/* EEPROM default contents */
+	ROM_LOAD( "93c46.7k",    0x000000, 0x000080, CRC(d7ba2e5e) SHA1(d729557555c6fc1cd433b14017952cc63ec73573) )
+
+	DISK_REGION( "cdrom" )
+	DISK_IMAGE( "810uba02", 0, SHA1(ca3b957e3e33435391fbf630f9ed89aa08a70c8f) )
+ROM_END
+
+ROM_START( evilngte )
+	ROM_REGION64_BE( 0x200000, "boot", 0 )
+	ROM_LOAD16_WORD( "636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b) )
+
 	ROM_REGION( 0x1000, "timekeep", 0 ) /* timekeeper SRAM */
 	ROM_LOAD( "m48t58y.u1",  0x000000, 0x001000, CRC(169bb8f4) SHA1(55c0bafab5d309fe69156489186e232aa87ca0dd) )
 
@@ -1240,8 +1282,9 @@ ROM_END
 
 static DRIVER_INIT( m2 )
 {
-	unk3 = U64(0xffffffffffffffff);
-	unk20004 = 0;
+	konamim2_state *state = machine.driver_data<konamim2_state>();
+	state->m_unk3 = U64(0xffffffffffffffff);
+	state->m_unk20004 = 0;
 	cde_init(machine);
 }
 
@@ -1251,5 +1294,6 @@ GAME( 1997, totlvicj, totlvice, m2, m2, m2, ROT0, "Konami", "Total Vice (ver JAD
 //GAME( 1997, totlvica, totlvice, m2, m2, m2, ROT0, "Konami", "Total Vice (ver AAB)", GAME_NOT_WORKING | GAME_NO_SOUND )
 GAME( 1998, btltryst, 0,        m2, m2, m2, ROT0, "Konami", "Battle Tryst (ver JAC)", GAME_NOT_WORKING | GAME_NO_SOUND )
 GAME( 1998, heatof11, 0,        m2, m2, m2, ROT0, "Konami", "Heat of Eleven '98 (ver EAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
-GAME( 1998, evilngt,  0,        m2, m2, m2, ROT0, "Konami", "Evil Night (ver EAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1998, evilngt, 0,         m2, m2, m2, ROT0, "Konami", "Evil Night (ver UBA)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1998, evilngte,  evilngt,       m2, m2, m2, ROT0, "Konami", "Evil Night (ver EAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
 GAME( 1998, hellngt,  evilngt,  m2, m2, m2, ROT0, "Konami", "Hell Night (ver EAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
