@@ -68,26 +68,33 @@ Dumping Notes:
 #include "render.h"
 #include "machine/laserdsc.h"
 
+
+class lgp_state : public driver_device
+{
+public:
+	lgp_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	device_t *m_laserdisc;
+	UINT8 *m_tile_ram;
+	UINT8 *m_tile_control_ram;
+	emu_timer *m_irq_timer;
+};
+
+
 /* From italiandoh's notes */
 #define CPU_PCB_CLOCK (8000000)
 #define SOUND_PCB_CLOCK (6000000)
 
-/* Misc variables */
-static device_t *laserdisc;
-
-static UINT8 *tile_ram;
-static UINT8 *tile_control_ram;
-
-static emu_timer *irq_timer;
-
 
 /* VIDEO GOODS */
-static VIDEO_UPDATE( lgp )
+static SCREEN_UPDATE( lgp )
 {
+	lgp_state *state = screen->machine().driver_data<lgp_state>();
 	int charx, chary;
 
 	/* make color 0 transparent */
-	palette_set_color(screen->machine, 0, MAKE_ARGB(0,0,0,0));
+	palette_set_color(screen->machine(), 0, MAKE_ARGB(0,0,0,0));
 
 	/* clear */
 	bitmap_fill(bitmap, cliprect, 0);
@@ -101,8 +108,8 @@ static VIDEO_UPDATE( lgp )
 
 			/* Somewhere there's a flag that offsets the tilemap by 0x100*x */
 			/* Palette is likely set somewhere as well (tile_control_ram?) */
-			drawgfx_transpen(bitmap, cliprect, screen->machine->gfx[0],
-					tile_ram[current_screen_character],
+			drawgfx_transpen(bitmap, cliprect, screen->machine().gfx[0],
+					state->m_tile_ram[current_screen_character],
 					0,
 					0, 0, charx*8, chary*8, 0);
 		}
@@ -116,12 +123,14 @@ static VIDEO_UPDATE( lgp )
 /* Main Z80 R/W */
 static READ8_HANDLER(ldp_read)
 {
-	return laserdisc_data_r(laserdisc);
+	lgp_state *state = space->machine().driver_data<lgp_state>();
+	return laserdisc_data_r(state->m_laserdisc);
 }
 
 static WRITE8_HANDLER(ldp_write)
 {
-	laserdisc_data_w(laserdisc,data);
+	lgp_state *state = space->machine().driver_data<lgp_state>();
+	laserdisc_data_w(state->m_laserdisc,data);
 }
 
 
@@ -129,10 +138,10 @@ static WRITE8_HANDLER(ldp_write)
 
 
 /* PROGRAM MAPS */
-static ADDRESS_MAP_START( main_program_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( main_program_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000,0x7fff) AM_ROM
-	AM_RANGE(0xe000,0xe3ff) AM_RAM AM_BASE(&tile_ram)
-	AM_RANGE(0xe400,0xe7ff) AM_RAM AM_BASE(&tile_control_ram)
+	AM_RANGE(0xe000,0xe3ff) AM_RAM AM_BASE_MEMBER(lgp_state, m_tile_ram)
+	AM_RANGE(0xe400,0xe7ff) AM_RAM AM_BASE_MEMBER(lgp_state, m_tile_control_ram)
 
 //  AM_RANGE(0xef00,0xef00) AM_READ_PORT("IN_TEST")
 	AM_RANGE(0xef80,0xef80) AM_READWRITE(ldp_read,ldp_write)
@@ -145,7 +154,7 @@ static ADDRESS_MAP_START( main_program_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf000,0xffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_program_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_program_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000,0x3fff) AM_ROM
 	AM_RANGE(0x8000,0x83ff) AM_RAM
 	AM_RANGE(0x8400,0x8407) AM_RAM		/* Needs handler!  Communications? */
@@ -154,13 +163,13 @@ ADDRESS_MAP_END
 
 
 /* IO MAPS */
-static ADDRESS_MAP_START( main_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( main_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 //  AM_RANGE(0xfd,0xfd) AM_READ_PORT("IN_TEST")
 //  AM_RANGE(0xfe,0xfe) AM_READ_PORT("IN_TEST")
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( sound_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 ADDRESS_MAP_END
 
@@ -324,24 +333,26 @@ static TIMER_CALLBACK( irq_stop )
 
 static INTERRUPT_GEN( vblank_callback_lgp )
 {
+	lgp_state *state = device->machine().driver_data<lgp_state>();
 	// NMI
-	//cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
+	//device_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 
 	// IRQ
-	cpu_set_input_line(device, 0, ASSERT_LINE);
-	timer_adjust_oneshot(irq_timer, ATTOTIME_IN_USEC(50), 0);
+	device_set_input_line(device, 0, ASSERT_LINE);
+	state->m_irq_timer->adjust(attotime::from_usec(50));
 }
 
 
 static MACHINE_START( lgp )
 {
-	laserdisc = machine->device("laserdisc");
-    irq_timer = timer_alloc(machine, irq_stop, 0);
+	lgp_state *state = machine.driver_data<lgp_state>();
+	state->m_laserdisc = machine.device("laserdisc");
+	state->m_irq_timer = machine.scheduler().timer_alloc(FUNC(irq_stop));
 }
 
 
 /* DRIVER */
-static MACHINE_CONFIG_START( lgp, driver_device )
+static MACHINE_CONFIG_START( lgp, lgp_state )
 	/* main cpu */
 	MCFG_CPU_ADD("maincpu", Z80, CPU_PCB_CLOCK)
 	MCFG_CPU_PROGRAM_MAP(main_program_map)
