@@ -136,7 +136,6 @@
 #define ADDRESS_MAP_MODERN
 
 #include "emu.h"
-#include "deprecat.h"
 #include "includes/liberatr.h"
 
 #define MASTER_CLOCK 20000000 /* 20Mhz Main Clock Xtal */
@@ -146,9 +145,9 @@ void liberatr_state::machine_start()
 {
 	atarigen_state::machine_start();
 
-	state_save_register_device_item(this, 0, m_trackball_offset);
-	state_save_register_device_item(this, 0, m_ctrld);
-	state_save_register_device_item_array(this, 0, m_videoram);
+	save_item(NAME(m_trackball_offset));
+	save_item(NAME(m_ctrld));
+	save_item(NAME(m_videoram));
 }
 
 
@@ -161,13 +160,13 @@ void liberatr_state::machine_start()
 
 WRITE8_MEMBER( liberatr_state::led_w )
 {
-	set_led_status(&m_machine, offset, ~data & 0x10);
+	set_led_status(machine(), offset, ~data & 0x10);
 }
 
 
 WRITE8_MEMBER( liberatr_state::coin_counter_w )
 {
-	::coin_counter_w(&m_machine, offset ^ 0x01, data & 0x10);
+	::coin_counter_w(machine(), offset ^ 0x01, data & 0x10);
 }
 
 
@@ -184,8 +183,8 @@ WRITE8_MEMBER( liberatr_state::trackball_reset_w )
 	/* input becomes the starting point for the trackball counters */
 	if (((data ^ m_ctrld) & 0x10) && (data & 0x10))
 	{
-		UINT8 trackball = input_port_read(&m_machine, "FAKE");
-		UINT8 switches = input_port_read(&m_machine, "IN0");
+		UINT8 trackball = input_port_read(machine(), "FAKE");
+		UINT8 switches = input_port_read(machine(), "IN0");
 		m_trackball_offset = ((trackball & 0xf0) - (switches & 0xf0)) | ((trackball - switches) & 0x0f);
 	}
 	m_ctrld = data & 0x10;
@@ -197,13 +196,13 @@ READ8_MEMBER( liberatr_state::port0_r )
 	/* if ctrld is high, the /ld signal on the LS191 is NOT set, meaning that the trackball is counting */
 	if (m_ctrld)
 	{
-		UINT8 trackball = input_port_read(&m_machine, "FAKE");
+		UINT8 trackball = input_port_read(machine(), "FAKE");
 		return ((trackball & 0xf0) - (m_trackball_offset & 0xf0)) | ((trackball - m_trackball_offset) & 0x0f);
 	}
 
 	/* otherwise, the LS191 is simply passing through the raw switch inputs */
 	else
-		return input_port_read(&m_machine, "IN0");
+		return input_port_read(machine(), "IN0");
 }
 
 
@@ -214,7 +213,7 @@ READ8_MEMBER( liberatr_state::port0_r )
  *
  *************************************/
 
-static ADDRESS_MAP_START( liberatr_map, ADDRESS_SPACE_PROGRAM, 8, liberatr_state )
+static ADDRESS_MAP_START( liberatr_map, AS_PROGRAM, 8, liberatr_state )
 	AM_RANGE(0x0000, 0x0000) AM_RAM AM_SHARE("xcoord")
 	AM_RANGE(0x0001, 0x0001) AM_RAM AM_SHARE("ycoord")
 	AM_RANGE(0x0002, 0x0002) AM_READWRITE(bitmap_xy_r, bitmap_xy_w)
@@ -247,7 +246,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( liberat2_map, ADDRESS_SPACE_PROGRAM, 8, liberatr_state )
+static ADDRESS_MAP_START( liberat2_map, AS_PROGRAM, 8, liberatr_state )
 	AM_RANGE(0x0000, 0x0000) AM_RAM AM_SHARE("xcoord")
 	AM_RANGE(0x0001, 0x0001) AM_RAM AM_SHARE("ycoord")
 	AM_RANGE(0x0002, 0x0002) AM_READWRITE(bitmap_xy_r, bitmap_xy_w)
@@ -391,7 +390,7 @@ static MACHINE_CONFIG_START( liberatr, liberatr_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M6502, MASTER_CLOCK/16) /* 1.25Mhz divided from 20Mhz master clock */
 	MCFG_CPU_PROGRAM_MAP(liberatr_map)
-	MCFG_CPU_VBLANK_INT_HACK(irq0_line_hold,4)
+	MCFG_CPU_PERIODIC_INT(irq0_line_hold,4*60)
 
 	MCFG_ER2055_ADD("earom")
 
