@@ -61,35 +61,35 @@ and two large (paddles pretending to be) guns.
 class m79amb_state : public driver_device
 {
 public:
-	m79amb_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	m79amb_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *        videoram;
-	UINT8 *        mask;
+	UINT8 *        m_videoram;
+	UINT8 *        m_mask;
 
 	/* misc */
-	UINT8 lut_gun1[0x100];
-	UINT8 lut_gun2[0x100];
+	UINT8 m_lut_gun1[0x100];
+	UINT8 m_lut_gun2[0x100];
 };
 
 
 static WRITE8_HANDLER( ramtek_videoram_w )
 {
-	m79amb_state *state = space->machine->driver_data<m79amb_state>();
-	state->videoram[offset] = data & ~*state->mask;
+	m79amb_state *state = space->machine().driver_data<m79amb_state>();
+	state->m_videoram[offset] = data & ~*state->m_mask;
 }
 
-static VIDEO_UPDATE( ramtek )
+static SCREEN_UPDATE( ramtek )
 {
-	m79amb_state *state = screen->machine->driver_data<m79amb_state>();
+	m79amb_state *state = screen->machine().driver_data<m79amb_state>();
 	offs_t offs;
 
 	for (offs = 0; offs < 0x2000; offs++)
 	{
 		int i;
 
-		UINT8 data = state->videoram[offs];
+		UINT8 data = state->m_videoram[offs];
 		int y = offs >> 5;
 		int x = (offs & 0x1f) << 3;
 
@@ -109,20 +109,20 @@ static VIDEO_UPDATE( ramtek )
 
 static READ8_HANDLER( gray5bit_controller0_r )
 {
-	m79amb_state *state = space->machine->driver_data<m79amb_state>();
-	UINT8 port_data = input_port_read(space->machine, "8004");
-	UINT8 gun_pos = input_port_read(space->machine, "GUN1");
+	m79amb_state *state = space->machine().driver_data<m79amb_state>();
+	UINT8 port_data = input_port_read(space->machine(), "8004");
+	UINT8 gun_pos = input_port_read(space->machine(), "GUN1");
 
-	return (port_data & 0xe0) | state->lut_gun1[gun_pos];
+	return (port_data & 0xe0) | state->m_lut_gun1[gun_pos];
 }
 
 static READ8_HANDLER( gray5bit_controller1_r )
 {
-	m79amb_state *state = space->machine->driver_data<m79amb_state>();
-	UINT8 port_data = input_port_read(space->machine, "8005");
-	UINT8 gun_pos = input_port_read(space->machine, "GUN2");
+	m79amb_state *state = space->machine().driver_data<m79amb_state>();
+	UINT8 port_data = input_port_read(space->machine(), "8005");
+	UINT8 gun_pos = input_port_read(space->machine(), "GUN2");
 
-	return (port_data & 0xe0) | state->lut_gun2[gun_pos];
+	return (port_data & 0xe0) | state->m_lut_gun2[gun_pos];
 }
 
 static WRITE8_HANDLER( m79amb_8002_w )
@@ -132,12 +132,12 @@ static WRITE8_HANDLER( m79amb_8002_w )
 	output_set_value("EXP_LAMP", data ? 1 : 0);
 }
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
-	AM_RANGE(0x4000, 0x5fff) AM_RAM_WRITE(ramtek_videoram_w) AM_BASE_MEMBER(m79amb_state, videoram)
+	AM_RANGE(0x4000, 0x5fff) AM_RAM_WRITE(ramtek_videoram_w) AM_BASE_MEMBER(m79amb_state, m_videoram)
 	AM_RANGE(0x6000, 0x63ff) AM_RAM					/* ?? */
 	AM_RANGE(0x8000, 0x8000) AM_READ_PORT("8000") AM_DEVWRITE("discrete", m79amb_8000_w)
-	AM_RANGE(0x8001, 0x8001) AM_WRITEONLY AM_BASE_MEMBER(m79amb_state, mask)
+	AM_RANGE(0x8001, 0x8001) AM_WRITEONLY AM_BASE_MEMBER(m79amb_state, m_mask)
 	AM_RANGE(0x8002, 0x8002) AM_READ_PORT("8002") AM_WRITE(m79amb_8002_w)
 	AM_RANGE(0x8003, 0x8003) AM_DEVWRITE("discrete", m79amb_8003_w)
 	AM_RANGE(0x8004, 0x8004) AM_READ(gray5bit_controller0_r)
@@ -200,7 +200,7 @@ INPUT_PORTS_END
 
 static INTERRUPT_GEN( m79amb_interrupt )
 {
-	cpu_set_input_line_and_vector(device, 0, HOLD_LINE, 0xcf);  /* RST 08h */
+	device_set_input_line_and_vector(device, 0, HOLD_LINE, 0xcf);  /* RST 08h */
 }
 
 static MACHINE_CONFIG_START( m79amb, m79amb_state )
@@ -217,8 +217,7 @@ static MACHINE_CONFIG_START( m79amb, m79amb_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 32*8-1)
-
-	MCFG_VIDEO_UPDATE(ramtek)
+	MCFG_SCREEN_UPDATE(ramtek)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -288,8 +287,8 @@ static const UINT8 lut_pos[0x20] = {
 
 static DRIVER_INIT( m79amb )
 {
-	m79amb_state *state = machine->driver_data<m79amb_state>();
-	UINT8 *rom = machine->region("maincpu")->base();
+	m79amb_state *state = machine.driver_data<m79amb_state>();
+	UINT8 *rom = machine.region("maincpu")->base();
 	int i, j;
 
 	/* PROM data is active low */
@@ -304,7 +303,7 @@ static DRIVER_INIT( m79amb )
 		{
 			if (i <= lut_cross[j])
 			{
-				state->lut_gun1[i] = lut_pos[j];
+				state->m_lut_gun1[i] = lut_pos[j];
 				break;
 			}
 		}
@@ -314,7 +313,7 @@ static DRIVER_INIT( m79amb )
 		{
 			if (i >= (253 - lut_cross[j]))
 			{
-				state->lut_gun2[i] = lut_pos[j];
+				state->m_lut_gun2[i] = lut_pos[j];
 				break;
 			}
 		}
