@@ -402,28 +402,41 @@
 #include "machine/nvram.h"
 
 
+class magicfly_state : public driver_device
+{
+public:
+	magicfly_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 *m_videoram;
+	UINT8 *m_colorram;
+	tilemap_t *m_bg_tilemap;
+	int m_input_selector;
+};
+
+
 /*************************
 *     Video Hardware     *
 *************************/
 
-static UINT8 *videoram;
-static UINT8 *colorram;
-static tilemap_t *bg_tilemap;
 
 static WRITE8_HANDLER( magicfly_videoram_w )
 {
-	videoram[offset] = data;
-	tilemap_mark_tile_dirty(bg_tilemap, offset);
+	magicfly_state *state = space->machine().driver_data<magicfly_state>();
+	state->m_videoram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
 }
 
 static WRITE8_HANDLER( magicfly_colorram_w )
 {
-	colorram[offset] = data;
-	tilemap_mark_tile_dirty(bg_tilemap, offset);
+	magicfly_state *state = space->machine().driver_data<magicfly_state>();
+	state->m_colorram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
 }
 
 static TILE_GET_INFO( get_magicfly_tile_info )
 {
+	magicfly_state *state = machine.driver_data<magicfly_state>();
 /*  - bits -
     7654 3210
     ---- -xxx   Tiles color.
@@ -433,27 +446,29 @@ static TILE_GET_INFO( get_magicfly_tile_info )
     x--- ----   Mirrored from bit 3. The code check this one to boot the game.
 
 */
-	int attr = colorram[tile_index];
-	int code = videoram[tile_index];
+	int attr = state->m_colorram[tile_index];
+	int code = state->m_videoram[tile_index];
 	int bank = (attr & 0x10) >> 4;   /* bit 4 switch the gfx banks */
 	int color = attr & 0x07;         /* bits 0-2 for color */
 
     /* Seems that bit 7 is mirrored from bit 3 to have a normal boot */
     /* Boot only check the first color RAM offset */
 
-	colorram[0] = colorram[0] | ((colorram[0] & 0x08) << 4);	/* only for 1st offset */
-	//colorram[tile_index] = attr | ((attr & 0x08) << 4);         /* for the whole color RAM */
+	state->m_colorram[0] = state->m_colorram[0] | ((state->m_colorram[0] & 0x08) << 4);	/* only for 1st offset */
+	//state->m_colorram[tile_index] = attr | ((attr & 0x08) << 4);         /* for the whole color RAM */
 
 	SET_TILE_INFO(bank, code, color, 0);
 }
 
 static VIDEO_START(magicfly)
 {
-	bg_tilemap = tilemap_create(machine, get_magicfly_tile_info, tilemap_scan_rows, 8, 8, 32, 29);
+	magicfly_state *state = machine.driver_data<magicfly_state>();
+	state->m_bg_tilemap = tilemap_create(machine, get_magicfly_tile_info, tilemap_scan_rows, 8, 8, 32, 29);
 }
 
 static TILE_GET_INFO( get_7mezzo_tile_info )
 {
+	magicfly_state *state = machine.driver_data<magicfly_state>();
 /*  - bits -
     7654 3210
     ---- -xxx   Tiles color.
@@ -463,28 +478,30 @@ static TILE_GET_INFO( get_7mezzo_tile_info )
     x--- ----   Mirrored from bit 2. The code check this one to boot the game.
 
 */
-	int attr = colorram[tile_index];
-	int code = videoram[tile_index];
+	int attr = state->m_colorram[tile_index];
+	int code = state->m_videoram[tile_index];
 	int bank = (attr & 0x10) >> 4;    /* bit 4 switch the gfx banks */
 	int color = attr & 0x07;          /* bits 0-2 for color */
 
     /* Seems that bit 7 is mirrored from bit 2 to have a normal boot */
     /* Boot only check the first color RAM offset */
 
-	colorram[0] = colorram[0] | ((colorram[0] & 0x04) << 5);	/* only for 1st offset */
-	//colorram[tile_index] = attr | ((attr & 0x04) << 5);         /* for the whole color RAM */
+	state->m_colorram[0] = state->m_colorram[0] | ((state->m_colorram[0] & 0x04) << 5);	/* only for 1st offset */
+	//state->m_colorram[tile_index] = attr | ((attr & 0x04) << 5);         /* for the whole color RAM */
 
 	SET_TILE_INFO(bank, code, color, 0);
 }
 
 static VIDEO_START( 7mezzo )
 {
-	bg_tilemap = tilemap_create(machine, get_7mezzo_tile_info, tilemap_scan_rows, 8, 8, 32, 29);
+	magicfly_state *state = machine.driver_data<magicfly_state>();
+	state->m_bg_tilemap = tilemap_create(machine, get_7mezzo_tile_info, tilemap_scan_rows, 8, 8, 32, 29);
 }
 
-static VIDEO_UPDATE( magicfly )
+static SCREEN_UPDATE( magicfly )
 {
-	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
+	magicfly_state *state = screen->machine().driver_data<magicfly_state>();
+	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
 	return 0;
 }
 
@@ -515,23 +532,24 @@ static PALETTE_INIT( magicfly )
 *         R/W Handlers        *
 ******************************/
 
-static int input_selector = 0;
 
 static READ8_HANDLER( mux_port_r )
 {
-	switch( input_selector )
+	magicfly_state *state = space->machine().driver_data<magicfly_state>();
+	switch( state->m_input_selector )
 	{
-		case 0x01: return input_port_read(space->machine, "IN0-0");
-		case 0x02: return input_port_read(space->machine, "IN0-1");
-		case 0x04: return input_port_read(space->machine, "IN0-2");
-		case 0x08: return input_port_read(space->machine, "IN0-3");
-		case 0x00: return input_port_read(space->machine, "DSW0");
+		case 0x01: return input_port_read(space->machine(), "IN0-0");
+		case 0x02: return input_port_read(space->machine(), "IN0-1");
+		case 0x04: return input_port_read(space->machine(), "IN0-2");
+		case 0x08: return input_port_read(space->machine(), "IN0-3");
+		case 0x00: return input_port_read(space->machine(), "DSW0");
 	}
 	return 0xff;
 }
 
 static WRITE8_HANDLER( mux_port_w )
 {
+	magicfly_state *state = space->machine().driver_data<magicfly_state>();
 /*  - bits -
     7654 3210
     ---- xxxx   Input selector.
@@ -541,13 +559,13 @@ static WRITE8_HANDLER( mux_port_w )
     x--- ----   Sound DAC.
 
 */
-	input_selector = data & 0x0f;	/* Input Selector */
+	state->m_input_selector = data & 0x0f;	/* Input Selector */
 
-	dac_data_w(space->machine->device("dac"), data & 0x80);		/* Sound DAC */
+	dac_data_w(space->machine().device("dac"), data & 0x80);		/* Sound DAC */
 
-	coin_counter_w(space->machine, 0, data & 0x40);	/* Coin1 */
-	coin_counter_w(space->machine, 1, data & 0x10);	/* Coin2 */
-	coin_counter_w(space->machine, 2, data & 0x20);	/* Payout */
+	coin_counter_w(space->machine(), 0, data & 0x40);	/* Coin1 */
+	coin_counter_w(space->machine(), 1, data & 0x10);	/* Coin2 */
+	coin_counter_w(space->machine(), 2, data & 0x20);	/* Payout */
 }
 
 
@@ -555,12 +573,12 @@ static WRITE8_HANDLER( mux_port_w )
 * Memory map information *
 *************************/
 
-static ADDRESS_MAP_START( magicfly_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( magicfly_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_SHARE("nvram")    /* MK48Z02B NVRAM */
-	AM_RANGE(0x0800, 0x0800) AM_DEVWRITE("crtc", mc6845_address_w)
-	AM_RANGE(0x0801, 0x0801) AM_DEVREADWRITE("crtc", mc6845_register_r, mc6845_register_w)
-	AM_RANGE(0x1000, 0x13ff) AM_RAM_WRITE(magicfly_videoram_w) AM_BASE(&videoram)	/* HM6116LP #1 (2K x 8) RAM (only 1st half used) */
-	AM_RANGE(0x1800, 0x1bff) AM_RAM_WRITE(magicfly_colorram_w) AM_BASE(&colorram)	/* HM6116LP #2 (2K x 8) RAM (only 1st half used) */
+	AM_RANGE(0x0800, 0x0800) AM_DEVWRITE_MODERN("crtc", mc6845_device, address_w)
+	AM_RANGE(0x0801, 0x0801) AM_DEVREADWRITE_MODERN("crtc", mc6845_device, register_r, register_w)
+	AM_RANGE(0x1000, 0x13ff) AM_RAM_WRITE(magicfly_videoram_w) AM_BASE_MEMBER(magicfly_state, m_videoram)	/* HM6116LP #1 (2K x 8) RAM (only 1st half used) */
+	AM_RANGE(0x1800, 0x1bff) AM_RAM_WRITE(magicfly_colorram_w) AM_BASE_MEMBER(magicfly_state, m_colorram)	/* HM6116LP #2 (2K x 8) RAM (only 1st half used) */
 	AM_RANGE(0x2800, 0x2800) AM_READ(mux_port_r)	/* multiplexed input port */
 	AM_RANGE(0x3000, 0x3000) AM_WRITE(mux_port_w)	/* output port */
 	AM_RANGE(0xc000, 0xffff) AM_ROM					/* ROM space */
@@ -756,7 +774,7 @@ static const mc6845_interface mc6845_intf =
 *    Machine Drivers     *
 *************************/
 
-static MACHINE_CONFIG_START( magicfly, driver_device )
+static MACHINE_CONFIG_START( magicfly, magicfly_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M6502, MASTER_CLOCK/12)	/* guess */
@@ -772,13 +790,13 @@ static MACHINE_CONFIG_START( magicfly, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE((39+1)*8, (31+1)*8)				/* Taken from MC6845 init, registers 00 & 04. Normally programmed with (value-1). */
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 29*8-1)	/* Taken from MC6845 init, registers 01 & 06. */
+	MCFG_SCREEN_UPDATE(magicfly)
 
 	MCFG_GFXDECODE(magicfly)
 	MCFG_PALETTE_LENGTH(256)
 	MCFG_PALETTE_INIT(magicfly)
 
 	MCFG_VIDEO_START(magicfly)
-	MCFG_VIDEO_UPDATE(magicfly)
 
 	MCFG_MC6845_ADD("crtc", MC6845, MASTER_CLOCK/16, mc6845_intf) /* guess */
 
