@@ -89,63 +89,63 @@ struct _speedup_entry
 class mediagx_state : public driver_device
 {
 public:
-	mediagx_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	mediagx_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	UINT32 *cga_ram;
-	UINT32 *bios_ram;
-	UINT32 *vram;
-	UINT8 pal[768];
+	UINT32 *m_cga_ram;
+	UINT32 *m_bios_ram;
+	UINT32 *m_vram;
+	UINT8 m_pal[768];
 
-	UINT32 *main_ram;
+	UINT32 *m_main_ram;
 
-	UINT32 disp_ctrl_reg[256/4];
-	int frame_width;
-	int frame_height;
+	UINT32 m_disp_ctrl_reg[256/4];
+	int m_frame_width;
+	int m_frame_height;
 
-	UINT32 memory_ctrl_reg[256/4];
-	int pal_index;
+	UINT32 m_memory_ctrl_reg[256/4];
+	int m_pal_index;
 
-	UINT32 biu_ctrl_reg[256/4];
+	UINT32 m_biu_ctrl_reg[256/4];
 
-	UINT8 mediagx_config_reg_sel;
-	UINT8 mediagx_config_regs[256];
+	UINT8 m_mediagx_config_reg_sel;
+	UINT8 m_mediagx_config_regs[256];
 
-	//UINT8 controls_data;
-	UINT8 parallel_pointer;
-	UINT8 parallel_latched;
-	UINT32 parport;
-	//int control_num;
-	//int control_num2;
-	//int control_read;
+	//UINT8 m_controls_data;
+	UINT8 m_parallel_pointer;
+	UINT8 m_parallel_latched;
+	UINT32 m_parport;
+	//int m_control_num;
+	//int m_control_num2;
+	//int m_control_read;
 
-	UINT32 cx5510_regs[256/4];
+	UINT32 m_cx5510_regs[256/4];
 
-	INT16 *dacl;
-	INT16 *dacr;
-	int dacl_ptr;
-	int dacr_ptr;
+	INT16 *m_dacl;
+	INT16 *m_dacr;
+	int m_dacl_ptr;
+	int m_dacr_ptr;
 
-	UINT8 ad1847_regs[16];
-	UINT32 ad1847_sample_counter;
-	UINT32 ad1847_sample_rate;
+	UINT8 m_ad1847_regs[16];
+	UINT32 m_ad1847_sample_counter;
+	UINT32 m_ad1847_sample_rate;
 
-	dmadac_sound_device *dmadac[2];
+	dmadac_sound_device *m_dmadac[2];
 
-	pit8254_device	*pit8254;
-	pic8259_device	*pic8259_1;
-	pic8259_device	*pic8259_2;
-	i8237_device	*dma8237_1;
-	i8237_device	*dma8237_2;
+	pit8254_device	*m_pit8254;
+	pic8259_device	*m_pic8259_1;
+	pic8259_device	*m_pic8259_2;
+	i8237_device	*m_dma8237_1;
+	i8237_device	*m_dma8237_2;
 
-	int dma_channel;
-	UINT8 dma_offset[2][4];
-	UINT8 at_pages[0x10];
+	int m_dma_channel;
+	UINT8 m_dma_offset[2][4];
+	UINT8 m_at_pages[0x10];
 
 #if SPEEDUP_HACKS
-	const speedup_entry *speedup_table;
-	UINT32 speedup_hits[12];
-	int speedup_count;
+	const speedup_entry *m_speedup_table;
+	UINT32 m_speedup_hits[12];
+	int m_speedup_count;
 #endif
 };
 
@@ -205,7 +205,7 @@ static void draw_char(bitmap_t *bitmap, const rectangle *cliprect, const gfx_ele
 	int i,j;
 	const UINT8 *dp;
 	int index = 0;
-	const pen_t *pens = gfx->machine->pens;
+	const pen_t *pens = gfx->machine().pens;
 
 	dp = gfx_element_get_data(gfx, ch);
 
@@ -226,46 +226,46 @@ static void draw_char(bitmap_t *bitmap, const rectangle *cliprect, const gfx_ele
 	}
 }
 
-static void draw_framebuffer(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void draw_framebuffer(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
-	mediagx_state *state = machine->driver_data<mediagx_state>();
+	mediagx_state *state = machine.driver_data<mediagx_state>();
 	int i, j;
 	int width, height;
-	int line_delta = (state->disp_ctrl_reg[DC_LINE_DELTA] & 0x3ff) * 4;
+	int line_delta = (state->m_disp_ctrl_reg[DC_LINE_DELTA] & 0x3ff) * 4;
 
-	width = (state->disp_ctrl_reg[DC_H_TIMING_1] & 0x7ff) + 1;
-	if (state->disp_ctrl_reg[DC_TIMING_CFG] & 0x8000)		// pixel double
+	width = (state->m_disp_ctrl_reg[DC_H_TIMING_1] & 0x7ff) + 1;
+	if (state->m_disp_ctrl_reg[DC_TIMING_CFG] & 0x8000)		// pixel double
 	{
 		width >>= 1;
 	}
 	width += 4;
 
-	height = (state->disp_ctrl_reg[DC_V_TIMING_1] & 0x7ff) + 1;
+	height = (state->m_disp_ctrl_reg[DC_V_TIMING_1] & 0x7ff) + 1;
 
-	if ( (width != state->frame_width || height != state->frame_height) &&
+	if ( (width != state->m_frame_width || height != state->m_frame_height) &&
 		 (width > 1 && height > 1 && width <= 640 && height <= 480) )
 	{
 		rectangle visarea;
 
-		state->frame_width = width;
-		state->frame_height = height;
+		state->m_frame_width = width;
+		state->m_frame_height = height;
 
 		visarea.min_x = visarea.min_y = 0;
 		visarea.max_x = width - 1;
 		visarea.max_y = height - 1;
-		machine->primary_screen->configure(width, height * 262 / 240, visarea, machine->primary_screen->frame_period().attoseconds);
+		machine.primary_screen->configure(width, height * 262 / 240, visarea, machine.primary_screen->frame_period().attoseconds);
 	}
 
-	if (state->disp_ctrl_reg[DC_OUTPUT_CFG] & 0x1)		// 8-bit mode
+	if (state->m_disp_ctrl_reg[DC_OUTPUT_CFG] & 0x1)		// 8-bit mode
 	{
-		UINT8 *framebuf = (UINT8*)&state->vram[state->disp_ctrl_reg[DC_FB_ST_OFFSET]/4];
-		UINT8 *pal = state->pal;
+		UINT8 *framebuf = (UINT8*)&state->m_vram[state->m_disp_ctrl_reg[DC_FB_ST_OFFSET]/4];
+		UINT8 *pal = state->m_pal;
 
-		for (j=0; j < state->frame_height; j++)
+		for (j=0; j < state->m_frame_height; j++)
 		{
 			UINT32 *p = BITMAP_ADDR32(bitmap, j, 0);
 			UINT8 *si = &framebuf[j * line_delta];
-			for (i=0; i < state->frame_width; i++)
+			for (i=0; i < state->m_frame_width; i++)
 			{
 				int c = *si++;
 				int r = pal[(c*3)+0] << 2;
@@ -278,16 +278,16 @@ static void draw_framebuffer(running_machine *machine, bitmap_t *bitmap, const r
 	}
 	else			// 16-bit
 	{
-		UINT16 *framebuf = (UINT16*)&state->vram[state->disp_ctrl_reg[DC_FB_ST_OFFSET]/4];
+		UINT16 *framebuf = (UINT16*)&state->m_vram[state->m_disp_ctrl_reg[DC_FB_ST_OFFSET]/4];
 
 		// RGB 5-6-5 mode
-		if ((state->disp_ctrl_reg[DC_OUTPUT_CFG] & 0x2) == 0)
+		if ((state->m_disp_ctrl_reg[DC_OUTPUT_CFG] & 0x2) == 0)
 		{
-			for (j=0; j < state->frame_height; j++)
+			for (j=0; j < state->m_frame_height; j++)
 			{
 				UINT32 *p = BITMAP_ADDR32(bitmap, j, 0);
 				UINT16 *si = &framebuf[j * (line_delta/2)];
-				for (i=0; i < state->frame_width; i++)
+				for (i=0; i < state->m_frame_width; i++)
 				{
 					UINT16 c = *si++;
 					int r = ((c >> 11) & 0x1f) << 3;
@@ -301,11 +301,11 @@ static void draw_framebuffer(running_machine *machine, bitmap_t *bitmap, const r
 		// RGB 5-5-5 mode
 		else
 		{
-			for (j=0; j < state->frame_height; j++)
+			for (j=0; j < state->m_frame_height; j++)
 			{
 				UINT32 *p = BITMAP_ADDR32(bitmap, j, 0);
 				UINT16 *si = &framebuf[j * (line_delta/2)];
-				for (i=0; i < state->frame_width; i++)
+				for (i=0; i < state->m_frame_width; i++)
 				{
 					UINT16 c = *si++;
 					int r = ((c >> 10) & 0x1f) << 3;
@@ -319,12 +319,12 @@ static void draw_framebuffer(running_machine *machine, bitmap_t *bitmap, const r
 	}
 }
 
-static void draw_cga(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
+static void draw_cga(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
-	mediagx_state *state = machine->driver_data<mediagx_state>();
+	mediagx_state *state = machine.driver_data<mediagx_state>();
 	int i, j;
-	const gfx_element *gfx = machine->gfx[0];
-	UINT32 *cga = state->cga_ram;
+	const gfx_element *gfx = machine.gfx[0];
+	UINT32 *cga = state->m_cga_ram;
 	int index = 0;
 
 	for (j=0; j < 25; j++)
@@ -343,36 +343,36 @@ static void draw_cga(running_machine *machine, bitmap_t *bitmap, const rectangle
 	}
 }
 
-static VIDEO_UPDATE(mediagx)
+static SCREEN_UPDATE(mediagx)
 {
-	mediagx_state *state = screen->machine->driver_data<mediagx_state>();
+	mediagx_state *state = screen->machine().driver_data<mediagx_state>();
 	bitmap_fill(bitmap, cliprect, 0);
 
-	draw_framebuffer(screen->machine, bitmap, cliprect);
+	draw_framebuffer(screen->machine(), bitmap, cliprect);
 
-	if (state->disp_ctrl_reg[DC_OUTPUT_CFG] & 0x1)	// don't show MDA text screen on 16-bit mode. this is basically a hack
+	if (state->m_disp_ctrl_reg[DC_OUTPUT_CFG] & 0x1)	// don't show MDA text screen on 16-bit mode. this is basically a hack
 	{
-		draw_cga(screen->machine, bitmap, cliprect);
+		draw_cga(screen->machine(), bitmap, cliprect);
 	}
 	return 0;
 }
 
 static READ32_HANDLER( disp_ctrl_r )
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
-	UINT32 r = state->disp_ctrl_reg[offset];
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
+	UINT32 r = state->m_disp_ctrl_reg[offset];
 
 	switch (offset)
 	{
 		case DC_TIMING_CFG:
 			r |= 0x40000000;
 
-			if (space->machine->primary_screen->vpos() >= state->frame_height)
+			if (space->machine().primary_screen->vpos() >= state->m_frame_height)
 				r &= ~0x40000000;
 
 #if SPEEDUP_HACKS
 			// wait for vblank speedup
-			cpu_spinuntil_int(space->cpu);
+			device_spin_until_interrupt(&space->device());
 #endif
 			break;
 	}
@@ -382,9 +382,9 @@ static READ32_HANDLER( disp_ctrl_r )
 
 static WRITE32_HANDLER( disp_ctrl_w )
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
 
-	COMBINE_DATA(state->disp_ctrl_reg + offset);
+	COMBINE_DATA(state->m_disp_ctrl_reg + offset);
 }
 
 
@@ -423,32 +423,32 @@ static WRITE32_DEVICE_HANDLER( fdc_w )
 
 static READ32_HANDLER( memory_ctrl_r )
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
 
-	return state->memory_ctrl_reg[offset];
+	return state->m_memory_ctrl_reg[offset];
 }
 
 static WRITE32_HANDLER( memory_ctrl_w )
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
 
 	//mame_printf_debug("memory_ctrl_w %08X, %08X, %08X\n", data, offset, mem_mask);
 	if (offset == 7)
 	{
-		state->pal_index = 0;
+		state->m_pal_index = 0;
 	}
 	else if (offset == 8)
 	{
-		state->pal[state->pal_index] = data & 0xff;
-		state->pal_index++;
-		if (state->pal_index >= 768)
+		state->m_pal[state->m_pal_index] = data & 0xff;
+		state->m_pal_index++;
+		if (state->m_pal_index >= 768)
 		{
-			state->pal_index = 0;
+			state->m_pal_index = 0;
 		}
 	}
 	else
 	{
-		COMBINE_DATA(state->memory_ctrl_reg + offset);
+		COMBINE_DATA(state->m_memory_ctrl_reg + offset);
 	}
 }
 
@@ -456,21 +456,21 @@ static WRITE32_HANDLER( memory_ctrl_w )
 
 static READ32_HANDLER( biu_ctrl_r )
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
 
 	if (offset == 0)
 	{
 		return 0xffffff;
 	}
-	return state->biu_ctrl_reg[offset];
+	return state->m_biu_ctrl_reg[offset];
 }
 
 static WRITE32_HANDLER( biu_ctrl_w )
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
 
 	//mame_printf_debug("biu_ctrl_w %08X, %08X, %08X\n", data, offset, mem_mask);
-	COMBINE_DATA(state->biu_ctrl_reg + offset);
+	COMBINE_DATA(state->m_biu_ctrl_reg + offset);
 
 	if (offset == 3)		// BC_XMAP_3 register
 	{
@@ -487,18 +487,18 @@ static WRITE32_HANDLER(bios_ram_w)
 
 static UINT8 mediagx_config_reg_r(device_t *device)
 {
-	mediagx_state *state = device->machine->driver_data<mediagx_state>();
+	mediagx_state *state = device->machine().driver_data<mediagx_state>();
 
 	//mame_printf_debug("mediagx_config_reg_r %02X\n", mediagx_config_reg_sel);
-	return state->mediagx_config_regs[state->mediagx_config_reg_sel];
+	return state->m_mediagx_config_regs[state->m_mediagx_config_reg_sel];
 }
 
 static void mediagx_config_reg_w(device_t *device, UINT8 data)
 {
-	mediagx_state *state = device->machine->driver_data<mediagx_state>();
+	mediagx_state *state = device->machine().driver_data<mediagx_state>();
 
 	//mame_printf_debug("mediagx_config_reg_w %02X, %02X\n", mediagx_config_reg_sel, data);
-	state->mediagx_config_regs[state->mediagx_config_reg_sel] = data;
+	state->m_mediagx_config_regs[state->m_mediagx_config_reg_sel] = data;
 }
 
 static READ8_DEVICE_HANDLER( io20_r )
@@ -522,12 +522,12 @@ static READ8_DEVICE_HANDLER( io20_r )
 
 static WRITE8_DEVICE_HANDLER( io20_w )
 {
-	mediagx_state *state = device->machine->driver_data<mediagx_state>();
+	mediagx_state *state = device->machine().driver_data<mediagx_state>();
 
 	// 0x22, 0x23, Cyrix configuration registers
 	if (offset == 0x02)
 	{
-		state->mediagx_config_reg_sel = data;
+		state->m_mediagx_config_reg_sel = data;
 	}
 	else if (offset == 0x03)
 	{
@@ -541,35 +541,35 @@ static WRITE8_DEVICE_HANDLER( io20_w )
 
 static READ32_HANDLER( parallel_port_r )
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
 	UINT32 r = 0;
 	//static const char *const portnames[] = { "IN0", "IN1", "IN2", "IN3", "IN4", "IN5", "IN6", "IN7", "IN8" }; // but parallel_pointer takes values 0 -> 23
 
 	if (ACCESSING_BITS_8_15)
 	{
-		UINT8 nibble = state->parallel_latched;//(input_port_read_safe(space->machine, state->portnames[state->parallel_pointer / 3], 0) >> (4 * (state->parallel_pointer % 3))) & 15;
+		UINT8 nibble = state->m_parallel_latched;//(input_port_read_safe(space->machine(), state->m_portnames[state->m_parallel_pointer / 3], 0) >> (4 * (state->m_parallel_pointer % 3))) & 15;
 		r |= ((~nibble & 0x08) << 12) | ((nibble & 0x07) << 11);
-		logerror("%08X:parallel_port_r()\n", cpu_get_pc(space->cpu));
+		logerror("%08X:parallel_port_r()\n", cpu_get_pc(&space->device()));
 #if 0
-		if (state->controls_data == 0x18)
+		if (state->m_controls_data == 0x18)
 		{
-			r |= input_port_read(space->machine, "IN0") << 8;
+			r |= input_port_read(space->machine(), "IN0") << 8;
 		}
-		else if (state->controls_data == 0x60)
+		else if (state->m_controls_data == 0x60)
 		{
-			r |= input_port_read(space->machine, "IN1") << 8;
+			r |= input_port_read(space->machine(), "IN1") << 8;
 		}
-		else if (state->controls_data == 0xff || state->controls_data == 0x50)
+		else if (state->m_controls_data == 0xff || state->m_controls_data == 0x50)
 		{
-			r |= input_port_read(space->machine, "IN2") << 8;
+			r |= input_port_read(space->machine(), "IN2") << 8;
 		}
 
-		//r |= state->control_read << 8;
+		//r |= state->m_control_read << 8;
 #endif
 	}
 	if (ACCESSING_BITS_16_23)
 	{
-		r |= state->parport & 0xff0000;
+		r |= state->m_parport & 0xff0000;
 	}
 
 	return r;
@@ -577,10 +577,10 @@ static READ32_HANDLER( parallel_port_r )
 
 static WRITE32_HANDLER( parallel_port_w )
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
 	static const char *const portnames[] = { "IN0", "IN1", "IN2", "IN3", "IN4", "IN5", "IN6", "IN7", "IN8" };	// but parallel_pointer takes values 0 -> 23
 
-	COMBINE_DATA( &state->parport );
+	COMBINE_DATA( &state->m_parport );
 
 	if (ACCESSING_BITS_0_7)
 	{
@@ -599,16 +599,16 @@ static WRITE32_HANDLER( parallel_port_w )
                 7x..ff = advance pointer
         */
 
-		logerror("%08X:", cpu_get_pc(space->cpu));
+		logerror("%08X:", cpu_get_pc(&space->device()));
 
-		state->parallel_latched = (input_port_read_safe(space->machine, portnames[state->parallel_pointer / 3], 0) >> (4 * (state->parallel_pointer % 3))) & 15;
+		state->m_parallel_latched = (input_port_read_safe(space->machine(), portnames[state->m_parallel_pointer / 3], 0) >> (4 * (state->m_parallel_pointer % 3))) & 15;
 		//parallel_pointer++;
 		//logerror("[%02X] Advance pointer to %d\n", data, parallel_pointer);
 		switch (data & 0xfc)
 		{
 			case 0x18:
-				state->parallel_pointer = data & 3;
-				logerror("[%02X] Reset pointer to %d\n", data, state->parallel_pointer);
+				state->m_parallel_pointer = data & 3;
+				logerror("[%02X] Reset pointer to %d\n", data, state->m_parallel_pointer);
 				break;
 
 			case 0x20:
@@ -649,8 +649,8 @@ static WRITE32_HANDLER( parallel_port_w )
 			default:
 				if (data >= 0x70)
 				{
-					state->parallel_pointer++;
-					logerror("[%02X] Advance pointer to %d\n", data, state->parallel_pointer);
+					state->m_parallel_pointer++;
+					logerror("[%02X] Advance pointer to %d\n", data, state->m_parallel_pointer);
 				}
 				else
 					logerror("[%02X] Unknown write\n", data);
@@ -661,7 +661,7 @@ static WRITE32_HANDLER( parallel_port_w )
 
 static UINT32 cx5510_pci_r(device_t *busdevice, device_t *device, int function, int reg, UINT32 mem_mask)
 {
-	mediagx_state *state = busdevice->machine->driver_data<mediagx_state>();
+	mediagx_state *state = busdevice->machine().driver_data<mediagx_state>();
 
 	//mame_printf_debug("CX5510: PCI read %d, %02X, %08X\n", function, reg, mem_mask);
 	switch (reg)
@@ -669,36 +669,36 @@ static UINT32 cx5510_pci_r(device_t *busdevice, device_t *device, int function,
 		case 0:		return 0x00001078;
 	}
 
-	return state->cx5510_regs[reg/4];
+	return state->m_cx5510_regs[reg/4];
 }
 
 static void cx5510_pci_w(device_t *busdevice, device_t *device, int function, int reg, UINT32 data, UINT32 mem_mask)
 {
-	mediagx_state *state = busdevice->machine->driver_data<mediagx_state>();
+	mediagx_state *state = busdevice->machine().driver_data<mediagx_state>();
 
 	//mame_printf_debug("CX5510: PCI write %d, %02X, %08X, %08X\n", function, reg, data, mem_mask);
-	COMBINE_DATA(state->cx5510_regs + (reg/4));
+	COMBINE_DATA(state->m_cx5510_regs + (reg/4));
 }
 
 /* Analog Devices AD1847 Stereo DAC */
 
 static TIMER_DEVICE_CALLBACK( sound_timer_callback )
 {
-	mediagx_state *state = timer.machine->driver_data<mediagx_state>();
+	mediagx_state *state = timer.machine().driver_data<mediagx_state>();
 
-	state->ad1847_sample_counter = 0;
-	timer.adjust(ATTOTIME_IN_MSEC(10));
+	state->m_ad1847_sample_counter = 0;
+	timer.adjust(attotime::from_msec(10));
 
-	dmadac_transfer(&state->dmadac[0], 1, 0, 1, state->dacl_ptr, state->dacl);
-	dmadac_transfer(&state->dmadac[1], 1, 0, 1, state->dacr_ptr, state->dacr);
+	dmadac_transfer(&state->m_dmadac[0], 1, 0, 1, state->m_dacl_ptr, state->m_dacl);
+	dmadac_transfer(&state->m_dmadac[1], 1, 0, 1, state->m_dacr_ptr, state->m_dacr);
 
-	state->dacl_ptr = 0;
-	state->dacr_ptr = 0;
+	state->m_dacl_ptr = 0;
+	state->m_dacr_ptr = 0;
 }
 
-static void ad1847_reg_write(running_machine *machine, int reg, UINT8 data)
+static void ad1847_reg_write(running_machine &machine, int reg, UINT8 data)
 {
-	mediagx_state *state = machine->driver_data<mediagx_state>();
+	mediagx_state *state = machine.driver_data<mediagx_state>();
 	static const int divide_factor[] = { 3072, 1536, 896, 768, 448, 384, 512, 2560 };
 
 	switch (reg)
@@ -707,14 +707,14 @@ static void ad1847_reg_write(running_machine *machine, int reg, UINT8 data)
 		{
 			if (data & 0x1)
 			{
-				state->ad1847_sample_rate = 16934400 / divide_factor[(data >> 1) & 0x7];
+				state->m_ad1847_sample_rate = 16934400 / divide_factor[(data >> 1) & 0x7];
 			}
 			else
 			{
-				state->ad1847_sample_rate = 24576000 / divide_factor[(data >> 1) & 0x7];
+				state->m_ad1847_sample_rate = 24576000 / divide_factor[(data >> 1) & 0x7];
 			}
 
-			dmadac_set_frequency(&state->dmadac[0], 2, state->ad1847_sample_rate);
+			dmadac_set_frequency(&state->m_dmadac[0], 2, state->m_ad1847_sample_rate);
 
 			if (data & 0x20)
 			{
@@ -729,7 +729,7 @@ static void ad1847_reg_write(running_machine *machine, int reg, UINT8 data)
 
 		default:
 		{
-			state->ad1847_regs[reg] = data;
+			state->m_ad1847_regs[reg] = data;
 			break;
 		}
 	}
@@ -737,39 +737,39 @@ static void ad1847_reg_write(running_machine *machine, int reg, UINT8 data)
 
 static READ32_HANDLER( ad1847_r )
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
 
 	switch (offset)
 	{
 		case 0x14/4:
-			return ((state->ad1847_sample_rate) / 100) - state->ad1847_sample_counter;
+			return ((state->m_ad1847_sample_rate) / 100) - state->m_ad1847_sample_counter;
 	}
 	return 0;
 }
 
 static WRITE32_HANDLER( ad1847_w )
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
 
 	if (offset == 0)
 	{
 		if (ACCESSING_BITS_16_31)
 		{
 			UINT16 ldata = (data >> 16) & 0xffff;
-			state->dacl[state->dacl_ptr++] = ldata;
+			state->m_dacl[state->m_dacl_ptr++] = ldata;
 		}
 		if (ACCESSING_BITS_0_15)
 		{
 			UINT16 rdata = data & 0xffff;
-			state->dacr[state->dacr_ptr++] = rdata;
+			state->m_dacr[state->m_dacr_ptr++] = rdata;
 		}
 
-		state->ad1847_sample_counter++;
+		state->m_ad1847_sample_counter++;
 	}
 	else if (offset == 3)
 	{
 		int reg = (data >> 8) & 0xf;
-		ad1847_reg_write(space->machine, reg, data & 0xff);
+		ad1847_reg_write(space->machine(), reg, data & 0xff);
 	}
 }
 
@@ -783,22 +783,22 @@ static WRITE32_HANDLER( ad1847_w )
 
 static READ8_HANDLER(at_page8_r)
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
-	UINT8 data = state->at_pages[offset % 0x10];
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
+	UINT8 data = state->m_at_pages[offset % 0x10];
 
 	switch(offset % 8)
 	{
 	case 1:
-		data = state->dma_offset[(offset / 8) & 1][2];
+		data = state->m_dma_offset[(offset / 8) & 1][2];
 		break;
 	case 2:
-		data = state->dma_offset[(offset / 8) & 1][3];
+		data = state->m_dma_offset[(offset / 8) & 1][3];
 		break;
 	case 3:
-		data = state->dma_offset[(offset / 8) & 1][1];
+		data = state->m_dma_offset[(offset / 8) & 1][1];
 		break;
 	case 7:
-		data = state->dma_offset[(offset / 8) & 1][0];
+		data = state->m_dma_offset[(offset / 8) & 1][0];
 		break;
 	}
 	return data;
@@ -807,23 +807,23 @@ static READ8_HANDLER(at_page8_r)
 
 static WRITE8_HANDLER(at_page8_w)
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
 
-	state->at_pages[offset % 0x10] = data;
+	state->m_at_pages[offset % 0x10] = data;
 
 	switch(offset % 8)
 	{
 	case 1:
-		state->dma_offset[(offset / 8) & 1][2] = data;
+		state->m_dma_offset[(offset / 8) & 1][2] = data;
 		break;
 	case 2:
-		state->dma_offset[(offset / 8) & 1][3] = data;
+		state->m_dma_offset[(offset / 8) & 1][3] = data;
 		break;
 	case 3:
-		state->dma_offset[(offset / 8) & 1][1] = data;
+		state->m_dma_offset[(offset / 8) & 1][1] = data;
 		break;
 	case 7:
-		state->dma_offset[(offset / 8) & 1][0] = data;
+		state->m_dma_offset[(offset / 8) & 1][0] = data;
 		break;
 	}
 }
@@ -831,7 +831,7 @@ static WRITE8_HANDLER(at_page8_w)
 
 static WRITE_LINE_DEVICE_HANDLER( pc_dma_hrq_changed )
 {
-	cputag_set_input_line(device->machine, "maincpu", INPUT_LINE_HALT, state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine(), "maincpu", INPUT_LINE_HALT, state ? ASSERT_LINE : CLEAR_LINE);
 
 	/* Assert HLDA */
 	i8237_hlda_w( device, state );
@@ -840,8 +840,8 @@ static WRITE_LINE_DEVICE_HANDLER( pc_dma_hrq_changed )
 
 static READ8_HANDLER( pc_dma_read_byte )
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
-	offs_t page_offset = (((offs_t) state->dma_offset[0][state->dma_channel]) << 16)
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
+	offs_t page_offset = (((offs_t) state->m_dma_offset[0][state->m_dma_channel]) << 16)
 		& 0xFF0000;
 
 	return space->read_byte(page_offset + offset);
@@ -850,8 +850,8 @@ static READ8_HANDLER( pc_dma_read_byte )
 
 static WRITE8_HANDLER( pc_dma_write_byte )
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
-	offs_t page_offset = (((offs_t) state->dma_offset[0][state->dma_channel]) << 16)
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
+	offs_t page_offset = (((offs_t) state->m_dma_offset[0][state->m_dma_channel]) << 16)
 		& 0xFF0000;
 
 	space->write_byte(page_offset + offset, data);
@@ -859,9 +859,9 @@ static WRITE8_HANDLER( pc_dma_write_byte )
 
 static void set_dma_channel(device_t *device, int channel, int _state)
 {
-	mediagx_state *state = device->machine->driver_data<mediagx_state>();
+	mediagx_state *state = device->machine().driver_data<mediagx_state>();
 
-	if (!_state) state->dma_channel = channel;
+	if (!_state) state->m_dma_channel = channel;
 }
 
 static WRITE_LINE_DEVICE_HANDLER( pc_dack0_w ) { set_dma_channel(device, 0, state); }
@@ -894,20 +894,20 @@ static I8237_INTERFACE( dma8237_2_config )
 
 /*****************************************************************************/
 
-static ADDRESS_MAP_START( mediagx_map, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x00000000, 0x0009ffff) AM_RAM AM_BASE_MEMBER(mediagx_state, main_ram)
+static ADDRESS_MAP_START( mediagx_map, AS_PROGRAM, 32 )
+	AM_RANGE(0x00000000, 0x0009ffff) AM_RAM AM_BASE_MEMBER(mediagx_state, m_main_ram)
 	AM_RANGE(0x000a0000, 0x000affff) AM_RAM
-	AM_RANGE(0x000b0000, 0x000b7fff) AM_RAM AM_BASE_MEMBER(mediagx_state, cga_ram)
-	AM_RANGE(0x000c0000, 0x000fffff) AM_RAM AM_BASE_MEMBER(mediagx_state, bios_ram)
+	AM_RANGE(0x000b0000, 0x000b7fff) AM_RAM AM_BASE_MEMBER(mediagx_state, m_cga_ram)
+	AM_RANGE(0x000c0000, 0x000fffff) AM_RAM AM_BASE_MEMBER(mediagx_state, m_bios_ram)
 	AM_RANGE(0x00100000, 0x00ffffff) AM_RAM
 	AM_RANGE(0x40008000, 0x400080ff) AM_READWRITE(biu_ctrl_r, biu_ctrl_w)
 	AM_RANGE(0x40008300, 0x400083ff) AM_READWRITE(disp_ctrl_r, disp_ctrl_w)
 	AM_RANGE(0x40008400, 0x400084ff) AM_READWRITE(memory_ctrl_r, memory_ctrl_w)
-	AM_RANGE(0x40800000, 0x40bfffff) AM_RAM AM_BASE_MEMBER(mediagx_state, vram)
+	AM_RANGE(0x40800000, 0x40bfffff) AM_RAM AM_BASE_MEMBER(mediagx_state, m_vram)
 	AM_RANGE(0xfffc0000, 0xffffffff) AM_ROM AM_REGION("bios", 0)	/* System BIOS */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START(mediagx_io, ADDRESS_SPACE_IO, 32)
+static ADDRESS_MAP_START(mediagx_io, AS_IO, 32)
 	AM_RANGE(0x0000, 0x001f) AM_DEVREADWRITE8("dma8237_1", i8237_r, i8237_w, 0xffffffff)
 	AM_RANGE(0x0020, 0x003f) AM_DEVREADWRITE8("pic8259_master", io20_r, io20_w, 0xffffffff)
 	AM_RANGE(0x0040, 0x005f) AM_DEVREADWRITE8("pit8254", pit8253_r, pit8253_w, 0xffffffff)
@@ -1006,47 +1006,40 @@ INPUT_PORTS_END
 
 static IRQ_CALLBACK(irq_callback)
 {
-	mediagx_state *state = device->machine->driver_data<mediagx_state>();
-	int r;
-
-	r = pic8259_acknowledge( state->pic8259_2);
-	if (r==0)
-	{
-		r = pic8259_acknowledge( state->pic8259_1);
-	}
-	return r;
+	mediagx_state *state = device->machine().driver_data<mediagx_state>();
+	return pic8259_acknowledge( state->m_pic8259_1);
 }
 
 static MACHINE_START(mediagx)
 {
-	mediagx_state *state = machine->driver_data<mediagx_state>();
+	mediagx_state *state = machine.driver_data<mediagx_state>();
 
-	state->pit8254 = machine->device<pit8254_device>( "pit8254" );
-	state->pic8259_1 = machine->device<pic8259_device>( "pic8259_master" );
-	state->pic8259_2 = machine->device<pic8259_device>( "pic8259_slave" );
-	state->dma8237_1 = machine->device<i8237_device>( "dma8237_1" );
-	state->dma8237_2 = machine->device<i8237_device>( "dma8237_2" );
+	state->m_pit8254 = machine.device<pit8254_device>( "pit8254" );
+	state->m_pic8259_1 = machine.device<pic8259_device>( "pic8259_master" );
+	state->m_pic8259_2 = machine.device<pic8259_device>( "pic8259_slave" );
+	state->m_dma8237_1 = machine.device<i8237_device>( "dma8237_1" );
+	state->m_dma8237_2 = machine.device<i8237_device>( "dma8237_2" );
 
-	state->dacl = auto_alloc_array(machine, INT16, 65536);
-	state->dacr = auto_alloc_array(machine, INT16, 65536);
+	state->m_dacl = auto_alloc_array(machine, INT16, 65536);
+	state->m_dacr = auto_alloc_array(machine, INT16, 65536);
 }
 
 static MACHINE_RESET(mediagx)
 {
-	mediagx_state *state = machine->driver_data<mediagx_state>();
-	UINT8 *rom = machine->region("bios")->base();
+	mediagx_state *state = machine.driver_data<mediagx_state>();
+	UINT8 *rom = machine.region("bios")->base();
 
-	cpu_set_irq_callback(machine->device("maincpu"), irq_callback);
+	device_set_irq_callback(machine.device("maincpu"), irq_callback);
 
-	memcpy(state->bios_ram, rom, 0x40000);
-	machine->device("maincpu")->reset();
+	memcpy(state->m_bios_ram, rom, 0x40000);
+	machine.device("maincpu")->reset();
 
-	timer_device *sound_timer = machine->device<timer_device>("sound_timer");
-	sound_timer->adjust(ATTOTIME_IN_MSEC(10));
+	timer_device *sound_timer = machine.device<timer_device>("sound_timer");
+	sound_timer->adjust(attotime::from_msec(10));
 
-	state->dmadac[0] = machine->device<dmadac_sound_device>("dac1");
-	state->dmadac[1] = machine->device<dmadac_sound_device>("dac2");
-	dmadac_enable(&state->dmadac[0], 2, 1);
+	state->m_dmadac[0] = machine.device<dmadac_sound_device>("dac1");
+	state->m_dmadac[1] = machine.device<dmadac_sound_device>("dac2");
+	dmadac_enable(&state->m_dmadac[0], 2, 1);
 	devtag_reset(machine, "ide");
 }
 
@@ -1058,17 +1051,30 @@ static MACHINE_RESET(mediagx)
 
 static WRITE_LINE_DEVICE_HANDLER( mediagx_pic8259_1_set_int_line )
 {
-	cputag_set_input_line(device->machine, "maincpu", 0, state ? HOLD_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine(), "maincpu", 0, state ? HOLD_LINE : CLEAR_LINE);
+}
+
+static READ8_DEVICE_HANDLER( get_slave_ack )
+{
+	mediagx_state *state = device->machine().driver_data<mediagx_state>();
+	if (offset==2) { // IRQ = 2
+		return pic8259_acknowledge(state->m_pic8259_2);
+	}
+	return 0x00;
 }
 
 static const struct pic8259_interface mediagx_pic8259_1_config =
 {
-	DEVCB_LINE(mediagx_pic8259_1_set_int_line)
+	DEVCB_LINE(mediagx_pic8259_1_set_int_line),
+	DEVCB_LINE_VCC,
+	DEVCB_HANDLER(get_slave_ack)
 };
 
 static const struct pic8259_interface mediagx_pic8259_2_config =
 {
-	DEVCB_DEVICE_LINE("pic8259_master", pic8259_ir2_w)
+	DEVCB_DEVICE_LINE("pic8259_master", pic8259_ir2_w),
+	DEVCB_LINE_GND,
+	DEVCB_NULL
 };
 
 
@@ -1133,12 +1139,12 @@ static MACHINE_CONFIG_START( mediagx, mediagx_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(640, 480)
 	MCFG_SCREEN_VISIBLE_AREA(0, 639, 0, 239)
+	MCFG_SCREEN_UPDATE(mediagx)
 
 	MCFG_GFXDECODE(CGA)
 	MCFG_PALETTE_LENGTH(16)
 
 	MCFG_VIDEO_START(mediagx)
-	MCFG_VIDEO_UPDATE(mediagx)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
@@ -1150,30 +1156,30 @@ static MACHINE_CONFIG_START( mediagx, mediagx_state )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "rspeaker", 1.0)
 MACHINE_CONFIG_END
 
-static void set_gate_a20(running_machine *machine, int a20)
+static void set_gate_a20(running_machine &machine, int a20)
 {
 	cputag_set_input_line(machine, "maincpu", INPUT_LINE_A20, a20);
 }
 
-static void keyboard_interrupt(running_machine *machine, int _state)
+static void keyboard_interrupt(running_machine &machine, int _state)
 {
-	mediagx_state *state = machine->driver_data<mediagx_state>();
+	mediagx_state *state = machine.driver_data<mediagx_state>();
 
-	pic8259_ir1_w(state->pic8259_1, _state);
+	pic8259_ir1_w(state->m_pic8259_1, _state);
 }
 
 static void ide_interrupt(device_t *device, int _state)
 {
-	mediagx_state *state = device->machine->driver_data<mediagx_state>();
+	mediagx_state *state = device->machine().driver_data<mediagx_state>();
 
-	pic8259_ir6_w(state->pic8259_2, _state);
+	pic8259_ir6_w(state->m_pic8259_2, _state);
 }
 
-static int mediagx_get_out2(running_machine *machine)
+static int mediagx_get_out2(running_machine &machine)
 {
-	mediagx_state *state = machine->driver_data<mediagx_state>();
+	mediagx_state *state = machine.driver_data<mediagx_state>();
 
-	return pit8253_get_output( state->pit8254, 2 );
+	return pit8253_get_output( state->m_pit8254, 2 );
 }
 
 static const struct kbdc8042_interface at8042 =
@@ -1181,18 +1187,18 @@ static const struct kbdc8042_interface at8042 =
 	KBDC8042_AT386, set_gate_a20, keyboard_interrupt, mediagx_get_out2
 };
 
-static void mediagx_set_keyb_int(running_machine *machine, int _state)
+static void mediagx_set_keyb_int(running_machine &machine, int _state)
 {
-	mediagx_state *state = machine->driver_data<mediagx_state>();
+	mediagx_state *state = machine.driver_data<mediagx_state>();
 
-	pic8259_ir1_w(state->pic8259_1, _state);
+	pic8259_ir1_w(state->m_pic8259_1, _state);
 }
 
-static void init_mediagx(running_machine *machine)
+static void init_mediagx(running_machine &machine)
 {
-	mediagx_state *state = machine->driver_data<mediagx_state>();
+	mediagx_state *state = machine.driver_data<mediagx_state>();
 
-	state->frame_width = state->frame_height = 1;
+	state->m_frame_width = state->m_frame_height = 1;
 
 	init_pc_common(machine, PCCOMMON_KEYBOARD_AT,mediagx_set_keyb_int);
 
@@ -1203,14 +1209,14 @@ static void init_mediagx(running_machine *machine)
 
 INLINE UINT32 generic_speedup(address_space *space, int idx)
 {
-	mediagx_state *state = space->machine->driver_data<mediagx_state>();
+	mediagx_state *state = space->machine().driver_data<mediagx_state>();
 
-	if (cpu_get_pc(space->cpu) == state->speedup_table[idx].pc)
+	if (cpu_get_pc(&space->device()) == state->m_speedup_table[idx].pc)
 	{
-		state->speedup_hits[idx]++;
-		cpu_spinuntil_int(space->cpu);
+		state->m_speedup_hits[idx]++;
+		device_spin_until_interrupt(&space->device());
 	}
-	return state->main_ram[state->speedup_table[idx].offset/4];
+	return state->m_main_ram[state->m_speedup_table[idx].offset/4];
 }
 
 static READ32_HANDLER( speedup0_r ) { return generic_speedup(space, 0); }
@@ -1226,11 +1232,11 @@ static READ32_HANDLER( speedup9_r ) { return generic_speedup(space, 9); }
 static READ32_HANDLER( speedup10_r ) { return generic_speedup(space, 10); }
 static READ32_HANDLER( speedup11_r ) { return generic_speedup(space, 11); }
 
-static const read32_space_func speedup_handlers[] =
+static const struct { read32_space_func func; const char *name; } speedup_handlers[] =
 {
-	speedup0_r,		speedup1_r,		speedup2_r,		speedup3_r,
-	speedup4_r,		speedup5_r,		speedup6_r,		speedup7_r,
-	speedup8_r,		speedup9_r,		speedup10_r,	speedup11_r
+	{ FUNC(speedup0_r) },	{ FUNC(speedup1_r) },	{ FUNC(speedup2_r) },	{ FUNC(speedup3_r) },
+	{ FUNC(speedup4_r) },	{ FUNC(speedup5_r) },	{ FUNC(speedup6_r) },	{ FUNC(speedup7_r) },
+	{ FUNC(speedup8_r) },	{ FUNC(speedup9_r) },	{ FUNC(speedup10_r) },	{ FUNC(speedup11_r) }
 };
 
 #ifdef MAME_DEBUG
@@ -1239,26 +1245,26 @@ static void report_speedups(running_machine &machine)
 	mediagx_state *state = machine.driver_data<mediagx_state>();
 	int i;
 
-	for (i = 0; i < state->speedup_count; i++)
-		printf("Speedup %2d: offs=%06X pc=%06X hits=%d\n", i, state->speedup_table[i].offset, state->speedup_table[i].pc, state->speedup_hits[i]);
+	for (i = 0; i < state->m_speedup_count; i++)
+		printf("Speedup %2d: offs=%06X pc=%06X hits=%d\n", i, state->m_speedup_table[i].offset, state->m_speedup_table[i].pc, state->m_speedup_hits[i]);
 }
 #endif
 
-static void install_speedups(running_machine *machine, const speedup_entry *entries, int count)
+static void install_speedups(running_machine &machine, const speedup_entry *entries, int count)
 {
-	mediagx_state *state = machine->driver_data<mediagx_state>();
+	mediagx_state *state = machine.driver_data<mediagx_state>();
 	int i;
 
 	assert(count < ARRAY_LENGTH(speedup_handlers));
 
-	state->speedup_table = entries;
-	state->speedup_count = count;
+	state->m_speedup_table = entries;
+	state->m_speedup_count = count;
 
 	for (i = 0; i < count; i++)
-		memory_install_read32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), entries[i].offset, entries[i].offset + 3, 0, 0, speedup_handlers[i]);
+		machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(entries[i].offset, entries[i].offset + 3, speedup_handlers[i].func, speedup_handlers[i].name);
 
 #ifdef MAME_DEBUG
-	machine->add_notifier(MACHINE_NOTIFY_EXIT, report_speedups);
+	machine.add_notifier(MACHINE_NOTIFY_EXIT, machine_notify_delegate(FUNC(report_speedups), &machine));
 #endif
 }
 
