@@ -47,17 +47,17 @@ metlclsh:
 
 static WRITE8_HANDLER( metlclsh_cause_irq )
 {
-	metlclsh_state *state = space->machine->driver_data<metlclsh_state>();
-	cpu_set_input_line(state->subcpu, M6809_IRQ_LINE, ASSERT_LINE);
+	metlclsh_state *state = space->machine().driver_data<metlclsh_state>();
+	device_set_input_line(state->m_subcpu, M6809_IRQ_LINE, ASSERT_LINE);
 }
 
 static WRITE8_HANDLER( metlclsh_ack_nmi )
 {
-	metlclsh_state *state = space->machine->driver_data<metlclsh_state>();
-	cpu_set_input_line(state->maincpu, INPUT_LINE_NMI, CLEAR_LINE);
+	metlclsh_state *state = space->machine().driver_data<metlclsh_state>();
+	device_set_input_line(state->m_maincpu, INPUT_LINE_NMI, CLEAR_LINE);
 }
 
-static ADDRESS_MAP_START( metlclsh_master_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( metlclsh_master_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0x9fff) AM_RAM AM_SHARE("share1")
 	AM_RANGE(0xa000, 0xbfff) AM_ROM
@@ -71,9 +71,9 @@ static ADDRESS_MAP_START( metlclsh_master_map, ADDRESS_SPACE_PROGRAM, 8 )
 /**/AM_RANGE(0xc800, 0xc82f) AM_RAM_WRITE(paletteram_xxxxBBBBGGGGRRRR_split1_w) AM_BASE_GENERIC(paletteram)
 /**/AM_RANGE(0xcc00, 0xcc2f) AM_RAM_WRITE(paletteram_xxxxBBBBGGGGRRRR_split2_w) AM_BASE_GENERIC(paletteram2)
 	AM_RANGE(0xd000, 0xd001) AM_DEVREADWRITE("ym1", ym2203_r,ym2203_w)
-/**/AM_RANGE(0xd800, 0xdfff) AM_RAM_WRITE(metlclsh_fgram_w) AM_BASE_MEMBER(metlclsh_state, fgram)
+/**/AM_RANGE(0xd800, 0xdfff) AM_RAM_WRITE(metlclsh_fgram_w) AM_BASE_MEMBER(metlclsh_state, m_fgram)
 	AM_RANGE(0xe000, 0xe001) AM_DEVWRITE("ym2", ym3526_w	)
-	AM_RANGE(0xe800, 0xe9ff) AM_RAM AM_BASE_SIZE_MEMBER(metlclsh_state, spriteram, spriteram_size)
+	AM_RANGE(0xe800, 0xe9ff) AM_RAM AM_BASE_SIZE_MEMBER(metlclsh_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0xfff0, 0xffff) AM_ROM									// Reset/IRQ vectors
 ADDRESS_MAP_END
 
@@ -86,28 +86,28 @@ ADDRESS_MAP_END
 
 static WRITE8_HANDLER( metlclsh_cause_nmi2 )
 {
-	metlclsh_state *state = space->machine->driver_data<metlclsh_state>();
-	cpu_set_input_line(state->maincpu, INPUT_LINE_NMI, ASSERT_LINE);
+	metlclsh_state *state = space->machine().driver_data<metlclsh_state>();
+	device_set_input_line(state->m_maincpu, INPUT_LINE_NMI, ASSERT_LINE);
 }
 
 static WRITE8_HANDLER( metlclsh_ack_irq2 )
 {
-	metlclsh_state *state = space->machine->driver_data<metlclsh_state>();
-	cpu_set_input_line(state->subcpu, M6809_IRQ_LINE, CLEAR_LINE);
+	metlclsh_state *state = space->machine().driver_data<metlclsh_state>();
+	device_set_input_line(state->m_subcpu, M6809_IRQ_LINE, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( metlclsh_ack_nmi2 )
 {
-	metlclsh_state *state = space->machine->driver_data<metlclsh_state>();
-	cpu_set_input_line(state->subcpu, INPUT_LINE_NMI, CLEAR_LINE);
+	metlclsh_state *state = space->machine().driver_data<metlclsh_state>();
+	device_set_input_line(state->m_subcpu, INPUT_LINE_NMI, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( metlclsh_flipscreen_w )
 {
-	flip_screen_set(space->machine, data & 1);
+	flip_screen_set(space->machine(), data & 1);
 }
 
-static ADDRESS_MAP_START( metlclsh_slave_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( metlclsh_slave_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0x9fff) AM_RAM AM_SHARE("share1")
 	AM_RANGE(0xc000, 0xc000) AM_READ_PORT("IN0") AM_WRITE(metlclsh_gfxbank_w)	// bg tiles bank
@@ -116,10 +116,10 @@ static ADDRESS_MAP_START( metlclsh_slave_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc003, 0xc003) AM_READ_PORT("DSW")
 	AM_RANGE(0xc0c0, 0xc0c0) AM_WRITE(metlclsh_cause_nmi2)			// cause nmi on cpu #1
 	AM_RANGE(0xc0c1, 0xc0c1) AM_WRITE(metlclsh_ack_irq2)			// irq ack
-	AM_RANGE(0xd000, 0xd7ff) AM_ROMBANK("bank1") AM_WRITE(metlclsh_bgram_w) AM_BASE_MEMBER(metlclsh_state, bgram) // this is banked
+	AM_RANGE(0xd000, 0xd7ff) AM_ROMBANK("bank1") AM_WRITE(metlclsh_bgram_w) AM_BASE_MEMBER(metlclsh_state, m_bgram) // this is banked
 	AM_RANGE(0xe301, 0xe301) AM_WRITE(metlclsh_flipscreen_w)		// 0/1
 	AM_RANGE(0xe401, 0xe401) AM_WRITE(metlclsh_rambank_w)
-	AM_RANGE(0xe402, 0xe403) AM_WRITEONLY AM_BASE_MEMBER(metlclsh_state, scrollx)
+	AM_RANGE(0xe402, 0xe403) AM_WRITEONLY AM_BASE_MEMBER(metlclsh_state, m_scrollx)
 //  AM_RANGE(0xe404, 0xe404) AM_WRITENOP                            // ? 0
 //  AM_RANGE(0xe410, 0xe410) AM_WRITENOP                            // ? 0 on startup only
 	AM_RANGE(0xe417, 0xe417) AM_WRITE(metlclsh_ack_nmi2)			// nmi ack
@@ -255,8 +255,8 @@ GFXDECODE_END
 
 static void metlclsh_irqhandler(device_t *device, int linestate)
 {
-	metlclsh_state *state = device->machine->driver_data<metlclsh_state>();
-	cpu_set_input_line(state->maincpu, M6809_IRQ_LINE, linestate);
+	metlclsh_state *state = device->machine().driver_data<metlclsh_state>();
+	device_set_input_line(state->m_maincpu, M6809_IRQ_LINE, linestate);
 }
 
 static const ym3526_interface ym3526_config =
@@ -269,29 +269,29 @@ static INTERRUPT_GEN( metlclsh_interrupt2 )
 	if (cpu_getiloops(device) == 0)
 		return;
 	/* generate NMI on coin insertion */
-	if ((~input_port_read(device->machine, "IN2") & 0xc0) || (~input_port_read(device->machine, "DSW") & 0x40))
-		cpu_set_input_line(device, INPUT_LINE_NMI, ASSERT_LINE);
+	if ((~input_port_read(device->machine(), "IN2") & 0xc0) || (~input_port_read(device->machine(), "DSW") & 0x40)) /* TODO: remove me */
+		device_set_input_line(device, INPUT_LINE_NMI, ASSERT_LINE);
 }
 
 static MACHINE_START( metlclsh )
 {
-	metlclsh_state *state = machine->driver_data<metlclsh_state>();
+	metlclsh_state *state = machine.driver_data<metlclsh_state>();
 
-	state->maincpu = machine->device("maincpu");
-	state->subcpu = machine->device("sub");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_subcpu = machine.device("sub");
 
-	state_save_register_global(machine, state->write_mask);
-	state_save_register_global(machine, state->gfxbank);
+	state->save_item(NAME(state->m_write_mask));
+	state->save_item(NAME(state->m_gfxbank));
 }
 
 static MACHINE_RESET( metlclsh )
 {
-	metlclsh_state *state = machine->driver_data<metlclsh_state>();
+	metlclsh_state *state = machine.driver_data<metlclsh_state>();
 
 	flip_screen_set(machine, 0);
 
-	state->write_mask = 0;
-	state->gfxbank = 0;
+	state->m_write_mask = 0;
+	state->m_gfxbank = 0;
 }
 
 static MACHINE_CONFIG_START( metlclsh, metlclsh_state )
@@ -316,12 +316,12 @@ static MACHINE_CONFIG_START( metlclsh, metlclsh_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(metlclsh)
 
 	MCFG_GFXDECODE(metlclsh)
 	MCFG_PALETTE_LENGTH(3 * 16)
 
 	MCFG_VIDEO_START(metlclsh)
-	MCFG_VIDEO_UPDATE(metlclsh)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
