@@ -91,14 +91,31 @@ Changes (2008-12-10, Roberto Fresca):
 #include "mil4000.lh"
 
 
-static UINT16 *sc0_vram,*sc1_vram,*sc2_vram,*sc3_vram;
-static tilemap_t *sc0_tilemap,*sc1_tilemap,*sc2_tilemap,*sc3_tilemap;
+class mil4000_state : public driver_device
+{
+public:
+	mil4000_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT16 *m_sc0_vram;
+	UINT16 *m_sc1_vram;
+	UINT16 *m_sc2_vram;
+	UINT16 *m_sc3_vram;
+	tilemap_t *m_sc0_tilemap;
+	tilemap_t *m_sc1_tilemap;
+	tilemap_t *m_sc2_tilemap;
+	tilemap_t *m_sc3_tilemap;
+	UINT16 m_vblank;
+	UINT16 m_hblank;
+};
+
 
 static TILE_GET_INFO( get_sc0_tile_info )
 {
-	UINT32 data = (sc0_vram[tile_index*2]<<16) | sc0_vram[tile_index*2+1];
+	mil4000_state *state = machine.driver_data<mil4000_state>();
+	UINT32 data = (state->m_sc0_vram[tile_index*2]<<16) | state->m_sc0_vram[tile_index*2+1];
 	int tile = data >> 14;
-	int color = (sc0_vram[tile_index*2+1] & 0x1f)+0;
+	int color = (state->m_sc0_vram[tile_index*2+1] & 0x1f)+0;
 
 	SET_TILE_INFO(
 			0,
@@ -109,9 +126,10 @@ static TILE_GET_INFO( get_sc0_tile_info )
 
 static TILE_GET_INFO( get_sc1_tile_info )
 {
-	UINT32 data = (sc1_vram[tile_index*2]<<16) | sc1_vram[tile_index*2+1];
+	mil4000_state *state = machine.driver_data<mil4000_state>();
+	UINT32 data = (state->m_sc1_vram[tile_index*2]<<16) | state->m_sc1_vram[tile_index*2+1];
 	int tile = data >> 14;
-	int color = (sc1_vram[tile_index*2+1] & 0x1f)+0x10;
+	int color = (state->m_sc1_vram[tile_index*2+1] & 0x1f)+0x10;
 
 	SET_TILE_INFO(
 			0,
@@ -122,9 +140,10 @@ static TILE_GET_INFO( get_sc1_tile_info )
 
 static TILE_GET_INFO( get_sc2_tile_info )
 {
-	UINT32 data = (sc2_vram[tile_index*2]<<16) | sc2_vram[tile_index*2+1];
+	mil4000_state *state = machine.driver_data<mil4000_state>();
+	UINT32 data = (state->m_sc2_vram[tile_index*2]<<16) | state->m_sc2_vram[tile_index*2+1];
 	int tile = data >> 14;
-	int color = (sc2_vram[tile_index*2+1] & 0x1f)+0x20;
+	int color = (state->m_sc2_vram[tile_index*2+1] & 0x1f)+0x20;
 
 	SET_TILE_INFO(
 			0,
@@ -135,9 +154,10 @@ static TILE_GET_INFO( get_sc2_tile_info )
 
 static TILE_GET_INFO( get_sc3_tile_info )
 {
-	UINT32 data = (sc3_vram[tile_index*2]<<16) | sc3_vram[tile_index*2+1];
+	mil4000_state *state = machine.driver_data<mil4000_state>();
+	UINT32 data = (state->m_sc3_vram[tile_index*2]<<16) | state->m_sc3_vram[tile_index*2+1];
 	int tile = data >> 14;
-	int color = (sc3_vram[tile_index*2+1] & 0x1f)+0x30;
+	int color = (state->m_sc3_vram[tile_index*2+1] & 0x1f)+0x30;
 
 	SET_TILE_INFO(
 			0,
@@ -148,49 +168,44 @@ static TILE_GET_INFO( get_sc3_tile_info )
 
 static VIDEO_START(mil4000)
 {
-	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
-	int i;
+	mil4000_state *state = machine.driver_data<mil4000_state>();
+	state->m_sc0_tilemap = tilemap_create(machine, get_sc0_tile_info,tilemap_scan_rows,8,8,64,64);
+	state->m_sc1_tilemap = tilemap_create(machine, get_sc1_tile_info,tilemap_scan_rows,8,8,64,64);
+	state->m_sc2_tilemap = tilemap_create(machine, get_sc2_tile_info,tilemap_scan_rows,8,8,64,64);
+	state->m_sc3_tilemap = tilemap_create(machine, get_sc3_tile_info,tilemap_scan_rows,8,8,64,64);
 
-	// game doesn't clear the palette, so to avoid seeing mame defaults we clear it
-	for (i=0;i<0x800;i++)
-		palette_set_color(space->machine, i, MAKE_RGB(0, 0, 0));
-
-	sc0_tilemap = tilemap_create(machine, get_sc0_tile_info,tilemap_scan_rows,8,8,64,64);
-	sc1_tilemap = tilemap_create(machine, get_sc1_tile_info,tilemap_scan_rows,8,8,64,64);
-	sc2_tilemap = tilemap_create(machine, get_sc2_tile_info,tilemap_scan_rows,8,8,64,64);
-	sc3_tilemap = tilemap_create(machine, get_sc3_tile_info,tilemap_scan_rows,8,8,64,64);
-
-	tilemap_set_transparent_pen(sc1_tilemap,0);
-	tilemap_set_transparent_pen(sc2_tilemap,0);
-	tilemap_set_transparent_pen(sc3_tilemap,0);
+	tilemap_set_transparent_pen(state->m_sc1_tilemap,0);
+	tilemap_set_transparent_pen(state->m_sc2_tilemap,0);
+	tilemap_set_transparent_pen(state->m_sc3_tilemap,0);
 }
 
-static VIDEO_UPDATE(mil4000)
+static SCREEN_UPDATE(mil4000)
 {
-	tilemap_draw(bitmap,cliprect,sc0_tilemap,0,0);
-	tilemap_draw(bitmap,cliprect,sc1_tilemap,0,0);
-	tilemap_draw(bitmap,cliprect,sc2_tilemap,0,0);
-	tilemap_draw(bitmap,cliprect,sc3_tilemap,0,0);
+	mil4000_state *state = screen->machine().driver_data<mil4000_state>();
+	tilemap_draw(bitmap,cliprect,state->m_sc0_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,state->m_sc1_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,state->m_sc2_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,state->m_sc3_tilemap,0,0);
 	return 0;
 }
 
 /*TODO*/
 static READ16_HANDLER( hvretrace_r )
 {
-	static UINT16 res;
-	static UINT16 vblank = 0,hblank = 0;
+	mil4000_state *state = space->machine().driver_data<mil4000_state>();
+	UINT16 res;
 
 	res = 0;
 
-	vblank^=1;
-	hblank^=1;
+	state->m_vblank^=1;
+	state->m_hblank^=1;
 
 	/*V-Blank*/
-	if (vblank)
+	if (state->m_vblank)
 		res|= 0x80;
 
 	/*H-Blank*/
-	if (hblank)
+	if (state->m_hblank)
 		res|= 0x40;
 
 	return res;
@@ -199,26 +214,30 @@ static READ16_HANDLER( hvretrace_r )
 
 static WRITE16_HANDLER( sc0_vram_w )
 {
-	sc0_vram[offset] = data;
-	tilemap_mark_tile_dirty(sc0_tilemap,offset/2);
+	mil4000_state *state = space->machine().driver_data<mil4000_state>();
+	state->m_sc0_vram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_sc0_tilemap,offset/2);
 }
 
 static WRITE16_HANDLER( sc1_vram_w )
 {
-	sc1_vram[offset] = data;
-	tilemap_mark_tile_dirty(sc1_tilemap,offset/2);
+	mil4000_state *state = space->machine().driver_data<mil4000_state>();
+	state->m_sc1_vram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_sc1_tilemap,offset/2);
 }
 
 static WRITE16_HANDLER( sc2_vram_w )
 {
-	sc2_vram[offset] = data;
-	tilemap_mark_tile_dirty(sc2_tilemap,offset/2);
+	mil4000_state *state = space->machine().driver_data<mil4000_state>();
+	state->m_sc2_vram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_sc2_tilemap,offset/2);
 }
 
 static WRITE16_HANDLER( sc3_vram_w )
 {
-	sc3_vram[offset] = data;
-	tilemap_mark_tile_dirty(sc3_tilemap,offset/2);
+	mil4000_state *state = space->machine().driver_data<mil4000_state>();
+	state->m_sc3_vram[offset] = data;
+	tilemap_mark_tile_dirty(state->m_sc3_tilemap,offset/2);
 }
 
 /*end of video stuff*/
@@ -235,10 +254,10 @@ static WRITE16_HANDLER( sc3_vram_w )
 */
 static WRITE16_HANDLER( output_w )
 {
-	static int i;
+	int i;
 
 	for(i=0;i<3;i++)
-		coin_counter_w(space->machine, i, data & 0x2000);
+		coin_counter_w(space->machine(), i, data & 0x2000);
 
 	output_set_lamp_value(0, (data) & 1);		/* HOLD1 */
 	output_set_lamp_value(1, (data >> 1) & 1);	/* HOLD2 */
@@ -251,12 +270,12 @@ static WRITE16_HANDLER( output_w )
 //  popmessage("%04x\n",data);
 }
 
-static ADDRESS_MAP_START( mil4000_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( mil4000_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
-	AM_RANGE(0x500000, 0x503fff) AM_RAM_WRITE(sc0_vram_w) AM_BASE(&sc0_vram)	// CY62256L-70, U77
-	AM_RANGE(0x504000, 0x507fff) AM_RAM_WRITE(sc1_vram_w) AM_BASE(&sc1_vram)	// CY62256L-70, U77
-	AM_RANGE(0x508000, 0x50bfff) AM_RAM_WRITE(sc2_vram_w) AM_BASE(&sc2_vram)	// CY62256L-70, U78
-	AM_RANGE(0x50c000, 0x50ffff) AM_RAM_WRITE(sc3_vram_w) AM_BASE(&sc3_vram)	// CY62256L-70, U78
+	AM_RANGE(0x500000, 0x503fff) AM_RAM_WRITE(sc0_vram_w) AM_BASE_MEMBER(mil4000_state, m_sc0_vram)	// CY62256L-70, U77
+	AM_RANGE(0x504000, 0x507fff) AM_RAM_WRITE(sc1_vram_w) AM_BASE_MEMBER(mil4000_state, m_sc1_vram)	// CY62256L-70, U77
+	AM_RANGE(0x508000, 0x50bfff) AM_RAM_WRITE(sc2_vram_w) AM_BASE_MEMBER(mil4000_state, m_sc2_vram)	// CY62256L-70, U78
+	AM_RANGE(0x50c000, 0x50ffff) AM_RAM_WRITE(sc3_vram_w) AM_BASE_MEMBER(mil4000_state, m_sc3_vram)	// CY62256L-70, U78
 
 	AM_RANGE(0x708000, 0x708001) AM_READ_PORT("IN0")
 	AM_RANGE(0x708002, 0x708003) AM_READ_PORT("IN1")
@@ -344,7 +363,7 @@ static GFXDECODE_START( mil4000 )
 GFXDECODE_END
 
 
-static MACHINE_CONFIG_START( mil4000, driver_device )
+static MACHINE_CONFIG_START( mil4000, mil4000_state )
 	MCFG_CPU_ADD("maincpu", M68000, 12000000 )	// ?
 	MCFG_CPU_PROGRAM_MAP(mil4000_map)
 	// irq 2/4/5 point to the same place, others invalid
@@ -358,11 +377,13 @@ static MACHINE_CONFIG_START( mil4000, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(320, 240)
 	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, 0, 240-1)
+	MCFG_SCREEN_UPDATE(mil4000)
 
 	MCFG_PALETTE_LENGTH(0x800)
+	MCFG_PALETTE_INIT(all_black)
+
 	MCFG_GFXDECODE(mil4000)
 	MCFG_VIDEO_START(mil4000)
-	MCFG_VIDEO_UPDATE(mil4000)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_OKIM6295_ADD("oki", 1000000, OKIM6295_PIN7_HIGH) // frequency from 1000 kHz resonator. pin 7 high not verified.
