@@ -38,149 +38,84 @@ MR_01-.3A    [a0b758aa]
 #include "includes/decoprot.h"
 #include "video/deco16ic.h"
 #include "sound/okim6295.h"
+#include "video/decospr.h"
 
 class mirage_state : public driver_device
 {
 public:
-	mirage_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config),
-		  maincpu(*this, "maincpu"),
-		  deco16ic(*this, "deco_custom"),
-		  oki_sfx(*this, "oki_sfx"),
-		  oki_bgm(*this, "oki_bgm") { }
+	mirage_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag),
+		  m_maincpu(*this, "maincpu"),
+		  m_deco_tilegen1(*this, "tilegen1"),
+		  m_oki_sfx(*this, "oki_sfx"),
+		  m_oki_bgm(*this, "oki_bgm") { }
 
 	/* memory pointers */
-	UINT16 *  pf1_rowscroll;
-	UINT16 *  pf2_rowscroll;
-//  UINT16 *  spriteram;
-//  UINT16 *  paletteram;    // currently this uses generic palette handling (in deco16ic.c)
-//  size_t    spriteram_size;
+	UINT16 *  m_pf1_rowscroll;
+	UINT16 *  m_pf2_rowscroll;
+//  UINT16 *  m_spriteram;
+//  UINT16 *  m_paletteram;    // currently this uses generic palette handling (in decocomn.c)
+//  size_t    m_spriteram_size;
 
 	/* misc */
-	UINT8 mux_data;
+	UINT8 m_mux_data;
 
 	/* devices */
-	required_device<m68000_device> maincpu;
-	required_device<deco16ic_device> deco16ic;
-	required_device<okim6295_device> oki_sfx;
-	required_device<okim6295_device> oki_bgm;
+	required_device<m68000_device> m_maincpu;
+	required_device<deco16ic_device> m_deco_tilegen1;
+	required_device<okim6295_device> m_oki_sfx;
+	required_device<okim6295_device> m_oki_bgm;
 };
 
-
-static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int pri )
+static VIDEO_START( mirage )
 {
-	//mirage_state *state = machine->driver_data<mirage_state>();
-	UINT16 *spriteram = machine->generic.buffered_spriteram.u16;//state->spriteram;
-	int offs;
-
-	for (offs = 0; offs < 0x400; offs += 4)
-	{
-		int x, y, sprite, colour, multi, fx, fy, inc, flash, mult;
-
-		sprite = spriteram[offs + 1];
-		if (!sprite)
-			continue;
-
-		y = spriteram[offs];
-		flash = y & 0x1000;
-
-		if (flash && (machine->primary_screen->frame_number() & 1))
-			continue;
-
-		if (pri != ((y & 0x8000) >> 15))
-			continue;
-
-		x = spriteram[offs + 2];
-		colour = (x >> 9) & 0x1f;
-
-		fx = y & 0x2000;
-		fy = y & 0x4000;
-
-		multi = (1 << ((y & 0x0600) >> 9)) - 1;	/* 1x, 2x, 4x, 8x height */
-
-		x = x & 0x01ff;
-		y = y & 0x01ff;
-		if (x >= 320) x -= 512;
-		if (y >= 256) y -= 512;
-		y = 240 - y;
-		x = 304 - x;
-
-		if (x > 320)
-			continue;
-
-		sprite &= ~multi;
-		if (fy)
-			inc = -1;
-		else
-		{
-			sprite += multi;
-			inc = 1;
-		}
-
-		if (flip_screen_get(machine))
-		{
-			y =240 - y;
-			x =304 - x;
-			if (fx) fx = 0; else fx = 1;
-			if (fy) fy = 0; else fy = 1;
-			mult = 16;
-		}
-		else mult = -16;
-
-		while (multi >= 0)
-		{
-			drawgfx_transpen(bitmap,cliprect,machine->gfx[2],
-					sprite - multi * inc,
-					colour,
-					fx,fy,
-					x,y + mult * multi,0);
-
-			multi--;
-		}
-	}
+	machine.device<decospr_device>("spritegen")->alloc_sprite_bitmap(machine);
 }
 
-static VIDEO_UPDATE( mirage )
+static SCREEN_UPDATE( mirage )
 {
-	mirage_state *state = screen->machine->driver_data<mirage_state>();
-	UINT16 flip = deco16ic_pf12_control_r(state->deco16ic, 0, 0xffff);
+	mirage_state *state = screen->machine().driver_data<mirage_state>();
+	UINT16 flip = deco16ic_pf_control_r(state->m_deco_tilegen1, 0, 0xffff);
 
-	flip_screen_set(screen->machine, BIT(flip, 7));
-	deco16ic_pf12_update(state->deco16ic, state->pf1_rowscroll, state->pf2_rowscroll);
+	flip_screen_set(screen->machine(), BIT(flip, 7));
+
+	screen->machine().device<decospr_device>("spritegen")->draw_sprites(screen->machine(), bitmap, cliprect, screen->machine().generic.buffered_spriteram.u16, 0x400);
+
+	deco16ic_pf_update(state->m_deco_tilegen1, state->m_pf1_rowscroll, state->m_pf2_rowscroll);
 
 	bitmap_fill(bitmap, cliprect, 256); /* not verified */
 
-	deco16ic_tilemap_2_draw(state->deco16ic, bitmap, cliprect, TILEMAP_DRAW_OPAQUE, 0);
-	draw_sprites(screen->machine, bitmap, cliprect, 1);
-	deco16ic_tilemap_1_draw(state->deco16ic, bitmap, cliprect, 0, 0);
-	draw_sprites(screen->machine, bitmap, cliprect, 0);
+	deco16ic_tilemap_2_draw(state->m_deco_tilegen1, bitmap, cliprect, TILEMAP_DRAW_OPAQUE, 0);
+	screen->machine().device<decospr_device>("spritegen")->inefficient_copy_sprite_bitmap(screen->machine(), bitmap, cliprect, 0x0800, 0x0800, 0x200, 0x1ff);
+	deco16ic_tilemap_1_draw(state->m_deco_tilegen1, bitmap, cliprect, 0, 0);
+	screen->machine().device<decospr_device>("spritegen")->inefficient_copy_sprite_bitmap(screen->machine(), bitmap, cliprect, 0x0000, 0x0800, 0x200, 0x1ff);
 
 	return 0;
 }
 
-static VIDEO_EOF( mirage )
+static SCREEN_EOF( mirage )
 {
-	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = machine.device("maincpu")->memory().space(AS_PROGRAM);
 	buffer_spriteram16_w(space,0,0,0xffff);
 }
 
 
 static WRITE16_HANDLER( mirage_mux_w )
 {
-	mirage_state *state = space->machine->driver_data<mirage_state>();
-	state->mux_data = data & 0x1f;
+	mirage_state *state = space->machine().driver_data<mirage_state>();
+	state->m_mux_data = data & 0x1f;
 }
 
 static READ16_HANDLER( mirage_input_r )
 {
-	mirage_state *state = space->machine->driver_data<mirage_state>();
-	switch (state->mux_data & 0x1f)
+	mirage_state *state = space->machine().driver_data<mirage_state>();
+	switch (state->m_mux_data & 0x1f)
 	{
-		case 0x01: return input_port_read(space->machine, "KEY0");
-		case 0x02: return input_port_read(space->machine, "KEY1");
-		case 0x04: return input_port_read(space->machine, "KEY2");
-		case 0x08: return input_port_read(space->machine, "KEY3");
-		case 0x10: return input_port_read(space->machine, "KEY4");
+		case 0x01: return input_port_read(space->machine(), "KEY0");
+		case 0x02: return input_port_read(space->machine(), "KEY1");
+		case 0x04: return input_port_read(space->machine(), "KEY2");
+		case 0x08: return input_port_read(space->machine(), "KEY3");
+		case 0x10: return input_port_read(space->machine(), "KEY4");
 	}
 
 	return 0xffff;
@@ -188,26 +123,26 @@ static READ16_HANDLER( mirage_input_r )
 
 static WRITE16_HANDLER( okim1_rombank_w )
 {
-	mirage_state *state = space->machine->driver_data<mirage_state>();
-	state->oki_sfx->set_bank_base(0x40000 * (data & 0x3));
+	mirage_state *state = space->machine().driver_data<mirage_state>();
+	state->m_oki_sfx->set_bank_base(0x40000 * (data & 0x3));
 }
 
 static WRITE16_HANDLER( okim0_rombank_w )
 {
-	mirage_state *state = space->machine->driver_data<mirage_state>();
+	mirage_state *state = space->machine().driver_data<mirage_state>();
 
 	/*bits 4-6 used on POST? */
-	state->oki_bgm->set_bank_base(0x40000 * (data & 0x7));
+	state->m_oki_bgm->set_bank_base(0x40000 * (data & 0x7));
 }
 
-static ADDRESS_MAP_START( mirage_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( mirage_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	/* tilemaps */
-	AM_RANGE(0x100000, 0x101fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf1_data_r, deco16ic_pf1_data_w) // 0x100000 - 0x101fff tested
-	AM_RANGE(0x102000, 0x103fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf2_data_r, deco16ic_pf2_data_w) // 0x102000 - 0x102fff tested
+	AM_RANGE(0x100000, 0x101fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_r, deco16ic_pf1_data_w) // 0x100000 - 0x101fff tested
+	AM_RANGE(0x102000, 0x103fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf2_data_r, deco16ic_pf2_data_w) // 0x102000 - 0x102fff tested
 	/* linescroll */
-	AM_RANGE(0x110000, 0x110bff) AM_RAM AM_BASE_MEMBER(mirage_state, pf1_rowscroll)
-	AM_RANGE(0x112000, 0x112bff) AM_RAM AM_BASE_MEMBER(mirage_state, pf2_rowscroll)
+	AM_RANGE(0x110000, 0x110bff) AM_RAM AM_BASE_MEMBER(mirage_state, m_pf1_rowscroll)
+	AM_RANGE(0x112000, 0x112bff) AM_RAM AM_BASE_MEMBER(mirage_state, m_pf2_rowscroll)
 	AM_RANGE(0x120000, 0x1207ff) AM_RAM AM_BASE_SIZE_GENERIC(spriteram)
 	AM_RANGE(0x130000, 0x1307ff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x140000, 0x14000f) AM_DEVREADWRITE8_MODERN("oki_sfx", okim6295_device, read, write, 0x00ff)
@@ -215,7 +150,7 @@ static ADDRESS_MAP_START( mirage_map, ADDRESS_SPACE_PROGRAM, 16 )
 //  AM_RANGE(0x140006, 0x140007) AM_READ(random_readers)
 //  AM_RANGE(0x150006, 0x150007) AM_READNOP
 	AM_RANGE(0x160000, 0x160001) AM_WRITENOP
-	AM_RANGE(0x168000, 0x16800f) AM_DEVWRITE("deco_custom", deco16ic_pf12_control_w)
+	AM_RANGE(0x168000, 0x16800f) AM_DEVWRITE("tilegen1", deco16ic_pf_control_w)
 	AM_RANGE(0x16a000, 0x16a001) AM_WRITENOP
 	AM_RANGE(0x16c000, 0x16c001) AM_WRITE(okim1_rombank_w)
 	AM_RANGE(0x16c002, 0x16c003) AM_WRITE(okim0_rombank_w)
@@ -352,32 +287,31 @@ static int mirage_bank_callback( const int bank )
 	return ((bank >> 4) & 0x7) * 0x1000;
 }
 
-static const deco16ic_interface mirage_deco16ic_intf =
+static const deco16ic_interface mirage_deco16ic_tilegen1_intf =
 {
 	"screen",
-	1, 0, 1,
-	0x0f, 0x0f, 0x0f, 0x0f,	/* trans masks (default values) */
-	0, 16, 0, 16, /* color base (default values) */
-	0x0f, 0x0f, 0x0f, 0x0f,	/* color masks (default values) */
+	0, 1,
+	0x0f, 0x0f,	/* trans masks (default values) */
+	0, 16, /* color base (default values) */
+	0x0f, 0x0f,	/* color masks (default values) */
 	mirage_bank_callback,
 	mirage_bank_callback,
-	NULL,
-	NULL
+	0,1,
 };
 
 
 static MACHINE_START( mirage )
 {
-	mirage_state *state = machine->driver_data<mirage_state>();
+	mirage_state *state = machine.driver_data<mirage_state>();
 
-	state_save_register_global(machine, state->mux_data);
+	state->save_item(NAME(state->m_mux_data));
 }
 
 static MACHINE_RESET( mirage )
 {
-	mirage_state *state = machine->driver_data<mirage_state>();
+	mirage_state *state = machine.driver_data<mirage_state>();
 
-	state->mux_data = 0;
+	state->m_mux_data = 0;
 }
 
 static MACHINE_CONFIG_START( mirage, mirage_state )
@@ -396,17 +330,20 @@ static MACHINE_CONFIG_START( mirage, mirage_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(58)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(529))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_UPDATE(mirage)
+	MCFG_SCREEN_EOF(mirage)
+
+	MCFG_VIDEO_START(mirage)
 
 	MCFG_GFXDECODE(mirage)
 	MCFG_PALETTE_LENGTH(1024)
 
-	MCFG_VIDEO_UPDATE(mirage)
-	MCFG_VIDEO_EOF(mirage)
-
-	MCFG_DECO16IC_ADD("deco_custom", mirage_deco16ic_intf)
+	MCFG_DECO16IC_ADD("tilegen1", mirage_deco16ic_tilegen1_intf)
+	MCFG_DEVICE_ADD("spritegen", DECO_SPRITE, 0)
+	decospr_device::set_gfx_region(*device, 2);
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
