@@ -46,6 +46,7 @@ Bucky:
 #include "sound/okim6295.h"
 #include "sound/k054539.h"
 #include "video/konicdev.h"
+#include "machine/k053252.h"
 #include "includes/konamipt.h"
 #include "includes/moo.h"
 
@@ -66,8 +67,8 @@ static const eeprom_interface eeprom_intf =
 
 static READ16_HANDLER( control2_r )
 {
-	moo_state *state = space->machine->driver_data<moo_state>();
-	return state->cur_control2;
+	moo_state *state = space->machine().driver_data<moo_state>();
+	return state->m_cur_control2;
 }
 
 static WRITE16_HANDLER( control2_w )
@@ -80,27 +81,27 @@ static WRITE16_HANDLER( control2_w )
 	/* bit 10 is watchdog */
 	/* bit 11 is enable irq 4 (unconfirmed) */
 
-	moo_state *state = space->machine->driver_data<moo_state>();
-	COMBINE_DATA(&state->cur_control2);
+	moo_state *state = space->machine().driver_data<moo_state>();
+	COMBINE_DATA(&state->m_cur_control2);
 
-	input_port_write(space->machine, "EEPROMOUT", state->cur_control2, 0xff);
+	input_port_write(space->machine(), "EEPROMOUT", state->m_cur_control2, 0xff);
 
 	if (data & 0x100)
-		k053246_set_objcha_line(state->k053246, ASSERT_LINE);
+		k053246_set_objcha_line(state->m_k053246, ASSERT_LINE);
 	else
-		k053246_set_objcha_line(state->k053246, CLEAR_LINE);
+		k053246_set_objcha_line(state->m_k053246, CLEAR_LINE);
 }
 
 
-static void moo_objdma( running_machine *machine, int type )
+static void moo_objdma( running_machine &machine, int type )
 {
-	moo_state *state = machine->driver_data<moo_state>();
+	moo_state *state = machine.driver_data<moo_state>();
 	int num_inactive;
 	UINT16 *src, *dst, zmask;
-	int counter = k053247_get_dy(state->k053246);
+	int counter = k053247_get_dy(state->m_k053246);
 
-	k053247_get_ram(state->k053246, &dst);
-	src = state->spriteram;
+	k053247_get_ram(state->m_k053246, &dst);
+	src = state->m_spriteram;
 	num_inactive = counter = 256;
 
 	zmask = (type) ? 0x00ff : 0xffff;
@@ -121,37 +122,37 @@ static void moo_objdma( running_machine *machine, int type )
 
 static TIMER_CALLBACK( dmaend_callback )
 {
-	moo_state *state = machine->driver_data<moo_state>();
-	if (state->cur_control2 & 0x800)
-		cpu_set_input_line(state->maincpu, 4, HOLD_LINE);
+	moo_state *state = machine.driver_data<moo_state>();
+	if (state->m_cur_control2 & 0x800)
+		device_set_input_line(state->m_maincpu, 4, HOLD_LINE);
 }
 
 static INTERRUPT_GEN( moo_interrupt )
 {
-	moo_state *state = device->machine->driver_data<moo_state>();
-	if (k053246_is_irq_enabled(state->k053246))
+	moo_state *state = device->machine().driver_data<moo_state>();
+	if (k053246_is_irq_enabled(state->m_k053246))
 	{
-		moo_objdma(device->machine, state->game_type);
+		moo_objdma(device->machine(), state->m_game_type);
 
 		// schedule DMA end interrupt (delay shortened to catch up with V-blank)
-        timer_adjust_oneshot(state->dmaend_timer, ATTOTIME_IN_USEC(MOO_DMADELAY), 0);
+        state->m_dmaend_timer->adjust(attotime::from_usec(MOO_DMADELAY));
 	}
 
 	// trigger V-blank interrupt
-	if (state->cur_control2 & 0x20)
-		cpu_set_input_line(device, 5, HOLD_LINE);
+	if (state->m_cur_control2 & 0x20)
+		device_set_input_line(device, 5, HOLD_LINE);
 }
 
 static INTERRUPT_GEN( moobl_interrupt )
 {
-	moo_state *state = device->machine->driver_data<moo_state>();
-	moo_objdma(device->machine, state->game_type);
+	moo_state *state = device->machine().driver_data<moo_state>();
+	moo_objdma(device->machine(), state->m_game_type);
 
 	// schedule DMA end interrupt (delay shortened to catch up with V-blank)
-    timer_adjust_oneshot(state->dmaend_timer, ATTOTIME_IN_USEC(MOO_DMADELAY), 0);
+    state->m_dmaend_timer->adjust(attotime::from_usec(MOO_DMADELAY));
 
 	// trigger V-blank interrupt
-	cpu_set_input_line(device, 5, HOLD_LINE);
+	device_set_input_line(device, 5, HOLD_LINE);
 }
 
 static WRITE16_HANDLER( sound_cmd1_w )
@@ -171,8 +172,8 @@ static WRITE16_HANDLER( sound_cmd2_w )
 
 static WRITE16_HANDLER( sound_irq_w )
 {
-	moo_state *state = space->machine->driver_data<moo_state>();
-	cpu_set_input_line(state->audiocpu, 0, HOLD_LINE);
+	moo_state *state = space->machine().driver_data<moo_state>();
+	device_set_input_line(state->m_audiocpu, 0, HOLD_LINE);
 }
 
 static READ16_HANDLER( sound_status_r )
@@ -182,7 +183,7 @@ static READ16_HANDLER( sound_status_r )
 
 static WRITE8_HANDLER( sound_bankswitch_w )
 {
-	memory_set_bankptr(space->machine, "bank1", space->machine->region("soundcpu")->base() + 0x10000 + (data&0xf)*0x4000);
+	memory_set_bankptr(space->machine(), "bank1", space->machine().region("soundcpu")->base() + 0x10000 + (data&0xf)*0x4000);
 }
 
 
@@ -192,28 +193,28 @@ static WRITE8_HANDLER( sound_bankswitch_w )
 /* of RAM, but they put 0x10000 there. The CPU can access them all. */
 static READ16_HANDLER( K053247_scattered_word_r )
 {
-	moo_state *state = space->machine->driver_data<moo_state>();
+	moo_state *state = space->machine().driver_data<moo_state>();
 
 	if (offset & 0x0078)
-		return state->spriteram[offset];
+		return state->m_spriteram[offset];
 	else
 	{
 		offset = (offset & 0x0007) | ((offset & 0x7f80) >> 4);
-		return k053247_word_r(state->k053246, offset, mem_mask);
+		return k053247_word_r(state->m_k053246, offset, mem_mask);
 	}
 }
 
 static WRITE16_HANDLER( K053247_scattered_word_w )
 {
-	moo_state *state = space->machine->driver_data<moo_state>();
+	moo_state *state = space->machine().driver_data<moo_state>();
 
 	if (offset & 0x0078)
-		COMBINE_DATA(state->spriteram + offset);
+		COMBINE_DATA(state->m_spriteram + offset);
 	else
 	{
 		offset = (offset & 0x0007) | ((offset & 0x7f80) >> 4);
 
-		k053247_word_w(state->k053246, offset, data, mem_mask);
+		k053247_word_w(state->m_k053246, offset, data, mem_mask);
 	}
 }
 
@@ -222,17 +223,17 @@ static WRITE16_HANDLER( K053247_scattered_word_w )
 
 static WRITE16_HANDLER( moo_prot_w )
 {
-	moo_state *state = space->machine->driver_data<moo_state>();
+	moo_state *state = space->machine().driver_data<moo_state>();
 	UINT32 src1, src2, dst, length, a, b, res;
 
-	COMBINE_DATA(&state->protram[offset]);
+	COMBINE_DATA(&state->m_protram[offset]);
 
 	if (offset == 0xc)	// trigger operation
 	{
-		src1 = (state->protram[1] & 0xff) << 16 | state->protram[0];
-		src2 = (state->protram[3] & 0xff) << 16 | state->protram[2];
-		dst = (state->protram[5] & 0xff) << 16 | state->protram[4];
-		length = state->protram[0xf];
+		src1 = (state->m_protram[1] & 0xff) << 16 | state->m_protram[0];
+		src2 = (state->m_protram[3] & 0xff) << 16 | state->m_protram[2];
+		dst = (state->m_protram[5] & 0xff) << 16 | state->m_protram[4];
+		length = state->m_protram[0xf];
 
 		while (length)
 		{
@@ -258,7 +259,7 @@ static WRITE16_DEVICE_HANDLER( moobl_oki_bank_w )
 	downcast<okim6295_device *>(device)->set_bank_base((data & 0x0f) * 0x40000);
 }
 
-static ADDRESS_MAP_START( moo_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( moo_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	AM_RANGE(0x0c0000, 0x0c003f) AM_DEVWRITE("k056832", k056832_word_w)
 	AM_RANGE(0x0c2000, 0x0c2007) AM_DEVWRITE("k053246", k053246_word_w)
@@ -267,7 +268,7 @@ static ADDRESS_MAP_START( moo_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x0ca000, 0x0ca01f) AM_DEVWRITE("k054338", k054338_word_w)		/* K054338 alpha blending engine */
 	AM_RANGE(0x0cc000, 0x0cc01f) AM_DEVWRITE("k053251", k053251_lsb_w)
 	AM_RANGE(0x0ce000, 0x0ce01f) AM_WRITE(moo_prot_w)
-	AM_RANGE(0x0d0000, 0x0d001f) AM_WRITEONLY					/* CCU regs (ignored) */
+	AM_RANGE(0x0d0000, 0x0d001f) AM_DEVREADWRITE8("k053252",k053252_r,k053252_w,0x00ff)					/* CCU regs (ignored) */
 	AM_RANGE(0x0d4000, 0x0d4001) AM_WRITE(sound_irq_w)
 	AM_RANGE(0x0d600c, 0x0d600d) AM_WRITE(sound_cmd1_w)
 	AM_RANGE(0x0d600e, 0x0d600f) AM_WRITE(sound_cmd2_w)
@@ -280,8 +281,8 @@ static ADDRESS_MAP_START( moo_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x0dc002, 0x0dc003) AM_READ_PORT("IN1")
 	AM_RANGE(0x0de000, 0x0de001) AM_READWRITE(control2_r, control2_w)
 	AM_RANGE(0x100000, 0x17ffff) AM_ROM
-	AM_RANGE(0x180000, 0x18ffff) AM_RAM	AM_BASE_MEMBER(moo_state, workram)		/* Work RAM */
-	AM_RANGE(0x190000, 0x19ffff) AM_RAM AM_BASE_MEMBER(moo_state, spriteram)	/* Sprite RAM */
+	AM_RANGE(0x180000, 0x18ffff) AM_RAM	AM_BASE_MEMBER(moo_state, m_workram)		/* Work RAM */
+	AM_RANGE(0x190000, 0x19ffff) AM_RAM AM_BASE_MEMBER(moo_state, m_spriteram)	/* Sprite RAM */
 	AM_RANGE(0x1a0000, 0x1a1fff) AM_DEVREADWRITE("k056832", k056832_ram_word_r, k056832_ram_word_w)	/* Graphic planes */
 	AM_RANGE(0x1a2000, 0x1a3fff) AM_DEVREADWRITE("k056832", k056832_ram_word_r, k056832_ram_word_w)	/* Graphic planes mirror */
 	AM_RANGE(0x1b0000, 0x1b1fff) AM_DEVREAD("k056832", k056832_rom_word_r)	/* Passthrough to tile roms */
@@ -291,12 +292,11 @@ static ADDRESS_MAP_START( moo_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x0c2000, 0x0c2007) AM_DEVREAD("k053246", k053246_reg_word_r)
 	AM_RANGE(0x0ca000, 0x0ca01f) AM_DEVREAD("k054338", k054338_word_r)
 	AM_RANGE(0x0cc000, 0x0cc01f) AM_DEVREAD("k053251", k053251_lsb_r)
-	AM_RANGE(0x0d0000, 0x0d001f) AM_RAM
 	AM_RANGE(0x0d8000, 0x0d8007) AM_DEVREAD("k056832", k056832_b_word_r)
 #endif
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( moobl_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( moobl_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	AM_RANGE(0x0c0000, 0x0c003f) AM_DEVWRITE("k056832", k056832_word_w)
 	AM_RANGE(0x0c2000, 0x0c2007) AM_DEVWRITE("k053246", k053246_word_w)
@@ -314,18 +314,18 @@ static ADDRESS_MAP_START( moobl_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x0dc002, 0x0dc003) AM_READ_PORT("IN1")
 	AM_RANGE(0x0de000, 0x0de001) AM_READWRITE(control2_r, control2_w)
 	AM_RANGE(0x100000, 0x17ffff) AM_ROM
-	AM_RANGE(0x180000, 0x18ffff) AM_RAM AM_BASE_MEMBER(moo_state, workram)		 /* Work RAM */
-	AM_RANGE(0x190000, 0x19ffff) AM_RAM AM_BASE_MEMBER(moo_state, spriteram)	 /* Sprite RAM */
+	AM_RANGE(0x180000, 0x18ffff) AM_RAM AM_BASE_MEMBER(moo_state, m_workram)		 /* Work RAM */
+	AM_RANGE(0x190000, 0x19ffff) AM_RAM AM_BASE_MEMBER(moo_state, m_spriteram)	 /* Sprite RAM */
 	AM_RANGE(0x1a0000, 0x1a1fff) AM_DEVREADWRITE("k056832", k056832_ram_word_r, k056832_ram_word_w) /* Graphic planes */
 	AM_RANGE(0x1a2000, 0x1a3fff) AM_DEVREADWRITE("k056832", k056832_ram_word_r, k056832_ram_word_w)	/* Graphic planes mirror */
 	AM_RANGE(0x1b0000, 0x1b1fff) AM_DEVREAD("k056832", k056832_rom_word_r)	/* Passthrough to tile roms */
 	AM_RANGE(0x1c0000, 0x1c1fff) AM_RAM_WRITE(paletteram16_xrgb_word_be_w) AM_BASE_GENERIC(paletteram)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( bucky_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( bucky_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	AM_RANGE(0x080000, 0x08ffff) AM_RAM
-	AM_RANGE(0x090000, 0x09ffff) AM_RAM AM_BASE_MEMBER(moo_state, spriteram)	/* Sprite RAM */
+	AM_RANGE(0x090000, 0x09ffff) AM_RAM AM_BASE_MEMBER(moo_state, m_spriteram)	/* Sprite RAM */
 	AM_RANGE(0x0a0000, 0x0affff) AM_RAM							/* extra sprite RAM? */
 	AM_RANGE(0x0c0000, 0x0c003f) AM_DEVWRITE("k056832", k056832_word_w)
 	AM_RANGE(0x0c2000, 0x0c2007) AM_DEVWRITE("k053246", k053246_word_w)
@@ -333,7 +333,7 @@ static ADDRESS_MAP_START( bucky_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x0ca000, 0x0ca01f) AM_DEVWRITE("k054338", k054338_word_w)		/* K054338 alpha blending engine */
 	AM_RANGE(0x0cc000, 0x0cc01f) AM_DEVWRITE("k053251", k053251_lsb_w)
 	AM_RANGE(0x0ce000, 0x0ce01f) AM_WRITE(moo_prot_w)
-	AM_RANGE(0x0d0000, 0x0d001f) AM_WRITEONLY					/* CCU regs (ignored) */
+	AM_RANGE(0x0d0000, 0x0d001f) AM_DEVREADWRITE8("k053252",k053252_r,k053252_w,0x00ff)					/* CCU regs (ignored) */
 	AM_RANGE(0x0d2000, 0x0d20ff) AM_DEVREADWRITE("k054000", k054000_lsb_r, k054000_lsb_w)
 	AM_RANGE(0x0d4000, 0x0d4001) AM_WRITE(sound_irq_w)
 	AM_RANGE(0x0d600c, 0x0d600d) AM_WRITE(sound_cmd1_w)
@@ -357,12 +357,11 @@ static ADDRESS_MAP_START( bucky_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x0c2000, 0x0c2007) AM_DEVREAD("k053246", k053246_reg_word_r)
 	AM_RANGE(0x0ca000, 0x0ca01f) AM_DEVREAD("k054338", k054338_word_r)
 	AM_RANGE(0x0cc000, 0x0cc01f) AM_DEVREAD("k053251", k053251_lsb_r)
-	AM_RANGE(0x0d0000, 0x0d001f) AM_RAM
 	AM_RANGE(0x0d8000, 0x0d8007) AM_DEVREAD("k056832", k056832_b_word_r)
 #endif
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0xbfff) AM_ROMBANK("bank1")
 	AM_RANGE(0xc000, 0xdfff) AM_RAM
@@ -386,25 +385,25 @@ static INPUT_PORTS_START( moo )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE4 )
 
 	PORT_START("IN1")
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_READ_LINE_DEVICE("eeprom", eeprom_read_bit)
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_READ_LINE_DEVICE_MEMBER("eeprom", eeprom_device, read_bit)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SPECIAL )	/* EEPROM ready (always 1) */
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_SERVICE_NO_TOGGLE(0x08, IP_ACTIVE_LOW)
-	PORT_DIPNAME( 0x10, 0x00, "Sound Output")
+	PORT_DIPNAME( 0x10, 0x00, "Sound Output")		PORT_DIPLOCATION("SW1:1")
 	PORT_DIPSETTING(    0x10, DEF_STR( Mono ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Stereo ) )
-	PORT_DIPNAME( 0x20, 0x20, "Coin Mechanism")
+	PORT_DIPNAME( 0x20, 0x20, "Coin Mechanism") 		PORT_DIPLOCATION("SW1:2")
 	PORT_DIPSETTING(    0x20, "Common")
 	PORT_DIPSETTING(    0x00, "Independent")
-	PORT_DIPNAME( 0xc0, 0x80, "Number of Players")
+	PORT_DIPNAME( 0xc0, 0x80, "Number of Players")		PORT_DIPLOCATION("SW1:3,4")
 	PORT_DIPSETTING(    0xc0, "2")
 	PORT_DIPSETTING(    0x40, "3")
 	PORT_DIPSETTING(    0x80, "4")
 
 	PORT_START( "EEPROMOUT" )
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_write_bit)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_set_cs_line)
-	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE("eeprom", eeprom_set_clock_line)
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, write_bit)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, set_cs_line)
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_OUTPUT ) PORT_WRITE_LINE_DEVICE_MEMBER("eeprom", eeprom_device, set_clock_line)
 
 	PORT_START("P1_P3")
 	KONAMI16_LSB( 1, IPT_UNKNOWN, IPT_START1 )
@@ -431,43 +430,43 @@ INPUT_PORTS_END
 
 static MACHINE_START( moo )
 {
-	moo_state *state = machine->driver_data<moo_state>();
+	moo_state *state = machine.driver_data<moo_state>();
 
-	state->maincpu = machine->device("maincpu");
-	state->audiocpu = machine->device("soundcpu");
-	state->k054539 = machine->device("k054539");
-	state->k053246 = machine->device("k053246");
-	state->k053251 = machine->device("k053251");
-	state->k056832 = machine->device("k056832");
-	state->k054338 = machine->device("k054338");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_audiocpu = machine.device("soundcpu");
+	state->m_k054539 = machine.device("k054539");
+	state->m_k053246 = machine.device("k053246");
+	state->m_k053251 = machine.device("k053251");
+	state->m_k056832 = machine.device("k056832");
+	state->m_k054338 = machine.device("k054338");
 
-	state_save_register_global(machine, state->cur_control2);
-	state_save_register_global(machine, state->alpha_enabled);
-	state_save_register_global(machine, state->sprite_colorbase);
-	state_save_register_global_array(machine, state->layer_colorbase);
-	state_save_register_global_array(machine, state->layerpri);
-	state_save_register_global_array(machine, state->protram);
+	state->save_item(NAME(state->m_cur_control2));
+	state->save_item(NAME(state->m_alpha_enabled));
+	state->save_item(NAME(state->m_sprite_colorbase));
+	state->save_item(NAME(state->m_layer_colorbase));
+	state->save_item(NAME(state->m_layerpri));
+	state->save_item(NAME(state->m_protram));
 
-    state->dmaend_timer = timer_alloc(machine, dmaend_callback, 0);
+    state->m_dmaend_timer = machine.scheduler().timer_alloc(FUNC(dmaend_callback));
 }
 
 static MACHINE_RESET( moo )
 {
-	moo_state *state = machine->driver_data<moo_state>();
+	moo_state *state = machine.driver_data<moo_state>();
 	int i;
 
 	for (i = 0; i < 16; i++)
-		state->protram[i] = 0;
+		state->m_protram[i] = 0;
 
 	for (i = 0; i < 4; i++)
-		state->layer_colorbase[i] = 0;
+		state->m_layer_colorbase[i] = 0;
 
 	for (i = 0; i < 3; i++)
-		state->layerpri[i] = 0;
+		state->m_layerpri[i] = 0;
 
-	state->cur_control2 = 0;
-	state->alpha_enabled = 0;
-	state->sprite_colorbase = 0;
+	state->m_cur_control2 = 0;
+	state->m_alpha_enabled = 0;
+	state->m_sprite_colorbase = 0;
 }
 
 static const k056832_interface moo_k056832_intf =
@@ -506,6 +505,15 @@ static const k054338_interface moo_k054338_intf =
 	"none"
 };
 
+static const k053252_interface moo_k053252_intf =
+{
+	"screen",
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_NULL,
+	40, 16
+};
 
 static MACHINE_CONFIG_START( moo, moo_state )
 
@@ -522,6 +530,8 @@ static MACHINE_CONFIG_START( moo, moo_state )
 
 	MCFG_EEPROM_ADD("eeprom", eeprom_intf)
 
+	MCFG_K053252_ADD("k053252", 16000000/2, moo_k053252_intf)
+
 	/* video hardware */
 	MCFG_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS | VIDEO_HAS_HIGHLIGHTS | VIDEO_UPDATE_AFTER_VBLANK)
 
@@ -531,11 +541,11 @@ static MACHINE_CONFIG_START( moo, moo_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(40, 40+384-1, 16, 16+224-1)
+	MCFG_SCREEN_UPDATE(moo)
 
 	MCFG_PALETTE_LENGTH(2048)
 
 	MCFG_VIDEO_START(moo)
-	MCFG_VIDEO_UPDATE(moo)
 
 	MCFG_K053247_ADD("k053246", moo_k053247_intf)
 	MCFG_K056832_ADD("k056832", moo_k056832_intf)
@@ -575,11 +585,11 @@ static MACHINE_CONFIG_START( moobl, moo_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(40, 40+384-1, 16, 16+224-1)
+	MCFG_SCREEN_UPDATE(moo)
 
 	MCFG_PALETTE_LENGTH(2048)
 
 	MCFG_VIDEO_START(moo)
-	MCFG_VIDEO_UPDATE(moo)
 
 	MCFG_K053247_ADD("k053246", moo_k053247_intf)
 	MCFG_K056832_ADD("k056832", moo_k056832_intf)
@@ -610,11 +620,11 @@ MACHINE_CONFIG_END
 
 
 
-ROM_START( moo ) /* Version EA - Euro Ver A */
+ROM_START( moomesa ) /* Version EA - Euro Ver A */
 	ROM_REGION( 0x180000, "maincpu", 0 )
 	/* main program */
-	ROM_LOAD16_BYTE( "151b01",    0x000000,  0x40000, CRC(fb2fa298) SHA1(f03b24681a2b329ba797fd2780ac9a3cf862ebcb) )
-	ROM_LOAD16_BYTE( "151b02.ea", 0x000001,  0x40000, CRC(37b30c01) SHA1(cb91739097a4a36f8f8d92998d822ffc851e1279) )
+	ROM_LOAD16_BYTE( "151_b01",    0x000000,  0x40000, CRC(fb2fa298) SHA1(f03b24681a2b329ba797fd2780ac9a3cf862ebcb) )
+	ROM_LOAD16_BYTE( "151_ea_b02", 0x000001,  0x40000, CRC(37b30c01) SHA1(cb91739097a4a36f8f8d92998d822ffc851e1279) )
 
 	/* data */
 	ROM_LOAD16_BYTE( "151a03", 0x100000,  0x40000, CRC(c896d3ea) SHA1(ea83c63e2c3dbc4f1e1d49f1852a78ffc1f0ea4b) )
@@ -645,11 +655,11 @@ ROM_START( moo ) /* Version EA - Euro Ver A */
 	ROM_LOAD( "moo.nv", 0x0000, 0x080, CRC(7bd904a8) SHA1(8747c5c62d1832e290be8ace73c61b1f228c0bec) )
 ROM_END
 
-ROM_START( mooua ) /* Version UA - USA Ver A */
+ROM_START( moomesau ) /* Version UA - USA Ver A */
 	ROM_REGION( 0x180000, "maincpu", 0 )
 	/* main program */
-	ROM_LOAD16_BYTE( "151b01",    0x000000,  0x40000, CRC(fb2fa298) SHA1(f03b24681a2b329ba797fd2780ac9a3cf862ebcb) )
-	ROM_LOAD16_BYTE( "151b02.ua", 0x000001,  0x40000, CRC(3d9f4d59) SHA1(db47044bd4935fce94ec659242c9819c30eb6d0f) )
+	ROM_LOAD16_BYTE( "151_c01",    0x000000,  0x40000, CRC(10555732) SHA1(b67cb756c250ddd6f3291683b3f3449e13a2ee83) ) /* Version UAC? */
+	ROM_LOAD16_BYTE( "151_ua_c02", 0x000001,  0x40000, CRC(52ae87b0) SHA1(552d41a2ddd040f92c6a3cfdc07f9d6e751ac9c1) )
 
 	/* data */
 	ROM_LOAD16_BYTE( "151a03", 0x100000,  0x40000, CRC(c896d3ea) SHA1(ea83c63e2c3dbc4f1e1d49f1852a78ffc1f0ea4b) )
@@ -680,11 +690,46 @@ ROM_START( mooua ) /* Version UA - USA Ver A */
 	ROM_LOAD( "moou.nv", 0x0000, 0x080, CRC(a5cb137a) SHA1(119df859d6b5c366481305b1433eea0deadc3fa9) )
 ROM_END
 
-ROM_START( mooaa ) /* Version AA - Asia Ver A */
+ROM_START( moomesaua ) /* Version UA - USA Ver A */
 	ROM_REGION( 0x180000, "maincpu", 0 )
 	/* main program */
-	ROM_LOAD16_BYTE( "151b01",    0x000000,  0x40000, CRC(fb2fa298) SHA1(f03b24681a2b329ba797fd2780ac9a3cf862ebcb) )
-	ROM_LOAD16_BYTE( "151b02.aa", 0x000001,  0x40000, CRC(2162d593) SHA1(a6cfe4a57b3f22b2aa0f04f91acefe3b7bea9e76) )
+	ROM_LOAD16_BYTE( "151_b01",    0x000000,  0x40000, CRC(fb2fa298) SHA1(f03b24681a2b329ba797fd2780ac9a3cf862ebcb) ) /* Version UAB? */
+	ROM_LOAD16_BYTE( "151_ua_b02", 0x000001,  0x40000, CRC(3d9f4d59) SHA1(db47044bd4935fce94ec659242c9819c30eb6d0f) )
+
+	/* data */
+	ROM_LOAD16_BYTE( "151a03", 0x100000,  0x40000, CRC(c896d3ea) SHA1(ea83c63e2c3dbc4f1e1d49f1852a78ffc1f0ea4b) )
+	ROM_LOAD16_BYTE( "151a04", 0x100001,  0x40000, CRC(3b24706a) SHA1(c2a77944284e35ff57f0774fa7b67e53d3b63e1f) )
+
+	ROM_REGION( 0x050000, "soundcpu", 0 )
+	/* Z80 sound program */
+	ROM_LOAD( "151a07", 0x000000, 0x040000, CRC(cde247fc) SHA1(cdee0228db55d53ae43d7cd2d9001dadd20c2c61) )
+	ROM_RELOAD(         0x010000, 0x040000 )
+
+	ROM_REGION( 0x200000, "gfx1", 0 )
+	/* tilemaps */
+	ROM_LOAD( "151a05", 0x000000, 0x100000, CRC(bc616249) SHA1(58c1f1a03ce9bead8f79d12ce4b2d342432b24b5) )
+	ROM_LOAD( "151a06", 0x100000, 0x100000, CRC(38dbcac1) SHA1(c357779733921695b20ac586db5b475f5b2b8f4c) )
+
+	ROM_REGION( 0x800000, "gfx2", 0 )
+	/* sprites */
+	ROM_LOAD( "151a10", 0x000000, 0x200000, CRC(376c64f1) SHA1(eb69c5a27f9795e28f04a503955132f0a9e4de12) )
+	ROM_LOAD( "151a11", 0x200000, 0x200000, CRC(e7f49225) SHA1(1255b214f29b6507540dad5892c60a7ae2aafc5c) )
+	ROM_LOAD( "151a12", 0x400000, 0x200000, CRC(4978555f) SHA1(d9871f21d0c8a512b408e137e2e80e9392c2bf6f) )
+	ROM_LOAD( "151a13", 0x600000, 0x200000, CRC(4771f525) SHA1(218d86b6230919b5db0304dac00513eb6b27ba9a) )
+
+	ROM_REGION( 0x200000, "k054539", 0 )
+	/* K054539 samples */
+	ROM_LOAD( "151a08", 0x000000, 0x200000, CRC(962251d7) SHA1(32dccf515d2ca8eeffb45cada3dcc60089991b77) )
+
+	ROM_REGION( 0x80, "eeprom", 0 ) // default eeprom to prevent game booting upside down with error
+	ROM_LOAD( "moou.nv", 0x0000, 0x080, CRC(a5cb137a) SHA1(119df859d6b5c366481305b1433eea0deadc3fa9) )
+ROM_END
+
+ROM_START( moomesaa ) /* Version AA - Asia Ver A */
+	ROM_REGION( 0x180000, "maincpu", 0 )
+	/* main program */
+	ROM_LOAD16_BYTE( "151_b01",    0x000000,  0x40000, CRC(fb2fa298) SHA1(f03b24681a2b329ba797fd2780ac9a3cf862ebcb) )
+	ROM_LOAD16_BYTE( "151_ua_b02", 0x000001,  0x40000, CRC(2162d593) SHA1(a6cfe4a57b3f22b2aa0f04f91acefe3b7bea9e76) )
 
 	/* data */
 	ROM_LOAD16_BYTE( "151a03", 0x100000,  0x40000, CRC(c896d3ea) SHA1(ea83c63e2c3dbc4f1e1d49f1852a78ffc1f0ea4b) )
@@ -824,7 +869,7 @@ ROM_START( buckyaa )
 ROM_END
 
 
-ROM_START( moobl )
+ROM_START( moomesabl )
 	ROM_REGION( 0x180000, "maincpu", 0 )
 	ROM_LOAD16_WORD_SWAP( "moo03.rom", 0x000000, 0x80000, CRC(fed6a1cb) SHA1(be58e266973930d643b5e15dcc974a82e1a3ae35) )
 	ROM_LOAD16_WORD_SWAP( "moo04.rom", 0x100000, 0x80000, CRC(ec45892a) SHA1(594330cbbfbca87e61ddf519e565018b6eaf5a20) )
@@ -880,15 +925,16 @@ ROM_END
 
 static DRIVER_INIT( moo )
 {
-	moo_state *state = machine->driver_data<moo_state>();
-	state->game_type = (!strcmp(machine->gamedrv->name, "bucky") || !strcmp(machine->gamedrv->name, "buckyua"));
+	moo_state *state = machine.driver_data<moo_state>();
+	state->m_game_type = (!strcmp(machine.system().name, "bucky") || !strcmp(machine.system().name, "buckyua"));
 }
 
 
-GAME( 1992, moo,     0,       moo,     moo,     moo,      ROT0, "Konami", "Wild West C.O.W.-Boys of Moo Mesa (ver EA)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
-GAME( 1992, mooua,   moo,     moo,     moo,     moo,      ROT0, "Konami", "Wild West C.O.W.-Boys of Moo Mesa (ver UA)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
-GAME( 1992, mooaa,   moo,     moo,     moo,     moo,      ROT0, "Konami", "Wild West C.O.W.-Boys of Moo Mesa (ver AA)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
-GAME( 1992, moobl,   moo,     moobl,   moo,     moo,      ROT0, "bootleg", "Wild West C.O.W.-Boys of Moo Mesa (bootleg ver AA)", GAME_NOT_WORKING | GAME_SUPPORTS_SAVE )
-GAME( 1992, bucky,   0,       bucky,   bucky,   moo,      ROT0, "Konami", "Bucky O'Hare (ver EA)", GAME_SUPPORTS_SAVE )
-GAME( 1992, buckyua, bucky,   bucky,   bucky,   moo,      ROT0, "Konami", "Bucky O'Hare (ver UA)", GAME_SUPPORTS_SAVE )
-GAME( 1992, buckyaa, bucky,   bucky,   bucky,   moo,      ROT0, "Konami", "Bucky O'Hare (ver AA)", GAME_SUPPORTS_SAVE )
+GAME( 1992, moomesa,  0,       moo,     moo,     moo,      ROT0, "Konami", "Wild West C.O.W.-Boys of Moo Mesa (ver EA)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
+GAME( 1992, moomesau, moomesa, moo,     moo,     moo,      ROT0, "Konami", "Wild West C.O.W.-Boys of Moo Mesa (ver UA, set 1)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
+GAME( 1992, moomesaua,moomesa, moo,     moo,     moo,      ROT0, "Konami", "Wild West C.O.W.-Boys of Moo Mesa (ver UA, set 2)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
+GAME( 1992, moomesaa, moomesa, moo,     moo,     moo,      ROT0, "Konami", "Wild West C.O.W.-Boys of Moo Mesa (ver AA)", GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
+GAME( 1992, moomesabl,moomesa, moobl,   moo,     moo,      ROT0, "bootleg", "Wild West C.O.W.-Boys of Moo Mesa (bootleg ver AA)", GAME_NOT_WORKING | GAME_SUPPORTS_SAVE )
+GAME( 1992, bucky,    0,       bucky,   bucky,   moo,      ROT0, "Konami", "Bucky O'Hare (ver EA)", GAME_SUPPORTS_SAVE )
+GAME( 1992, buckyua,  bucky,   bucky,   bucky,   moo,      ROT0, "Konami", "Bucky O'Hare (ver UA)", GAME_SUPPORTS_SAVE )
+GAME( 1992, buckyaa,  bucky,   bucky,   bucky,   moo,      ROT0, "Konami", "Bucky O'Hare (ver AA)", GAME_SUPPORTS_SAVE )
