@@ -37,7 +37,16 @@ Dumped: 06/04/2009 f205v
 #include "cpu/z80/z80.h"
 #include "sound/dac.h"
 
-static UINT8* murogmbl_video;
+
+class murogmbl_state : public driver_device
+{
+public:
+	murogmbl_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8* m_video;
+};
+
 
 static PALETTE_INIT( murogmbl )
 {
@@ -64,11 +73,11 @@ static PALETTE_INIT( murogmbl )
 	}
 }
 
-static ADDRESS_MAP_START( murogmbl_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( murogmbl_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fFf) AM_ROM
 	AM_RANGE(0x4000, 0x43ff) AM_RAM
 	AM_RANGE(0x4800, 0x4bff) AM_RAM
-	AM_RANGE(0x5800, 0x5bff) AM_RAM AM_BASE(&murogmbl_video)
+	AM_RANGE(0x5800, 0x5bff) AM_RAM AM_BASE_MEMBER(murogmbl_state, m_video)
 	AM_RANGE(0x5c00, 0x5fff) AM_RAM
 	AM_RANGE(0x6000, 0x6000) AM_READ_PORT("IN0")
 	AM_RANGE(0x6800, 0x6800) AM_READ_PORT("DSW")
@@ -81,9 +90,10 @@ static VIDEO_START(murogmbl)
 
 }
 
-static VIDEO_UPDATE(murogmbl)
+static SCREEN_UPDATE(murogmbl)
 {
-	const gfx_element *gfx = screen->machine->gfx[0];
+	murogmbl_state *state = screen->machine().driver_data<murogmbl_state>();
+	const gfx_element *gfx = screen->machine().gfx[0];
 	int count = 0;
 
 	int y, x;
@@ -92,7 +102,7 @@ static VIDEO_UPDATE(murogmbl)
 	{
 		for (x = 0; x < 32; x++)
 		{
-			int tile = murogmbl_video[count];
+			int tile = state->m_video[count];
 			drawgfx_opaque(bitmap, cliprect, gfx, tile, 0, 0, 0, x * 8, y * 8);
 
 			count++;
@@ -166,7 +176,7 @@ static GFXDECODE_START( murogmbl )
 	GFXDECODE_ENTRY( "gfx1", 0, layout8x8x2,  0x0, 1 )
 GFXDECODE_END
 
-static MACHINE_CONFIG_START( murogmbl, driver_device )
+static MACHINE_CONFIG_START( murogmbl, murogmbl_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80, 1000000) /* Z80? */
 	MCFG_CPU_PROGRAM_MAP(murogmbl_map)
@@ -182,11 +192,11 @@ static MACHINE_CONFIG_START( murogmbl, driver_device )
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 32*8-1)
+	MCFG_SCREEN_UPDATE(murogmbl)
 
 	MCFG_PALETTE_LENGTH(0x100)
 
 	MCFG_VIDEO_START(murogmbl)
-	MCFG_VIDEO_UPDATE(murogmbl)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 	MCFG_SOUND_ADD("dac1", DAC, 0)
