@@ -112,14 +112,15 @@ TODO:
 
 static READ8_HANDLER( in0_port_r )
 {
-	int in0 = input_port_read(space->machine, "IN0");
+	naughtyb_state *state = space->machine().driver_data<naughtyb_state>();
+	int in0 = input_port_read(space->machine(), "IN0");
 
-	if ( naughtyb_cocktail )
+	if ( state->m_cocktail )
 	{
 		// cabinet == cocktail -AND- handling player 2
 
 		in0 = ( in0 & 0x03 ) |				// start buttons
-			  ( input_port_read(space->machine, "IN0_COCKTAIL") & 0xFC );	// cocktail inputs
+			  ( input_port_read(space->machine(), "IN0_COCKTAIL") & 0xFC );	// cocktail inputs
 	}
 
 	return in0;
@@ -129,8 +130,8 @@ static READ8_HANDLER( dsw0_port_r )
 {
 	// vblank replaces the cabinet dip
 
-	return ( ( input_port_read(space->machine, "DSW0") & 0x7F ) |		// dsw0
-			 ( input_port_read(space->machine, "FAKE") & 0x80 ) );		// vblank
+	return ( ( input_port_read(space->machine(), "DSW0") & 0x7F ) |		// dsw0
+			 ( input_port_read(space->machine(), "FAKE") & 0x80 ) );		// vblank
 }
 
 /* Pop Flamer
@@ -140,36 +141,33 @@ static READ8_HANDLER( dsw0_port_r )
    If the values all match then it will jump to 0x0011 instead of 0x0009 (refresh instead of reset)
    Paul Priest: tourniquet@mameworld.net */
 
-//static int popflame_prot_count = 0;
-static UINT8 popflame_prot_seed;
-static int r_index;
 
 static READ8_HANDLER( popflame_protection_r ) /* Not used by bootleg/hack */
 {
+	naughtyb_state *state = space->machine().driver_data<naughtyb_state>();
 	static const int seed00[4] = { 0x78, 0x68, 0x48, 0x38|0x80 };
 	static const int seed10[4] = { 0x68, 0x60, 0x68, 0x60|0x80 };
-	static int count;
-	static UINT8 seedxx;
+	UINT8 seedxx;
 
-	seedxx = (r_index < 0x89) ? 1 : 0;
+	seedxx = (state->m_r_index < 0x89) ? 1 : 0;
 
-	count = (count + 1) % 4;
-	if(popflame_prot_seed == 0x10)
-		return seed10[count] | seedxx;
+	state->m_prot_count = (state->m_prot_count + 1) % 4;
+	if(state->m_popflame_prot_seed == 0x10)
+		return seed10[state->m_prot_count] | seedxx;
 	else
-		return seed00[count] | seedxx;
+		return seed00[state->m_prot_count] | seedxx;
 
 #if 0
-	if ( cpu_get_pc(space->cpu) == (0x26F2 + 0x03) )
+	if ( cpu_get_pc(&space->device()) == (0x26F2 + 0x03) )
 	{
 		popflame_prot_count = 0;
 		return 0x01;
 	} /* Must not carry when rotated left */
 
-	if ( cpu_get_pc(space->cpu) == (0x26F9 + 0x03) )
+	if ( cpu_get_pc(&space->device()) == (0x26F9 + 0x03) )
 		return 0x80; /* Must carry when rotated left */
 
-	if ( cpu_get_pc(space->cpu) == (0x270F + 0x03) )
+	if ( cpu_get_pc(&space->device()) == (0x270F + 0x03) )
 	{
 		switch( popflame_prot_count++ )
 		{
@@ -179,13 +177,14 @@ static READ8_HANDLER( popflame_protection_r ) /* Not used by bootleg/hack */
 			case 3: return 0x38; /* x011 1xxx, matches 0x07 at $2693, stored in $400D */
 		}
 	}
-	logerror("CPU #0 PC %06x: unmapped protection read\n", cpu_get_pc(space->cpu));
+	logerror("CPU #0 PC %06x: unmapped protection read\n", cpu_get_pc(&space->device()));
 	return 0x00;
 #endif
 }
 
 static WRITE8_HANDLER( popflame_protection_w )
 {
+	naughtyb_state *state = space->machine().driver_data<naughtyb_state>();
 	/*
     Alternative protection check is executed at the end of stage 3, it seems some kind of pseudo "EEPROM" device:
 2720: 21 98 B0      ld   hl,$B098
@@ -236,37 +235,37 @@ static WRITE8_HANDLER( popflame_protection_w )
     ---- --x- puts a bit into the write buffer
     ---- ---x reset write index buffer
     */
-	if(data & 1 && ((popflame_prot_seed & 1) == 0)) //Note: we use the write buffer index
-		r_index = 0;
-	if(data & 8 && ((popflame_prot_seed & 8) == 0))
-		r_index++;
+	if(data & 1 && ((state->m_popflame_prot_seed & 1) == 0)) //Note: we use the write buffer index
+		state->m_r_index = 0;
+	if(data & 8 && ((state->m_popflame_prot_seed & 8) == 0))
+		state->m_r_index++;
 
-	popflame_prot_seed = data & 0x10;
+	state->m_popflame_prot_seed = data & 0x10;
 
 }
 
 
 
-static ADDRESS_MAP_START( naughtyb_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( naughtyb_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x7fff) AM_RAM
-	AM_RANGE(0x8000, 0x87ff) AM_RAM AM_BASE_MEMBER(naughtyb_state, videoram)
-	AM_RANGE(0x8800, 0x8fff) AM_RAM AM_BASE(&naughtyb_videoram2)
+	AM_RANGE(0x8000, 0x87ff) AM_RAM AM_BASE_MEMBER(naughtyb_state, m_videoram)
+	AM_RANGE(0x8800, 0x8fff) AM_RAM AM_BASE_MEMBER(naughtyb_state, m_videoram2)
 	AM_RANGE(0x9000, 0x97ff) AM_RAM_WRITE(naughtyb_videoreg_w)
-	AM_RANGE(0x9800, 0x9fff) AM_RAM AM_BASE(&naughtyb_scrollreg)
+	AM_RANGE(0x9800, 0x9fff) AM_RAM AM_BASE_MEMBER(naughtyb_state, m_scrollreg)
 	AM_RANGE(0xa000, 0xa7ff) AM_DEVWRITE("cust", pleiads_sound_control_a_w)
 	AM_RANGE(0xa800, 0xafff) AM_DEVWRITE("cust", pleiads_sound_control_b_w)
 	AM_RANGE(0xb000, 0xb7ff) AM_READ(in0_port_r)	// IN0
 	AM_RANGE(0xb800, 0xbfff) AM_READ(dsw0_port_r)	// DSW0
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( popflame_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( popflame_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x7fff) AM_RAM
-	AM_RANGE(0x8000, 0x87ff) AM_RAM AM_BASE_MEMBER(naughtyb_state, videoram)
-	AM_RANGE(0x8800, 0x8fff) AM_RAM AM_BASE(&naughtyb_videoram2)
+	AM_RANGE(0x8000, 0x87ff) AM_RAM AM_BASE_MEMBER(naughtyb_state, m_videoram)
+	AM_RANGE(0x8800, 0x8fff) AM_RAM AM_BASE_MEMBER(naughtyb_state, m_videoram2)
 	AM_RANGE(0x9000, 0x97ff) AM_RAM_WRITE(popflame_videoreg_w)
-	AM_RANGE(0x9800, 0x9fff) AM_RAM AM_BASE(&naughtyb_scrollreg)
+	AM_RANGE(0x9800, 0x9fff) AM_RAM AM_BASE_MEMBER(naughtyb_state, m_scrollreg)
 	AM_RANGE(0xa000, 0xa7ff) AM_DEVWRITE("cust", pleiads_sound_control_a_w)
 	AM_RANGE(0xa800, 0xafff) AM_DEVWRITE("cust", pleiads_sound_control_b_w)
 	AM_RANGE(0xb000, 0xb7ff) AM_READ(in0_port_r)	// IN0
@@ -283,10 +282,9 @@ ADDRESS_MAP_END
 
 ***************************************************************************/
 
-static INTERRUPT_GEN( naughtyb_interrupt )
+static INPUT_CHANGED( coin_inserted )
 {
-	if (input_port_read(device->machine, "FAKE") & 1)
-		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
+	cputag_set_input_line(field.machine(), "maincpu", INPUT_LINE_NMI, newval ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static INPUT_PORTS_START( naughtyb )
@@ -334,12 +332,7 @@ static INPUT_PORTS_START( naughtyb )
 	PORT_DIPSETTING(    0x80, DEF_STR( Cocktail ) )
 
 	PORT_START( "FAKE" )
-	// The coin slots are not memory mapped.
-	// This fake input port is used by the interrupt
-	// handler to be notified of coin insertions. We use IMPULSE to
-	// trigger exactly one interrupt, without having to check when the
-	// user releases the key.
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin_inserted, 0)
 	// when reading DSW0, bit 7 doesn't read cabinet, but vblank
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_VBLANK )
 INPUT_PORTS_END
@@ -387,12 +380,7 @@ static INPUT_PORTS_START( trvmstr )
 	PORT_DIPSETTING(    0x80, DEF_STR( Cocktail ) )
 
 	PORT_START( "FAKE" )
-	// The coin slots are not memory mapped.
-	// This fake input port is used by the interrupt
-	// handler to be notified of coin insertions. We use IMPULSE to
-	// trigger exactly one interrupt, without having to check when the
-	// user releases the key.
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin_inserted, 0)
 	// when reading DSW0, bit 7 doesn't read cabinet, but vblank
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_VBLANK )
 INPUT_PORTS_END
@@ -439,7 +427,6 @@ static MACHINE_CONFIG_START( naughtyb, naughtyb_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80, CLOCK_XTAL / 4) /* 12 MHz clock, divided by 4. CPU is a Z80A */
 	MCFG_CPU_PROGRAM_MAP(naughtyb_map)
-	MCFG_CPU_VBLANK_INT("screen", naughtyb_interrupt)
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
@@ -448,13 +435,13 @@ static MACHINE_CONFIG_START( naughtyb, naughtyb_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(36*8, 28*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 36*8-1, 0*8, 28*8-1)
+	MCFG_SCREEN_UPDATE(naughtyb)
 
 	MCFG_GFXDECODE(naughtyb)
 	MCFG_PALETTE_LENGTH(256)
 
 	MCFG_PALETTE_INIT(naughtyb)
 	MCFG_VIDEO_START(naughtyb)
-	MCFG_VIDEO_UPDATE(naughtyb)
 
 	/* sound hardware */
 	/* uses the TMS3615NS for sound */
@@ -475,7 +462,6 @@ static MACHINE_CONFIG_START( popflame, naughtyb_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80, CLOCK_XTAL / 4) /* 12 MHz clock, divided by 4. CPU is a Z80A */
 	MCFG_CPU_PROGRAM_MAP(popflame_map)
-	MCFG_CPU_VBLANK_INT("screen", naughtyb_interrupt)
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
@@ -484,13 +470,13 @@ static MACHINE_CONFIG_START( popflame, naughtyb_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(36*8, 28*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 36*8-1, 0*8, 28*8-1)
+	MCFG_SCREEN_UPDATE(naughtyb)
 
 	MCFG_GFXDECODE(naughtyb)
 	MCFG_PALETTE_LENGTH(256)
 
 	MCFG_PALETTE_INIT(naughtyb)
 	MCFG_VIDEO_START(naughtyb)
-	MCFG_VIDEO_UPDATE(naughtyb)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -855,31 +841,32 @@ ROM_END
 static DRIVER_INIT( popflame )
 {
 	/* install a handler to catch protection checks */
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x9000, 0x9000, 0, 0, popflame_protection_r);
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x9090, 0x9090, 0, 0, popflame_protection_r);
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x9000, 0x9000, FUNC(popflame_protection_r));
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x9090, 0x9090, FUNC(popflame_protection_r));
 
-	memory_install_write8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xb000, 0xb0ff, 0, 0, popflame_protection_w);
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0xb000, 0xb0ff, FUNC(popflame_protection_w));
 }
 
-static int question_offset = 0;
 
 static READ8_HANDLER( trvmstr_questions_r )
 {
-	return space->machine->region("user1")->base()[question_offset];
+	naughtyb_state *state = space->machine().driver_data<naughtyb_state>();
+	return space->machine().region("user1")->base()[state->m_question_offset];
 }
 
 static WRITE8_HANDLER( trvmstr_questions_w )
 {
+	naughtyb_state *state = space->machine().driver_data<naughtyb_state>();
 	switch(offset)
 	{
 	case 0:
-		question_offset = (question_offset & 0xffff00) | data;
+		state->m_question_offset = (state->m_question_offset & 0xffff00) | data;
 		break;
 	case 1:
-		question_offset = (question_offset & 0xff00ff) | (data << 8);
+		state->m_question_offset = (state->m_question_offset & 0xff00ff) | (data << 8);
 		break;
 	case 2:
-		question_offset = (question_offset & 0x00ffff) | (data << 16);
+		state->m_question_offset = (state->m_question_offset & 0x00ffff) | (data << 16);
 		break;
 	}
 }
@@ -887,7 +874,7 @@ static WRITE8_HANDLER( trvmstr_questions_w )
 static DRIVER_INIT( trvmstr )
 {
 	/* install questions' handlers  */
-	memory_install_readwrite8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xc000, 0xc002, 0, 0, trvmstr_questions_r, trvmstr_questions_w);
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_readwrite_handler(0xc000, 0xc002, FUNC(trvmstr_questions_r), FUNC(trvmstr_questions_w));
 }
 
 
