@@ -30,27 +30,28 @@ TODO:
 class nightgal_state : public driver_device
 {
 public:
-	nightgal_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
-
-	/* memory pointers */
-	UINT8 *    blit_buffer;
+	nightgal_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* video-related */
-	UINT8 blit_raw_data[3];
-	UINT8 true_blit[7];
-	UINT8 pen_data[0x10];
-	UINT8 pen_raw_data[0x10];
+	UINT8 m_blit_raw_data[3];
+	UINT8 m_true_blit[7];
+	UINT8 m_pen_data[0x10];
+	UINT8 m_pen_raw_data[0x10];
 
 	/* misc */
-	UINT8 nsc_latch, z80_latch;
-	UINT8 mux_data;
+	UINT8 m_nsc_latch;
+	UINT8 m_z80_latch;
+	UINT8 m_mux_data;
 
-	UINT8 *comms_ram;
+	UINT8 *m_comms_ram;
 
 	/* devices */
-	device_t *maincpu;
-	device_t *subcpu;
+	device_t *m_maincpu;
+	device_t *m_subcpu;
+
+	/* memory */
+	UINT8      m_blit_buffer[256*256];
 };
 
 
@@ -62,27 +63,26 @@ static READ8_HANDLER( blitter_status_r )
 
 static VIDEO_START( nightgal )
 {
-	nightgal_state *state = machine->driver_data<nightgal_state>();
-	state->blit_buffer = auto_alloc_array(machine, UINT8, 256*256);
+	nightgal_state *state = machine.driver_data<nightgal_state>();
 
-	state_save_register_global_pointer(machine, state->blit_buffer, 256*256);
+	state->save_item(NAME(state->m_blit_buffer));
 }
 
-static VIDEO_UPDATE( nightgal )
+static SCREEN_UPDATE( nightgal )
 {
-	nightgal_state *state = screen->machine->driver_data<nightgal_state>();
+	nightgal_state *state = screen->machine().driver_data<nightgal_state>();
 	int x, y;
 
 	for (y = cliprect->min_y; y <= cliprect->max_y; ++y)
 	{
-		UINT8 *src = &state->blit_buffer[y * 512 / 2 + cliprect->min_x];
+		UINT8 *src = &state->m_blit_buffer[y * 512 / 2 + cliprect->min_x];
 		UINT16 *dst = BITMAP_ADDR16(bitmap, y, cliprect->min_x);
 
 		for (x = cliprect->min_x; x <= cliprect->max_x; x += 2)
 		{
 			UINT32 srcpix = *src++;
-			*dst++ = screen->machine->pens[srcpix & 0xf];
-			*dst++ = screen->machine->pens[(srcpix >> 4) & 0xf];
+			*dst++ = screen->machine().pens[srcpix & 0xf];
+			*dst++ = screen->machine().pens[(srcpix >> 4) & 0xf];
 		}
 	}
 
@@ -90,9 +90,9 @@ static VIDEO_UPDATE( nightgal )
 	return 0;
 }
 
-static UINT8 nightgal_gfx_nibble( running_machine *machine, int niboffset )
+static UINT8 nightgal_gfx_nibble( running_machine &machine, int niboffset )
 {
-	UINT8 *blit_rom = machine->region("gfx1")->base();
+	UINT8 *blit_rom = machine.region("gfx1")->base();
 
 	if (niboffset & 1)
 	{
@@ -104,40 +104,40 @@ static UINT8 nightgal_gfx_nibble( running_machine *machine, int niboffset )
 	}
 }
 
-static void plot_nightgal_gfx_pixel( running_machine *machine, UINT8 pix, int x, int y )
+static void plot_nightgal_gfx_pixel( running_machine &machine, UINT8 pix, int x, int y )
 {
-	nightgal_state *state = machine->driver_data<nightgal_state>();
+	nightgal_state *state = machine.driver_data<nightgal_state>();
 	if (y >= 512) return;
 	if (x >= 512) return;
 	if (y < 0) return;
 	if (x < 0) return;
 
 	if (x & 1)
-		state->blit_buffer[(y * 256) + (x >> 1)] = (state->blit_buffer[(y * 256) + (x >> 1)] & 0x0f) | ((pix << 4) & 0xf0);
+		state->m_blit_buffer[(y * 256) + (x >> 1)] = (state->m_blit_buffer[(y * 256) + (x >> 1)] & 0x0f) | ((pix << 4) & 0xf0);
 	else
-		state->blit_buffer[(y * 256) + (x >> 1)] = (state->blit_buffer[(y * 256) + (x >> 1)] & 0xf0) | (pix & 0x0f);
+		state->m_blit_buffer[(y * 256) + (x >> 1)] = (state->m_blit_buffer[(y * 256) + (x >> 1)] & 0xf0) | (pix & 0x0f);
 }
 
 static WRITE8_HANDLER( nsc_true_blitter_w )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
 	int src, x, y, h, w, flipx;
-	state->true_blit[offset] = data;
+	state->m_true_blit[offset] = data;
 
 	/*trigger blitter write to ram,might not be correct...*/
 	if (offset == 5)
 	{
-      //printf("%02x %02x %02x %02x %02x %02x %02x\n", state->true_blit[0], state->true_blit[1], state->true_blit[2], state->true_blit[3], state->true_blit[4], state->true_blit[5], state->true_blit[6]);
-		w = (state->true_blit[4] & 0xff) + 1;
-		h = (state->true_blit[5] & 0xff) + 1;
-		src = ((state->true_blit[1] << 8) | (state->true_blit[0] << 0));
-		src |= (state->true_blit[6] & 3) << 16;
+      //printf("%02x %02x %02x %02x %02x %02x %02x\n", state->m_true_blit[0], state->m_true_blit[1], state->m_true_blit[2], state->m_true_blit[3], state->m_true_blit[4], state->m_true_blit[5], state->m_true_blit[6]);
+		w = (state->m_true_blit[4] & 0xff) + 1;
+		h = (state->m_true_blit[5] & 0xff) + 1;
+		src = ((state->m_true_blit[1] << 8) | (state->m_true_blit[0] << 0));
+		src |= (state->m_true_blit[6] & 3) << 16;
 
-		x = (state->true_blit[2] & 0xff);
-		y = (state->true_blit[3] & 0xff);
+		x = (state->m_true_blit[2] & 0xff);
+		y = (state->m_true_blit[3] & 0xff);
 
 		// lowest bit of src controls flipping / draw direction?
-		flipx = (state->true_blit[0] & 1);
+		flipx = (state->m_true_blit[0] & 1);
 
 		if (!flipx)
 			src += (w * h) - 1;
@@ -153,14 +153,14 @@ static WRITE8_HANDLER( nsc_true_blitter_w )
 				{
 					int drawx = (x + xcount) & 0xff;
 					int drawy = (y + ycount) & 0xff;
-					UINT8 dat = nightgal_gfx_nibble(space->machine, src + count);
-					UINT8 cur_pen_hi = state->pen_data[(dat & 0xf0) >> 4];
-					UINT8 cur_pen_lo = state->pen_data[(dat & 0x0f) >> 0];
+					UINT8 dat = nightgal_gfx_nibble(space->machine(), src + count);
+					UINT8 cur_pen_hi = state->m_pen_data[(dat & 0xf0) >> 4];
+					UINT8 cur_pen_lo = state->m_pen_data[(dat & 0x0f) >> 0];
 
 					dat = cur_pen_lo | (cur_pen_hi << 4);
 
 					if ((dat & 0xff) != 0)
-						plot_nightgal_gfx_pixel(space->machine, dat, drawx, drawy);
+						plot_nightgal_gfx_pixel(space->machine(), dat, drawx, drawy);
 
 					if (!flipx)
 						count--;
@@ -175,25 +175,25 @@ static WRITE8_HANDLER( nsc_true_blitter_w )
 /* different register writes (probably a PAL line swapping).*/
 static WRITE8_HANDLER( sexygal_nsc_true_blitter_w )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
 	int src, x, y, h, w, flipx;
-	state->true_blit[offset] = data;
+	state->m_true_blit[offset] = data;
 
 	/*trigger blitter write to ram,might not be correct...*/
 	if (offset == 6)
 	{
-      //printf("%02x %02x %02x %02x %02x %02x %02x\n", state->true_blit[0], state->true_blit[1], state->true_blit[2], state->true_blit[3], state->true_blit[4], state->true_blit[5], state->true_blit[6]);
-		w = (state->true_blit[5] & 0xff) + 1;
-		h = (state->true_blit[6] & 0xff) + 1;
-		src = ((state->true_blit[1] << 8) | (state->true_blit[0] << 0));
-		src |= (state->true_blit[2] & 3) << 16;
+      //printf("%02x %02x %02x %02x %02x %02x %02x\n", state->m_true_blit[0], state->m_true_blit[1], state->m_true_blit[2], state->m_true_blit[3], state->m_true_blit[4], state->m_true_blit[5], state->m_true_blit[6]);
+		w = (state->m_true_blit[5] & 0xff) + 1;
+		h = (state->m_true_blit[6] & 0xff) + 1;
+		src = ((state->m_true_blit[1] << 8) | (state->m_true_blit[0] << 0));
+		src |= (state->m_true_blit[2] & 3) << 16;
 
 
-		x = (state->true_blit[3] & 0xff);
-		y = (state->true_blit[4] & 0xff);
+		x = (state->m_true_blit[3] & 0xff);
+		y = (state->m_true_blit[4] & 0xff);
 
 		// lowest bit of src controls flipping / draw direction?
-		flipx = (state->true_blit[0] & 1);
+		flipx = (state->m_true_blit[0] & 1);
 
 		if (!flipx)
 			src += (w * h) - 1;
@@ -209,14 +209,14 @@ static WRITE8_HANDLER( sexygal_nsc_true_blitter_w )
 				{
 					int drawx = (x + xcount) & 0xff;
 					int drawy = (y + ycount) & 0xff;
-					UINT8 dat = nightgal_gfx_nibble(space->machine, src + count);
-					UINT8 cur_pen_hi = state->pen_data[(dat & 0xf0) >> 4];
-					UINT8 cur_pen_lo = state->pen_data[(dat & 0x0f) >> 0];
+					UINT8 dat = nightgal_gfx_nibble(space->machine(), src + count);
+					UINT8 cur_pen_hi = state->m_pen_data[(dat & 0xf0) >> 4];
+					UINT8 cur_pen_lo = state->m_pen_data[(dat & 0x0f) >> 0];
 
 					dat = cur_pen_lo | cur_pen_hi << 4;
 
 					if ((dat & 0xff) != 0)
-						plot_nightgal_gfx_pixel(space->machine, dat, drawx, drawy);
+						plot_nightgal_gfx_pixel(space->machine(), dat, drawx, drawy);
 
 					if (!flipx)
 						count--;
@@ -224,7 +224,7 @@ static WRITE8_HANDLER( sexygal_nsc_true_blitter_w )
 						count++;
 				}
 			}
-			//cpu_set_input_line(state->maincpu, INPUT_LINE_NMI, PULSE_LINE );
+			//device_set_input_line(state->m_maincpu, INPUT_LINE_NMI, PULSE_LINE );
 		}
 	}
 }
@@ -243,7 +243,7 @@ static PALETTE_INIT( nightgal )
 			2, resistances_b,  weights_b,  0, 0,
 			0, 0, 0, 0, 0);
 
-	for (i = 0; i < machine->total_colors(); i++)
+	for (i = 0; i < machine.total_colors(); i++)
 	{
 		int bit0, bit1, bit2;
 		int r, g, b;
@@ -292,113 +292,113 @@ master-slave algorythm
 -executes a wai (i.e. halt) opcode then expects to receive another irq...
 */
 
-#define MAIN_Z80_RUN   if(offset == 2) state->z80_latch = 0x00
-#define MAIN_Z80_HALT  if(offset == 2) state->z80_latch = 0x80
-//#define SUB_NCS_RUN state->ncs_latch = 0x00
-//#define SUB_NCS_HALT state->ncs_latch = 0x80
+#define MAIN_Z80_RUN   if(offset == 2) state->m_z80_latch = 0x00
+#define MAIN_Z80_HALT  if(offset == 2) state->m_z80_latch = 0x80
+//#define SUB_NCS_RUN state->m_ncs_latch = 0x00
+//#define SUB_NCS_HALT state->m_ncs_latch = 0x80
 #ifdef UNUSED_CODE
 static WRITE8_HANDLER( nsc_latch_w )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
-	cpu_set_input_line(state->subcpu, 0, HOLD_LINE );
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
+	device_set_input_line(state->m_subcpu, 0, HOLD_LINE );
 }
 
 static READ8_HANDLER( nsc_latch_r )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
 
-	return state->z80_latch;
+	return state->m_z80_latch;
 }
 
 static WRITE8_HANDLER( z80_latch_w )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
-	state->nsc_latch = data;
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
+	state->m_nsc_latch = data;
 }
 
 static READ8_HANDLER( z80_latch_r )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
-	return state->nsc_latch;
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
+	return state->m_nsc_latch;
 }
 
 /*z80 -> MCU video params*/
 static WRITE8_HANDLER( blitter_w )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
-	state->blit_raw_data[offset] = data;
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
+	state->m_blit_raw_data[offset] = data;
 	MAIN_Z80_HALT;
 }
 
 static READ8_HANDLER( nsc_blit_r )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
 	MAIN_Z80_RUN;
-	return state->blit_raw_data[offset];
+	return state->m_blit_raw_data[offset];
 }
 #endif
 /* TODO: simplify this (error in the document) */
 
 static WRITE8_HANDLER( royalqn_blitter_0_w )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
-	state->blit_raw_data[0] = data;
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
+	state->m_blit_raw_data[0] = data;
 }
 
 static WRITE8_HANDLER( royalqn_blitter_1_w )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
-	state->blit_raw_data[1] = data;
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
+	state->m_blit_raw_data[1] = data;
 }
 
 static WRITE8_HANDLER( royalqn_blitter_2_w )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
-	state->blit_raw_data[2] = data;
-	cpu_set_input_line(state->subcpu, 0, ASSERT_LINE );
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
+	state->m_blit_raw_data[2] = data;
+	device_set_input_line(state->m_subcpu, 0, ASSERT_LINE );
 }
 
 static READ8_HANDLER( royalqn_nsc_blit_r )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
 
 	if(offset == 2)
-		cpu_set_input_line(state->subcpu, 0, CLEAR_LINE );
+		device_set_input_line(state->m_subcpu, 0, CLEAR_LINE );
 
-	return state->blit_raw_data[offset];
+	return state->m_blit_raw_data[offset];
 }
 
 static READ8_HANDLER( royalqn_comm_r )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
 
-	return (state->comms_ram[offset] & 0x80) | (0x7f); //bits 6-0 are undefined, presumably open bus
+	return (state->m_comms_ram[offset] & 0x80) | (0x7f); //bits 6-0 are undefined, presumably open bus
 }
 
 static WRITE8_HANDLER( royalqn_comm_w )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
 
-	state->comms_ram[offset] = data & 0x80;
+	state->m_comms_ram[offset] = data & 0x80;
 }
 
 #ifdef UNUSED_CODE
 static WRITE8_HANDLER( blit_vregs_w )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
-	state->pen_raw_data[offset] = data;
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
+	state->m_pen_raw_data[offset] = data;
 }
 
 static READ8_HANDLER( blit_vregs_r )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
-	return state->pen_raw_data[offset];
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
+	return state->m_pen_raw_data[offset];
 }
 #endif
 static WRITE8_HANDLER( blit_true_vregs_w )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
-	state->pen_data[offset] = data;
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
+	state->m_pen_data[offset] = data;
 }
 
 /********************************************
@@ -409,49 +409,49 @@ static WRITE8_HANDLER( blit_true_vregs_w )
 
 static WRITE8_HANDLER( mux_w )
 {
-	nightgal_state *state = space->machine->driver_data<nightgal_state>();
-	state->mux_data = ~data;
-	//printf("%02x\n", state->mux_data);
+	nightgal_state *state = space->machine().driver_data<nightgal_state>();
+	state->m_mux_data = ~data;
+	//printf("%02x\n", state->m_mux_data);
 }
 
 static READ8_DEVICE_HANDLER( input_1p_r )
 {
-	nightgal_state *state = device->machine->driver_data<nightgal_state>();
-	UINT8 cr_clear = input_port_read(device->machine, "CR_CLEAR");
+	nightgal_state *state = device->machine().driver_data<nightgal_state>();
+	UINT8 cr_clear = input_port_read(device->machine(), "CR_CLEAR");
 
-	switch (state->mux_data)
+	switch (state->m_mux_data)
 	{
-		case 0x01: return input_port_read(device->machine, "PL1_1") | cr_clear;
-		case 0x02: return input_port_read(device->machine, "PL1_2") | cr_clear;
-		case 0x04: return input_port_read(device->machine, "PL1_3") | cr_clear;
-		case 0x08: return input_port_read(device->machine, "PL1_4") | cr_clear;
-		case 0x10: return input_port_read(device->machine, "PL1_5") | cr_clear;
-		case 0x20: return input_port_read(device->machine, "PL1_6") | cr_clear;
+		case 0x01: return input_port_read(device->machine(), "PL1_1") | cr_clear;
+		case 0x02: return input_port_read(device->machine(), "PL1_2") | cr_clear;
+		case 0x04: return input_port_read(device->machine(), "PL1_3") | cr_clear;
+		case 0x08: return input_port_read(device->machine(), "PL1_4") | cr_clear;
+		case 0x10: return input_port_read(device->machine(), "PL1_5") | cr_clear;
+		case 0x20: return input_port_read(device->machine(), "PL1_6") | cr_clear;
 	}
-	//printf("%04x\n", state->mux_data);
+	//printf("%04x\n", state->m_mux_data);
 
-	return (input_port_read(device->machine, "PL1_1") & input_port_read(device->machine, "PL1_2") & input_port_read(device->machine, "PL1_3") &
-	       input_port_read(device->machine, "PL1_4") & input_port_read(device->machine, "PL1_5") & input_port_read(device->machine, "PL1_6")) | cr_clear;
+	return (input_port_read(device->machine(), "PL1_1") & input_port_read(device->machine(), "PL1_2") & input_port_read(device->machine(), "PL1_3") &
+	       input_port_read(device->machine(), "PL1_4") & input_port_read(device->machine(), "PL1_5") & input_port_read(device->machine(), "PL1_6")) | cr_clear;
 }
 
 static READ8_DEVICE_HANDLER( input_2p_r )
 {
-	nightgal_state *state = device->machine->driver_data<nightgal_state>();
-	UINT8 coin_port = input_port_read(device->machine, "COINS");
+	nightgal_state *state = device->machine().driver_data<nightgal_state>();
+	UINT8 coin_port = input_port_read(device->machine(), "COINS");
 
-	switch (state->mux_data)
+	switch (state->m_mux_data)
 	{
-		case 0x01: return input_port_read(device->machine, "PL2_1") | coin_port;
-		case 0x02: return input_port_read(device->machine, "PL2_2") | coin_port;
-		case 0x04: return input_port_read(device->machine, "PL2_3") | coin_port;
-		case 0x08: return input_port_read(device->machine, "PL2_4") | coin_port;
-		case 0x10: return input_port_read(device->machine, "PL2_5") | coin_port;
-		case 0x20: return input_port_read(device->machine, "PL2_6") | coin_port;
+		case 0x01: return input_port_read(device->machine(), "PL2_1") | coin_port;
+		case 0x02: return input_port_read(device->machine(), "PL2_2") | coin_port;
+		case 0x04: return input_port_read(device->machine(), "PL2_3") | coin_port;
+		case 0x08: return input_port_read(device->machine(), "PL2_4") | coin_port;
+		case 0x10: return input_port_read(device->machine(), "PL2_5") | coin_port;
+		case 0x20: return input_port_read(device->machine(), "PL2_6") | coin_port;
 	}
-	//printf("%04x\n", state->mux_data);
+	//printf("%04x\n", state->m_mux_data);
 
-	return (input_port_read(device->machine, "PL2_1") & input_port_read(device->machine, "PL2_2") & input_port_read(device->machine, "PL2_3") &
-	       input_port_read(device->machine, "PL2_4") & input_port_read(device->machine, "PL2_5") & input_port_read(device->machine, "PL2_6")) | coin_port;
+	return (input_port_read(device->machine(), "PL2_1") & input_port_read(device->machine(), "PL2_2") & input_port_read(device->machine(), "PL2_3") &
+	       input_port_read(device->machine(), "PL2_4") & input_port_read(device->machine(), "PL2_5") & input_port_read(device->machine(), "PL2_6")) | coin_port;
 }
 
 /********************************************
@@ -464,7 +464,7 @@ static READ8_DEVICE_HANDLER( input_2p_r )
 * Night Gal
 ********************************/
 #ifdef UNUSED_CODE
-static ADDRESS_MAP_START( nightgal_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( nightgal_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0xc100, 0xc100) AM_READ(nsc_latch_r)
 	AM_RANGE(0xc200, 0xc200) AM_WRITE(nsc_latch_w)
@@ -472,7 +472,7 @@ static ADDRESS_MAP_START( nightgal_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( nightgal_io, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( nightgal_io, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x01,0x01) AM_DEVREAD("aysnd", ay8910_r)
 	AM_RANGE(0x02,0x03) AM_DEVWRITE("aysnd", ay8910_data_address_w)
@@ -485,7 +485,7 @@ static ADDRESS_MAP_START( nightgal_io, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x12,0x14) AM_WRITE(blitter_w) //data for the nsc to be processed
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( nsc_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( nsc_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x007f) AM_RAM
 	AM_RANGE(0x0080, 0x0080) AM_READ(blitter_status_r)
 	AM_RANGE(0x0081, 0x0083) AM_READ(nsc_blit_r)
@@ -505,14 +505,14 @@ ADDRESS_MAP_END
 * Sexy Gal
 ********************************/
 
-static ADDRESS_MAP_START( sexygal_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sexygal_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0xbfff) AM_RAM //???
-	AM_RANGE(0xe000, 0xefff) AM_READWRITE(royalqn_comm_r, royalqn_comm_w) AM_BASE_MEMBER(nightgal_state,comms_ram)
+	AM_RANGE(0xe000, 0xefff) AM_READWRITE(royalqn_comm_r, royalqn_comm_w) AM_BASE_MEMBER(nightgal_state,m_comms_ram)
 	AM_RANGE(0xf000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sexygal_io, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( sexygal_io, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00,0x01) AM_DEVREADWRITE("ymsnd", ym2203_r, ym2203_w)
 //  AM_RANGE(0x10,0x10) AM_WRITE(output_w)
@@ -523,7 +523,7 @@ static ADDRESS_MAP_START( sexygal_io, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x14,0x14) AM_MIRROR(0xe8) AM_READNOP AM_WRITE(royalqn_blitter_2_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sexygal_nsc_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sexygal_nsc_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x007f) AM_RAM
 	AM_RANGE(0x0080, 0x0080) AM_READ(blitter_status_r)
 	AM_RANGE(0x0081, 0x0083) AM_READ(royalqn_nsc_blit_r)
@@ -532,7 +532,7 @@ static ADDRESS_MAP_START( sexygal_nsc_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x00a0, 0x00af) AM_WRITE(blit_true_vregs_w)
 	AM_RANGE(0x00b0, 0x00b0) AM_WRITENOP // bltflip register
 
-	AM_RANGE(0x1000, 0x13ff) AM_MIRROR(0x2c00) AM_READWRITE(royalqn_comm_r, royalqn_comm_w) AM_BASE_MEMBER(nightgal_state,comms_ram)
+	AM_RANGE(0x1000, 0x13ff) AM_MIRROR(0x2c00) AM_READWRITE(royalqn_comm_r, royalqn_comm_w) AM_BASE_MEMBER(nightgal_state,m_comms_ram)
 	AM_RANGE(0xc000, 0xffff) AM_ROM AM_WRITENOP
 ADDRESS_MAP_END
 
@@ -540,14 +540,14 @@ ADDRESS_MAP_END
 * Royal Queen
 ********************************/
 
-static ADDRESS_MAP_START( royalqn_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( royalqn_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0xbfff) AM_NOP
-	AM_RANGE(0xc000, 0xdfff) AM_READWRITE(royalqn_comm_r, royalqn_comm_w) AM_BASE_MEMBER(nightgal_state,comms_ram)
+	AM_RANGE(0xc000, 0xdfff) AM_READWRITE(royalqn_comm_r, royalqn_comm_w) AM_BASE_MEMBER(nightgal_state,m_comms_ram)
 	AM_RANGE(0xe000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( royalqn_io, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( royalqn_io, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x01,0x01) AM_MIRROR(0xec) AM_DEVREAD("aysnd", ay8910_r)
 	AM_RANGE(0x02,0x03) AM_MIRROR(0xec) AM_DEVWRITE("aysnd", ay8910_data_address_w)
@@ -561,7 +561,7 @@ static ADDRESS_MAP_START( royalqn_io, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x17,0x17) AM_MIRROR(0xe8) AM_NOP
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( royalqn_nsc_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( royalqn_nsc_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x007f) AM_RAM
 	AM_RANGE(0x0080, 0x0080) AM_READ(blitter_status_r)
 	AM_RANGE(0x0081, 0x0083) AM_READ(royalqn_nsc_blit_r)
@@ -827,33 +827,33 @@ static const ay8910_interface ay8910_config =
 
 static MACHINE_START( nightgal )
 {
-	nightgal_state *state = machine->driver_data<nightgal_state>();
+	nightgal_state *state = machine.driver_data<nightgal_state>();
 
-	state->maincpu = machine->device("maincpu");
-	state->subcpu = machine->device("sub");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_subcpu = machine.device("sub");
 
-	state_save_register_global(machine, state->nsc_latch);
-	state_save_register_global(machine, state->z80_latch);
-	state_save_register_global(machine, state->mux_data);
+	state->save_item(NAME(state->m_nsc_latch));
+	state->save_item(NAME(state->m_z80_latch));
+	state->save_item(NAME(state->m_mux_data));
 
-	state_save_register_global_array(machine, state->blit_raw_data);
-	state_save_register_global_array(machine, state->true_blit);
-	state_save_register_global_array(machine, state->pen_data);
-	state_save_register_global_array(machine, state->pen_raw_data);
+	state->save_item(NAME(state->m_blit_raw_data));
+	state->save_item(NAME(state->m_true_blit));
+	state->save_item(NAME(state->m_pen_data));
+	state->save_item(NAME(state->m_pen_raw_data));
 }
 
 static MACHINE_RESET( nightgal )
 {
-	nightgal_state *state = machine->driver_data<nightgal_state>();
+	nightgal_state *state = machine.driver_data<nightgal_state>();
 
-	state->nsc_latch = 0;
-	state->z80_latch = 0;
-	state->mux_data = 0;
+	state->m_nsc_latch = 0;
+	state->m_z80_latch = 0;
+	state->m_mux_data = 0;
 
-	memset(state->blit_raw_data, 0, ARRAY_LENGTH(state->blit_raw_data));
-	memset(state->true_blit, 0, ARRAY_LENGTH(state->true_blit));
-	memset(state->pen_data, 0, ARRAY_LENGTH(state->pen_data));
-	memset(state->pen_raw_data, 0, ARRAY_LENGTH(state->pen_raw_data));
+	memset(state->m_blit_raw_data, 0, ARRAY_LENGTH(state->m_blit_raw_data));
+	memset(state->m_true_blit, 0, ARRAY_LENGTH(state->m_true_blit));
+	memset(state->m_pen_data, 0, ARRAY_LENGTH(state->m_pen_data));
+	memset(state->m_pen_raw_data, 0, ARRAY_LENGTH(state->m_pen_raw_data));
 }
 
 static MACHINE_CONFIG_START( royalqn, nightgal_state )
@@ -880,12 +880,12 @@ static MACHINE_CONFIG_START( royalqn, nightgal_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(256, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 256-1, 0, 256-1)
+	MCFG_SCREEN_UPDATE(nightgal)
 	MCFG_PALETTE_INIT(nightgal)
 
 	MCFG_PALETTE_LENGTH(0x10)
 
 	MCFG_VIDEO_START(nightgal)
-	MCFG_VIDEO_UPDATE(nightgal)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -1224,7 +1224,7 @@ ROM_END
 
 static DRIVER_INIT( royalqn )
 {
-	UINT8 *ROM = machine->region("sub")->base();
+	UINT8 *ROM = machine.region("sub")->base();
 
 	/* patch open bus / protection */
 	ROM[0xc27e] = 0x02;
@@ -1233,7 +1233,7 @@ static DRIVER_INIT( royalqn )
 
 static DRIVER_INIT( ngalsumr )
 {
-	UINT8 *ROM = machine->region("sub")->base();
+	UINT8 *ROM = machine.region("sub")->base();
 
 	/* patch protection */
 	ROM[0xd6ce] = 0x02;
