@@ -229,87 +229,91 @@ Stephh's notes (based on the games M68000 code and some tests) :
 class nmg5_state : public driver_device
 {
 public:
-	nmg5_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	nmg5_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT16 *    fg_videoram;
-	UINT16 *    bg_videoram;
-	UINT16 *    scroll_ram;
-	UINT16 *    bitmap;
-	UINT16 *    spriteram;
-//  UINT16 *  paletteram;    // currently this uses generic palette handling
-	size_t      spriteram_size;
+	UINT16 *    m_fg_videoram;
+	UINT16 *    m_bg_videoram;
+	UINT16 *    m_scroll_ram;
+	UINT16 *    m_bitmap;
+	UINT16 *    m_spriteram;
+//  UINT16 *  m_paletteram;    // currently this uses generic palette handling
+	size_t      m_spriteram_size;
 
 	/* video-related */
-	tilemap_t  *bg_tilemap, *fg_tilemap;
+	tilemap_t  *m_bg_tilemap;
+	tilemap_t  *m_fg_tilemap;
 
 	/* misc */
-	UINT8 prot_val, input_data, priority_reg, gfx_bank;
+	UINT8 m_prot_val;
+	UINT8 m_input_data;
+	UINT8 m_priority_reg;
+	UINT8 m_gfx_bank;
 
 	/* devices */
-	device_t *maincpu;
-	device_t *soundcpu;
+	device_t *m_maincpu;
+	device_t *m_soundcpu;
 };
 
 
 
 static WRITE16_HANDLER( fg_videoram_w )
 {
-	nmg5_state *state = space->machine->driver_data<nmg5_state>();
-	COMBINE_DATA(&state->fg_videoram[offset]);
-	tilemap_mark_tile_dirty(state->fg_tilemap, offset);
+	nmg5_state *state = space->machine().driver_data<nmg5_state>();
+	COMBINE_DATA(&state->m_fg_videoram[offset]);
+	tilemap_mark_tile_dirty(state->m_fg_tilemap, offset);
 }
 
 static WRITE16_HANDLER( bg_videoram_w )
 {
-	nmg5_state *state = space->machine->driver_data<nmg5_state>();
-	COMBINE_DATA(&state->bg_videoram[offset]);
-	tilemap_mark_tile_dirty(state->bg_tilemap, offset);
+	nmg5_state *state = space->machine().driver_data<nmg5_state>();
+	COMBINE_DATA(&state->m_bg_videoram[offset]);
+	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
 }
 
 static WRITE16_HANDLER( nmg5_soundlatch_w )
 {
-	nmg5_state *state = space->machine->driver_data<nmg5_state>();
+	nmg5_state *state = space->machine().driver_data<nmg5_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
 		soundlatch_w(space, 0, data & 0xff);
-		cpu_set_input_line(state->soundcpu, INPUT_LINE_NMI, PULSE_LINE);
+		device_set_input_line(state->m_soundcpu, INPUT_LINE_NMI, PULSE_LINE);
 	}
 }
 
 static READ16_HANDLER( prot_r )
 {
-	nmg5_state *state = space->machine->driver_data<nmg5_state>();
-	return state->prot_val | state->input_data;
+	nmg5_state *state = space->machine().driver_data<nmg5_state>();
+	return state->m_prot_val | state->m_input_data;
 }
 
 static WRITE16_HANDLER( prot_w )
 {
-	nmg5_state *state = space->machine->driver_data<nmg5_state>();
-	state->input_data = data & 0x0f;
+	nmg5_state *state = space->machine().driver_data<nmg5_state>();
+	state->m_input_data = data & 0x0f;
 }
 
 static WRITE16_HANDLER( gfx_bank_w )
 {
-	nmg5_state *state = space->machine->driver_data<nmg5_state>();
+	nmg5_state *state = space->machine().driver_data<nmg5_state>();
 
-	if (state->gfx_bank != (data & 3))
+	if (state->m_gfx_bank != (data & 3))
 	{
-		state->gfx_bank = data & 3;
-		tilemap_mark_all_tiles_dirty_all(space->machine);
+		state->m_gfx_bank = data & 3;
+		tilemap_mark_all_tiles_dirty_all(space->machine());
 	}
 }
 
 static WRITE16_HANDLER( priority_reg_w )
 {
-	nmg5_state *state = space->machine->driver_data<nmg5_state>();
+	nmg5_state *state = space->machine().driver_data<nmg5_state>();
 
-	state->priority_reg = data & 7;
+	state->m_priority_reg = data & 7;
 
-	if (state->priority_reg == 4 || state->priority_reg == 5 || state->priority_reg == 6)
-		popmessage("unknown priority_reg value = %d\n", state->priority_reg);
+	if (state->m_priority_reg == 4 || state->m_priority_reg == 5 || state->m_priority_reg == 6)
+		popmessage("unknown priority_reg value = %d\n", state->m_priority_reg);
 }
 
 static WRITE8_DEVICE_HANDLER( oki_banking_w )
@@ -323,11 +327,11 @@ static WRITE8_DEVICE_HANDLER( oki_banking_w )
 
 ********************************************************************/
 
-static ADDRESS_MAP_START( nmg5_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( nmg5_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x120000, 0x12ffff) AM_RAM
 	AM_RANGE(0x140000, 0x1407ff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0x160000, 0x1607ff) AM_RAM AM_BASE_SIZE_MEMBER(nmg5_state, spriteram, spriteram_size)
+	AM_RANGE(0x160000, 0x1607ff) AM_RAM AM_BASE_SIZE_MEMBER(nmg5_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x180000, 0x180001) AM_WRITE(nmg5_soundlatch_w)
 	AM_RANGE(0x180002, 0x180003) AM_WRITENOP
 	AM_RANGE(0x180004, 0x180005) AM_READWRITE(prot_r, prot_w)
@@ -336,18 +340,18 @@ static ADDRESS_MAP_START( nmg5_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x18000a, 0x18000b) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x18000c, 0x18000d) AM_READ_PORT("INPUTS")
 	AM_RANGE(0x18000e, 0x18000f) AM_WRITE(priority_reg_w)
-	AM_RANGE(0x300002, 0x300009) AM_WRITEONLY AM_BASE_MEMBER(nmg5_state, scroll_ram)
+	AM_RANGE(0x300002, 0x300009) AM_WRITEONLY AM_BASE_MEMBER(nmg5_state, m_scroll_ram)
 	AM_RANGE(0x30000a, 0x30000f) AM_WRITENOP
-	AM_RANGE(0x320000, 0x321fff) AM_RAM_WRITE(bg_videoram_w) AM_BASE_MEMBER(nmg5_state, bg_videoram)
-	AM_RANGE(0x322000, 0x323fff) AM_RAM_WRITE(fg_videoram_w) AM_BASE_MEMBER(nmg5_state, fg_videoram)
-	AM_RANGE(0x800000, 0x80ffff) AM_RAM AM_BASE_MEMBER(nmg5_state, bitmap)
+	AM_RANGE(0x320000, 0x321fff) AM_RAM_WRITE(bg_videoram_w) AM_BASE_MEMBER(nmg5_state, m_bg_videoram)
+	AM_RANGE(0x322000, 0x323fff) AM_RAM_WRITE(fg_videoram_w) AM_BASE_MEMBER(nmg5_state, m_fg_videoram)
+	AM_RANGE(0x800000, 0x80ffff) AM_RAM AM_BASE_MEMBER(nmg5_state, m_bitmap)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( pclubys_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( pclubys_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x200000, 0x20ffff) AM_RAM
 	AM_RANGE(0x440000, 0x4407ff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0x460000, 0x4607ff) AM_RAM AM_BASE_SIZE_MEMBER(nmg5_state, spriteram, spriteram_size)
+	AM_RANGE(0x460000, 0x4607ff) AM_RAM AM_BASE_SIZE_MEMBER(nmg5_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x480000, 0x480001) AM_WRITE(nmg5_soundlatch_w)
 	AM_RANGE(0x480002, 0x480003) AM_WRITENOP
 	AM_RANGE(0x480004, 0x480005) AM_READWRITE(prot_r, prot_w)
@@ -356,10 +360,10 @@ static ADDRESS_MAP_START( pclubys_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x48000a, 0x48000b) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x48000c, 0x48000d) AM_READ_PORT("INPUTS")
 	AM_RANGE(0x48000e, 0x48000f) AM_WRITE(priority_reg_w)
-	AM_RANGE(0x500002, 0x500009) AM_WRITEONLY AM_BASE_MEMBER(nmg5_state, scroll_ram)
-	AM_RANGE(0x520000, 0x521fff) AM_RAM_WRITE(bg_videoram_w) AM_BASE_MEMBER(nmg5_state, bg_videoram)
-	AM_RANGE(0x522000, 0x523fff) AM_RAM_WRITE(fg_videoram_w) AM_BASE_MEMBER(nmg5_state, fg_videoram)
-	AM_RANGE(0x800000, 0x80ffff) AM_RAM AM_BASE_MEMBER(nmg5_state, bitmap)
+	AM_RANGE(0x500002, 0x500009) AM_WRITEONLY AM_BASE_MEMBER(nmg5_state, m_scroll_ram)
+	AM_RANGE(0x520000, 0x521fff) AM_RAM_WRITE(bg_videoram_w) AM_BASE_MEMBER(nmg5_state, m_bg_videoram)
+	AM_RANGE(0x522000, 0x523fff) AM_RAM_WRITE(fg_videoram_w) AM_BASE_MEMBER(nmg5_state, m_fg_videoram)
+	AM_RANGE(0x800000, 0x80ffff) AM_RAM AM_BASE_MEMBER(nmg5_state, m_bitmap)
 ADDRESS_MAP_END
 
 /*******************************************************************
@@ -368,17 +372,17 @@ ADDRESS_MAP_END
 
 ********************************************************************/
 
-static ADDRESS_MAP_START( nmg5_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( nmg5_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xdfff) AM_ROM
 	AM_RANGE(0xe000, 0xe7ff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( pclubys_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( pclubys_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xf7ff) AM_ROM
 	AM_RANGE(0xf800, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( sound_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_DEVWRITE("oki", oki_banking_w)
 	AM_RANGE(0x10, 0x11) AM_DEVREADWRITE("ymsnd", ym3812_r, ym3812_w)
@@ -823,31 +827,31 @@ static INPUT_PORTS_START( wondstck )
 INPUT_PORTS_END
 
 
-INLINE void get_tile_info( running_machine *machine, tile_data *tileinfo, int tile_index, UINT16 *vram, int color )
+INLINE void get_tile_info( running_machine &machine, tile_data *tileinfo, int tile_index, UINT16 *vram, int color )
 {
-	nmg5_state *state = machine->driver_data<nmg5_state>();
-	SET_TILE_INFO(0, vram[tile_index] | (state->gfx_bank << 16), color, 0);
+	nmg5_state *state = machine.driver_data<nmg5_state>();
+	SET_TILE_INFO(0, vram[tile_index] | (state->m_gfx_bank << 16), color, 0);
 }
 
-static TILE_GET_INFO( fg_get_tile_info ) { nmg5_state *state = machine->driver_data<nmg5_state>();	get_tile_info(machine, tileinfo, tile_index, state->fg_videoram, 0); }
-static TILE_GET_INFO( bg_get_tile_info ) { nmg5_state *state = machine->driver_data<nmg5_state>();	get_tile_info(machine, tileinfo, tile_index, state->bg_videoram, 1); }
+static TILE_GET_INFO( fg_get_tile_info ) { nmg5_state *state = machine.driver_data<nmg5_state>();	get_tile_info(machine, tileinfo, tile_index, state->m_fg_videoram, 0); }
+static TILE_GET_INFO( bg_get_tile_info ) { nmg5_state *state = machine.driver_data<nmg5_state>();	get_tile_info(machine, tileinfo, tile_index, state->m_bg_videoram, 1); }
 
 static VIDEO_START( nmg5 )
 {
-	nmg5_state *state = machine->driver_data<nmg5_state>();
+	nmg5_state *state = machine.driver_data<nmg5_state>();
 
-	state->bg_tilemap = tilemap_create(machine, bg_get_tile_info, tilemap_scan_rows, 8, 8, 64, 64);
-	state->fg_tilemap = tilemap_create(machine, fg_get_tile_info, tilemap_scan_rows, 8, 8, 64, 64);
-	tilemap_set_transparent_pen(state->fg_tilemap, 0);
+	state->m_bg_tilemap = tilemap_create(machine, bg_get_tile_info, tilemap_scan_rows, 8, 8, 64, 64);
+	state->m_fg_tilemap = tilemap_create(machine, fg_get_tile_info, tilemap_scan_rows, 8, 8, 64, 64);
+	tilemap_set_transparent_pen(state->m_fg_tilemap, 0);
 }
 
-static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect )
+static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect )
 {
-	nmg5_state *state = machine->driver_data<nmg5_state>();
-	UINT16 *spriteram = state->spriteram;
+	nmg5_state *state = machine.driver_data<nmg5_state>();
+	UINT16 *spriteram = state->m_spriteram;
 	int offs;
 
-	for (offs = 0; offs < state->spriteram_size / 2; offs += 4)
+	for (offs = 0; offs < state->m_spriteram_size / 2; offs += 4)
 	{
 		int sx, sy, code, color, flipx, flipy, height, y;
 
@@ -861,14 +865,14 @@ static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rect
 
 		for (y = 0; y < height; y++)
 		{
-			drawgfx_transpen(bitmap,cliprect,machine->gfx[1],
+			drawgfx_transpen(bitmap,cliprect,machine.gfx[1],
 					code + (flipy ? height-1 - y : y),
 					color,
 					flipx,flipy,
 					sx & 0x1ff,248 - ((sy + 0x10 * (height - y)) & 0x1ff),0);
 
 			/* wrap around */
-			drawgfx_transpen(bitmap,cliprect,machine->gfx[1],
+			drawgfx_transpen(bitmap,cliprect,machine.gfx[1],
 					code + (flipy ? height-1 - y : y),
 					color,
 					flipx,flipy,
@@ -877,9 +881,9 @@ static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rect
 	}
 }
 
-static void draw_bitmap( running_machine *machine, bitmap_t *bitmap )
+static void draw_bitmap( running_machine &machine, bitmap_t *bitmap )
 {
-	nmg5_state *state = machine->driver_data<nmg5_state>();
+	nmg5_state *state = machine.driver_data<nmg5_state>();
 	int yyy = 256;
 	int xxx = 512 / 4;
 	UINT16 x, y, count;
@@ -892,13 +896,13 @@ static void draw_bitmap( running_machine *machine, bitmap_t *bitmap )
 	{
 		for (x = 0; x < xxx; x++)
 		{
-			pix = (state->bitmap[count] & 0xf000) >> 12;
+			pix = (state->m_bitmap[count] & 0xf000) >> 12;
 			if (pix) *BITMAP_ADDR16(bitmap, y + yoff, x * 4 + 0 + xoff) = pix + 0x300;
-			pix = (state->bitmap[count] & 0x0f00) >> 8;
+			pix = (state->m_bitmap[count] & 0x0f00) >> 8;
 			if (pix) *BITMAP_ADDR16(bitmap, y + yoff, x * 4 + 1 + xoff) = pix + 0x300;
-			pix = (state->bitmap[count] & 0x00f0) >> 4;
+			pix = (state->m_bitmap[count] & 0x00f0) >> 4;
 			if (pix) *BITMAP_ADDR16(bitmap, y + yoff, x * 4 + 2 + xoff) = pix + 0x300;
-			pix = (state->bitmap[count] & 0x000f) >> 0;
+			pix = (state->m_bitmap[count] & 0x000f) >> 0;
 			if (pix) *BITMAP_ADDR16(bitmap, y + yoff, x * 4 + 3 + xoff) = pix + 0x300;
 
 			count++;
@@ -907,46 +911,46 @@ static void draw_bitmap( running_machine *machine, bitmap_t *bitmap )
 }
 
 
-static VIDEO_UPDATE( nmg5 )
+static SCREEN_UPDATE( nmg5 )
 {
-	nmg5_state *state = screen->machine->driver_data<nmg5_state>();
+	nmg5_state *state = screen->machine().driver_data<nmg5_state>();
 
-	tilemap_set_scrolly(state->bg_tilemap, 0, state->scroll_ram[3] + 9);
-	tilemap_set_scrollx(state->bg_tilemap, 0, state->scroll_ram[2] + 3);
-	tilemap_set_scrolly(state->fg_tilemap, 0, state->scroll_ram[1] + 9);
-	tilemap_set_scrollx(state->fg_tilemap, 0, state->scroll_ram[0] - 1);
+	tilemap_set_scrolly(state->m_bg_tilemap, 0, state->m_scroll_ram[3] + 9);
+	tilemap_set_scrollx(state->m_bg_tilemap, 0, state->m_scroll_ram[2] + 3);
+	tilemap_set_scrolly(state->m_fg_tilemap, 0, state->m_scroll_ram[1] + 9);
+	tilemap_set_scrollx(state->m_fg_tilemap, 0, state->m_scroll_ram[0] - 1);
 
-	tilemap_draw(bitmap, cliprect, state->bg_tilemap, 0, 0);
+	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
 
-	if (state->priority_reg == 0)
+	if (state->m_priority_reg == 0)
 	{
-		draw_sprites(screen->machine, bitmap, cliprect);
-		tilemap_draw(bitmap, cliprect, state->fg_tilemap, 0, 0);
-		draw_bitmap(screen->machine, bitmap);
+		draw_sprites(screen->machine(), bitmap, cliprect);
+		tilemap_draw(bitmap, cliprect, state->m_fg_tilemap, 0, 0);
+		draw_bitmap(screen->machine(), bitmap);
 	}
-	else if (state->priority_reg == 1)
+	else if (state->m_priority_reg == 1)
 	{
-		draw_bitmap(screen->machine, bitmap);
-		draw_sprites(screen->machine, bitmap, cliprect);
-		tilemap_draw(bitmap, cliprect, state->fg_tilemap, 0, 0);
+		draw_bitmap(screen->machine(), bitmap);
+		draw_sprites(screen->machine(), bitmap, cliprect);
+		tilemap_draw(bitmap, cliprect, state->m_fg_tilemap, 0, 0);
 	}
-	else if (state->priority_reg == 2)
+	else if (state->m_priority_reg == 2)
 	{
-		draw_sprites(screen->machine, bitmap, cliprect);
-		draw_bitmap(screen->machine, bitmap);
-		tilemap_draw(bitmap, cliprect, state->fg_tilemap, 0, 0);
+		draw_sprites(screen->machine(), bitmap, cliprect);
+		draw_bitmap(screen->machine(), bitmap);
+		tilemap_draw(bitmap, cliprect, state->m_fg_tilemap, 0, 0);
 	}
-	else if (state->priority_reg == 3)
+	else if (state->m_priority_reg == 3)
 	{
-		tilemap_draw(bitmap, cliprect, state->fg_tilemap, 0, 0);
-		draw_sprites(screen->machine, bitmap, cliprect);
-		draw_bitmap(screen->machine, bitmap);
+		tilemap_draw(bitmap, cliprect, state->m_fg_tilemap, 0, 0);
+		draw_sprites(screen->machine(), bitmap, cliprect);
+		draw_bitmap(screen->machine(), bitmap);
 	}
-	else if (state->priority_reg == 7)
+	else if (state->m_priority_reg == 7)
 	{
-		tilemap_draw(bitmap, cliprect, state->fg_tilemap, 0, 0);
-		draw_bitmap(screen->machine, bitmap);
-		draw_sprites(screen->machine, bitmap, cliprect);
+		tilemap_draw(bitmap, cliprect, state->m_fg_tilemap, 0, 0);
+		draw_bitmap(screen->machine(), bitmap);
+		draw_sprites(screen->machine(), bitmap, cliprect);
 	}
 	return 0;
 }
@@ -998,8 +1002,8 @@ GFXDECODE_END
 
 static void soundirq( device_t *device, int state )
 {
-	nmg5_state *driver_state = device->machine->driver_data<nmg5_state>();
-	cpu_set_input_line(driver_state->soundcpu, 0, state);
+	nmg5_state *driver_state = device->machine().driver_data<nmg5_state>();
+	device_set_input_line(driver_state->m_soundcpu, 0, state);
 }
 
 static const ym3812_interface ym3812_intf =
@@ -1009,25 +1013,25 @@ static const ym3812_interface ym3812_intf =
 
 static MACHINE_START( nmg5 )
 {
-	nmg5_state *state = machine->driver_data<nmg5_state>();
+	nmg5_state *state = machine.driver_data<nmg5_state>();
 
-	state->maincpu = machine->device("maincpu");
-	state->soundcpu = machine->device("soundcpu");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_soundcpu = machine.device("soundcpu");
 
-	state_save_register_global(machine, state->gfx_bank);
-	state_save_register_global(machine, state->priority_reg);
-	state_save_register_global(machine, state->input_data);
+	state->save_item(NAME(state->m_gfx_bank));
+	state->save_item(NAME(state->m_priority_reg));
+	state->save_item(NAME(state->m_input_data));
 }
 
 static MACHINE_RESET( nmg5 )
 {
-	nmg5_state *state = machine->driver_data<nmg5_state>();
+	nmg5_state *state = machine.driver_data<nmg5_state>();
 
 	/* some games don't set the priority register so it should be hard-coded to a normal layout */
-	state->priority_reg = 7;
+	state->m_priority_reg = 7;
 
-	state->gfx_bank = 0;
-	state->input_data = 0;
+	state->m_gfx_bank = 0;
+	state->m_input_data = 0;
 }
 
 static MACHINE_CONFIG_START( nmg5, nmg5_state )
@@ -1051,12 +1055,12 @@ static MACHINE_CONFIG_START( nmg5, nmg5_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(320, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 319, 0, 239)
+	MCFG_SCREEN_UPDATE(nmg5)
 
 	MCFG_GFXDECODE(nmg5)
 	MCFG_PALETTE_LENGTH(0x400)
 
 	MCFG_VIDEO_START(nmg5)
-	MCFG_VIDEO_UPDATE(nmg5)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -1523,26 +1527,26 @@ ROM_END
 
 static DRIVER_INIT( prot_val_00 )
 {
-	nmg5_state *state = machine->driver_data<nmg5_state>();
-	state->prot_val = 0x00;
+	nmg5_state *state = machine.driver_data<nmg5_state>();
+	state->m_prot_val = 0x00;
 }
 
 static DRIVER_INIT( prot_val_10 )
 {
-	nmg5_state *state = machine->driver_data<nmg5_state>();
-	state->prot_val = 0x10;
+	nmg5_state *state = machine.driver_data<nmg5_state>();
+	state->m_prot_val = 0x10;
 }
 
 static DRIVER_INIT( prot_val_20 )
 {
-	nmg5_state *state = machine->driver_data<nmg5_state>();
-	state->prot_val = 0x20;
+	nmg5_state *state = machine.driver_data<nmg5_state>();
+	state->m_prot_val = 0x20;
 }
 
 static DRIVER_INIT( prot_val_40 )
 {
-	nmg5_state *state = machine->driver_data<nmg5_state>();
-	state->prot_val = 0x40;
+	nmg5_state *state = machine.driver_data<nmg5_state>();
+	state->m_prot_val = 0x40;
 }
 
 GAME( 1998, nmg5,     0,       nmg5,     nmg5,     prot_val_10, ROT0, "Yun Sung", "Multi 5 / New Multi Game 5", GAME_SUPPORTS_SAVE )
