@@ -297,7 +297,19 @@ Contra III   CONTRA_III_1   TC574000   CONTRA_III_0   TC574000    GAME1_NSSU
 #include "cpu/z80/z80.h"
 #include "includes/snes.h"
 
-static ADDRESS_MAP_START( snes_map, ADDRESS_SPACE_PROGRAM, 8)
+
+class nss_state : public snes_state
+{
+public:
+	nss_state(const machine_config &mconfig, device_type type, const char *tag)
+		: snes_state(mconfig, type, tag) { }
+
+	UINT8 m_m50458_rom_bank;
+	UINT8 m_vblank_bit;
+};
+
+
+static ADDRESS_MAP_START( snes_map, AS_PROGRAM, 8)
 	AM_RANGE(0x000000, 0x2fffff) AM_READWRITE(snes_r_bank1, snes_w_bank1)	/* I/O and ROM (repeats for each bank) */
 	AM_RANGE(0x300000, 0x3fffff) AM_READWRITE(snes_r_bank2, snes_w_bank2)	/* I/O and ROM (repeats for each bank) */
 	AM_RANGE(0x400000, 0x5fffff) AM_READ(snes_r_bank3)						/* ROM (and reserved in Mode 20) */
@@ -318,7 +330,7 @@ static WRITE8_DEVICE_HANDLER( spc_ram_100_w )
 	spc_ram_w(device, offset + 0x100, data);
 }
 
-static ADDRESS_MAP_START( spc_mem, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( spc_mem, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x00ef) AM_DEVREADWRITE("spc700", spc_ram_r, spc_ram_w)	/* lower 32k ram */
 	AM_RANGE(0x00f0, 0x00ff) AM_DEVREADWRITE("spc700", spc_io_r, spc_io_w)  	/* spc io */
 	AM_RANGE(0x0100, 0xffff) AM_DEVWRITE("spc700", spc_ram_100_w)
@@ -345,6 +357,8 @@ bp 6f8d check the EEPROM2 results
 
 bp 6dce onward looks bogus, but it's probably the way it's intended to be
 
+M50458 charset is checked at 1382, a word checksum is provided at offsets 0xffe-0xfff of the given ROM
+
 */
 
 static READ8_HANDLER( nss_eeprom_r )
@@ -364,21 +378,21 @@ static WRITE8_HANDLER( nss_eeprom_w )
 //  printf("EEPROM write %02x\n",data);
 }
 
-static UINT8 m50458_rom_bank;
 
 static READ8_HANDLER( m50458_r )
 {
-	if(m50458_rom_bank)
+	nss_state *state = space->machine().driver_data<nss_state>();
+	if(state->m_m50458_rom_bank)
 	{
-		UINT8 *gfx_rom = memory_region(space->machine, "m50458_gfx");
+		UINT8 *gfx_rom = space->machine().region("m50458_gfx")->base();
 
-		return gfx_rom[offset & 0x7ff];
+		return gfx_rom[offset & 0xfff];
 	}
 	else
 	{
-		UINT8 *gfx_ram = memory_region(space->machine, "m50458_vram");
+		UINT8 *gfx_ram = space->machine().region("m50458_vram")->base();
 
-		return gfx_ram[offset & 0x7ff];
+		return gfx_ram[offset & 0xfff];
 	}
 
 	return 0;
@@ -386,22 +400,23 @@ static READ8_HANDLER( m50458_r )
 
 static WRITE8_HANDLER( m50458_w )
 {
-	if(m50458_rom_bank)
+	nss_state *state = space->machine().driver_data<nss_state>();
+	if(state->m_m50458_rom_bank)
 		logerror("Warning: write to M50458 GFX ROM!\n");
 	else
 	{
-		UINT8 *gfx_ram = memory_region(space->machine, "m50458_vram");
+		UINT8 *gfx_ram = space->machine().region("m50458_vram")->base();
 
-		gfx_ram[offset & 0x7ff] = data;
+		gfx_ram[offset & 0xfff] = data;
 	}
 }
 
 
-static ADDRESS_MAP_START( bios_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( bios_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROMBANK("bank1")
 	AM_RANGE(0x8000, 0x87ff) AM_RAM
 	AM_RANGE(0x8800, 0x8fff) AM_RAM // vram perhaps?
-	AM_RANGE(0x9000, 0x97ff) AM_MIRROR(0x800) AM_READWRITE(m50458_r,m50458_w) // M50458 vram & GFX rom routes here
+	AM_RANGE(0x9000, 0x9fff) AM_READWRITE(m50458_r,m50458_w) // M50458 vram & GFX rom routes here
 	AM_RANGE(0xa000, 0xa000) AM_READ(nss_eeprom_r)
 	AM_RANGE(0xe000, 0xe000) AM_WRITE(nss_eeprom_w)
 	AM_RANGE(0xc000, 0xdfff) AM_MIRROR(0x2000) AM_RAM AM_REGION("ibios_rom", 0x6000)
@@ -409,15 +424,15 @@ ADDRESS_MAP_END
 
 static READ8_HANDLER( port00_r )
 {
+	nss_state *state = space->machine().driver_data<nss_state>();
 	/*
     -x-- ---- almost certainly tied to the vblank signal
     */
 
-	static UINT8 vblank_bit;
 
-	vblank_bit^=0x40;
+	state->m_vblank_bit^=0x40;
 
-	return vblank_bit | 0xbf;
+	return state->m_vblank_bit | 0xbf;
 }
 
 
@@ -449,14 +464,15 @@ static READ8_HANDLER( port03_r )
 
 static WRITE8_HANDLER( port80_w )
 {
+	nss_state *state = space->machine().driver_data<nss_state>();
 	/*
-    ---- x--- written when 0x9000-0x9fff is read, probably a bankswitch
+    ---- -x-- written when 0x9000-0x9fff is read, probably a bankswitch
     ---- --x- see port 0x02 note
     ---- ---x BIOS bankswitch
     */
 
-	memory_set_bank(space->machine, "bank1", data & 1);
-	m50458_rom_bank = data & 8;
+	memory_set_bank(space->machine(), "bank1", data & 1);
+	state->m_m50458_rom_bank = data & 4;
 }
 
 static WRITE8_HANDLER( port82_w ) // EEPROM2?
@@ -468,7 +484,7 @@ static WRITE8_HANDLER( port82_w ) // EEPROM2?
     */
 }
 
-static ADDRESS_MAP_START( bios_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( bios_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(port00_r)
 	AM_RANGE(0x01, 0x01) AM_READ(port01_r)
@@ -481,15 +497,15 @@ static ADDRESS_MAP_START( bios_io_map, ADDRESS_SPACE_IO, 8 )
 
 ADDRESS_MAP_END
 
-
 static MACHINE_START( nss )
 {
-	UINT8 *ROM = memory_region(machine, "bios");
+	nss_state *state = machine.driver_data<nss_state>();
+	UINT8 *ROM = machine.region("bios")->base();
 
 	memory_configure_bank(machine, "bank1", 0, 2, &ROM[0x10000], 0x8000);
 	memory_set_bank(machine, "bank1", 0);
 
-	m50458_rom_bank = 0;
+	state->m_m50458_rom_bank = 0;
 
 	MACHINE_START_CALL(snes);
 }
@@ -556,7 +572,7 @@ static INPUT_PORTS_START( snes )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 
-#ifdef SNES_LAYER_DEBUG
+#if SNES_LAYER_DEBUG
 	PORT_START("DEBUG1")
 	PORT_CONFNAME( 0x03, 0x00, "Select BG1 priority" )
 	PORT_CONFSETTING(    0x00, "All" )
@@ -609,49 +625,77 @@ static INPUT_PORTS_START( snes )
 #endif
 INPUT_PORTS_END
 
-static MACHINE_DRIVER_START( snes )
+static const gfx_layout nss_char_layout_16x18 =
+{
+	16,18,
+	RGN_FRAC(1,1),
+	1,
+	{ 0 },
+	{ 0, 1, 2, 3, 4, 5, 6, 7,8,9,10,11,12,13,14,15 },
+	{ 0*16, 1*16, 2*16, 3*16, 4*16, 5*16, 6*16, 7*16,8*16, 9*16, 10*16, 11*16, 12*16, 13*16, 14*16, 15*16, 16*16,17*16 },
+	16*18
+};
 
-	/* driver data */
-	MDRV_DRIVER_DATA(snes_state)
+static const gfx_layout nss_char_layout_16x16 =
+{
+	16,16,
+	RGN_FRAC(1,1),
+	1,
+	{ 0 },
+	{ 0, 1, 2, 3, 4, 5, 6, 7,8,9,10,11,12,13,14,15 },
+	{ 0*16, 1*16, 2*16, 3*16, 4*16, 5*16, 6*16, 7*16,8*16, 9*16, 10*16, 11*16, 12*16, 13*16, 14*16, 15*16 },
+	16*16
+};
+
+
+/* decoded for debugging purpose, this will be nuked in the end... */
+static GFXDECODE_START( nss )
+	GFXDECODE_ENTRY( "chargen",   0x00000, nss_char_layout_16x18,    0, 1 )
+	GFXDECODE_ENTRY( "m50458_gfx",   0x00000, nss_char_layout_16x16,    0, 1 )
+GFXDECODE_END
+
+static MACHINE_CONFIG_START( snes, nss_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", _5A22, 3580000*6)	/* 2.68Mhz, also 3.58Mhz */
-	MDRV_CPU_PROGRAM_MAP(snes_map)
+	MCFG_CPU_ADD("maincpu", _5A22, 3580000*6)	/* 2.68Mhz, also 3.58Mhz */
+	MCFG_CPU_PROGRAM_MAP(snes_map)
 
-	MDRV_CPU_ADD("soundcpu", SPC700, 2048000/2)	/* 2.048 Mhz, but internal divider */
-	MDRV_CPU_PROGRAM_MAP(spc_mem)
+	MCFG_CPU_ADD("soundcpu", SPC700, 2048000/2)	/* 2.048 Mhz, but internal divider */
+	MCFG_CPU_PROGRAM_MAP(spc_mem)
 
-	MDRV_QUANTUM_TIME(HZ(24000))
+//  MCFG_QUANTUM_TIME(attotime::from_hz(24000))
+	MCFG_QUANTUM_PERFECT_CPU("maincpu")
 
-	MDRV_MACHINE_START( snes )
-	MDRV_MACHINE_RESET( snes )
+	MCFG_MACHINE_START( snes )
+	MCFG_MACHINE_RESET( snes )
 
 	/* video hardware */
-	MDRV_VIDEO_START( snes )
-	MDRV_VIDEO_UPDATE( snes )
+	MCFG_VIDEO_START( snes )
 
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_RAW_PARAMS(DOTCLK_NTSC, SNES_HTOTAL, 0, SNES_SCR_WIDTH, SNES_VTOTAL_NTSC, 0, SNES_SCR_HEIGHT_NTSC)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MCFG_SCREEN_RAW_PARAMS(DOTCLK_NTSC, SNES_HTOTAL, 0, SNES_SCR_WIDTH, SNES_VTOTAL_NTSC, 0, SNES_SCR_HEIGHT_NTSC)
+	MCFG_SCREEN_UPDATE( snes )
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
-	MDRV_SOUND_ADD("spc700", SNES, 0)
-	MDRV_SOUND_ROUTE(0, "lspeaker", 1.00)
-	MDRV_SOUND_ROUTE(1, "rspeaker", 1.00)
-MACHINE_DRIVER_END
+	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
+	MCFG_SOUND_ADD("spc700", SNES, 0)
+	MCFG_SOUND_ROUTE(0, "lspeaker", 1.00)
+	MCFG_SOUND_ROUTE(1, "rspeaker", 1.00)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( nss )
-	MDRV_IMPORT_FROM( snes )
+static MACHINE_CONFIG_DERIVED( nss, snes )
 
-	MDRV_CPU_ADD("bios", Z80, 4000000)
-	MDRV_CPU_PROGRAM_MAP(bios_map)
-	MDRV_CPU_IO_MAP(bios_io_map)
-	MDRV_CPU_VBLANK_INT("screen", nmi_line_pulse)
-//  MDRV_CPU_FLAGS(CPU_DISABLE)
+	MCFG_CPU_ADD("bios", Z80, 4000000)
+	MCFG_CPU_PROGRAM_MAP(bios_map)
+	MCFG_CPU_IO_MAP(bios_io_map)
+	MCFG_CPU_VBLANK_INT("screen", nmi_line_pulse)
+//  MCFG_CPU_FLAGS(CPU_DISABLE)
 
-	MDRV_MACHINE_START( nss )
-MACHINE_DRIVER_END
+	MCFG_GFXDECODE( nss )
+	MCFG_PALETTE_LENGTH(2)
+	MCFG_MACHINE_START( nss )
+MACHINE_CONFIG_END
 
 /***************************************************************************
 
@@ -662,14 +706,20 @@ MACHINE_DRIVER_END
 #define NSS_BIOS \
 	ROM_REGION(0x100,           "user5", 0)		/* IPL ROM */ \
 	ROM_LOAD("spc700.rom", 0, 0x40, CRC(44bb3a40) SHA1(97e352553e94242ae823547cd853eecda55c20f0) ) \
-	ROM_REGION(0x1000,           "addons", 0)		/* add-on chip ROMs (DSP1 could be needed if we dump smk). the second 0x800 host DSP3 ROM in MESS */\
-	ROM_LOAD("dsp1data.bin", 0x000000, 0x000800, CRC(4b02d66d) SHA1(1534f4403d2a0f68ba6e35186fe7595d33de34b1))\
+	ROM_REGION(0x10000,           "addons", ROMREGION_ERASE00)		/* add-on chip ROMs (DSP1 will be needed if we dump the NSS version of Super Mario Kart)*/\
+	ROM_LOAD( "dsp1b.bin", SNES_DSP1B_OFFSET, 0x002800, CRC(453557e0) SHA1(3a218b0e4572a8eba6d0121b17fdac9529609220) ) \
 	ROM_REGION(0x20000,         "bios",  0)		/* Bios CPU (what is it?) */ \
 	ROM_LOAD("nss-c.dat"  , 0x10000, 0x8000, CRC(a8e202b3) SHA1(b7afcfe4f5cf15df53452dc04be81929ced1efb2) )	/* bios */ \
 	ROM_LOAD("nss-ic14.02", 0x18000, 0x8000, CRC(e06cb58f) SHA1(62f507e91a2797919a78d627af53f029c7d81477) )	/* bios */ \
-	ROM_REGION( 0x800, "m50458_gfx", ROMREGION_ERASEFF ) \
-	ROM_LOAD("m50458_char", 0x000, 0x800, NO_DUMP ) \
-	ROM_REGION( 0x800, "m50458_vram", ROMREGION_ERASE00 ) \
+	ROM_REGION( 0x1200, "chargen", ROMREGION_ERASEFF ) \
+	ROM_LOAD("m50458_char.bin",     0x0000, 0x1200, BAD_DUMP CRC(011cc342) SHA1(d5b9f32d6e251b4b25945267d7c68c099bd83e96) ) \
+	ROM_REGION( 0x1000, "m50458_gfx", ROMREGION_ERASEFF ) \
+	ROM_LOAD("m50458_char_mod.bin", 0x0000, 0x1000, BAD_DUMP CRC(8c4326ef) SHA1(21a63c5245ff7f3f70cb45e217b3045b19d0d799) ) \
+	ROM_REGION( 0x1000, "m50458_vram", ROMREGION_ERASE00 ) \
+	ROM_REGION( 0x2000, "dspprg", ROMREGION_ERASEFF) \
+	ROM_REGION( 0x800, "dspdata", ROMREGION_ERASEFF)
+
+
 
 ROM_START( nss )
 	NSS_BIOS
