@@ -225,37 +225,54 @@ Thrill Drive 713A13  -       713A14  -
 #include "video/voodoo.h"
 #include "video/konicdev.h"
 
-static UINT8 led_reg0, led_reg1;
 
-static UINT32 *work_ram;
+class nwktr_state : public driver_device
+{
+public:
+	nwktr_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 m_led_reg0;
+	UINT8 m_led_reg1;
+	UINT32 *m_work_ram;
+	int m_fpga_uploaded;
+	int m_lanc2_ram_r;
+	int m_lanc2_ram_w;
+	UINT8 *m_lanc2_ram;
+	UINT32 *m_sharc_dataram;
+};
+
+
+
 
 
 static WRITE32_HANDLER( paletteram32_w )
 {
-	COMBINE_DATA(&space->machine->generic.paletteram.u32[offset]);
-	data = space->machine->generic.paletteram.u32[offset];
-	palette_set_color_rgb(space->machine, offset, pal5bit(data >> 10), pal5bit(data >> 5), pal5bit(data >> 0));
+	COMBINE_DATA(&space->machine().generic.paletteram.u32[offset]);
+	data = space->machine().generic.paletteram.u32[offset];
+	palette_set_color_rgb(space->machine(), offset, pal5bit(data >> 10), pal5bit(data >> 5), pal5bit(data >> 0));
 }
 
 static void voodoo_vblank_0(device_t *device, int param)
 {
-	cputag_set_input_line(device->machine, "maincpu", INPUT_LINE_IRQ0, ASSERT_LINE);
+	cputag_set_input_line(device->machine(), "maincpu", INPUT_LINE_IRQ0, ASSERT_LINE);
 }
 
 
-static VIDEO_UPDATE( nwktr )
+static SCREEN_UPDATE( nwktr )
 {
-	device_t *voodoo = screen->machine->device("voodoo");
-	device_t *k001604 = screen->machine->device("k001604");
+	nwktr_state *state = screen->machine().driver_data<nwktr_state>();
+	device_t *voodoo = screen->machine().device("voodoo");
+	device_t *k001604 = screen->machine().device("k001604");
 
-	bitmap_fill(bitmap, cliprect, screen->machine->pens[0]);
+	bitmap_fill(bitmap, cliprect, screen->machine().pens[0]);
 
 	voodoo_update(voodoo, bitmap, cliprect);
 
 	k001604_draw_front_layer(k001604, bitmap, cliprect);
 
-	draw_7segment_led(bitmap, 3, 3, led_reg0);
-	draw_7segment_led(bitmap, 9, 3, led_reg1);
+	draw_7segment_led(bitmap, 3, 3, state->m_led_reg0);
+	draw_7segment_led(bitmap, 9, 3, state->m_led_reg1);
 	return 0;
 }
 
@@ -263,21 +280,21 @@ static VIDEO_UPDATE( nwktr )
 
 static READ32_HANDLER( sysreg_r )
 {
-	device_t *adc12138 = space->machine->device("adc12138");
+	device_t *adc12138 = space->machine().device("adc12138");
 	UINT32 r = 0;
 	if (offset == 0)
 	{
 		if (ACCESSING_BITS_24_31)
 		{
-			r |= input_port_read(space->machine, "IN0") << 24;
+			r |= input_port_read(space->machine(), "IN0") << 24;
 		}
 		if (ACCESSING_BITS_16_23)
 		{
-			r |= input_port_read(space->machine, "IN1") << 16;
+			r |= input_port_read(space->machine(), "IN1") << 16;
 		}
 		if (ACCESSING_BITS_8_15)
 		{
-			r |= input_port_read(space->machine, "IN2") << 8;
+			r |= input_port_read(space->machine(), "IN2") << 8;
 		}
 		if (ACCESSING_BITS_0_7)
 		{
@@ -288,7 +305,7 @@ static READ32_HANDLER( sysreg_r )
 	{
 		if (ACCESSING_BITS_24_31)
 		{
-			r |= input_port_read(space->machine, "DSW") << 24;
+			r |= input_port_read(space->machine(), "DSW") << 24;
 		}
 	}
 	return r;
@@ -296,16 +313,17 @@ static READ32_HANDLER( sysreg_r )
 
 static WRITE32_HANDLER( sysreg_w )
 {
-	device_t *adc12138 = space->machine->device("adc12138");
+	nwktr_state *state = space->machine().driver_data<nwktr_state>();
+	device_t *adc12138 = space->machine().device("adc12138");
 	if( offset == 0 )
 	{
 		if (ACCESSING_BITS_24_31)
 		{
-			led_reg0 = (data >> 24) & 0xff;
+			state->m_led_reg0 = (data >> 24) & 0xff;
 		}
 		if (ACCESSING_BITS_16_23)
 		{
-			led_reg1 = (data >> 16) & 0xff;
+			state->m_led_reg1 = (data >> 16) & 0xff;
 		}
 		return;
 	}
@@ -327,39 +345,37 @@ static WRITE32_HANDLER( sysreg_w )
 		{
 			if (data & 0x80)	// CG Board 1 IRQ Ack
 			{
-				//cputag_set_input_line(space->machine, "maincpu", INPUT_LINE_IRQ1, CLEAR_LINE);
+				//cputag_set_input_line(space->machine(), "maincpu", INPUT_LINE_IRQ1, CLEAR_LINE);
 			}
 			if (data & 0x40)	// CG Board 0 IRQ Ack
 			{
-				//cputag_set_input_line(space->machine, "maincpu", INPUT_LINE_IRQ0, CLEAR_LINE);
+				//cputag_set_input_line(space->machine(), "maincpu", INPUT_LINE_IRQ0, CLEAR_LINE);
 			}
 		}
 		return;
 	}
 }
 
-static int fpga_uploaded = 0;
-static int lanc2_ram_r = 0;
-static int lanc2_ram_w = 0;
-static UINT8 *lanc2_ram;
 
-static void lanc2_init(running_machine *machine)
+static void lanc2_init(running_machine &machine)
 {
-	fpga_uploaded = 0;
-	lanc2_ram_r = 0;
-	lanc2_ram_w = 0;
-	lanc2_ram = auto_alloc_array(machine, UINT8, 0x8000);
+	nwktr_state *state = machine.driver_data<nwktr_state>();
+	state->m_fpga_uploaded = 0;
+	state->m_lanc2_ram_r = 0;
+	state->m_lanc2_ram_w = 0;
+	state->m_lanc2_ram = auto_alloc_array(machine, UINT8, 0x8000);
 }
 
 static READ32_HANDLER( lanc1_r )
 {
+	nwktr_state *state = space->machine().driver_data<nwktr_state>();
 	switch (offset)
 	{
 		case 0x40/4:
 		{
 			UINT32 r = 0;
 
-			r |= (fpga_uploaded) ? (1 << 6) : 0;
+			r |= (state->m_fpga_uploaded) ? (1 << 6) : 0;
 			r |= 1 << 5;
 
 			return (r) << 24;
@@ -367,7 +383,7 @@ static READ32_HANDLER( lanc1_r )
 
 		default:
 		{
-			//printf("lanc1_r: %08X, %08X at %08X\n", offset, mem_mask, cpu_get_pc(space->cpu));
+			//printf("lanc1_r: %08X, %08X at %08X\n", offset, mem_mask, cpu_get_pc(&space->device()));
 			return 0xffffffff;
 		}
 	}
@@ -375,19 +391,20 @@ static READ32_HANDLER( lanc1_r )
 
 static WRITE32_HANDLER( lanc1_w )
 {
-	//printf("lanc1_w: %08X, %08X, %08X at %08X\n", data, offset, mem_mask, cpu_get_pc(space->cpu));
+	//printf("lanc1_w: %08X, %08X, %08X at %08X\n", data, offset, mem_mask, cpu_get_pc(&space->device()));
 }
 
 static READ32_HANDLER( lanc2_r )
 {
+	nwktr_state *state = space->machine().driver_data<nwktr_state>();
 	UINT32 r = 0;
 
 	if (offset == 0)
 	{
 		if (ACCESSING_BITS_0_7)
 		{
-			r |= lanc2_ram[lanc2_ram_r & 0x7fff];
-			lanc2_ram_r++;
+			r |= state->m_lanc2_ram[state->m_lanc2_ram_r & 0x7fff];
+			state->m_lanc2_ram_r++;
 		}
 		else
 		{
@@ -403,13 +420,14 @@ static READ32_HANDLER( lanc2_r )
 		}
 	}
 
-	//printf("lanc2_r: %08X, %08X at %08X\n", offset, mem_mask, cpu_get_pc(space->cpu));
+	//printf("lanc2_r: %08X, %08X at %08X\n", offset, mem_mask, cpu_get_pc(&space->device()));
 
 	return r;
 }
 
 static WRITE32_HANDLER( lanc2_w )
 {
+	nwktr_state *state = space->machine().driver_data<nwktr_state>();
 	if (offset == 0)
 	{
 		if (ACCESSING_BITS_24_31)
@@ -425,52 +443,53 @@ static WRITE32_HANDLER( lanc2_w )
 					((value << 5) & 0x40) |
 					((value << 7) & 0x80);
 
-			fpga_uploaded = 1;
+			state->m_fpga_uploaded = 1;
 
-			//printf("lanc2_fpga_w: %02X at %08X\n", value, cpu_get_pc(space->cpu));
+			//printf("lanc2_fpga_w: %02X at %08X\n", value, cpu_get_pc(&space->device()));
 		}
 		else if (ACCESSING_BITS_0_7)
 		{
-			lanc2_ram[lanc2_ram_w & 0x7fff] = data & 0xff;
-			lanc2_ram_w++;
+			state->m_lanc2_ram[state->m_lanc2_ram_w & 0x7fff] = data & 0xff;
+			state->m_lanc2_ram_w++;
 		}
 		else
 		{
-			//printf("lanc2_w: %08X, %08X, %08X at %08X\n", data, offset, mem_mask, cpu_get_pc(space->cpu));
+			//printf("lanc2_w: %08X, %08X, %08X at %08X\n", data, offset, mem_mask, cpu_get_pc(&space->device()));
 		}
 	}
 	if (offset == 4)
 	{
-		if (mame_stricmp(space->machine->gamedrv->name, "thrilld") == 0)
+		if (mame_stricmp(space->machine().system().name, "thrilld") == 0)
 		{
-			work_ram[(0x3ffed0/4) + 0] = 0x472a3731;
-			work_ram[(0x3ffed0/4) + 1] = 0x33202020;
-			work_ram[(0x3ffed0/4) + 2] = 0x2d2d2a2a;
-			work_ram[(0x3ffed0/4) + 3] = 0x2a207878;
+			state->m_work_ram[(0x3ffed0/4) + 0] = 0x472a3731;
+			state->m_work_ram[(0x3ffed0/4) + 1] = 0x33202020;
+			state->m_work_ram[(0x3ffed0/4) + 2] = 0x2d2d2a2a;
+			state->m_work_ram[(0x3ffed0/4) + 3] = 0x2a207878;
 
-			work_ram[(0x3fff40/4) + 0] = 0x47433731;
-			work_ram[(0x3fff40/4) + 1] = 0x33000000;
-			work_ram[(0x3fff40/4) + 2] = 0x19994a41;
-			work_ram[(0x3fff40/4) + 3] = 0x4100a9b1;
+			state->m_work_ram[(0x3fff40/4) + 0] = 0x47433731;
+			state->m_work_ram[(0x3fff40/4) + 1] = 0x33000000;
+			state->m_work_ram[(0x3fff40/4) + 2] = 0x19994a41;
+			state->m_work_ram[(0x3fff40/4) + 3] = 0x4100a9b1;
 		}
 	}
 
-	//printf("lanc2_w: %08X, %08X, %08X at %08X\n", data, offset, mem_mask, cpu_get_pc(space->cpu));
+	//printf("lanc2_w: %08X, %08X, %08X at %08X\n", data, offset, mem_mask, cpu_get_pc(&space->device()));
 }
 
 /*****************************************************************************/
 
 static MACHINE_START( nwktr )
 {
+	nwktr_state *state = machine.driver_data<nwktr_state>();
 	/* set conservative DRC options */
-	ppcdrc_set_options(machine->device("maincpu"), PPCDRC_COMPATIBLE_OPTIONS);
+	ppcdrc_set_options(machine.device("maincpu"), PPCDRC_COMPATIBLE_OPTIONS);
 
 	/* configure fast RAM regions for DRC */
-	ppcdrc_add_fastram(machine->device("maincpu"), 0x00000000, 0x003fffff, FALSE, work_ram);
+	ppcdrc_add_fastram(machine.device("maincpu"), 0x00000000, 0x003fffff, FALSE, state->m_work_ram);
 }
 
-static ADDRESS_MAP_START( nwktr_map, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x00000000, 0x003fffff) AM_RAM AM_BASE(&work_ram)		/* Work RAM */
+static ADDRESS_MAP_START( nwktr_map, AS_PROGRAM, 32 )
+	AM_RANGE(0x00000000, 0x003fffff) AM_RAM AM_BASE_MEMBER(nwktr_state, m_work_ram)		/* Work RAM */
 	AM_RANGE(0x74000000, 0x740000ff) AM_DEVREADWRITE("k001604", k001604_reg_r, k001604_reg_w)
 	AM_RANGE(0x74010000, 0x74017fff) AM_RAM_WRITE(paletteram32_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x74020000, 0x7403ffff) AM_DEVREADWRITE("k001604", k001604_tile_r, k001604_tile_w)
@@ -492,7 +511,7 @@ ADDRESS_MAP_END
 
 /*****************************************************************************/
 
-static ADDRESS_MAP_START( sound_memmap, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( sound_memmap, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	AM_RANGE(0x100000, 0x10ffff) AM_RAM		/* Work RAM */
 	AM_RANGE(0x200000, 0x200fff) AM_DEVREADWRITE("rfsnd", rf5c400_r, rf5c400_w)		/* Ricoh RF5C400 */
@@ -502,19 +521,20 @@ ADDRESS_MAP_END
 
 /*****************************************************************************/
 
-static UINT32 *sharc_dataram;
 
 static READ32_HANDLER( dsp_dataram_r )
 {
-	return sharc_dataram[offset] & 0xffff;
+	nwktr_state *state = space->machine().driver_data<nwktr_state>();
+	return state->m_sharc_dataram[offset] & 0xffff;
 }
 
 static WRITE32_HANDLER( dsp_dataram_w )
 {
-	sharc_dataram[offset] = data;
+	nwktr_state *state = space->machine().driver_data<nwktr_state>();
+	state->m_sharc_dataram[offset] = data;
 }
 
-static ADDRESS_MAP_START( sharc_map, ADDRESS_SPACE_DATA, 32 )
+static ADDRESS_MAP_START( sharc_map, AS_DATA, 32 )
 	AM_RANGE(0x0400000, 0x041ffff) AM_READWRITE(cgboard_0_shared_sharc_r, cgboard_0_shared_sharc_w)
 	AM_RANGE(0x0500000, 0x05fffff) AM_READWRITE(dsp_dataram_r, dsp_dataram_w)
 	AM_RANGE(0x1400000, 0x14fffff) AM_RAM
@@ -601,11 +621,11 @@ static double adc12138_input_callback( device_t *device, UINT8 input )
 	int value = 0;
 	switch (input)
 	{
-		case 0:		value = input_port_read(device->machine, "ANALOG1") - 0x800; break;
-		case 1:		value = input_port_read(device->machine, "ANALOG2"); break;
-		case 2:		value = input_port_read(device->machine, "ANALOG3"); break;
-		case 3:		value = input_port_read(device->machine, "ANALOG4"); break;
-		case 4:		value = input_port_read(device->machine, "ANALOG5"); break;
+		case 0:		value = input_port_read(device->machine(), "ANALOG1") - 0x800; break;
+		case 1:		value = input_port_read(device->machine(), "ANALOG2"); break;
+		case 2:		value = input_port_read(device->machine(), "ANALOG3"); break;
+		case 3:		value = input_port_read(device->machine(), "ANALOG4"); break;
+		case 4:		value = input_port_read(device->machine(), "ANALOG5"); break;
 	}
 
 	return (double)(value) / 2047.0;
@@ -615,12 +635,12 @@ static const adc12138_interface nwktr_adc_interface = {
 	adc12138_input_callback
 };
 
-static void sound_irq_callback(running_machine *machine, int irq)
+static void sound_irq_callback(running_machine &machine, int irq)
 {
 	if (irq == 0)
-		generic_pulse_irq_line(machine->device("audiocpu"), INPUT_LINE_IRQ1);
+		generic_pulse_irq_line(machine.device("audiocpu"), INPUT_LINE_IRQ1);
 	else
-		generic_pulse_irq_line(machine->device("audiocpu"), INPUT_LINE_IRQ2);
+		generic_pulse_irq_line(machine.device("audiocpu"), INPUT_LINE_IRQ2);
 }
 
 static const k056800_interface nwktr_k056800_interface =
@@ -652,7 +672,7 @@ static MACHINE_RESET( nwktr )
 	cputag_set_input_line(machine, "dsp", INPUT_LINE_RESET, ASSERT_LINE);
 }
 
-static MACHINE_CONFIG_START( nwktr, driver_device )
+static MACHINE_CONFIG_START( nwktr, nwktr_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", PPC403GA, 64000000/2)	/* PowerPC 403GA 32MHz */
@@ -665,7 +685,7 @@ static MACHINE_CONFIG_START( nwktr, driver_device )
 	MCFG_CPU_CONFIG(sharc_cfg)
 	MCFG_CPU_DATA_MAP(sharc_map)
 
-	MCFG_QUANTUM_TIME(HZ(6000))
+	MCFG_QUANTUM_TIME(attotime::from_hz(6000))
 
 	MCFG_MACHINE_START(nwktr)
 	MCFG_MACHINE_RESET(nwktr)
@@ -684,11 +704,10 @@ static MACHINE_CONFIG_START( nwktr, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(512, 384)
 	MCFG_SCREEN_VISIBLE_AREA(0, 511, 0, 383)
+	MCFG_SCREEN_UPDATE(nwktr)
 
 	MCFG_PALETTE_LENGTH(65536)
 
-	MCFG_VIDEO_UPDATE(nwktr)
-
 	MCFG_K001604_ADD("k001604", racingj_k001604_intf)
 
 	MCFG_K056800_ADD("k056800", nwktr_k056800_interface)
@@ -715,11 +734,12 @@ MACHINE_CONFIG_END
 
 static DRIVER_INIT(nwktr)
 {
+	nwktr_state *state = machine.driver_data<nwktr_state>();
 	init_konami_cgboard(machine, 1, CGBOARD_TYPE_NWKTR);
-	set_cgboard_texture_bank(machine, 0, "bank5", machine->region("user5")->base());
+	set_cgboard_texture_bank(machine, 0, "bank5", machine.region("user5")->base());
 
-	sharc_dataram = auto_alloc_array(machine, UINT32, 0x100000/4);
-	led_reg0 = led_reg1 = 0x7f;
+	state->m_sharc_dataram = auto_alloc_array(machine, UINT32, 0x100000/4);
+	state->m_led_reg0 = state->m_led_reg1 = 0x7f;
 
 	lanc2_init(machine);
 }
@@ -750,7 +770,7 @@ ROM_START(racingj)
 	ROM_LOAD( "m48t58y-70pc1", 0x000000, 0x002000, CRC(47e1628c) SHA1(7c42d06ae2f2cd24d083890f333552cbf4f1d3c9) )
 ROM_END
 
-ROM_START(racingj2)
+ROM_START(racingj2j)
 	ROM_REGION32_BE(0x200000, "user1", 0)	/* PowerPC program roms */
 	ROM_LOAD16_WORD_SWAP("888a01.27p", 0x000000, 0x200000, CRC(d077890a) SHA1(08b252324cf46fbcdb95e8f9312287920cd87c5d) )
 
@@ -774,6 +794,30 @@ ROM_START(racingj2)
 	ROM_LOAD( "m48t58y-70pc1", 0x000000, 0x002000, CRC(f691f5ab) SHA1(e81f652c5caa2caa8bd1c6d6db488d849bda058e) )
 ROM_END
 
+ROM_START(racingj2)
+	ROM_REGION32_BE(0x200000, "user1", 0)	/* PowerPC program roms */
+	ROM_LOAD16_WORD_SWAP("888a01.27p", 0x000000, 0x200000, CRC(d077890a) SHA1(08b252324cf46fbcdb95e8f9312287920cd87c5d) )
+
+	ROM_REGION32_BE(0x800000, "user2", 0)		/* Data roms */
+	ROM_LOAD32_WORD_SWAP( "676a04.bin",	0x000000, 0x200000, CRC(d7808cb6) SHA1(0668fae5bb94cc120fe196d4b18200f7b512317f) )
+	ROM_LOAD32_WORD_SWAP( "676a05.bin",	0x000002, 0x200000, CRC(fb4de1ad) SHA1(f6aa4eb1b5d22901a2aaf899ed3237a9dfdc55b5) )
+	ROM_LOAD32_WORD_SWAP( "888a06.12t",	0x400000, 0x200000, CRC(00cbec4d) SHA1(1ce7807d86e90edbf4eecba462a27c725f5ad862) )
+
+	ROM_REGION32_BE(0x800000, "user5", 0)	/* CG Board Texture roms */
+	ROM_LOAD32_WORD_SWAP( "888a13.8x",    0x000000, 0x400000, CRC(2292f530) SHA1(0f4d1332708fd5366a065e0a928cc9610558b42d) )
+	ROM_LOAD32_WORD_SWAP( "888a14.16x",   0x000002, 0x400000, CRC(6a834a26) SHA1(d1fbd7ae6afd05f0edac4efde12a5a45aa2bc7df) )
+
+	ROM_REGION(0x80000, "audiocpu", 0)		/* 68k program roms */
+	ROM_LOAD16_WORD_SWAP( "888a08.7s",    0x000000, 0x080000, CRC(55fbea65) SHA1(ad953f758181731efccadcabc4326e6634c359e8) )
+
+	ROM_REGION(0x1000000, "rfsnd", 0)		/* PCM sample roms */
+	ROM_LOAD( "888a09.16p",   0x000000, 0x400000, CRC(11e2fed2) SHA1(24b8a367b59fedb62c56f066342f2fa87b135fc5) )
+	ROM_LOAD( "888a10.14p",   0x400000, 0x400000, CRC(328ce610) SHA1(dbbc779a1890c53298c0db129d496df048929496) )
+
+	ROM_REGION(0x2000, "m48t58",0)
+	ROM_LOAD( "m48t58y-70pc1.35d", 0x000000, 0x002000, CRC(1aa43a1f) SHA1(814b691b8a358bf1545a13d595d17070e612e9a4) )
+ROM_END
+
 ROM_START(thrilld)
 	ROM_REGION32_BE(0x200000, "user1", 0)	/* PowerPC program roms */
 	ROM_LOAD16_WORD_SWAP("713be01.27p", 0x000000, 0x200000, CRC(d84a7723) SHA1(f4e9e08591b7e5e8419266dbe744d56a185384ed) )
@@ -820,9 +864,35 @@ ROM_START(thrilldb)
 	ROM_LOAD( "m48t58y-70pc1", 0x000000, 0x002000, CRC(5d8fbcb2) SHA1(74ad91544d2a200cf599a565005476623075e7d6) )
 ROM_END
 
+ROM_START(thrilldae)
+	ROM_REGION32_BE(0x200000, "user1", 0)	/* PowerPC program roms */
+	ROM_LOAD16_WORD_SWAP("713bb01.27p", 0x000000, 0x200000, CRC(535fe4e8) SHA1(acd8194a4dafce289dbdfd874f0b799f25aeb73f) )
+
+	ROM_REGION32_BE(0x800000, "user2", 0)		/* Data roms */
+	ROM_LOAD32_WORD_SWAP("713a04.16t", 0x000000, 0x200000, CRC(c994aaa8) SHA1(d82b9930a11e5384ad583684a27c95beec03cd5a) )
+	ROM_LOAD32_WORD_SWAP("713a05.14t", 0x000002, 0x200000, CRC(6f1e6802) SHA1(91f8a170327e9b4ee6a64aee0c106b981a317e69) )
+
+	ROM_REGION32_BE(0x800000, "user5", 0)	/* CG Board Texture roms */
+	ROM_LOAD32_WORD_SWAP( "713a13.8x",    0x000000, 0x400000, CRC(b795c66b) SHA1(6e50de0d5cc444ffaa0fec7ada8c07f643374bb2) )
+	ROM_LOAD32_WORD_SWAP( "713a14.16x",   0x000002, 0x400000, CRC(5275a629) SHA1(16fadef06975f0f3625cac8f84e2e77ed7d75e15) )
+
+	ROM_REGION(0x80000, "audiocpu", 0)		/* 68k program roms */
+	ROM_LOAD16_WORD_SWAP( "713a08.7s",    0x000000, 0x080000, CRC(6a72a825) SHA1(abeac99c5343efacabcb0cdff6d34f9f967024db) )
+
+	ROM_REGION(0x1000000, "rfsnd", 0)		/* PCM sample roms */
+	ROM_LOAD( "713a09.16p",   0x000000, 0x400000, CRC(058f250a) SHA1(63b8e60004ec49009633e86b4992c00083def9a8) )
+	ROM_LOAD( "713a10.14p",   0x400000, 0x400000, CRC(27f9833e) SHA1(1540f00d2571ecb81b914c553682b67fca94bbbd) )
+
+	ROM_REGION(0x2000, "m48t58",0)
+	ROM_LOAD( "m48t58y-70pc1", 0x000000, 0x002000, CRC(056ea8fa) SHA1(23574e0c1d011dab8644f3d98763d4a2d11a05b3)  )
+ROM_END
+
 /*****************************************************************************/
 
-GAME( 1998, racingj,    0,       nwktr,   nwktr, nwktr, ROT0, "Konami", "Racing Jam", GAME_NOT_WORKING | GAME_NO_SOUND )
-GAME( 1999, racingj2,   racingj, nwktr,   nwktr, nwktr, ROT0, "Konami", "Racing Jam: Chapter 2", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1998, racingj,    0,       nwktr,   nwktr, nwktr, ROT0, "Konami", "Racing Jam (JAC)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1999, racingj2,   racingj, nwktr,   nwktr, nwktr, ROT0, "Konami", "Racing Jam: Chapter 2 (EAE)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1999, racingj2j,  racingj, nwktr,   nwktr, nwktr, ROT0, "Konami", "Racing Jam: Chapter 2 (JAE)", GAME_NOT_WORKING | GAME_NO_SOUND )
 GAME( 1998, thrilld,    0,       thrilld, nwktr, nwktr, ROT0, "Konami", "Thrill Drive (JAE)", GAME_NOT_WORKING | GAME_IMPERFECT_SOUND )
 GAME( 1998, thrilldb,   thrilld, thrilld, nwktr, nwktr, ROT0, "Konami", "Thrill Drive (JAB)", GAME_NOT_WORKING | GAME_IMPERFECT_SOUND )
+GAME( 1998, thrilldae,  thrilld, thrilld, nwktr, nwktr, ROT0, "Konami", "Thrill Drive (EAA)", GAME_NOT_WORKING | GAME_IMPERFECT_SOUND )
+
