@@ -42,6 +42,16 @@ HuC6280A (Hudson)
 #include "cpu/h6280/h6280.h"
 #include "sound/c6280.h"
 
+
+class paranoia_state : public driver_device
+{
+public:
+	paranoia_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+};
+
+
 static INPUT_PORTS_START( paranoia )
     PORT_START( "JOY" )
     PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON2 ) /* button I */
@@ -54,7 +64,7 @@ static INPUT_PORTS_START( paranoia )
     PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT )
 INPUT_PORTS_END
 
-static ADDRESS_MAP_START( pce_mem , ADDRESS_SPACE_PROGRAM, 8)
+static ADDRESS_MAP_START( pce_mem , AS_PROGRAM, 8)
 	AM_RANGE( 0x000000, 0x03FFFF) AM_ROM
 	AM_RANGE( 0x1F0000, 0x1F1FFF) AM_RAM AM_MIRROR(0x6000) AM_BASE( &pce_user_ram )
 	AM_RANGE( 0x1FE000, 0x1FE3FF) AM_READWRITE( vdc_0_r, vdc_0_w )
@@ -65,7 +75,7 @@ static ADDRESS_MAP_START( pce_mem , ADDRESS_SPACE_PROGRAM, 8)
 	AM_RANGE( 0x1FF400, 0x1FF7FF) AM_READWRITE( h6280_irq_status_r, h6280_irq_status_w )
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( pce_io , ADDRESS_SPACE_IO, 8)
+static ADDRESS_MAP_START( pce_io , AS_IO, 8)
 	AM_RANGE( 0x00, 0x03) AM_READWRITE( vdc_0_r, vdc_0_w )
 ADDRESS_MAP_END
 
@@ -87,7 +97,7 @@ static WRITE8_HANDLER( paranoia_8085_8155_w )
 	}
 }
 
-static ADDRESS_MAP_START(paranoia_8085_map, ADDRESS_SPACE_PROGRAM, 8)
+static ADDRESS_MAP_START(paranoia_8085_map, AS_PROGRAM, 8)
 	AM_RANGE( 0x0000, 0x7fff) AM_ROM
 	AM_RANGE( 0x8000, 0x80ff) AM_RAM
 	AM_RANGE( 0x8100, 0x8105) AM_WRITE( paranoia_8085_8155_w )
@@ -95,10 +105,10 @@ static ADDRESS_MAP_START(paranoia_8085_map, ADDRESS_SPACE_PROGRAM, 8)
 	AM_RANGE( 0xe000, 0xe1ff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START(paranoia_8085_io_map, ADDRESS_SPACE_IO, 8)
+static ADDRESS_MAP_START(paranoia_8085_io_map, AS_IO, 8)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START(paranoia_z80_map, ADDRESS_SPACE_PROGRAM, 8)
+static ADDRESS_MAP_START(paranoia_z80_map, AS_PROGRAM, 8)
 	AM_RANGE( 0x0000, 0x3fff) AM_ROM
 	AM_RANGE( 0x6000, 0x67ff) AM_RAM
 	AM_RANGE( 0x7000, 0x73ff) AM_RAM
@@ -122,7 +132,7 @@ static WRITE8_HANDLER(paranoia_z80_io_37_w)
 {
 }
 
-static ADDRESS_MAP_START(paranoia_z80_io_map, ADDRESS_SPACE_IO, 8)
+static ADDRESS_MAP_START(paranoia_z80_io_map, AS_IO, 8)
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE( 0x01, 0x01 ) AM_READ( paranoia_z80_io_01_r )
 	AM_RANGE( 0x02, 0x02 ) AM_READ( paranoia_z80_io_02_r )
@@ -135,14 +145,14 @@ static const c6280_interface c6280_config =
 	"maincpu"
 };
 
-static MACHINE_CONFIG_START( paranoia, driver_device )
+static MACHINE_CONFIG_START( paranoia, paranoia_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", H6280, PCE_MAIN_CLOCK/3)
 	MCFG_CPU_PROGRAM_MAP(pce_mem)
 	MCFG_CPU_IO_MAP(pce_io)
 	MCFG_CPU_VBLANK_INT_HACK(pce_interrupt, VDC_LPF)
 
-	MCFG_QUANTUM_TIME(HZ(60))
+	MCFG_QUANTUM_TIME(attotime::from_hz(60))
 
 	MCFG_CPU_ADD("sub", I8085A, 18000000/3)
 	MCFG_CPU_PROGRAM_MAP(paranoia_8085_map)
@@ -157,13 +167,13 @@ static MACHINE_CONFIG_START( paranoia, driver_device )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_RAW_PARAMS(PCE_MAIN_CLOCK/2, VDC_WPF, 70, 70 + 512 + 32, VDC_LPF, 14, 14+242)
+	MCFG_SCREEN_UPDATE( pce )
 
 	/* MCFG_GFXDECODE( pce_gfxdecodeinfo ) */
 	MCFG_PALETTE_LENGTH(1024)
 	MCFG_PALETTE_INIT( vce )
 
 	MCFG_VIDEO_START( pce )
-	MCFG_VIDEO_UPDATE( pce )
 
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker","rspeaker")
 	MCFG_SOUND_ADD("c6280", C6280, PCE_MAIN_CLOCK/6)
