@@ -18,48 +18,49 @@
 #include "sound/3812intf.h"
 #include "sound/msm5205.h"
 #include "includes/pcktgal.h"
+#include "video/decbac06.h"
 
 /***************************************************************************/
 
 static WRITE8_HANDLER( pcktgal_bank_w )
 {
-	UINT8 *RAM = space->machine->region("maincpu")->base();
+	UINT8 *RAM = space->machine().region("maincpu")->base();
 
-	if (data & 1) { memory_set_bankptr(space->machine, "bank1", &RAM[0x4000]); }
-	else { memory_set_bankptr(space->machine, "bank1", &RAM[0x10000]); }
+	if (data & 1) { memory_set_bankptr(space->machine(), "bank1", &RAM[0x4000]); }
+	else { memory_set_bankptr(space->machine(), "bank1", &RAM[0x10000]); }
 
-	if (data & 2) { memory_set_bankptr(space->machine, "bank2", &RAM[0x6000]); }
-	else { memory_set_bankptr(space->machine, "bank2", &RAM[0x12000]); }
+	if (data & 2) { memory_set_bankptr(space->machine(), "bank2", &RAM[0x6000]); }
+	else { memory_set_bankptr(space->machine(), "bank2", &RAM[0x12000]); }
 }
 
 static WRITE8_HANDLER( pcktgal_sound_bank_w )
 {
-	memory_set_bank(space->machine, "bank3", (data >> 2) & 1);
+	memory_set_bank(space->machine(), "bank3", (data >> 2) & 1);
 }
 
 static WRITE8_HANDLER( pcktgal_sound_w )
 {
 	soundlatch_w(space, 0, data);
-	cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
+	cputag_set_input_line(space->machine(), "audiocpu", INPUT_LINE_NMI, PULSE_LINE);
 }
 
-static int msm5205next;
 
 static void pcktgal_adpcm_int(device_t *device)
 {
-	static int toggle;
+	pcktgal_state *state = device->machine().driver_data<pcktgal_state>();
 
-	msm5205_data_w(device,msm5205next >> 4);
-	msm5205next<<=4;
+	msm5205_data_w(device,state->m_msm5205next >> 4);
+	state->m_msm5205next<<=4;
 
-	toggle = 1 - toggle;
-	if (toggle)
-		cputag_set_input_line(device->machine, "audiocpu", M6502_IRQ_LINE, HOLD_LINE);
+	state->m_toggle = 1 - state->m_toggle;
+	if (state->m_toggle)
+		cputag_set_input_line(device->machine(), "audiocpu", M6502_IRQ_LINE, HOLD_LINE);
 }
 
 static WRITE8_HANDLER( pcktgal_adpcm_data_w )
 {
-	msm5205next=data;
+	pcktgal_state *state = space->machine().driver_data<pcktgal_state>();
+	state->m_msm5205next=data;
 }
 
 static READ8_DEVICE_HANDLER( pcktgal_adpcm_reset_r )
@@ -70,13 +71,14 @@ static READ8_DEVICE_HANDLER( pcktgal_adpcm_reset_r )
 
 /***************************************************************************/
 
-static ADDRESS_MAP_START( pcktgal_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( pcktgal_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_RAM
-	AM_RANGE(0x0800, 0x0fff) AM_RAM_WRITE(pcktgal_videoram_w) AM_BASE_MEMBER(pcktgal_state, videoram)
-	AM_RANGE(0x1000, 0x11ff) AM_RAM AM_BASE_SIZE_GENERIC(spriteram)
+	AM_RANGE(0x0800, 0x0fff) AM_DEVREADWRITE("tilegen1", deco_bac06_pf_data_8bit_r, deco_bac06_pf_data_8bit_w)
+	AM_RANGE(0x1000, 0x11ff) AM_RAM AM_BASE_SIZE_MEMBER(pcktgal_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x1800, 0x1800) AM_READ_PORT("P1")
-	AM_RANGE(0x1801, 0x1801) AM_WRITE(pcktgal_flipscreen_w)
-	/* 1800 - 0x181f are unused BAC-06 registers, see video/dec0.c */
+	AM_RANGE(0x1800, 0x1807) AM_DEVWRITE("tilegen1", deco_bac06_pf_control0_8bit_w)
+	AM_RANGE(0x1810, 0x181f) AM_DEVREADWRITE("tilegen1", deco_bac06_pf_control1_8bit_r, deco_bac06_pf_control1_8bit_w)
+
 	AM_RANGE(0x1a00, 0x1a00) AM_READ_PORT("P2") AM_WRITE(pcktgal_sound_w)
 	AM_RANGE(0x1c00, 0x1c00) AM_READ_PORT("DSW") AM_WRITE(pcktgal_bank_w)
 	AM_RANGE(0x4000, 0x5fff) AM_ROMBANK("bank1")
@@ -87,7 +89,7 @@ ADDRESS_MAP_END
 
 /***************************************************************************/
 
-static ADDRESS_MAP_START( pcktgal_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( pcktgal_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_RAM
 	AM_RANGE(0x0800, 0x0801) AM_DEVWRITE("ym1", ym2203_w)
 	AM_RANGE(0x1000, 0x1001) AM_DEVWRITE("ym2", ym3812_w)
@@ -234,13 +236,15 @@ static MACHINE_CONFIG_START( pcktgal, pcktgal_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(pcktgal)
 
 	MCFG_GFXDECODE(pcktgal)
 	MCFG_PALETTE_LENGTH(512)
 
 	MCFG_PALETTE_INIT(pcktgal)
-	MCFG_VIDEO_START(pcktgal)
-	MCFG_VIDEO_UPDATE(pcktgal)
+
+	MCFG_DEVICE_ADD("tilegen1", DECO_BAC06, 0)
+	deco_bac06_device::set_gfx_region_wide(*device, 0,0,0);
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -259,6 +263,8 @@ MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( bootleg, pcktgal )
 	MCFG_GFXDECODE(bootleg)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_UPDATE(pcktgalb)
 MACHINE_CONFIG_END
 
 /***************************************************************************/
@@ -407,9 +413,9 @@ ROM_END
 static DRIVER_INIT( deco222 )
 {
 	int A;
-	address_space *space = cputag_get_address_space(machine, "audiocpu", ADDRESS_SPACE_PROGRAM);
+	address_space *space = machine.device("audiocpu")->memory().space(AS_PROGRAM);
 	UINT8 *decrypted = auto_alloc_array(machine, UINT8, 0x10000);
-	UINT8 *rom = machine->region("audiocpu")->base();
+	UINT8 *rom = machine.region("audiocpu")->base();
 
 	space->set_decrypted_region(0x8000, 0xffff, decrypted);
 
@@ -417,17 +423,17 @@ static DRIVER_INIT( deco222 )
 	for (A = 0x8000;A < 0x18000;A++)
 		decrypted[A-0x8000] = (rom[A] & 0x9f) | ((rom[A] & 0x20) << 1) | ((rom[A] & 0x40) >> 1);
 
-	memory_configure_bank(machine, "bank3", 0, 2, machine->region("audiocpu")->base() + 0x10000, 0x4000);
+	memory_configure_bank(machine, "bank3", 0, 2, machine.region("audiocpu")->base() + 0x10000, 0x4000);
 	memory_configure_bank_decrypted(machine, "bank3", 0, 2, &decrypted[0x8000], 0x4000);
 }
 
 static DRIVER_INIT( graphics )
 {
-	UINT8 *rom = machine->region("gfx1")->base();
-	int len = machine->region("gfx1")->bytes();
+	UINT8 *rom = machine.region("gfx1")->base();
+	int len = machine.region("gfx1")->bytes();
 	int i,j,temp[16];
 
-	memory_configure_bank(machine, "bank3", 0, 2, machine->region("audiocpu")->base() + 0x10000, 0x4000);
+	memory_configure_bank(machine, "bank3", 0, 2, machine.region("audiocpu")->base() + 0x10000, 0x4000);
 
 	/* Tile graphics roms have some swapped lines, original version only */
 	for (i = 0x00000;i < len;i += 32)
