@@ -70,6 +70,41 @@ the main program is 9th October 1990.
 #include "sound/hc55516.h"
 #include "sound/beep.h"
 
+
+class pcxt_state : public driver_device
+{
+public:
+	pcxt_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 *m_vga_vram;
+	UINT8 *m_work_ram;
+	UINT8 m_video_regs[0x19];
+	UINT8 *m_vga_mode;
+	UINT8 m_hv_blank;
+	UINT8 *m_vga_bg_bank;
+	int m_bank;
+	int m_lastvalue;
+	UINT8 m_video_index;
+	UINT8 m_disk_data[2];
+	UINT8 m_port_b_data;
+	UINT8 m_wss1_data;
+	UINT8 m_wss2_data;
+	UINT8 m_status;
+	UINT8 m_clr_status;
+	UINT8 m_drive_data;
+	int m_dma_channel;
+	UINT8 m_dma_offset[2][4];
+	UINT8 m_at_pages[0x10];
+
+	device_t	*m_pit8253;
+	device_t	*m_pic8259_1;
+	device_t	*m_pic8259_2;
+	device_t	*m_dma8237_1;
+	device_t	*m_dma8237_2;
+};
+
+
 #define SET_VISIBLE_AREA(_x_,_y_) \
 	{ \
 	rectangle visarea; \
@@ -77,26 +112,17 @@ the main program is 9th October 1990.
 	visarea.max_x = _x_-1; \
 	visarea.min_y = 0; \
 	visarea.max_y = _y_-1; \
-	machine->primary_screen->configure(_x_, _y_, visarea, machine->primary_screen->frame_period().attoseconds ); \
+	machine.primary_screen->configure(_x_, _y_, visarea, machine.primary_screen->frame_period().attoseconds ); \
 	} \
 
 
-static UINT8 *vga_vram,*work_ram;
-static UINT8 video_regs[0x19];
-static UINT8 *vga_mode;
-static UINT8 hv_blank;
-static UINT8 *vga_bg_bank;
-
-static int bank;
-static int lastvalue;
-
 /*Add here Video regs defines...*/
 
 
 #define RES_320x200 0
 #define RES_640x200 1
 
-static void cga_alphanumeric_tilemap(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs,UINT8 gfx_num);
+static void cga_alphanumeric_tilemap(running_machine &machine, bitmap_t *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs,UINT8 gfx_num);
 
 static VIDEO_START( filetto )
 {
@@ -113,18 +139,18 @@ static READ8_HANDLER( vga_hvretrace_r )
     ---- x--- Vertical Retrace
     ---- ---x Horizontal Retrace
     */
-	static UINT8 res;
-	static int h,w;
+	UINT8 res;
+	int h,w;
 	res = 0;
-	h = space->machine->primary_screen->height();
-	w = space->machine->primary_screen->width();
+	h = space->machine().primary_screen->height();
+	w = space->machine().primary_screen->width();
 
 //  popmessage("%d %d",h,w);
 
-	if (space->machine->primary_screen->hpos() > h)
+	if (space->machine().primary_screen->hpos() > h)
 		res|= 1;
 
-	if (space->machine->primary_screen->vpos() > w)
+	if (space->machine().primary_screen->vpos() > w)
 		res|= 8;
 
 	return res;
@@ -132,20 +158,21 @@ static READ8_HANDLER( vga_hvretrace_r )
 
 /*Basic Graphic mode */
 /*TODO: non-black colours should use the bright versions*/
-static void cga_graphic_bitmap(running_machine *machine,bitmap_t *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs)
+static void cga_graphic_bitmap(running_machine &machine,bitmap_t *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs)
 {
-	static UINT16 x,y;
-	static UINT32 offs;
+	pcxt_state *state = machine.driver_data<pcxt_state>();
+	UINT16 x,y;
+	UINT32 offs;
 
 	SET_VISIBLE_AREA(320,200);
 	offs = map_offs;
 	for(y=0;y<200;y+=2)
 		for(x=0;x<320;x+=4)
 		{
-			*BITMAP_ADDR16(bitmap, y, x+0) = machine->pens[0x200+(((vga_vram[offs] & 0xc0)>>6)<<1)];
-			*BITMAP_ADDR16(bitmap, y, x+1) = machine->pens[0x200+(((vga_vram[offs] & 0x30)>>4)<<1)];
-			*BITMAP_ADDR16(bitmap, y, x+2) = machine->pens[0x200+(((vga_vram[offs] & 0x0c)>>2)<<1)];
-			*BITMAP_ADDR16(bitmap, y, x+3) = machine->pens[0x200+(((vga_vram[offs] & 0x03)>>0)<<1)];
+			*BITMAP_ADDR16(bitmap, y, x+0) = machine.pens[0x200+(((state->m_vga_vram[offs] & 0xc0)>>6)<<1)];
+			*BITMAP_ADDR16(bitmap, y, x+1) = machine.pens[0x200+(((state->m_vga_vram[offs] & 0x30)>>4)<<1)];
+			*BITMAP_ADDR16(bitmap, y, x+2) = machine.pens[0x200+(((state->m_vga_vram[offs] & 0x0c)>>2)<<1)];
+			*BITMAP_ADDR16(bitmap, y, x+3) = machine.pens[0x200+(((state->m_vga_vram[offs] & 0x03)>>0)<<1)];
 			offs++;
 		}
 
@@ -153,10 +180,10 @@ static void cga_graphic_bitmap(running_machine *machine,bitmap_t *bitmap,const r
 	for(y=1;y<200;y+=2)
 		for(x=0;x<320;x+=4)
 		{
-			*BITMAP_ADDR16(bitmap, y, x+0) = machine->pens[0x200+(((vga_vram[offs] & 0xc0)>>6)<<1)];
-			*BITMAP_ADDR16(bitmap, y, x+1) = machine->pens[0x200+(((vga_vram[offs] & 0x30)>>4)<<1)];
-			*BITMAP_ADDR16(bitmap, y, x+2) = machine->pens[0x200+(((vga_vram[offs] & 0x0c)>>2)<<1)];
-			*BITMAP_ADDR16(bitmap, y, x+3) = machine->pens[0x200+(((vga_vram[offs] & 0x03)>>0)<<1)];
+			*BITMAP_ADDR16(bitmap, y, x+0) = machine.pens[0x200+(((state->m_vga_vram[offs] & 0xc0)>>6)<<1)];
+			*BITMAP_ADDR16(bitmap, y, x+1) = machine.pens[0x200+(((state->m_vga_vram[offs] & 0x30)>>4)<<1)];
+			*BITMAP_ADDR16(bitmap, y, x+2) = machine.pens[0x200+(((state->m_vga_vram[offs] & 0x0c)>>2)<<1)];
+			*BITMAP_ADDR16(bitmap, y, x+3) = machine.pens[0x200+(((state->m_vga_vram[offs] & 0x03)>>0)<<1)];
 			offs++;
 		}
 
@@ -164,9 +191,10 @@ static void cga_graphic_bitmap(running_machine *machine,bitmap_t *bitmap,const r
 
 
 
-static void cga_alphanumeric_tilemap(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs,UINT8 gfx_num)
+static void cga_alphanumeric_tilemap(running_machine &machine, bitmap_t *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs,UINT8 gfx_num)
 {
-	static UINT32 offs,x,y,max_x,max_y;
+	pcxt_state *state = machine.driver_data<pcxt_state>();
+	UINT32 offs,x,y,max_x,max_y;
 
 	/*define the visible area*/
 	switch(size)
@@ -181,6 +209,8 @@ static void cga_alphanumeric_tilemap(running_machine *machine, bitmap_t *bitmap,
 			max_x = 80;
 			max_y = 25;
 			break;
+		default:
+			fatalerror("Unknown size");
 	}
 
 	offs = map_offs;
@@ -188,10 +218,10 @@ static void cga_alphanumeric_tilemap(running_machine *machine, bitmap_t *bitmap,
 	for(y=0;y<max_y;y++)
 		for(x=0;x<max_x;x++)
 		{
-			int tile =  vga_vram[offs] & 0xff;
-			int color = vga_vram[offs+1] & 0xff;
+			int tile =  state->m_vga_vram[offs] & 0xff;
+			int color = state->m_vga_vram[offs+1] & 0xff;
 
-			drawgfx_transpen(bitmap,cliprect,machine->gfx[gfx_num],
+			drawgfx_transpen(bitmap,cliprect,machine.gfx[gfx_num],
 					tile,
 					color,
 					0,0,
@@ -203,8 +233,9 @@ static void cga_alphanumeric_tilemap(running_machine *machine, bitmap_t *bitmap,
 }
 
 
-static VIDEO_UPDATE( filetto )
+static SCREEN_UPDATE( filetto )
 {
+	pcxt_state *state = screen->machine().driver_data<pcxt_state>();
 /*          xx1x xxxx  Attribute bit 7. 0=blink, 1=Intesity
             xxx1 xxxx  640x200 mode
             xxxx 1xxx  Enable video signal
@@ -214,19 +245,19 @@ static VIDEO_UPDATE( filetto )
             */
 	bitmap_fill(bitmap, cliprect, 0);
 
-	if(vga_mode[0] & 8)
+	if(state->m_vga_mode[0] & 8)
 	{
-		if(vga_mode[0] & 2)
-			cga_graphic_bitmap(screen->machine,bitmap,cliprect,0,0x18000);
+		if(state->m_vga_mode[0] & 2)
+			cga_graphic_bitmap(screen->machine(),bitmap,cliprect,0,0x18000);
 		else
 		{
-			switch(vga_mode[0] & 1)
+			switch(state->m_vga_mode[0] & 1)
 			{
 				case 0x00:
-					cga_alphanumeric_tilemap(screen->machine,bitmap,cliprect,RES_320x200,0x18000,2);
+					cga_alphanumeric_tilemap(screen->machine(),bitmap,cliprect,RES_320x200,0x18000,2);
 					break;
 				case 0x01:
-					cga_alphanumeric_tilemap(screen->machine,bitmap,cliprect,RES_640x200,0x18000,2);
+					cga_alphanumeric_tilemap(screen->machine(),bitmap,cliprect,RES_640x200,0x18000,2);
 					break;
 			}
 		}
@@ -235,14 +266,15 @@ static VIDEO_UPDATE( filetto )
 	return 0;
 }
 
-static void vga_bitmap_layer(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect)
+static void vga_bitmap_layer(running_machine &machine, bitmap_t *bitmap,const rectangle *cliprect)
 {
+	pcxt_state *state = machine.driver_data<pcxt_state>();
 	int x,y,z;
-	UINT8 *region = machine->region("user1")->base();
-	static UINT32 cur_bank;
+	UINT8 *region = machine.region("user1")->base();
+	UINT32 cur_bank;
 
 	/*TODO: might be a different descramble algorythm plus plain bg bank*/
-	cur_bank = (((8-vga_bg_bank[0]) & 0x1f)*0x10000);
+	cur_bank = (((8-state->m_vga_bg_bank[0]) & 0x1f)*0x10000);
 
 	for(y=0;y<200;y+=8)
 	{
@@ -255,25 +287,26 @@ static void vga_bitmap_layer(running_machine *machine, bitmap_t *bitmap,const re
 }
 
 /*S3 Video card,VGA*/
-static VIDEO_UPDATE( tetriskr )
+static SCREEN_UPDATE( tetriskr )
 {
+	pcxt_state *state = screen->machine().driver_data<pcxt_state>();
 	bitmap_fill(bitmap, cliprect, 0);
 
-	if(vga_mode[0] & 8)
+	if(state->m_vga_mode[0] & 8)
 	{
-		if(vga_mode[0] & 2)
-			cga_graphic_bitmap(screen->machine,bitmap,cliprect,0,0x18000);
+		if(state->m_vga_mode[0] & 2)
+			cga_graphic_bitmap(screen->machine(),bitmap,cliprect,0,0x18000);
 		else
 		{
-			vga_bitmap_layer(screen->machine,bitmap,cliprect);
+			vga_bitmap_layer(screen->machine(),bitmap,cliprect);
 
-			switch(vga_mode[0] & 1)
+			switch(state->m_vga_mode[0] & 1)
 			{
 				case 0x00:
-					cga_alphanumeric_tilemap(screen->machine,bitmap,cliprect,RES_320x200,0x18000,0);
+					cga_alphanumeric_tilemap(screen->machine(),bitmap,cliprect,RES_320x200,0x18000,0);
 					break;
 				case 0x01:
-					cga_alphanumeric_tilemap(screen->machine,bitmap,cliprect,RES_640x200,0x18000,0);
+					cga_alphanumeric_tilemap(screen->machine(),bitmap,cliprect,RES_640x200,0x18000,0);
 					break;
 			}
 		}
@@ -284,59 +317,54 @@ static VIDEO_UPDATE( tetriskr )
 
 static READ8_HANDLER( vga_regs_r )
 {
-	logerror("(PC=%05x) Warning: VGA reg port read\n",cpu_get_pc(space->cpu));
+	logerror("(PC=%05x) Warning: VGA reg port read\n",cpu_get_pc(&space->device()));
 	return 0xff;
 }
 
 static WRITE8_HANDLER( vga_regs_w )
 {
-	static UINT8 video_index;
+	pcxt_state *state = space->machine().driver_data<pcxt_state>();
 
 	if(offset == 0)
 	{
-		video_index = data;
+		state->m_video_index = data;
 	}
 	if(offset == 1)
 	{
-		if(video_index <= 0x18)
+		if(state->m_video_index <= 0x18)
 		{
-			video_regs[video_index] = data;
-			//logerror("write %02x to video register [%02x]",data,video_index);
+			state->m_video_regs[state->m_video_index] = data;
+			//logerror("write %02x to video register [%02x]",data,state->m_video_index);
 		}
 		else
-			logerror("(PC=%05x) Warning: Undefined VGA reg port write (I=%02x D=%02x)\n",cpu_get_pc(space->cpu),video_index,data);
+			logerror("(PC=%05x) Warning: Undefined VGA reg port write (I=%02x D=%02x)\n",cpu_get_pc(&space->device()),state->m_video_index,data);
 	}
 }
 
 static WRITE8_HANDLER( vga_vram_w )
 {
-	vga_vram[offset] = data;
+	pcxt_state *state = space->machine().driver_data<pcxt_state>();
+	state->m_vga_vram[offset] = data;
 }
 
 /*end of Video HW file*/
 
-static struct {
-	device_t	*pit8253;
-	device_t	*pic8259_1;
-	device_t	*pic8259_2;
-	device_t	*dma8237_1;
-	device_t	*dma8237_2;
-} filetto_devices;
 
 
-static UINT8 disk_data[2];
 
 static READ8_HANDLER( disk_iobank_r )
 {
-	//printf("Read Prototyping card [%02x] @ PC=%05x\n",offset,cpu_get_pc(space->cpu));
-	//if(offset == 0) return input_port_read(space->machine, "DSW");
-	if(offset == 1) return input_port_read(space->machine, "IN1");
+	pcxt_state *state = space->machine().driver_data<pcxt_state>();
+	//printf("Read Prototyping card [%02x] @ PC=%05x\n",offset,cpu_get_pc(&space->device()));
+	//if(offset == 0) return input_port_read(space->machine(), "DSW");
+	if(offset == 1) return input_port_read(space->machine(), "IN1");
 
-	return disk_data[offset];
+	return state->m_disk_data[offset];
 }
 
 static WRITE8_HANDLER( disk_iobank_w )
 {
+	pcxt_state *state = space->machine().driver_data<pcxt_state>();
 /*
     BIOS does a single out $0310,$F0 on reset
 
@@ -367,27 +395,27 @@ static WRITE8_HANDLER( disk_iobank_w )
 	}
 	else
 	{
-		if((lastvalue == 0xF0) && (data == 0xF2))
+		if((state->m_lastvalue == 0xF0) && (data == 0xF2))
 			newbank = 0;
-		else if ((lastvalue == 0xF1) && (data == 0xF2))
+		else if ((state->m_lastvalue == 0xF1) && (data == 0xF2))
 			newbank = 1;
-		else if ((lastvalue == 0xF0) && (data == 0xF3))
+		else if ((state->m_lastvalue == 0xF0) && (data == 0xF3))
 			newbank = 2;
-		else if ((lastvalue == 0xF1) && (data == 0xF3))
+		else if ((state->m_lastvalue == 0xF1) && (data == 0xF3))
 			newbank = 3;
 	}
 
 //  printf("newbank = %d\n", newbank);
 
-	if (newbank != bank)
+	if (newbank != state->m_bank)
 	{
-		bank = newbank;
-		memory_set_bankptr(space->machine,  "bank1",space->machine->region("user1")->base() + 0x10000 * bank );
+		state->m_bank = newbank;
+		memory_set_bankptr(space->machine(),  "bank1",space->machine().region("user1")->base() + 0x10000 * state->m_bank );
 	}
 
-	lastvalue = data;
+	state->m_lastvalue = data;
 
-	disk_data[offset] = data;
+	state->m_disk_data[offset] = data;
 }
 
 /*********************************
@@ -413,12 +441,11 @@ static const struct pit8253_config pc_pit8253_config =
 	}
 };
 
-static UINT8 port_b_data;
-static UINT8 wss1_data,wss2_data;
 
 static READ8_DEVICE_HANDLER( port_a_r )
 {
-	if(!(port_b_data & 0x80))//???
+	pcxt_state *state = device->machine().driver_data<pcxt_state>();
+	if(!(state->m_port_b_data & 0x80))//???
 	{
 		/*
         x--- ---- Undefined (Always 0)
@@ -428,11 +455,11 @@ static READ8_DEVICE_HANDLER( port_a_r )
         ---- --x- 8087 NDP installed
         ---- ---x Undefined (Always 1)
         */
-		return wss1_data;
+		return state->m_wss1_data;
 	}
 	else//keyboard emulation
 	{
-		//cputag_set_input_line(device->machine, "maincpu", 1, PULSE_LINE);
+		//cputag_set_input_line(device->machine(), "maincpu", 1, PULSE_LINE);
 		return 0x00;//Keyboard is disconnected
 		//return 0xaa;//Keyboard code
 	}
@@ -440,12 +467,14 @@ static READ8_DEVICE_HANDLER( port_a_r )
 
 static READ8_DEVICE_HANDLER( port_b_r )
 {
-	return port_b_data;
+	pcxt_state *state = device->machine().driver_data<pcxt_state>();
+	return state->m_port_b_data;
 }
 
 static READ8_DEVICE_HANDLER( port_c_r )
 {
-	return wss2_data;//???
+	pcxt_state *state = device->machine().driver_data<pcxt_state>();
+	return state->m_wss2_data;//???
 }
 
 /*'buzzer' sound routes here*/
@@ -453,29 +482,32 @@ static READ8_DEVICE_HANDLER( port_c_r )
 /* The Korean Tetris uses it as a regular buzzer,probably the sound is all in there...*/
 static WRITE8_DEVICE_HANDLER( port_b_w )
 {
-	port_b_data = data;
-// device_t *beep = device->machine->device("beep");
-// device_t *cvsd = device->machine->device("cvsd");
+	pcxt_state *state = device->machine().driver_data<pcxt_state>();
+	state->m_port_b_data = data;
+// device_t *beep = device->machine().device("beep");
+// device_t *cvsd = device->machine().device("cvsd");
 //  hc55516_digit_w(cvsd, data);
 //  popmessage("%02x\n",data);
 //  beep_set_state(beep, 0);
 //  beep_set_state(beep, 1);
-//  beep_set_frequency(beep, port_b_data);
+//  beep_set_frequency(beep, state->m_port_b_data);
 }
 
 static WRITE8_DEVICE_HANDLER( wss_1_w )
 {
-	wss1_data = data;
+	pcxt_state *state = device->machine().driver_data<pcxt_state>();
+	state->m_wss1_data = data;
 }
 
 static WRITE8_DEVICE_HANDLER( wss_2_w )
 {
-	wss2_data = data;
+	pcxt_state *state = device->machine().driver_data<pcxt_state>();
+	state->m_wss2_data = data;
 }
 
 static WRITE8_DEVICE_HANDLER( sys_reset_w )
 {
-	cputag_set_input_line(device->machine, "maincpu", INPUT_LINE_RESET, PULSE_LINE);
+	cputag_set_input_line(device->machine(), "maincpu", INPUT_LINE_RESET, PULSE_LINE);
 }
 
 
@@ -501,7 +533,6 @@ static const ppi8255_interface filetto_ppi8255_intf[2] =
 
 /*Floppy Disk Controller 765 device*/
 /*Currently we only emulate it at a point that the BIOS will pass the checks*/
-static UINT8 status;
 
 #define FDC_BUSY 0x10
 #define FDC_WRITE 0x40
@@ -509,49 +540,49 @@ static UINT8 status;
 
 static READ8_HANDLER( fdc765_status_r )
 {
-	static UINT8 tmp,clr_status;
-//  popmessage("Read FDC status @ PC=%05x",cpu_get_pc(space->cpu));
-	tmp = status | 0x80;
-	clr_status++;
-	if(clr_status == 0x10)
+	pcxt_state *state = space->machine().driver_data<pcxt_state>();
+	UINT8 tmp;
+//  popmessage("Read FDC status @ PC=%05x",cpu_get_pc(&space->device()));
+	tmp = state->m_status | 0x80;
+	state->m_clr_status++;
+	if(state->m_clr_status == 0x10)
 	{
-		status = 0;
-		clr_status = 0;
+		state->m_status = 0;
+		state->m_clr_status = 0;
 	}
 	return tmp;
 }
 
 static READ8_HANDLER( fdc765_data_r )
 {
-	status = (FDC_READ);
+	pcxt_state *state = space->machine().driver_data<pcxt_state>();
+	state->m_status = (FDC_READ);
 	return 0xc0;
 }
 
 static WRITE8_HANDLER( fdc765_data_w )
 {
-	status = (FDC_WRITE);
+	pcxt_state *state = space->machine().driver_data<pcxt_state>();
+	state->m_status = (FDC_WRITE);
 }
 
-static UINT8 drive_data;
 
 static WRITE8_HANDLER( drive_selection_w )
 {
-	drive_data = data;
+	pcxt_state *state = space->machine().driver_data<pcxt_state>();
+	state->m_drive_data = data;
 	/*write to this area then expects that location [43e] has the bit 7 activated*/
-	work_ram[0x3e] = 0x80;
+	state->m_work_ram[0x3e] = 0x80;
 }
 
 /******************
 DMA8237 Controller
 ******************/
 
-static int dma_channel;
-static UINT8 dma_offset[2][4];
-static UINT8 at_pages[0x10];
 
 static WRITE_LINE_DEVICE_HANDLER( pc_dma_hrq_changed )
 {
-	cputag_set_input_line(device->machine, "maincpu", INPUT_LINE_HALT, state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine(), "maincpu", INPUT_LINE_HALT, state ? ASSERT_LINE : CLEAR_LINE);
 
 	/* Assert HLDA */
 	i8237_hlda_w( device, state );
@@ -560,7 +591,8 @@ static WRITE_LINE_DEVICE_HANDLER( pc_dma_hrq_changed )
 
 static READ8_HANDLER( pc_dma_read_byte )
 {
-	offs_t page_offset = (((offs_t) dma_offset[0][dma_channel]) << 16)
+	pcxt_state *state = space->machine().driver_data<pcxt_state>();
+	offs_t page_offset = (((offs_t) state->m_dma_offset[0][state->m_dma_channel]) << 16)
 		& 0xFF0000;
 
 	return space->read_byte(page_offset + offset);
@@ -569,7 +601,8 @@ static READ8_HANDLER( pc_dma_read_byte )
 
 static WRITE8_HANDLER( pc_dma_write_byte )
 {
-	offs_t page_offset = (((offs_t) dma_offset[0][dma_channel]) << 16)
+	pcxt_state *state = space->machine().driver_data<pcxt_state>();
+	offs_t page_offset = (((offs_t) state->m_dma_offset[0][state->m_dma_channel]) << 16)
 		& 0xFF0000;
 
 	space->write_byte(page_offset + offset, data);
@@ -577,20 +610,21 @@ static WRITE8_HANDLER( pc_dma_write_byte )
 
 static READ8_HANDLER(dma_page_select_r)
 {
-	UINT8 data = at_pages[offset % 0x10];
+	pcxt_state *state = space->machine().driver_data<pcxt_state>();
+	UINT8 data = state->m_at_pages[offset % 0x10];
 
 	switch(offset % 8) {
 	case 1:
-		data = dma_offset[(offset / 8) & 1][2];
+		data = state->m_dma_offset[(offset / 8) & 1][2];
 		break;
 	case 2:
-		data = dma_offset[(offset / 8) & 1][3];
+		data = state->m_dma_offset[(offset / 8) & 1][3];
 		break;
 	case 3:
-		data = dma_offset[(offset / 8) & 1][1];
+		data = state->m_dma_offset[(offset / 8) & 1][1];
 		break;
 	case 7:
-		data = dma_offset[(offset / 8) & 1][0];
+		data = state->m_dma_offset[(offset / 8) & 1][0];
 		break;
 	}
 	return data;
@@ -599,27 +633,29 @@ static READ8_HANDLER(dma_page_select_r)
 
 static WRITE8_HANDLER(dma_page_select_w)
 {
-	at_pages[offset % 0x10] = data;
+	pcxt_state *state = space->machine().driver_data<pcxt_state>();
+	state->m_at_pages[offset % 0x10] = data;
 
 	switch(offset % 8) {
 	case 1:
-		dma_offset[(offset / 8) & 1][2] = data;
+		state->m_dma_offset[(offset / 8) & 1][2] = data;
 		break;
 	case 2:
-		dma_offset[(offset / 8) & 1][3] = data;
+		state->m_dma_offset[(offset / 8) & 1][3] = data;
 		break;
 	case 3:
-		dma_offset[(offset / 8) & 1][1] = data;
+		state->m_dma_offset[(offset / 8) & 1][1] = data;
 		break;
 	case 7:
-		dma_offset[(offset / 8) & 1][0] = data;
+		state->m_dma_offset[(offset / 8) & 1][0] = data;
 		break;
 	}
 }
 
 static void set_dma_channel(device_t *device, int channel, int state)
 {
-	if (!state) dma_channel = channel;
+	pcxt_state *drvstate = device->machine().driver_data<pcxt_state>();
+	if (!state) drvstate->m_dma_channel = channel;
 }
 
 static WRITE_LINE_DEVICE_HANDLER( pc_dack0_w ) { set_dma_channel(device, 0, state); }
@@ -644,40 +680,48 @@ static I8237_INTERFACE( dma8237_1_config )
 
 static WRITE_LINE_DEVICE_HANDLER( pic8259_1_set_int_line )
 {
-	cputag_set_input_line(device->machine, "maincpu", 0, state ? HOLD_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine(), "maincpu", 0, state ? HOLD_LINE : CLEAR_LINE);
+}
+
+static READ8_DEVICE_HANDLER( get_slave_ack )
+{
+	pcxt_state *state = device->machine().driver_data<pcxt_state>();
+	if (offset==2) { // IRQ = 2
+		return pic8259_acknowledge(state->m_pic8259_2);
+	}
+	return 0x00;
 }
 
 static const struct pic8259_interface pic8259_1_config =
 {
-	DEVCB_LINE(pic8259_1_set_int_line)
+	DEVCB_LINE(pic8259_1_set_int_line),
+	DEVCB_LINE_VCC,
+	DEVCB_HANDLER(get_slave_ack)
 };
 
 static const struct pic8259_interface pic8259_2_config =
 {
-	DEVCB_DEVICE_LINE("pic8259_1", pic8259_ir2_w)
+	DEVCB_DEVICE_LINE("pic8259_1", pic8259_ir2_w),
+	DEVCB_LINE_GND,
+	DEVCB_NULL
 };
 
 static IRQ_CALLBACK(irq_callback)
 {
-	int r = 0;
-	r = pic8259_acknowledge(filetto_devices.pic8259_2);
-	if (r==0)
-	{
-		r = pic8259_acknowledge(filetto_devices.pic8259_1);
-	}
-	return r;
+	pcxt_state *state = device->machine().driver_data<pcxt_state>();
+	return pic8259_acknowledge(state->m_pic8259_1);
 }
 
-static ADDRESS_MAP_START( filetto_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( filetto_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x00000, 0x003ff) AM_RAM //irq vectors
-	AM_RANGE(0x00400, 0x007ff) AM_RAM AM_BASE(&work_ram)
+	AM_RANGE(0x00400, 0x007ff) AM_RAM AM_BASE_MEMBER(pcxt_state, m_work_ram)
 	AM_RANGE(0x00800, 0x9ffff) AM_RAM //work RAM 640KB
-	AM_RANGE(0xa0000, 0xbffff) AM_RAM_WRITE(vga_vram_w) AM_BASE(&vga_vram)//VGA RAM
+	AM_RANGE(0xa0000, 0xbffff) AM_RAM_WRITE(vga_vram_w) AM_BASE_MEMBER(pcxt_state, m_vga_vram)//VGA RAM
 	AM_RANGE(0xc0000, 0xcffff) AM_ROMBANK("bank1")
 	AM_RANGE(0xf0000, 0xfffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( filetto_io, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( filetto_io, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0x3ff)
 	AM_RANGE(0x0000, 0x000f) AM_DEVREADWRITE("dma8237_1", i8237_r, i8237_w ) //8237 DMA Controller
 	AM_RANGE(0x0020, 0x002f) AM_DEVREADWRITE("pic8259_1", pic8259_r, pic8259_w ) //8259 Interrupt control
@@ -697,7 +741,7 @@ static ADDRESS_MAP_START( filetto_io, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x03bc, 0x03bf) AM_RAM //printer port
 	AM_RANGE(0x03b4, 0x03b5) AM_READWRITE(vga_regs_r,vga_regs_w) //various VGA/CGA/EGA regs
 	AM_RANGE(0x03d4, 0x03d5) AM_READWRITE(vga_regs_r,vga_regs_w) //mirror of above
-	AM_RANGE(0x03d8, 0x03d9) AM_RAM AM_BASE(&vga_mode)
+	AM_RANGE(0x03d8, 0x03d9) AM_RAM AM_BASE_MEMBER(pcxt_state, m_vga_mode)
 	AM_RANGE(0x03ba, 0x03bb) AM_READ(vga_hvretrace_r)//Controls H-Blank/V-Blank
 	AM_RANGE(0x03da, 0x03db) AM_READ(vga_hvretrace_r)//mirror of above
 	AM_RANGE(0x03f2, 0x03f2) AM_WRITE(drive_selection_w)
@@ -706,7 +750,7 @@ static ADDRESS_MAP_START( filetto_io, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x03f8, 0x03ff) AM_RAM //rs232c (serial) port
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( tetriskr_io, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( tetriskr_io, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0x3ff)
 	AM_RANGE(0x0000, 0x000f) AM_DEVREADWRITE("dma8237_1", i8237_r, i8237_w ) //8237 DMA Controller
 	AM_RANGE(0x0020, 0x002f) AM_DEVREADWRITE("pic8259_1", pic8259_r, pic8259_w ) //8259 Interrupt control
@@ -723,14 +767,14 @@ static ADDRESS_MAP_START( tetriskr_io, ADDRESS_SPACE_IO, 8 )
 //  AM_RANGE(0x0310, 0x0311) AM_READWRITE(disk_iobank_r,disk_iobank_w) //Prototyping card
 //  AM_RANGE(0x0312, 0x0312) AM_READ_PORT("IN0") //Prototyping card,read only
 	AM_RANGE(0x0378, 0x037f) AM_RAM //printer (parallel) port
-	AM_RANGE(0x03c0, 0x03c0) AM_RAM AM_BASE(&vga_bg_bank)
+	AM_RANGE(0x03c0, 0x03c0) AM_RAM AM_BASE_MEMBER(pcxt_state, m_vga_bg_bank)
 	AM_RANGE(0x03c8, 0x03c8) AM_READ_PORT("IN0")
 	AM_RANGE(0x03c9, 0x03c9) AM_READ_PORT("IN1")
 //  AM_RANGE(0x03ce, 0x03ce) AM_READ_PORT("IN1")
 	AM_RANGE(0x03bc, 0x03bf) AM_RAM //printer port
 	AM_RANGE(0x03b4, 0x03b5) AM_READWRITE(vga_regs_r,vga_regs_w) //various VGA/CGA/EGA regs
 	AM_RANGE(0x03d4, 0x03d5) AM_READWRITE(vga_regs_r,vga_regs_w) //mirror of above
-	AM_RANGE(0x03d8, 0x03d9) AM_RAM AM_BASE(&vga_mode)
+	AM_RANGE(0x03d8, 0x03d9) AM_RAM AM_BASE_MEMBER(pcxt_state, m_vga_mode)
 	AM_RANGE(0x03ba, 0x03bb) AM_READ(vga_hvretrace_r)//Controls H-Blank/V-Blank
 	AM_RANGE(0x03da, 0x03db) AM_READ(vga_hvretrace_r)//mirror of above
 	AM_RANGE(0x03f2, 0x03f2) AM_WRITE(drive_selection_w)
@@ -906,18 +950,19 @@ static PALETTE_INIT(filetto)
 
 static MACHINE_RESET( filetto )
 {
-	bank = -1;
-	lastvalue = -1;
-	hv_blank = 0;
-	cpu_set_irq_callback(machine->device("maincpu"), irq_callback);
-	filetto_devices.pit8253 = machine->device( "pit8253" );
-	filetto_devices.pic8259_1 = machine->device( "pic8259_1" );
-	filetto_devices.pic8259_2 = machine->device( "pic8259_2" );
-	filetto_devices.dma8237_1 = machine->device( "dma8237_1" );
-	filetto_devices.dma8237_2 = machine->device( "dma8237_2" );
+	pcxt_state *state = machine.driver_data<pcxt_state>();
+	state->m_bank = -1;
+	state->m_lastvalue = -1;
+	state->m_hv_blank = 0;
+	device_set_irq_callback(machine.device("maincpu"), irq_callback);
+	state->m_pit8253 = machine.device( "pit8253" );
+	state->m_pic8259_1 = machine.device( "pic8259_1" );
+	state->m_pic8259_2 = machine.device( "pic8259_2" );
+	state->m_dma8237_1 = machine.device( "dma8237_1" );
+	state->m_dma8237_2 = machine.device( "dma8237_2" );
 }
 
-static MACHINE_CONFIG_START( filetto, driver_device )
+static MACHINE_CONFIG_START( filetto, pcxt_state )
 	MCFG_CPU_ADD("maincpu", I8088, 8000000) //or regular PC-XT 14318180/3 clock?
 	MCFG_CPU_PROGRAM_MAP(filetto_map)
 	MCFG_CPU_IO_MAP(filetto_io)
@@ -945,13 +990,13 @@ static MACHINE_CONFIG_START( filetto, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(640, 480)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 640-1, 0*8, 480-1)
+	MCFG_SCREEN_UPDATE(filetto)
 
 	MCFG_PALETTE_LENGTH(0x300)
 
 	MCFG_PALETTE_INIT(filetto)
 
 	MCFG_VIDEO_START(filetto)
-	MCFG_VIDEO_UPDATE(filetto)
 
 	/*Sound Hardware*/
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -964,7 +1009,7 @@ static MACHINE_CONFIG_START( filetto, driver_device )
 	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.33)
 MACHINE_CONFIG_END
 
-static MACHINE_CONFIG_START( tetriskr, driver_device )
+static MACHINE_CONFIG_START( tetriskr, pcxt_state )
 	MCFG_CPU_ADD("maincpu", I8088, 14318180/3)
 	MCFG_CPU_PROGRAM_MAP(filetto_map)
 	MCFG_CPU_IO_MAP(tetriskr_io)
@@ -992,13 +1037,13 @@ static MACHINE_CONFIG_START( tetriskr, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(640, 480)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 640-1, 0*8, 480-1)
+	MCFG_SCREEN_UPDATE(tetriskr)
 
 	MCFG_PALETTE_LENGTH(0x300)
 
 	MCFG_PALETTE_INIT(filetto)
 
 	MCFG_VIDEO_START(tetriskr)
-	MCFG_VIDEO_UPDATE(tetriskr)
 
 	/*Sound Hardware*/
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -1064,8 +1109,8 @@ static DRIVER_INIT( tetriskr )
 {
 	int i,j,k;
 	int index=0;
-	UINT8 *region = machine->region("user1")->base();
-	UINT8 *gfx = machine->region("gfx2")->base();
+	UINT8 *region = machine.region("user1")->base();
+	UINT8 *gfx = machine.region("gfx2")->base();
 
 	for(i=0;i<0x20000;i++)
 	{
