@@ -178,12 +178,34 @@ Stephh's log (2007.11.28) :
 class peplus_state : public driver_device
 {
 public:
-	peplus_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config),
-		  cmos_ram(*this, "cmos") { }
+	peplus_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag),
+		  m_cmos_ram(*this, "cmos") { }
 
-	UINT8 *videoram;
-	required_shared_ptr<UINT8> cmos_ram;
+	UINT8 *m_videoram;
+	required_shared_ptr<UINT8> m_cmos_ram;
+	UINT16 m_autohold_addr;
+	tilemap_t *m_bg_tilemap;
+	UINT8 m_wingboard;
+	UINT8 m_jumper_e16_e17;
+	UINT8 *m_program_ram;
+	UINT8 *m_s3000_ram;
+	UINT8 *m_s5000_ram;
+	UINT8 *m_s7000_ram;
+	UINT8 *m_sb000_ram;
+	UINT8 *m_sd000_ram;
+	UINT8 *m_sf000_ram;
+	UINT16 m_vid_address;
+	UINT8 *m_palette_ram;
+	UINT8 *m_palette_ram2;
+	UINT8 *m_io_port;
+	UINT64 m_last_cycles;
+	UINT8 m_coin_state;
+	UINT64 m_last_door;
+	UINT8 m_door_open;
+	UINT64 m_last_coin_out;
+	UINT8 m_coin_out_state;
+	int m_sda_dir;
 };
 
 
@@ -192,41 +214,7 @@ public:
 #define MC6845_CLOCK		((MASTER_CLOCK)/8/3)
 #define SOUND_CLOCK			((MASTER_CLOCK)/12)
 
-static UINT16 autohold_addr; /* address to patch in program RAM to enable autohold feature */
 
-static tilemap_t *bg_tilemap;
-static UINT8 wingboard;
-static UINT8 jumper_e16_e17; /* Set this to TRUE when CG chips are 27c512 instead of 27c256 */
-
-/* Pointers to External RAM */
-static UINT8 *program_ram;
-static UINT8 *s3000_ram;
-static UINT8 *s5000_ram;
-static UINT8 *s7000_ram;
-static UINT8 *sb000_ram;
-static UINT8 *sd000_ram;
-static UINT8 *sf000_ram;
-
-/* Variables used instead of CRTC6845 system */
-static UINT16 vid_address = 0;
-
-/* Holds upper video address, palette number and jumper_e16_e17 flag */
-static UINT8 *palette_ram;
-static UINT8 *palette_ram2;
-
-/* IO Ports */
-static UINT8 *io_port;
-
-/* Coin, Door, Hopper and EEPROM States */
-static UINT64 last_cycles;
-static UINT8 coin_state = 0;
-static UINT64 last_door;
-static UINT8 door_open = 0;
-static UINT64 last_coin_out;
-static UINT8 coin_out_state = 0;
-static int sda_dir = 0;
-
-/* Static Variables */
 #define eeprom_NVRAM_SIZE   0x200 // 4k Bit
 
 /* EEPROM is a X2404P 4K-bit Serial I2C Bus */
@@ -258,17 +246,18 @@ static const mc6845_interface mc6845_intf =
 * Memory Copy *
 ***************/
 
-static void peplus_load_superdata(running_machine *machine, const char *bank_name)
+static void peplus_load_superdata(running_machine &machine, const char *bank_name)
 {
-    UINT8 *super_data = machine->region(bank_name)->base();
+	peplus_state *state = machine.driver_data<peplus_state>();
+    UINT8 *super_data = machine.region(bank_name)->base();
 
     /* Distribute Superboard Data */
-    memcpy(s3000_ram, &super_data[0x3000], 0x1000);
-    memcpy(s5000_ram, &super_data[0x5000], 0x1000);
-    memcpy(s7000_ram, &super_data[0x7000], 0x1000);
-    memcpy(sb000_ram, &super_data[0xb000], 0x1000);
-    memcpy(sd000_ram, &super_data[0xd000], 0x1000);
-    memcpy(sf000_ram, &super_data[0xf000], 0x1000);
+    memcpy(state->m_s3000_ram, &super_data[0x3000], 0x1000);
+    memcpy(state->m_s5000_ram, &super_data[0x5000], 0x1000);
+    memcpy(state->m_s7000_ram, &super_data[0x7000], 0x1000);
+    memcpy(state->m_sb000_ram, &super_data[0xb000], 0x1000);
+    memcpy(state->m_sd000_ram, &super_data[0xd000], 0x1000);
+    memcpy(state->m_sf000_ram, &super_data[0xf000], 0x1000);
 }
 
 
@@ -280,7 +269,7 @@ static WRITE8_HANDLER( peplus_bgcolor_w )
 {
 	int i;
 
-	for (i = 0; i < space->machine->total_colors(); i++)
+	for (i = 0; i < space->machine().total_colors(); i++)
 	{
 		int bit0, bit1, bit2, r, g, b;
 
@@ -302,7 +291,7 @@ static WRITE8_HANDLER( peplus_bgcolor_w )
 		bit2 = 0;
 		b = 0x21 * bit2 + 0x47 * bit1 + 0x97 * bit0;
 
-		palette_set_color(space->machine, (15 + (i*16)), MAKE_RGB(r, g, b));
+		palette_set_color(space->machine(), (15 + (i*16)), MAKE_RGB(r, g, b));
 	}
 }
 
@@ -311,7 +300,8 @@ static WRITE8_HANDLER( peplus_bgcolor_w )
 
 static MC6845_ON_UPDATE_ADDR_CHANGED(crtc_addr)
 {
-	vid_address = address;
+	peplus_state *state = device->machine().driver_data<peplus_state>();
+	state->m_vid_address = address;
 }
 
 static WRITE8_DEVICE_HANDLER( peplus_crtc_mode_w )
@@ -321,45 +311,46 @@ static WRITE8_DEVICE_HANDLER( peplus_crtc_mode_w )
 
 static TIMER_CALLBACK(assert_lp_cb)
 {
-	mc6845_assert_light_pen_input((device_t *) ptr);
+	downcast<mc6845_device *>((device_t*)ptr)->assert_light_pen_input();
 }
 
 static void handle_lightpen( device_t *device )
 {
-    int x_val = input_port_read_safe(device->machine, "TOUCH_X",0x00);
-    int y_val = input_port_read_safe(device->machine, "TOUCH_Y",0x00);
-    const rectangle &vis_area = device->machine->primary_screen->visible_area();
+    int x_val = input_port_read_safe(device->machine(), "TOUCH_X",0x00);
+    int y_val = input_port_read_safe(device->machine(), "TOUCH_Y",0x00);
+    const rectangle &vis_area = device->machine().primary_screen->visible_area();
     int xt, yt;
 
     xt = x_val * (vis_area.max_x - vis_area.min_x) / 1024 + vis_area.min_x;
     yt = y_val * (vis_area.max_y - vis_area.min_y) / 1024 + vis_area.min_y;
 
-     timer_set(device->machine, device->machine->primary_screen->time_until_pos(yt, xt), (void *) device, 0, assert_lp_cb);
+     device->machine().scheduler().timer_set(device->machine().primary_screen->time_until_pos(yt, xt), FUNC(assert_lp_cb), 0, device);
 }
 
 static WRITE_LINE_DEVICE_HANDLER(crtc_vsync)
 {
-	cputag_set_input_line(device->machine, "maincpu", 0, state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine(), "maincpu", 0, state ? ASSERT_LINE : CLEAR_LINE);
 	handle_lightpen(device);
 }
 
-static WRITE8_DEVICE_HANDLER( peplus_crtc_display_w )
+static WRITE8_HANDLER( peplus_crtc_display_w )
 {
-	peplus_state *state = device->machine->driver_data<peplus_state>();
-	UINT8 *videoram = state->videoram;
-	videoram[vid_address] = data;
-	palette_ram[vid_address] = io_port[1];
-	palette_ram2[vid_address] = io_port[3];
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	UINT8 *videoram = state->m_videoram;
+	videoram[state->m_vid_address] = data;
+	state->m_palette_ram[state->m_vid_address] = state->m_io_port[1];
+	state->m_palette_ram2[state->m_vid_address] = state->m_io_port[3];
 
-	tilemap_mark_tile_dirty(bg_tilemap, vid_address);
+	tilemap_mark_tile_dirty(state->m_bg_tilemap, state->m_vid_address);
 
 	/* An access here triggers a device read !*/
-	(void) mc6845_register_r(device, 0);
+	space->machine().device<mc6845_device>("crtc")->register_r(*space, 0);
 }
 
 static WRITE8_HANDLER( peplus_io_w )
 {
-	io_port[offset] = data;
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	state->m_io_port[offset] = data;
 }
 
 static WRITE8_HANDLER( peplus_duart_w )
@@ -369,51 +360,58 @@ static WRITE8_HANDLER( peplus_duart_w )
 
 static WRITE8_HANDLER( peplus_cmos_w )
 {
-	peplus_state *state = space->machine->driver_data<peplus_state>();
+	peplus_state *state = space->machine().driver_data<peplus_state>();
 	char bank_name[6];
 
 	/* Test for Wingboard PAL Trigger Condition */
-	if (offset == 0x1fff && wingboard && data < 5)
+	if (offset == 0x1fff && state->m_wingboard && data < 5)
 	{
 		sprintf(bank_name, "user%d", data + 1);
-		peplus_load_superdata(space->machine, bank_name);
+		peplus_load_superdata(space->machine(), bank_name);
 	}
 
-	state->cmos_ram[offset] = data;
+	state->m_cmos_ram[offset] = data;
 }
 
 static WRITE8_HANDLER( peplus_s3000_w )
 {
-	s3000_ram[offset] = data;
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	state->m_s3000_ram[offset] = data;
 }
 
 static WRITE8_HANDLER( peplus_s5000_w )
 {
-	s5000_ram[offset] = data;
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	state->m_s5000_ram[offset] = data;
 }
 
 static WRITE8_HANDLER( peplus_s7000_w )
 {
-	s7000_ram[offset] = data;
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	state->m_s7000_ram[offset] = data;
 }
 
 static WRITE8_HANDLER( peplus_sb000_w )
 {
-	sb000_ram[offset] = data;
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	state->m_sb000_ram[offset] = data;
 }
 
 static WRITE8_HANDLER( peplus_sd000_w )
 {
-	sd000_ram[offset] = data;
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	state->m_sd000_ram[offset] = data;
 }
 
 static WRITE8_HANDLER( peplus_sf000_w )
 {
-	sf000_ram[offset] = data;
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	state->m_sf000_ram[offset] = data;
 }
 
 static WRITE8_HANDLER( peplus_output_bank_a_w )
 {
+	peplus_state *state = space->machine().driver_data<peplus_state>();
 	output_set_value("pe_bnka0",(data >> 0) & 1); /* Coin Lockout */
 	output_set_value("pe_bnka1",(data >> 1) & 1); /* Diverter */
 	output_set_value("pe_bnka2",(data >> 2) & 1); /* Bell */
@@ -423,9 +421,9 @@ static WRITE8_HANDLER( peplus_output_bank_a_w )
 	output_set_value("pe_bnka6",(data >> 6) & 1); /* specific to a kind of machine */
 	output_set_value("pe_bnka7",(data >> 7) & 1); /* specific to a kind of machine */
 
-    coin_out_state = 0;
+    state->m_coin_out_state = 0;
     if(((data >> 4) & 1) || ((data >> 5) & 1))
-        coin_out_state = 3;
+        state->m_coin_out_state = 3;
 }
 
 static WRITE8_HANDLER( peplus_output_bank_b_w )
@@ -454,8 +452,9 @@ static WRITE8_HANDLER( peplus_output_bank_c_w )
 
 static WRITE8_DEVICE_HANDLER(i2c_nvram_w)
 {
+	peplus_state *state = device->machine().driver_data<peplus_state>();
 	i2cmem_scl_write(device,BIT(data, 2));
-	sda_dir = BIT(data, 1);
+	state->m_sda_dir = BIT(data, 1);
 	i2cmem_sda_write(device,BIT(data, 0));
 }
 
@@ -466,7 +465,8 @@ static WRITE8_DEVICE_HANDLER(i2c_nvram_w)
 
 static READ8_HANDLER( peplus_io_r )
 {
-    return io_port[offset];
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+    return state->m_io_port[offset];
 }
 
 static READ8_HANDLER( peplus_duart_r )
@@ -477,44 +477,50 @@ static READ8_HANDLER( peplus_duart_r )
 
 static READ8_HANDLER( peplus_cmos_r )
 {
-	peplus_state *state = space->machine->driver_data<peplus_state>();
-	return state->cmos_ram[offset];
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	return state->m_cmos_ram[offset];
 }
 
 static READ8_HANDLER( peplus_s3000_r )
 {
-	return s3000_ram[offset];
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	return state->m_s3000_ram[offset];
 }
 
 static READ8_HANDLER( peplus_s5000_r )
 {
-	return s5000_ram[offset];
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	return state->m_s5000_ram[offset];
 }
 
 static READ8_HANDLER( peplus_s7000_r )
 {
-	return s7000_ram[offset];
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	return state->m_s7000_ram[offset];
 }
 
 static READ8_HANDLER( peplus_sb000_r )
 {
-	return sb000_ram[offset];
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	return state->m_sb000_ram[offset];
 }
 
 static READ8_HANDLER( peplus_sd000_r )
 {
-	return sd000_ram[offset];
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	return state->m_sd000_ram[offset];
 }
 
 static READ8_HANDLER( peplus_sf000_r )
 {
-	return sf000_ram[offset];
+	peplus_state *state = space->machine().driver_data<peplus_state>();
+	return state->m_sf000_ram[offset];
 }
 
 /* Last Color in Every Palette is bgcolor */
 static READ8_HANDLER( peplus_bgcolor_r )
 {
-	return palette_get_color(space->machine, 15); // Return bgcolor from First Palette
+	return palette_get_color(space->machine(), 15); // Return bgcolor from First Palette
 }
 
 static READ8_HANDLER( peplus_dropdoor_r )
@@ -529,6 +535,7 @@ static READ8_HANDLER( peplus_watchdog_r )
 
 static READ8_DEVICE_HANDLER( peplus_input_bank_a_r )
 {
+	peplus_state *state = device->machine().driver_data<peplus_state>();
 /*
         Bit 0 = COIN DETECTOR A
         Bit 1 = COIN DETECTOR B
@@ -542,29 +549,29 @@ static READ8_DEVICE_HANDLER( peplus_input_bank_a_r )
 	UINT8 bank_a = 0x50; // Turn Off Low Battery and Hopper Full Statuses
 	UINT8 coin_optics = 0x00;
     UINT8 coin_out = 0x00;
-	UINT64 curr_cycles = device->machine->firstcpu->total_cycles();
+	UINT64 curr_cycles = device->machine().firstcpu->total_cycles();
 	UINT16 door_wait = 500;
 
 	UINT8 sda = 0;
-	if(!sda_dir)
+	if(!state->m_sda_dir)
 	{
 		sda = i2cmem_sda_read(device);
 	}
 
-	if ((input_port_read_safe(device->machine, "SENSOR",0x00) & 0x01) == 0x01 && coin_state == 0) {
-		coin_state = 1; // Start Coin Cycle
-		last_cycles = device->machine->firstcpu->total_cycles();
+	if ((input_port_read_safe(device->machine(), "SENSOR",0x00) & 0x01) == 0x01 && state->m_coin_state == 0) {
+		state->m_coin_state = 1; // Start Coin Cycle
+		state->m_last_cycles = device->machine().firstcpu->total_cycles();
 	} else {
 		/* Process Next Coin Optic State */
-		if (curr_cycles - last_cycles > 600000/6 && coin_state != 0) {
-			coin_state++;
-			if (coin_state > 5)
-				coin_state = 0;
-			last_cycles = device->machine->firstcpu->total_cycles();
+		if (curr_cycles - state->m_last_cycles > 600000/6 && state->m_coin_state != 0) {
+			state->m_coin_state++;
+			if (state->m_coin_state > 5)
+				state->m_coin_state = 0;
+			state->m_last_cycles = device->machine().firstcpu->total_cycles();
 		}
 	}
 
-	switch (coin_state)
+	switch (state->m_coin_state)
 	{
 		case 0x00: // No Coin
 			coin_optics = 0x00;
@@ -586,29 +593,29 @@ static READ8_DEVICE_HANDLER( peplus_input_bank_a_r )
 			break;
 	}
 
-	if (wingboard)
+	if (state->m_wingboard)
 		door_wait = 12345;
 
-	if (curr_cycles - last_door > door_wait) {
-		if ((input_port_read_safe(device->machine, "DOOR",0xff) & 0x01) == 0x01) {
-			door_open = (!door_open & 0x01);
+	if (curr_cycles - state->m_last_door > door_wait) {
+		if ((input_port_read_safe(device->machine(), "DOOR",0xff) & 0x01) == 0x01) {
+			state->m_door_open = (!state->m_door_open & 0x01);
 		} else {
-			door_open = 1;
+			state->m_door_open = 1;
 		}
-		last_door = device->machine->firstcpu->total_cycles();
+		state->m_last_door = device->machine().firstcpu->total_cycles();
 	}
 
-	if (curr_cycles - last_coin_out > 600000/12 && coin_out_state != 0) { // Guessing with 600000
-		if (coin_out_state != 2) {
-            coin_out_state = 2; // Coin-Out Off
+	if (curr_cycles - state->m_last_coin_out > 600000/12 && state->m_coin_out_state != 0) { // Guessing with 600000
+		if (state->m_coin_out_state != 2) {
+            state->m_coin_out_state = 2; // Coin-Out Off
         } else {
-            coin_out_state = 3; // Coin-Out On
+            state->m_coin_out_state = 3; // Coin-Out On
         }
 
-		last_coin_out = device->machine->firstcpu->total_cycles();
+		state->m_last_coin_out = device->machine().firstcpu->total_cycles();
 	}
 
-    switch (coin_out_state)
+    switch (state->m_coin_out_state)
     {
         case 0x00: // No Coin-Out
 	        coin_out = 0x00;
@@ -624,7 +631,7 @@ static READ8_DEVICE_HANDLER( peplus_input_bank_a_r )
 	        break;
     }
 
-	bank_a = (sda<<7) | bank_a | (door_open<<5) | coin_optics | coin_out;
+	bank_a = (sda<<7) | bank_a | (state->m_door_open<<5) | coin_optics | coin_out;
 
 	return bank_a;
 }
@@ -636,17 +643,17 @@ static READ8_DEVICE_HANDLER( peplus_input_bank_a_r )
 
 static TILE_GET_INFO( get_bg_tile_info )
 {
-	peplus_state *state = machine->driver_data<peplus_state>();
-	UINT8 *videoram = state->videoram;
-	int pr = palette_ram[tile_index];
-	int pr2 = palette_ram2[tile_index];
+	peplus_state *state = machine.driver_data<peplus_state>();
+	UINT8 *videoram = state->m_videoram;
+	int pr = state->m_palette_ram[tile_index];
+	int pr2 = state->m_palette_ram2[tile_index];
 	int vr = videoram[tile_index];
 
 	int code = ((pr & 0x0f)*256) | vr;
 	int color = (pr>>4) & 0x0f;
 
 	// Access 2nd Half of CGs and CAP
-	if (jumper_e16_e17 && (pr2 & 0x10) == 0x10)
+	if (state->m_jumper_e16_e17 && (pr2 & 0x10) == 0x10)
 	{
 		code += 0x1000;
 		color += 0x10;
@@ -657,16 +664,18 @@ static TILE_GET_INFO( get_bg_tile_info )
 
 static VIDEO_START( peplus )
 {
-	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows, 8, 8, 40, 25);
-	palette_ram = auto_alloc_array(machine, UINT8, 0x3000);
-	memset(palette_ram, 0, 0x3000);
-	palette_ram2 = auto_alloc_array(machine, UINT8, 0x3000);
-	memset(palette_ram2, 0, 0x3000);
+	peplus_state *state = machine.driver_data<peplus_state>();
+	state->m_bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows, 8, 8, 40, 25);
+	state->m_palette_ram = auto_alloc_array(machine, UINT8, 0x3000);
+	memset(state->m_palette_ram, 0, 0x3000);
+	state->m_palette_ram2 = auto_alloc_array(machine, UINT8, 0x3000);
+	memset(state->m_palette_ram2, 0, 0x3000);
 }
 
-static VIDEO_UPDATE( peplus )
+static SCREEN_UPDATE( peplus )
 {
-	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
+	peplus_state *state = screen->machine().driver_data<peplus_state>();
+	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
 
 	return 0;
 }
@@ -681,7 +690,7 @@ static PALETTE_INIT( peplus )
 */
 	int i;
 
-	for (i = 0;i < machine->total_colors();i++)
+	for (i = 0;i < machine.total_colors();i++)
 	{
 		int bit0, bit1, bit2, r, g, b;
 
@@ -721,38 +730,38 @@ GFXDECODE_END
 * Memory map information *
 *************************/
 
-static ADDRESS_MAP_START( peplus_map, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xffff) AM_ROM AM_BASE(&program_ram)
+static ADDRESS_MAP_START( peplus_map, AS_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xffff) AM_ROM AM_BASE_MEMBER(peplus_state, m_program_ram)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( peplus_iomap, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( peplus_iomap, AS_IO, 8 )
 	// Battery-backed RAM (0x1000-0x01fff Extended RAM for Superboards Only)
 	AM_RANGE(0x0000, 0x1fff) AM_READWRITE(peplus_cmos_r, peplus_cmos_w) AM_SHARE("cmos")
 
 	// CRT Controller
 	AM_RANGE(0x2008, 0x2008) AM_DEVWRITE("crtc", peplus_crtc_mode_w)
-	AM_RANGE(0x2080, 0x2080) AM_DEVREADWRITE("crtc", mc6845_status_r, mc6845_address_w)
-	AM_RANGE(0x2081, 0x2081) AM_DEVREADWRITE("crtc", mc6845_register_r, mc6845_register_w)
-	AM_RANGE(0x2083, 0x2083) AM_DEVREADWRITE("crtc", mc6845_register_r, peplus_crtc_display_w)
+	AM_RANGE(0x2080, 0x2080) AM_DEVREADWRITE_MODERN("crtc", mc6845_device, status_r, address_w)
+	AM_RANGE(0x2081, 0x2081) AM_DEVREADWRITE_MODERN("crtc", mc6845_device, register_r, register_w)
+	AM_RANGE(0x2083, 0x2083) AM_DEVREAD_MODERN("crtc", mc6845_device, register_r) AM_WRITE(peplus_crtc_display_w)
 
     // Superboard Data
-	AM_RANGE(0x3000, 0x3fff) AM_READWRITE(peplus_s3000_r, peplus_s3000_w) AM_BASE(&s3000_ram)
+	AM_RANGE(0x3000, 0x3fff) AM_READWRITE(peplus_s3000_r, peplus_s3000_w) AM_BASE_MEMBER(peplus_state, m_s3000_ram)
 
 	// Sound and Dipswitches
 	AM_RANGE(0x4000, 0x4000) AM_DEVWRITE("aysnd", ay8910_address_w)
 	AM_RANGE(0x4004, 0x4004) AM_READ_PORT("SW1")/* likely ay8910 input port, not direct */ AM_DEVWRITE("aysnd", ay8910_data_w)
 
     // Superboard Data
-	AM_RANGE(0x5000, 0x5fff) AM_READWRITE(peplus_s5000_r, peplus_s5000_w) AM_BASE(&s5000_ram)
+	AM_RANGE(0x5000, 0x5fff) AM_READWRITE(peplus_s5000_r, peplus_s5000_w) AM_BASE_MEMBER(peplus_state, m_s5000_ram)
 
 	// Background Color Latch
 	AM_RANGE(0x6000, 0x6000) AM_READ(peplus_bgcolor_r) AM_WRITE(peplus_bgcolor_w)
 
     // Bogus Location for Video RAM
-	AM_RANGE(0x06001, 0x06400) AM_RAM AM_BASE_MEMBER(peplus_state, videoram)
+	AM_RANGE(0x06001, 0x06400) AM_RAM AM_BASE_MEMBER(peplus_state, m_videoram)
 
     // Superboard Data
-	AM_RANGE(0x7000, 0x7fff) AM_READWRITE(peplus_s7000_r, peplus_s7000_w) AM_BASE(&s7000_ram)
+	AM_RANGE(0x7000, 0x7fff) AM_READWRITE(peplus_s7000_r, peplus_s7000_w) AM_BASE_MEMBER(peplus_state, m_s7000_ram)
 
 	// Input Bank A, Output Bank C
 	AM_RANGE(0x8000, 0x8000) AM_DEVREAD("i2cmem",peplus_input_bank_a_r) AM_WRITE(peplus_output_bank_c_w)
@@ -764,22 +773,22 @@ static ADDRESS_MAP_START( peplus_iomap, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0xa000, 0xa000) AM_READ_PORT("IN0") AM_WRITE(peplus_output_bank_b_w)
 
     // Superboard Data
-	AM_RANGE(0xb000, 0xbfff) AM_READWRITE(peplus_sb000_r, peplus_sb000_w) AM_BASE(&sb000_ram)
+	AM_RANGE(0xb000, 0xbfff) AM_READWRITE(peplus_sb000_r, peplus_sb000_w) AM_BASE_MEMBER(peplus_state, m_sb000_ram)
 
 	// Output Bank A
 	AM_RANGE(0xc000, 0xc000) AM_READ(peplus_watchdog_r) AM_WRITE(peplus_output_bank_a_w)
 
     // Superboard Data
-	AM_RANGE(0xd000, 0xdfff) AM_READWRITE(peplus_sd000_r, peplus_sd000_w) AM_BASE(&sd000_ram)
+	AM_RANGE(0xd000, 0xdfff) AM_READWRITE(peplus_sd000_r, peplus_sd000_w) AM_BASE_MEMBER(peplus_state, m_sd000_ram)
 
 	// DUART
 	AM_RANGE(0xe000, 0xe00f) AM_READWRITE(peplus_duart_r, peplus_duart_w)
 
     // Superboard Data
-	AM_RANGE(0xf000, 0xffff) AM_READWRITE(peplus_sf000_r, peplus_sf000_w) AM_BASE(&sf000_ram)
+	AM_RANGE(0xf000, 0xffff) AM_READWRITE(peplus_sf000_r, peplus_sf000_w) AM_BASE_MEMBER(peplus_state, m_sf000_ram)
 
 	/* Ports start here */
-	AM_RANGE(MCS51_PORT_P0, MCS51_PORT_P3) AM_READ(peplus_io_r) AM_WRITE(peplus_io_w) AM_BASE(&io_port)
+	AM_RANGE(MCS51_PORT_P0, MCS51_PORT_P3) AM_READ(peplus_io_r) AM_WRITE(peplus_io_w) AM_BASE_MEMBER(peplus_state, m_io_port)
 ADDRESS_MAP_END
 
 
@@ -790,7 +799,7 @@ ADDRESS_MAP_END
 static CUSTOM_INPUT( peplus_input_r )
 {
 	UINT8 inp_ret = 0x00;
-	UINT8 inp_read = input_port_read(field->port->machine, (const char *)param);
+	UINT8 inp_read = input_port_read(field.machine(), (const char *)param);
 
 	if (inp_read & 0x01) inp_ret = 0x01;
 	if (inp_read & 0x02) inp_ret = 0x02;
@@ -987,27 +996,28 @@ INPUT_PORTS_END
 
 static MACHINE_RESET( peplus )
 {
-/*
-    AutoHold Feature Currently Disabled
+	/* AutoHold Feature Currently Disabled */
+#if 0
+	peplus_state *state = machine.driver_data<peplus_state>();
 
-    // pepp0158
-    program_ram[0xa19f] = 0x22; // RET - Disable Memory Test
-    program_ram[0xddea] = 0x22; // RET - Disable Program Checksum
-    autohold_addr = 0x5ffe; // AutoHold Address
+	// pepp0158
+	state->m_program_ram[0xa19f] = 0x22; // RET - Disable Memory Test
+	state->m_program_ram[0xddea] = 0x22; // RET - Disable Program Checksum
+	state->m_autohold_addr = 0x5ffe; // AutoHold Address
 
-    // pepp0188
-    program_ram[0x9a8d] = 0x22; // RET - Disable Memory Test
-    program_ram[0xf429] = 0x22; // RET - Disable Program Checksum
-    autohold_addr = 0x742f; // AutoHold Address
+	// pepp0188
+	state->m_program_ram[0x9a8d] = 0x22; // RET - Disable Memory Test
+	state->m_program_ram[0xf429] = 0x22; // RET - Disable Program Checksum
+	state->m_autohold_addr = 0x742f; // AutoHold Address
 
-    // pepp0516
-    program_ram[0x9a24] = 0x22; // RET - Disable Memory Test
-    program_ram[0xd61d] = 0x22; // RET - Disable Program Checksum
-    autohold_addr = 0x5e7e; // AutoHold Address
+	// pepp0516
+	state->m_program_ram[0x9a24] = 0x22; // RET - Disable Memory Test
+	state->m_program_ram[0xd61d] = 0x22; // RET - Disable Program Checksum
+	state->m_autohold_addr = 0x5e7e; // AutoHold Address
 
-    if (autohold_addr)
-        program_ram[autohold_addr] = input_port_read_safe(machine, "AUTOHOLD",0x00) & 0x01;
-*/
+	if (state->m_autohold_addr)
+		state->m_program_ram[state->m_autohold_addr] = input_port_read_safe(machine, "AUTOHOLD",0x00) & 0x01;
+#endif
 }
 
 
@@ -1030,6 +1040,7 @@ static MACHINE_CONFIG_START( peplus, peplus_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE((52+1)*8, (31+1)*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 25*8-1)
+	MCFG_SCREEN_UPDATE(peplus)
 
 	MCFG_GFXDECODE(peplus)
 	MCFG_PALETTE_LENGTH(16*16*2)
@@ -1039,7 +1050,6 @@ static MACHINE_CONFIG_START( peplus, peplus_state )
 
 	MCFG_PALETTE_INIT(peplus)
 	MCFG_VIDEO_START(peplus)
-	MCFG_VIDEO_UPDATE(peplus)
 
 	// sound hardware
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -1054,10 +1064,11 @@ MACHINE_CONFIG_END
 *****************/
 
 /* Normal board */
-static void peplus_init(running_machine *machine)
+static void peplus_init(running_machine &machine)
 {
+	peplus_state *state = machine.driver_data<peplus_state>();
 	/* default : no address to patch in program RAM to enable autohold feature */
-	autohold_addr = 0;
+	state->m_autohold_addr = 0;
 }
 
 
@@ -1068,16 +1079,18 @@ static void peplus_init(running_machine *machine)
 /* Normal board */
 static DRIVER_INIT( peplus )
 {
-	wingboard = FALSE;
-	jumper_e16_e17 = FALSE;
+	peplus_state *state = machine.driver_data<peplus_state>();
+	state->m_wingboard = FALSE;
+	state->m_jumper_e16_e17 = FALSE;
 	peplus_init(machine);
 }
 
 /* Superboard */
 static DRIVER_INIT( peplussb )
 {
-	wingboard = FALSE;
-	jumper_e16_e17 = FALSE;
+	peplus_state *state = machine.driver_data<peplus_state>();
+	state->m_wingboard = FALSE;
+	state->m_jumper_e16_e17 = FALSE;
 	peplus_load_superdata(machine, "user1");
 
 	peplus_init(machine);
@@ -1086,8 +1099,9 @@ static DRIVER_INIT( peplussb )
 /* Superboard with Attached Wingboard */
 static DRIVER_INIT( peplussbw )
 {
-	wingboard = TRUE;
-	jumper_e16_e17 = TRUE;
+	peplus_state *state = machine.driver_data<peplus_state>();
+	state->m_wingboard = TRUE;
+	state->m_jumper_e16_e17 = TRUE;
 	peplus_load_superdata(machine, "user1");
 
 	peplus_init(machine);
