@@ -35,107 +35,86 @@ Dumped by Chackn
 #include "sound/okim6295.h"
 #include "video/generic.h"
 
-static UINT8* janshi_vram1;
-static UINT8* janshi_vram2;
-static UINT8* janshi_back_vram;
-static UINT8* janshi_crtc_regs;
-static UINT8* janshi_unk1;
-static UINT8* janshi_widthflags;
-static UINT8* janshi_unk2;
 
-static ADDRESS_MAP_START( janshi_vdp_map8, 0, 8 )
+class pinkiri8_state : public driver_device
+{
+public:
+	pinkiri8_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	AM_RANGE(0xfc0000, 0xfc1fff) AM_RAM AM_BASE(&janshi_back_vram) // bg tilemap?
-	AM_RANGE(0xfc2000, 0xfc2fff) AM_RAM AM_BASE(&janshi_vram1) // xpos, colour, tile number etc.
+	UINT8* m_janshi_vram1;
+	UINT8* m_janshi_vram2;
+	UINT8* m_janshi_back_vram;
+	UINT8* m_janshi_crtc_regs;
+	UINT8* m_janshi_unk1;
+	UINT8* m_janshi_widthflags;
+	UINT8* m_janshi_unk2;
+	UINT32 m_vram_addr;
+	int m_prev_writes;
+	UINT8 m_mux_data;
+	UINT8 m_prot_read_index;
+	UINT8 m_prot_char[6];
+	UINT8 m_prot_index;
+};
 
-	AM_RANGE(0xfc3700, 0xfc377f) AM_RAM AM_BASE(&janshi_unk1) // ?? height related?
-	AM_RANGE(0xfc3780, 0xfc37bf) AM_RAM AM_BASE(&janshi_widthflags)
-	AM_RANGE(0xfc37c0, 0xfc37ff) AM_RAM AM_BASE(&janshi_unk2) // 2x increasing tables 00 10 20 30 etc.
 
-	AM_RANGE(0xfc3800, 0xfc3fff) AM_RAM AM_BASE(&janshi_vram2) // y pos + unknown
+static ADDRESS_MAP_START( janshi_vdp_map8, AS_0, 8 )
+
+	AM_RANGE(0xfc0000, 0xfc1fff) AM_RAM AM_BASE_MEMBER(pinkiri8_state, m_janshi_back_vram) // bg tilemap?
+	AM_RANGE(0xfc2000, 0xfc2fff) AM_RAM AM_BASE_MEMBER(pinkiri8_state, m_janshi_vram1) // xpos, colour, tile number etc.
+
+	AM_RANGE(0xfc3700, 0xfc377f) AM_RAM AM_BASE_MEMBER(pinkiri8_state, m_janshi_unk1) // ?? height related?
+	AM_RANGE(0xfc3780, 0xfc37bf) AM_RAM AM_BASE_MEMBER(pinkiri8_state, m_janshi_widthflags)
+	AM_RANGE(0xfc37c0, 0xfc37ff) AM_RAM AM_BASE_MEMBER(pinkiri8_state, m_janshi_unk2) // 2x increasing tables 00 10 20 30 etc.
+
+	AM_RANGE(0xfc3800, 0xfc3fff) AM_RAM AM_BASE_MEMBER(pinkiri8_state, m_janshi_vram2) // y pos + unknown
 
 	AM_RANGE(0xff0000, 0xff07ff) AM_RAM_WRITE(paletteram_xBBBBBGGGGGRRRRR_split1_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0xff2000, 0xff27ff) AM_RAM_WRITE(paletteram_xBBBBBGGGGGRRRRR_split2_w) AM_BASE_GENERIC(paletteram2)
 
-	AM_RANGE(0xff6000, 0xff601f) AM_RAM AM_BASE(&janshi_crtc_regs)
+	AM_RANGE(0xff6000, 0xff601f) AM_RAM AM_BASE_MEMBER(pinkiri8_state, m_janshi_crtc_regs)
 ADDRESS_MAP_END
 
 
 
 /* VDP device to give us our own memory map */
 
-class janshi_vdp_device_config : public device_config,
-								 public device_config_memory_interface
-{
-	friend class janshi_vdp_device;
-	janshi_vdp_device_config(const machine_config &mconfig, const char *tag, const device_config *owner, UINT32 clock);
-public:
-	static device_config *static_alloc_device_config(const machine_config &mconfig, const char *tag, const device_config *owner, UINT32 clock);
-	virtual device_t *alloc_device(running_machine &machine) const;
-protected:
-	virtual void device_config_complete();
-	virtual bool device_validity_check(const game_driver &driver) const;
-	virtual const address_space_config *memory_space_config(int spacenum = 0) const;
-	address_space_config		m_space_config;
-};
-
 class janshi_vdp_device : public device_t,
 						  public device_memory_interface
 {
-	friend class janshi_vdp_device_config;
-	janshi_vdp_device(running_machine &_machine, const janshi_vdp_device_config &config);
 public:
+	janshi_vdp_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock);
 protected:
+	virtual void device_config_complete();
+	virtual bool device_validity_check(emu_options &options, const game_driver &driver) const;
 	virtual void device_start();
 	virtual void device_reset();
-	const janshi_vdp_device_config &m_config;
+	virtual const address_space_config *memory_space_config(address_spacenum spacenum = AS_0) const;
+	address_space_config		m_space_config;
 };
 
-const device_type JANSHIVDP = janshi_vdp_device_config::static_alloc_device_config;
+const device_type JANSHIVDP = &device_creator<janshi_vdp_device>;
 
-janshi_vdp_device_config::janshi_vdp_device_config(const machine_config &mconfig, const char *tag, const device_config *owner, UINT32 clock)
-	: device_config(mconfig, static_alloc_device_config, "JANSHIVDP", tag, owner, clock),
-	  device_config_memory_interface(mconfig, *this),
+janshi_vdp_device::janshi_vdp_device(const machine_config &mconfig, const char *tag, device_t *owner, UINT32 clock)
+	: device_t(mconfig, JANSHIVDP, "JANSHIVDP", tag, owner, clock),
+	  device_memory_interface(mconfig, *this),
 	  m_space_config("janshi_vdp", ENDIANNESS_LITTLE, 8,24, 0, NULL, *ADDRESS_MAP_NAME(janshi_vdp_map8))
 {
 }
 
-device_config *janshi_vdp_device_config::static_alloc_device_config(const machine_config &mconfig, const char *tag, const device_config *owner, UINT32 clock)
-{
-	return global_alloc(janshi_vdp_device_config(mconfig, tag, owner, clock));
-}
-
-device_t *janshi_vdp_device_config::alloc_device(running_machine &machine) const
-{
-	return auto_alloc(&machine, janshi_vdp_device(machine, *this));
-}
-
-void janshi_vdp_device_config::device_config_complete()
+void janshi_vdp_device::device_config_complete()
 {
 //  int address_bits = 24;
 
 //  m_space_config = address_space_config("janshi_vdp", ENDIANNESS_BIG, 8,  address_bits, 0, *ADDRESS_MAP_NAME(janshi_vdp_map8));
 }
 
-bool janshi_vdp_device_config::device_validity_check(const game_driver &driver) const
+bool janshi_vdp_device::device_validity_check(emu_options &options, const game_driver &driver) const
 {
 	bool error = false;
 	return error;
 }
 
-const address_space_config *janshi_vdp_device_config::memory_space_config(int spacenum) const
-{
-	return (spacenum == 0) ? &m_space_config : NULL;
-}
-
-
-janshi_vdp_device::janshi_vdp_device(running_machine &_machine, const janshi_vdp_device_config &config)
-	: device_t(_machine, config),
-	  device_memory_interface(_machine, config, *this),
-	  m_config(config)
-{
-}
-
 void janshi_vdp_device::device_start()
 {
 }
@@ -144,12 +123,17 @@ void janshi_vdp_device::device_reset()
 {
 }
 
+const address_space_config *janshi_vdp_device::memory_space_config(address_spacenum spacenum) const
+{
+	return (spacenum == 0) ? &m_space_config : NULL;
+}
+
+
 /* end VDP device to give us our own memory map */
 
 
 
 
-static UINT32 vram_addr;
 
 static VIDEO_START( pinkiri8 )
 {
@@ -189,16 +173,17 @@ ronjan
 
 */
 
-static VIDEO_UPDATE( pinkiri8 )
+static SCREEN_UPDATE( pinkiri8 )
 {
-	static int col_bank;
-	const gfx_element *gfx = screen->machine->gfx[0];
+	pinkiri8_state *state = screen->machine().driver_data<pinkiri8_state>();
+	int col_bank;
+	const gfx_element *gfx = screen->machine().gfx[0];
 
-	static int game_type_hack = 0;
+	int game_type_hack = 0;
 
-	if (!strcmp(screen->machine->gamedrv->name,"janshi")) game_type_hack = 1;
+	if (!strcmp(screen->machine().system().name,"janshi")) game_type_hack = 1;
 
-	if ( input_code_pressed_once(screen->machine, KEYCODE_W) )
+	if ( screen->machine().input().code_pressed_once(KEYCODE_W) )
 	{
 		int i;
 		int count2;
@@ -207,7 +192,7 @@ static VIDEO_UPDATE( pinkiri8 )
 		for (i=0x00;i<0x40;i+=2)
 		{
 
-			printf("%02x, ", janshi_widthflags[i+1]);
+			printf("%02x, ", state->m_janshi_widthflags[i+1]);
 
 			count2++;
 
@@ -225,10 +210,10 @@ static VIDEO_UPDATE( pinkiri8 )
 
 
 
-	//popmessage("%02x",janshi_crtc_regs[0x0a]);
-	col_bank = (janshi_crtc_regs[0x0a] & 0x40) >> 6;
+	//popmessage("%02x",state->m_janshi_crtc_regs[0x0a]);
+	col_bank = (state->m_janshi_crtc_regs[0x0a] & 0x40) >> 6;
 
-	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine()));
 
 	/* FIXME: color is a bit of a mystery */
 	{
@@ -240,8 +225,8 @@ static VIDEO_UPDATE( pinkiri8 )
 		{
 			for(x=0;x<32;x++)
 			{
-				tile = janshi_back_vram[count+1]<<8 | janshi_back_vram[count+0];
-				attr = janshi_back_vram[count+2] ^ 0xf0;
+				tile = state->m_janshi_back_vram[count+1]<<8 | state->m_janshi_back_vram[count+0];
+				attr = state->m_janshi_back_vram[count+2] ^ 0xf0;
 				col = (attr >> 4) | 0x10;
 
 				drawgfx_transpen(bitmap,cliprect,gfx,tile,col,0,0,x*16,y*8,0);
@@ -252,7 +237,7 @@ static VIDEO_UPDATE( pinkiri8 )
 	}
 
 	{
-		int x,y,unk2;
+		int x,y; //,unk2;
 		int col;
 
 		int spr_offs,i;
@@ -277,15 +262,15 @@ static VIDEO_UPDATE( pinkiri8 )
 
           */
 
-			spr_offs = ((janshi_vram1[(i*4)+0] & 0xff) | (janshi_vram1[(i*4)+1]<<8)) & 0xffff;
-			col = (janshi_vram1[(i*4)+2] & 0xf8) >> 3;
-			x =   janshi_vram1[(i*4)+3];
+			spr_offs = ((state->m_janshi_vram1[(i*4)+0] & 0xff) | (state->m_janshi_vram1[(i*4)+1]<<8)) & 0xffff;
+			col = (state->m_janshi_vram1[(i*4)+2] & 0xf8) >> 3;
+			x =   state->m_janshi_vram1[(i*4)+3];
 
 			x &= 0xff;
 			x *= 2;
 
-			unk2 = janshi_vram2[(i*2)+1];
-			y = (janshi_vram2[(i*2)+0]);
+//          unk2 = state->m_janshi_vram2[(i*2)+1];
+			y = (state->m_janshi_vram2[(i*2)+0]);
 
 			y = 0x100-y;
 
@@ -298,11 +283,11 @@ static VIDEO_UPDATE( pinkiri8 )
 
 
 			// these bits seem to somehow determine the sprite height / widths for the sprite ram region?
-			int bit = janshi_widthflags[(i/0x20)*2 + 1];
+			int bit = state->m_janshi_widthflags[(i/0x20)*2 + 1];
 
 			if (bit)
 			{
-				//col = screen->machine->rand();
+				//col = screen->machine().rand();
 				width = 2;
 			}
 			else
@@ -392,7 +377,7 @@ static VIDEO_UPDATE( pinkiri8 )
 	return 0;
 }
 
-static ADDRESS_MAP_START( pinkiri8_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( pinkiri8_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x00000, 0x0bfff) AM_ROM
 	AM_RANGE(0x0c000, 0x0dfff) AM_RAM
 	AM_RANGE(0x0e000, 0x0ffff) AM_ROM
@@ -402,63 +387,64 @@ ADDRESS_MAP_END
 static WRITE8_HANDLER( output_regs_w )
 {
 	if(data & 0x40)
-		cputag_set_input_line(space->machine, "maincpu", INPUT_LINE_NMI, CLEAR_LINE);
+		cputag_set_input_line(space->machine(), "maincpu", INPUT_LINE_NMI, CLEAR_LINE);
 	//data & 0x80 is probably NMI mask
 }
 
-static int prev_writes = 0;
 
 #define LOG_VRAM 0
 
 static WRITE8_HANDLER( pinkiri8_vram_w )
 {
+	pinkiri8_state *state = space->machine().driver_data<pinkiri8_state>();
 	switch(offset)
 	{
 		case 0:
-			vram_addr = (data << 0)  | (vram_addr&0xffff00);
-			if (LOG_VRAM) printf("\n prev writes was %04x\n\naddress set to %04x -\n", prev_writes, vram_addr );
-			prev_writes = 0;
+			state->m_vram_addr = (data << 0)  | (state->m_vram_addr&0xffff00);
+			if (LOG_VRAM) printf("\n prev writes was %04x\n\naddress set to %04x -\n", state->m_prev_writes, state->m_vram_addr );
+			state->m_prev_writes = 0;
 			break;
 
 		case 1:
-			vram_addr = (data << 8)  | (vram_addr & 0xff00ff);
-			if (LOG_VRAM)printf("\naddress set to %04x\n", vram_addr);
+			state->m_vram_addr = (data << 8)  | (state->m_vram_addr & 0xff00ff);
+			if (LOG_VRAM)printf("\naddress set to %04x\n", state->m_vram_addr);
 			break;
 
 		case 2:
-			vram_addr = (data << 16) | (vram_addr & 0x00ffff);
-			if (LOG_VRAM)printf("\naddress set to %04x\n", vram_addr);
+			state->m_vram_addr = (data << 16) | (state->m_vram_addr & 0x00ffff);
+			if (LOG_VRAM)printf("\naddress set to %04x\n", state->m_vram_addr);
 			break;
 
 		case 3:
 
-			address_space *vdp_space = space->machine->device<janshi_vdp_device>("janshivdp")->space();
+			address_space *vdp_space = space->machine().device<janshi_vdp_device>("janshivdp")->space();
 
 			if (LOG_VRAM) printf("%02x ", data);
-			prev_writes++;
-			vram_addr++;
+			state->m_prev_writes++;
+			state->m_vram_addr++;
 
-			vdp_space->write_byte(vram_addr, data);
+			vdp_space->write_byte(state->m_vram_addr, data);
 			break;
 	}
 }
 
-static UINT8 mux_data;
 
 static WRITE8_HANDLER( mux_w )
 {
-	mux_data = data;
+	pinkiri8_state *state = space->machine().driver_data<pinkiri8_state>();
+	state->m_mux_data = data;
 }
 
 static READ8_HANDLER( mux_p2_r )
 {
-	switch(mux_data)
+	pinkiri8_state *state = space->machine().driver_data<pinkiri8_state>();
+	switch(state->m_mux_data)
 	{
-		case 0x01: return input_port_read(space->machine, "PL2_01");
-		case 0x02: return input_port_read(space->machine, "PL2_02");
-		case 0x04: return input_port_read(space->machine, "PL2_03");
-		case 0x08: return input_port_read(space->machine, "PL2_04");
-		case 0x10: return input_port_read(space->machine, "PL2_05");
+		case 0x01: return input_port_read(space->machine(), "PL2_01");
+		case 0x02: return input_port_read(space->machine(), "PL2_02");
+		case 0x04: return input_port_read(space->machine(), "PL2_03");
+		case 0x08: return input_port_read(space->machine(), "PL2_04");
+		case 0x10: return input_port_read(space->machine(), "PL2_05");
 	}
 
 	return 0xff;
@@ -466,19 +452,20 @@ static READ8_HANDLER( mux_p2_r )
 
 static READ8_HANDLER( mux_p1_r )
 {
-	switch(mux_data)
+	pinkiri8_state *state = space->machine().driver_data<pinkiri8_state>();
+	switch(state->m_mux_data)
 	{
-		case 0x01: return input_port_read(space->machine, "PL1_01");
-		case 0x02: return input_port_read(space->machine, "PL1_02");
-		case 0x04: return input_port_read(space->machine, "PL1_03");
-		case 0x08: return input_port_read(space->machine, "PL1_04");
-		case 0x10: return input_port_read(space->machine, "PL1_05");
+		case 0x01: return input_port_read(space->machine(), "PL1_01");
+		case 0x02: return input_port_read(space->machine(), "PL1_02");
+		case 0x04: return input_port_read(space->machine(), "PL1_03");
+		case 0x08: return input_port_read(space->machine(), "PL1_04");
+		case 0x10: return input_port_read(space->machine(), "PL1_05");
 	}
 
 	return 0xff;
 }
 
-static ADDRESS_MAP_START( pinkiri8_io, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( pinkiri8_io, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x3f) AM_RAM //Z180 internal I/O
 	AM_RANGE(0x60, 0x60) AM_WRITE(output_regs_w)
@@ -1107,7 +1094,7 @@ static GFXDECODE_START( pinkiri8 )
 	GFXDECODE_ENTRY( "gfx1", 0, charlayout,     0, 0x100 )
 GFXDECODE_END
 
-static MACHINE_CONFIG_START( pinkiri8, driver_device )
+static MACHINE_CONFIG_START( pinkiri8, pinkiri8_state )
 	MCFG_CPU_ADD("maincpu",Z180,16000000)
 	MCFG_CPU_PROGRAM_MAP(pinkiri8_map)
 	MCFG_CPU_IO_MAP(pinkiri8_io)
@@ -1119,11 +1106,12 @@ static MACHINE_CONFIG_START( pinkiri8, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0*8, 64*8-1)
+	MCFG_SCREEN_UPDATE(pinkiri8)
+
 	MCFG_GFXDECODE(pinkiri8)
 	MCFG_PALETTE_LENGTH(0x2000)
 
 	MCFG_VIDEO_START(pinkiri8)
-	MCFG_VIDEO_UPDATE(pinkiri8)
 
 	MCFG_DEVICE_ADD("janshivdp", JANSHIVDP, 0)
 
@@ -1188,35 +1176,35 @@ ROM_START( ronjan )
 	ROM_LOAD( "eagle.6", 0x00000, 0x40000, CRC(8197034d) SHA1(b501dc7a27b1faad1361c309afd726da14b8b5f5) )
 ROM_END
 
-static UINT8 prot_read_index;
 
 static READ8_HANDLER( ronjan_prot_r )
 {
+	pinkiri8_state *state = space->machine().driver_data<pinkiri8_state>();
 	static const char wing_str[6] = { 'W', 'I', 'N', 'G', '8', '9' };
 
-	prot_read_index++;
+	state->m_prot_read_index++;
 
-	if(prot_read_index & 1)
+	if(state->m_prot_read_index & 1)
 		return 0xff; //value is discarded
 
-	return wing_str[(prot_read_index >> 1)-1];
+	return wing_str[(state->m_prot_read_index >> 1)-1];
 }
 
 static WRITE8_HANDLER( ronjan_prot_w )
 {
-	static UINT8 prot_char[6],prot_index;
+	pinkiri8_state *state = space->machine().driver_data<pinkiri8_state>();
 
 	if(data == 0)
 	{
-		prot_index = 0;
+		state->m_prot_index = 0;
 	}
 	else
 	{
-		prot_char[prot_index] = data;
-		prot_index++;
+		state->m_prot_char[state->m_prot_index] = data;
+		state->m_prot_index++;
 
-		if(prot_char[0] == 'E' && prot_char[1] == 'R' && prot_char[2] == 'R' && prot_char[3] == 'O' && prot_char[4] == 'R')
-			prot_read_index = 0;
+		if(state->m_prot_char[0] == 'E' && state->m_prot_char[1] == 'R' && state->m_prot_char[2] == 'R' && state->m_prot_char[3] == 'O' && state->m_prot_char[4] == 'R')
+			state->m_prot_read_index = 0;
 	}
 }
 
@@ -1232,9 +1220,9 @@ static READ8_HANDLER( ronjan_patched_prot_r )
 
 static DRIVER_INIT( ronjan )
 {
-	memory_install_readwrite8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x90, 0x90, 0, 0, ronjan_prot_r, ronjan_prot_w);
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x66, 0x66, 0, 0, ronjan_prot_status_r);
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_IO), 0x9f, 0x9f, 0, 0, ronjan_patched_prot_r);
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_readwrite_handler(0x90, 0x90, FUNC(ronjan_prot_r), FUNC(ronjan_prot_w));
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x66, 0x66, FUNC(ronjan_prot_status_r));
+	machine.device("maincpu")->memory().space(AS_IO)->install_legacy_read_handler(0x9f, 0x9f, FUNC(ronjan_patched_prot_r));
 }
 
 GAME( 1992,  janshi,    0,   pinkiri8, janshi,    0,      ROT0, "Eagle",         "Janshi",          GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS | GAME_NOT_WORKING )
