@@ -125,6 +125,26 @@ CN1 standard DB15 VGA connector (15KHz)
 #include "machine/eeprom.h"
 
 
+class pntnpuzl_state : public driver_device
+{
+public:
+	pntnpuzl_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT16 m_eeprom;
+	UINT16* m_3a0000ram;
+	UINT16* m_bank;
+	int m_indx;
+	int m_sub;
+	int m_rgb[3];
+	UINT16 m_pntpzl_200000;
+	UINT16 m_serial;
+	UINT16 m_serial_out;
+	UINT16 m_read_count;
+	int m_touchscr[5];
+};
+
+
 static const eeprom_interface eeprom_intf =
 {
 	6,				/* address bits */
@@ -136,40 +156,43 @@ static const eeprom_interface eeprom_intf =
 	"*10011xxxx"	/* unlock command */
 };
 
-static UINT16 pntnpuzl_eeprom;
 
 static READ16_DEVICE_HANDLER( pntnpuzl_eeprom_r )
 {
+	pntnpuzl_state *state = device->machine().driver_data<pntnpuzl_state>();
 	/* bit 11 is EEPROM data */
-	return (pntnpuzl_eeprom & 0xf4ff) | (eeprom_read_bit(device)<<11) | (input_port_read(device->machine, "IN1") & 0x0300);
+	eeprom_device *eeprom = downcast<eeprom_device *>(device);
+	return (state->m_eeprom & 0xf4ff) | (eeprom->read_bit()<<11) | (input_port_read(device->machine(), "IN1") & 0x0300);
 }
 
 static WRITE16_DEVICE_HANDLER( pntnpuzl_eeprom_w )
 {
-	pntnpuzl_eeprom = data;
+	pntnpuzl_state *state = device->machine().driver_data<pntnpuzl_state>();
+	state->m_eeprom = data;
 
 	/* bit 12 is data */
 	/* bit 13 is clock (active high) */
 	/* bit 14 is cs (active high) */
 
-	eeprom_write_bit(device, data & 0x1000);
-	eeprom_set_cs_line(device, (data & 0x4000) ? CLEAR_LINE : ASSERT_LINE);
-	eeprom_set_clock_line(device, (data & 0x2000) ? ASSERT_LINE : CLEAR_LINE);
+	eeprom_device *eeprom = downcast<eeprom_device *>(device);
+	eeprom->write_bit(data & 0x1000);
+	eeprom->set_cs_line((data & 0x4000) ? CLEAR_LINE : ASSERT_LINE);
+	eeprom->set_clock_line((data & 0x2000) ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 
 
-static UINT16* pntnpuzl_3a0000ram;
-static UINT16* pntnpuzl_bank;
 /* vid */
 static VIDEO_START( pntnpuzl )
 {
-	pntnpuzl_3a0000ram=auto_alloc_array(machine, UINT16, 0x100000/2);
+	pntnpuzl_state *state = machine.driver_data<pntnpuzl_state>();
+	state->m_3a0000ram=auto_alloc_array(machine, UINT16, 0x100000/2);
 }
 
-static VIDEO_UPDATE( pntnpuzl )
+static SCREEN_UPDATE( pntnpuzl )
 {
+	pntnpuzl_state *state = screen->machine().driver_data<pntnpuzl_state>();
 	int x,y;
 	int count;
 #if 0
@@ -177,37 +200,37 @@ static VIDEO_UPDATE( pntnpuzl )
 	static int yyy=512;
 	static int sss=0xa8;
 
-	if ( input_code_pressed_once(screen->machine, KEYCODE_Q) )
+	if ( screen->machine().input().code_pressed_once(KEYCODE_Q) )
 	{
 		xxx--;
 		mame_printf_debug("xxx %04x\n",xxx);
 	}
 
-	if ( input_code_pressed_once(screen->machine, KEYCODE_W) )
+	if ( screen->machine().input().code_pressed_once(KEYCODE_W) )
 	{
 		xxx++;
 		mame_printf_debug("xxx %04x\n",xxx);
 	}
 
-	if ( input_code_pressed_once(screen->machine, KEYCODE_A) )
+	if ( screen->machine().input().code_pressed_once(KEYCODE_A) )
 	{
 		yyy--;
 		mame_printf_debug("yyy %04x\n",yyy);
 	}
 
-	if ( input_code_pressed_once(screen->machine, KEYCODE_S) )
+	if ( screen->machine().input().code_pressed_once(KEYCODE_S) )
 	{
 		yyy++;
 		mame_printf_debug("yyy %04x\n",yyy);
 	}
 
-	if ( input_code_pressed_once(screen->machine, KEYCODE_Z) )
+	if ( screen->machine().input().code_pressed_once(KEYCODE_Z) )
 	{
 		sss--;
 		mame_printf_debug("sss %04x\n",sss);
 	}
 
-	if ( input_code_pressed_once(screen->machine, KEYCODE_X) )
+	if ( screen->machine().input().code_pressed_once(KEYCODE_X) )
 	{
 		sss++;
 		mame_printf_debug("sss %04x\n",sss);
@@ -225,8 +248,8 @@ static VIDEO_UPDATE( pntnpuzl )
 	{
 		for(x=0;x<xxx;x+=2)
 		{
-			*BITMAP_ADDR16(bitmap, y, x) = (pntnpuzl_3a0000ram[count]&0x1f00)>>8;
-			*BITMAP_ADDR16(bitmap, y, x+1) = (pntnpuzl_3a0000ram[count]&0x001f)>>0;
+			*BITMAP_ADDR16(bitmap, y, x) = (state->m_3a0000ram[count]&0x1f00)>>8;
+			*BITMAP_ADDR16(bitmap, y, x+1) = (state->m_3a0000ram[count]&0x001f)>>0;
 			count++;
 		}
 	}
@@ -235,21 +258,21 @@ static VIDEO_UPDATE( pntnpuzl )
 
 static WRITE16_HANDLER( pntnpuzl_palette_w )
 {
-	static int indx,sub,rgb[3];
+	pntnpuzl_state *state = space->machine().driver_data<pntnpuzl_state>();
 
 	if (ACCESSING_BITS_8_15)
 	{
-		indx = data >> 8;
-		sub = 0;
+		state->m_indx = data >> 8;
+		state->m_sub = 0;
 	}
 	if (ACCESSING_BITS_0_7)
 	{
-		rgb[sub++] = data & 0xff;
-		if (sub == 3)
+		state->m_rgb[state->m_sub++] = data & 0xff;
+		if (state->m_sub == 3)
 		{
-			palette_set_color_rgb(space->machine,indx++,pal6bit(rgb[0]),pal6bit(rgb[1]),pal6bit(rgb[2]));
-			sub = 0;
-			if (indx == 256) indx = 0;
+			palette_set_color_rgb(space->machine(),state->m_indx++,pal6bit(state->m_rgb[0]),pal6bit(state->m_rgb[1]),pal6bit(state->m_rgb[2]));
+			state->m_sub = 0;
+			if (state->m_indx == 256) state->m_indx = 0;
 		}
 	}
 }
@@ -259,25 +282,27 @@ static WRITE16_HANDLER( pntnpuzl_palette_w )
 #ifdef UNUSED_FUNCTION
 READ16_HANDLER ( pntnpuzl_random_r )
 {
-	return space->machine->rand();
+	return space->machine().rand();
 }
 #endif
 
 static READ16_HANDLER( pntnpuzl_vid_r )
 {
-//  logerror("read_videoram: pc = %06x : offset %04x reg %04x\n",cpu_get_pc(space->cpu),offset*2, pntnpuzl_bank[0]);
-	return pntnpuzl_3a0000ram[offset+ (pntnpuzl_bank[0]&0x0001)*0x8000 ];
+	pntnpuzl_state *state = space->machine().driver_data<pntnpuzl_state>();
+//  logerror("read_videoram: pc = %06x : offset %04x reg %04x\n",cpu_get_pc(&space->device()),offset*2, state->m_bank[0]);
+	return state->m_3a0000ram[offset+ (state->m_bank[0]&0x0001)*0x8000 ];
 }
 
 static WRITE16_HANDLER( pntnpuzl_vid_w )
 {
-//  logerror("write_to_videoram: pc = %06x : offset %04x data %04x reg %04x\n",cpu_get_pc(space->cpu),offset*2, data, pntnpuzl_bank[0]);
-	COMBINE_DATA(&pntnpuzl_3a0000ram[offset+ (pntnpuzl_bank[0]&0x0001)*0x8000 ]);
+	pntnpuzl_state *state = space->machine().driver_data<pntnpuzl_state>();
+//  logerror("write_to_videoram: pc = %06x : offset %04x data %04x reg %04x\n",cpu_get_pc(&space->device()),offset*2, data, state->m_bank[0]);
+	COMBINE_DATA(&state->m_3a0000ram[offset+ (state->m_bank[0]&0x0001)*0x8000 ]);
 }
 
 static READ16_HANDLER( pntnpuzl_vblank_r )
 {
-	return (input_port_read(space->machine, "IN0") & 1) << 11;
+	return (input_port_read(space->machine(), "IN0") & 1) << 11;
 }
 
 
@@ -303,56 +328,57 @@ write                                     read
 01 53 45 32 0d                       ---> 80 0c
 01 03 46 31 38 0d                    ---> 80 0c
 */
-static UINT16 pntpzl_200000, serial, serial_out,read_count;
 
 static WRITE16_HANDLER( pntnpuzl_200000_w )
 {
+	pntnpuzl_state *state = space->machine().driver_data<pntnpuzl_state>();
 // logerror("200000: %04x\n",data);
 	// bit 12: set to 1 when going to serial output to 280018
-	if ((pntpzl_200000 & 0x1000) && !(data & 0x1000))
+	if ((state->m_pntpzl_200000 & 0x1000) && !(data & 0x1000))
 	{
-		serial_out = (serial>>1) & 0xff;
-		read_count = 0;
-		logerror("serial out: %02x\n",serial_out);
+		state->m_serial_out = (state->m_serial>>1) & 0xff;
+		state->m_read_count = 0;
+		logerror("serial out: %02x\n",state->m_serial_out);
 	}
 
-	pntpzl_200000 = data;
+	state->m_pntpzl_200000 = data;
 }
 
 static WRITE16_HANDLER( pntnpuzl_280018_w )
 {
-// logerror("%04x: 280018: %04x\n",cpu_get_pc(space->cpu),data);
-	serial >>= 1;
+	pntnpuzl_state *state = space->machine().driver_data<pntnpuzl_state>();
+// logerror("%04x: 280018: %04x\n",cpu_get_pc(&space->device()),data);
+	state->m_serial >>= 1;
 	if (data & 0x2000)
-		serial |= 0x400;
+		state->m_serial |= 0x400;
 }
 
 static READ16_HANDLER( pntnpuzl_280014_r )
 {
+	pntnpuzl_state *state = space->machine().driver_data<pntnpuzl_state>();
 	static const int startup[3] = { 0x80, 0x0c, 0x00 };
 	int res;
 
-	if (serial_out == 0x11)
+	if (state->m_serial_out == 0x11)
 	{
-		static int touchscr[5];
-		if (input_port_read(space->machine, "IN0") & 0x10)
+		if (input_port_read(space->machine(), "IN0") & 0x10)
 		{
-			touchscr[0] = 0x1b;
-			touchscr[2] = BITSWAP8(input_port_read(space->machine, "TOUCHX"),0,1,2,3,4,5,6,7);
-			touchscr[4] = BITSWAP8(input_port_read(space->machine, "TOUCHY"),0,1,2,3,4,5,6,7);
+			state->m_touchscr[0] = 0x1b;
+			state->m_touchscr[2] = BITSWAP8(input_port_read(space->machine(), "TOUCHX"),0,1,2,3,4,5,6,7);
+			state->m_touchscr[4] = BITSWAP8(input_port_read(space->machine(), "TOUCHY"),0,1,2,3,4,5,6,7);
 		}
 		else
-			touchscr[0] = 0;
+			state->m_touchscr[0] = 0;
 
-		if (read_count >= 10) read_count = 0;
-		res = touchscr[read_count/2];
-		read_count++;
+		if (state->m_read_count >= 10) state->m_read_count = 0;
+		res = state->m_touchscr[state->m_read_count/2];
+		state->m_read_count++;
 	}
 	else
 	{
-		if (read_count >= 6) read_count = 0;
-		res = startup[read_count/2];
-		read_count++;
+		if (state->m_read_count >= 6) state->m_read_count = 0;
+		res = startup[state->m_read_count/2];
+		state->m_read_count++;
 	}
 	logerror("read 280014: %02x\n",res);
 	return res << 8;
@@ -365,7 +391,7 @@ static READ16_HANDLER( pntnpuzl_28001a_r )
 
 
 
-static ADDRESS_MAP_START( pntnpuzl_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( pntnpuzl_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	AM_RANGE(0x080000, 0x080001) AM_READNOP //|
 	AM_RANGE(0x100000, 0x100001) AM_READNOP	//| irq lines clear
@@ -386,7 +412,7 @@ static ADDRESS_MAP_START( pntnpuzl_map, ADDRESS_SPACE_PROGRAM, 16 )
 
 	/* standard VGA */
 	AM_RANGE(0x3a0000, 0x3affff) AM_READWRITE(pntnpuzl_vid_r, pntnpuzl_vid_w)
-	AM_RANGE(0x3c03c4, 0x3c03c5) AM_RAM AM_BASE(&pntnpuzl_bank)//??
+	AM_RANGE(0x3c03c4, 0x3c03c5) AM_RAM AM_BASE_MEMBER(pntnpuzl_state, m_bank)//??
 	AM_RANGE(0x3c03c8, 0x3c03c9) AM_WRITE(pntnpuzl_palette_w)
 	AM_RANGE(0x3c03da, 0x3c03db) AM_READ(pntnpuzl_vblank_r)
 
@@ -396,11 +422,11 @@ ADDRESS_MAP_END
 
 static INTERRUPT_GEN( pntnpuzl_irq )
 {
-	if (input_port_read(device->machine, "IN0") & 0x02)	/* coin */
+	if (input_port_read(device->machine(), "IN0") & 0x02)	/* coin */
 		generic_pulse_irq_line(device, 1);
-	else if (input_port_read(device->machine, "IN0") & 0x04)	/* service */
+	else if (input_port_read(device->machine(), "IN0") & 0x04)	/* service */
 		generic_pulse_irq_line(device, 2);
-	else if (input_port_read(device->machine, "IN0") & 0x08)	/* coin */
+	else if (input_port_read(device->machine(), "IN0") & 0x08)	/* coin */
 		generic_pulse_irq_line(device, 4);
 }
 
@@ -436,7 +462,7 @@ INPUT_PORTS_END
 
 
 
-static MACHINE_CONFIG_START( pntnpuzl, driver_device )
+static MACHINE_CONFIG_START( pntnpuzl, pntnpuzl_state )
 	MCFG_CPU_ADD("maincpu", M68000, 12000000)//??
 	MCFG_CPU_PROGRAM_MAP(pntnpuzl_map)
 	MCFG_CPU_VBLANK_INT("screen", pntnpuzl_irq)	// irq1 = coin irq2 = service irq4 = coin
@@ -450,11 +476,11 @@ static MACHINE_CONFIG_START( pntnpuzl, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 50*8-1, 0*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(pntnpuzl)
 
 	MCFG_PALETTE_LENGTH(256)
 
 	MCFG_VIDEO_START(pntnpuzl)
-	MCFG_VIDEO_UPDATE(pntnpuzl)
 MACHINE_CONFIG_END
 
 ROM_START( pntnpuzl )
@@ -466,7 +492,7 @@ ROM_END
 
 static DRIVER_INIT(pip)
 {
-//  UINT16 *rom = (UINT16 *)machine->region("maincpu")->base();
+//  UINT16 *rom = (UINT16 *)machine.region("maincpu")->base();
 //  rom[0x2696/2] = 0x4e71;
 //  rom[0x26a0/2] = 0x4e71;
 }
