@@ -94,25 +94,6 @@ PC5380-9651            5380-JY3306A           5380-N1045503A
 #define MASTER_CLOCK	48000000
 
 
-/* global variables */
-UINT32 *	policetr_rambase;
-
-
-/* local variables */
-static UINT32 control_data;
-
-static UINT32 bsmt_reg;
-static UINT32 bsmt_data_bank;
-static UINT32 bsmt_data_offset;
-
-static UINT32 *speedup_data;
-static UINT64 last_cycles;
-static UINT32 loop_count;
-
-static offs_t speedup_pc;
-
-
-
 /*************************************
  *
  *  Interrupt handling
@@ -127,8 +108,8 @@ static TIMER_CALLBACK( irq5_gen )
 
 static INTERRUPT_GEN( irq4_gen )
 {
-	cpu_set_input_line(device, R3000_IRQ4, ASSERT_LINE);
-	timer_set(device->machine, device->machine->primary_screen->time_until_pos(0), NULL, 0, irq5_gen);
+	device_set_input_line(device, R3000_IRQ4, ASSERT_LINE);
+	device->machine().scheduler().timer_set(device->machine().primary_screen->time_until_pos(0), FUNC(irq5_gen));
 }
 
 
@@ -141,7 +122,8 @@ static INTERRUPT_GEN( irq4_gen )
 
 static WRITE32_HANDLER( control_w )
 {
-	UINT32 old = control_data;
+	policetr_state *state = space->machine().driver_data<policetr_state>();
+	UINT32 old = state->m_control_data;
 
 	// bit $80000000 = BSMT access/ROM read
 	// bit $20000000 = toggled every 64 IRQ4's
@@ -150,28 +132,27 @@ static WRITE32_HANDLER( control_w )
 	// bit $00400000 = EEPROM clock
 	// bit $00200000 = EEPROM enable (on 1)
 
-	COMBINE_DATA(&control_data);
+	COMBINE_DATA(&state->m_control_data);
 
 	/* handle EEPROM I/O */
 	if (ACCESSING_BITS_16_23)
 	{
-		device_t *device = space->machine->device("eeprom");
-		eeprom_write_bit(device, data & 0x00800000);
-		eeprom_set_cs_line(device, (data & 0x00200000) ? CLEAR_LINE : ASSERT_LINE);
-		eeprom_set_clock_line(device, (data & 0x00400000) ? ASSERT_LINE : CLEAR_LINE);
+		eeprom_device *eeprom = space->machine().device<eeprom_device>("eeprom");
+		eeprom->write_bit(data & 0x00800000);
+		eeprom->set_cs_line((data & 0x00200000) ? CLEAR_LINE : ASSERT_LINE);
+		eeprom->set_clock_line((data & 0x00400000) ? ASSERT_LINE : CLEAR_LINE);
 	}
 
 	/* toggling BSMT off then on causes a reset */
-	if (!(old & 0x80000000) && (control_data & 0x80000000))
+	if (!(old & 0x80000000) && (state->m_control_data & 0x80000000))
 	{
-		device_t *device = space->machine->device("bsmt");
-		bsmt2000_data_w(device, bsmt_data_bank, 0, 0xffff);
-		device->reset();
+		bsmt2000_device *bsmt = space->machine().device<bsmt2000_device>("bsmt");
+		bsmt->reset();
 	}
 
 	/* log any unknown bits */
 	if (data & 0x4f1fffff)
-		logerror("%08X: control_w = %08X & %08X\n", cpu_get_previouspc(space->cpu), data, mem_mask);
+		logerror("%08X: control_w = %08X & %08X\n", cpu_get_previouspc(&space->device()), data, mem_mask);
 }
 
 
@@ -182,27 +163,34 @@ static WRITE32_HANDLER( control_w )
  *
  *************************************/
 
-static WRITE32_DEVICE_HANDLER( policetr_bsmt2000_reg_w )
+static WRITE32_HANDLER( policetr_bsmt2000_reg_w )
 {
-	if (control_data & 0x80000000)
-		bsmt2000_data_w(device, bsmt_reg, data & 0xffff, mem_mask & 0xffff);
+	policetr_state *state = space->machine().driver_data<policetr_state>();
+	if (state->m_control_data & 0x80000000)
+		space->machine().device<bsmt2000_device>("bsmt")->write_data(data);
 	else
-		COMBINE_DATA(&bsmt_data_offset);
+		COMBINE_DATA(&state->m_bsmt_data_offset);
 }
 
 
 static WRITE32_HANDLER( policetr_bsmt2000_data_w )
 {
-	if (control_data & 0x80000000)
-		COMBINE_DATA(&bsmt_reg);
-	else
-		COMBINE_DATA(&bsmt_data_bank);
+	policetr_state *state = space->machine().driver_data<policetr_state>();
+	space->machine().device<bsmt2000_device>("bsmt")->write_reg(data);
+	COMBINE_DATA(&state->m_bsmt_data_bank);
+}
+
+
+static CUSTOM_INPUT( bsmt_status_r )
+{
+	return field.machine().device<bsmt2000_device>("bsmt")->read_status();
 }
 
 
 static READ32_HANDLER( bsmt2000_data_r )
 {
-	return space->machine->region("bsmt")->base()[bsmt_data_bank * 0x10000 + bsmt_data_offset] << 8;
+	policetr_state *state = space->machine().driver_data<policetr_state>();
+	return space->machine().region("bsmt")->base()[state->m_bsmt_data_bank * 0x10000 + state->m_bsmt_data_offset] << 8;
 }
 
 
@@ -215,26 +203,27 @@ static READ32_HANDLER( bsmt2000_data_r )
 
 static WRITE32_HANDLER( speedup_w )
 {
-	COMBINE_DATA(speedup_data);
+	policetr_state *state = space->machine().driver_data<policetr_state>();
+	COMBINE_DATA(state->m_speedup_data);
 
 	/* see if the PC matches */
-	if ((cpu_get_previouspc(space->cpu) & 0x1fffffff) == speedup_pc)
+	if ((cpu_get_previouspc(&space->device()) & 0x1fffffff) == state->m_speedup_pc)
 	{
-		UINT64 curr_cycles = space->machine->firstcpu->total_cycles();
+		UINT64 curr_cycles = space->machine().firstcpu->total_cycles();
 
 		/* if less than 50 cycles from the last time, count it */
-		if (curr_cycles - last_cycles < 50)
+		if (curr_cycles - state->m_last_cycles < 50)
 		{
-			loop_count++;
+			state->m_loop_count++;
 
 			/* more than 2 in a row and we spin */
-			if (loop_count > 2)
-				cpu_spinuntil_int(space->cpu);
+			if (state->m_loop_count > 2)
+				device_spin_until_interrupt(&space->device());
 		}
 		else
-			loop_count = 0;
+			state->m_loop_count = 0;
 
-		last_cycles = curr_cycles;
+		state->m_last_cycles = curr_cycles;
 	}
 }
 
@@ -265,13 +254,13 @@ static const eeprom_interface eeprom_interface_policetr =
  *
  *************************************/
 
-static ADDRESS_MAP_START( policetr_map, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x00000000, 0x0001ffff) AM_RAM AM_BASE(&policetr_rambase)
+static ADDRESS_MAP_START( policetr_map, AS_PROGRAM, 32 )
+	AM_RANGE(0x00000000, 0x0001ffff) AM_RAM AM_BASE_MEMBER(policetr_state, m_rambase)
 	AM_RANGE(0x00200000, 0x0020000f) AM_WRITE(policetr_video_w)
 	AM_RANGE(0x00400000, 0x00400003) AM_READ(policetr_video_r)
 	AM_RANGE(0x00500000, 0x00500003) AM_WRITENOP		// copies ROM here at startup, plus checksum
 	AM_RANGE(0x00600000, 0x00600003) AM_READ(bsmt2000_data_r)
-	AM_RANGE(0x00700000, 0x00700003) AM_DEVWRITE("bsmt", policetr_bsmt2000_reg_w)
+	AM_RANGE(0x00700000, 0x00700003) AM_WRITE(policetr_bsmt2000_reg_w)
 	AM_RANGE(0x00800000, 0x00800003) AM_WRITE(policetr_bsmt2000_data_w)
 	AM_RANGE(0x00900000, 0x00900003) AM_WRITE(policetr_palette_offset_w)
 	AM_RANGE(0x00920000, 0x00920003) AM_WRITE(policetr_palette_data_w)
@@ -284,15 +273,15 @@ static ADDRESS_MAP_START( policetr_map, ADDRESS_SPACE_PROGRAM, 32 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( sshooter_map, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x00000000, 0x0001ffff) AM_RAM AM_BASE(&policetr_rambase)
+static ADDRESS_MAP_START( sshooter_map, AS_PROGRAM, 32 )
+	AM_RANGE(0x00000000, 0x0001ffff) AM_RAM AM_BASE_MEMBER(policetr_state, m_rambase)
 	AM_RANGE(0x00200000, 0x00200003) AM_WRITE(policetr_bsmt2000_data_w)
 	AM_RANGE(0x00300000, 0x00300003) AM_WRITE(policetr_palette_offset_w)
 	AM_RANGE(0x00320000, 0x00320003) AM_WRITE(policetr_palette_data_w)
 	AM_RANGE(0x00400000, 0x00400003) AM_READ(policetr_video_r)
 	AM_RANGE(0x00500000, 0x00500003) AM_WRITENOP		// copies ROM here at startup, plus checksum
 	AM_RANGE(0x00600000, 0x00600003) AM_READ(bsmt2000_data_r)
-	AM_RANGE(0x00700000, 0x00700003) AM_DEVWRITE("bsmt", policetr_bsmt2000_reg_w)
+	AM_RANGE(0x00700000, 0x00700003) AM_WRITE(policetr_bsmt2000_reg_w)
 	AM_RANGE(0x00800000, 0x0080000f) AM_WRITE(policetr_video_w)
 	AM_RANGE(0x00a00000, 0x00a00003) AM_WRITE(control_w)
 	AM_RANGE(0x00a00000, 0x00a00003) AM_READ_PORT("IN0")
@@ -337,13 +326,13 @@ static INPUT_PORTS_START( policetr )
 	PORT_BIT( 0x00100000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_SERVICE( 0x00200000, IP_ACTIVE_LOW )		/* Not actually a dipswitch */
 	PORT_BIT( 0x00400000, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x00800000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x00800000, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(bsmt_status_r, NULL)
 	PORT_BIT( 0x01000000, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0x02000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x04000000, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x08000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x10000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x20000000, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_READ_LINE_DEVICE("eeprom", eeprom_read_bit)	/* EEPROM read */
+	PORT_BIT( 0x20000000, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_READ_LINE_DEVICE_MEMBER("eeprom", eeprom_device, read_bit)	/* EEPROM read */
 	PORT_BIT( 0x40000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
@@ -425,7 +414,7 @@ static const r3000_cpu_core r3000_config =
 };
 
 
-static MACHINE_CONFIG_START( policetr, driver_device )
+static MACHINE_CONFIG_START( policetr, policetr_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", R3000BE, MASTER_CLOCK/2)
@@ -443,16 +432,16 @@ static MACHINE_CONFIG_START( policetr, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(400, 262)	/* needs to be verified */
 	MCFG_SCREEN_VISIBLE_AREA(0, 393, 0, 239)
+	MCFG_SCREEN_UPDATE(policetr)
 
 	MCFG_PALETTE_LENGTH(256)
 
 	MCFG_VIDEO_START(policetr)
-	MCFG_VIDEO_UPDATE(policetr)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
-	MCFG_SOUND_ADD("bsmt", BSMT2000, MASTER_CLOCK/2)
+	MCFG_BSMT2000_ADD("bsmt", MASTER_CLOCK/2)
 	MCFG_SOUND_ROUTE(0, "lspeaker", 1.0)
 	MCFG_SOUND_ROUTE(1, "rspeaker", 1.0)
 MACHINE_CONFIG_END
@@ -486,7 +475,7 @@ ROM_START( policetr ) /* Rev 0.3 PCB , with all chips dated 04/01/97 */
 	ROM_LOAD32_BYTE( "pt-u111.bin", 0x00002, 0x20000, CRC(fb5ce933) SHA1(4a07ac3e2d86262061092f112cab89f8660dce3d) )
 	ROM_LOAD32_BYTE( "pt-u110.bin", 0x00003, 0x20000, CRC(40bd6f60) SHA1(156000d3c439eab45962f0a2681bd806a17f47ee) )
 
-	ROM_REGION( 0x600000, "bsmt", 0 )
+	ROM_REGION( 0x1000000, "bsmt", 0 )
 	ROM_LOAD( "pt-u160.bin", 0x000000, 0x100000, CRC(f267f813) SHA1(ae58507947fe2e9701b5df46565fd9908e2f9d77) )
 	ROM_RELOAD(              0x3f8000, 0x100000 )
 	ROM_LOAD( "pt-u162.bin", 0x100000, 0x100000, CRC(75fe850e) SHA1(ab8cf24ae6e5cf80f6a9a34e46f2b1596879643b) )
@@ -507,7 +496,7 @@ ROM_START( policetr11 ) /* Rev 0.3 PCB with all chips dated 01/06/97 */
 	ROM_LOAD32_BYTE( "pt-u111.v11", 0x00002, 0x20000, CRC(da6c45a7) SHA1(471bd372d2ad5bcb29af19dae09f3cfab4b010fd) )
 	ROM_LOAD32_BYTE( "pt-u110.v11", 0x00003, 0x20000, CRC(f1c8a8c0) SHA1(8a2d1ada002be6f2a3c2d21d193e7cde6531545a) )
 
-	ROM_REGION( 0x600000, "bsmt", 0 )
+	ROM_REGION( 0x1000000, "bsmt", 0 )
 	ROM_LOAD( "pt-u160.bin", 0x000000, 0x100000, CRC(f267f813) SHA1(ae58507947fe2e9701b5df46565fd9908e2f9d77) )
 	ROM_RELOAD(              0x3f8000, 0x100000 )
 	ROM_LOAD( "pt-u162.bin", 0x100000, 0x100000, CRC(75fe850e) SHA1(ab8cf24ae6e5cf80f6a9a34e46f2b1596879643b) )
@@ -533,7 +522,7 @@ ROM_START( policetr10 ) /* Rev 0.2 PCB with all chips dated 10/07/96 */
 	ROM_LOAD32_BYTE( "pt-u111.v10", 0x00002, 0x20000, CRC(61f79667) SHA1(25298cd8706b5c59f7c9e0f8d44db0df73c23403) )
 	ROM_LOAD32_BYTE( "pt-u110.v10", 0x00003, 0x20000, CRC(5c3c1548) SHA1(aab977274ecff7cb5fd540a3d0da7940e9707906) )
 
-	ROM_REGION( 0x600000, "bsmt", 0 )
+	ROM_REGION( 0x1000000, "bsmt", 0 )
 	/* Same data as the other sets, but split in 4 meg roms */
 	ROM_LOAD( "pt-u160.v10", 0x000000, 0x080000, CRC(cd374405) SHA1(e53689d4344c78c3faac22747ada28bc3add8c56) )
 	ROM_RELOAD(              0x3f8000, 0x080000 )
@@ -569,7 +558,7 @@ Note: With this version, the program roms are twice the size of those found on a
 	ROM_LOAD32_BYTE( "pt-av13.u111", 0x00002, 0x40000, CRC(8c4f3a64) SHA1(4953e6fc26bae7d6e7c7230f4ca76e3f5032af14) ) /* Checksum printed on label  F343 */
 	ROM_LOAD32_BYTE( "pt-av13.u110", 0x00003, 0x40000, CRC(738a8277) SHA1(423a9bcecb82959f38ae79a0728d72eb13ed93b3) ) /* Checksum printed on label  050C */
 
-	ROM_REGION( 0x600000, "bsmt", 0 )
+	ROM_REGION( 0x1000000, "bsmt", 0 )
 	ROM_LOAD( "pt-u160.bin", 0x000000, 0x100000, CRC(f267f813) SHA1(ae58507947fe2e9701b5df46565fd9908e2f9d77) )
 	ROM_RELOAD(              0x3f8000, 0x100000 )
 	ROM_LOAD( "pt-u162.bin", 0x100000, 0x100000, CRC(75fe850e) SHA1(ab8cf24ae6e5cf80f6a9a34e46f2b1596879643b) )
@@ -597,7 +586,7 @@ Note: If you set the dipswitch to service mode and reset the game within Mame. A
 	ROM_LOAD32_BYTE( "ptb-u111.v13", 0x00002, 0x20000, CRC(39e96d6a) SHA1(efe6ffe70432b94c98f3d7247408a6d2f6f9e33d) ) /* Checksum printed on label  E5F1 */
 	ROM_LOAD32_BYTE( "ptb-u110.v13", 0x00003, 0x20000, CRC(d7e6f4cb) SHA1(9dffe4937bc5cf47d870f06ae0dced362cd2dd66) ) /* Checksum printed on label  556D */
 
-	ROM_REGION( 0x600000, "bsmt", 0 )
+	ROM_REGION( 0x1000000, "bsmt", 0 )
 	ROM_LOAD( "pt-u160.bin", 0x000000, 0x100000, CRC(f267f813) SHA1(ae58507947fe2e9701b5df46565fd9908e2f9d77) )
 	ROM_RELOAD(              0x3f8000, 0x100000 )
 	ROM_LOAD( "pt-u162.bin", 0x100000, 0x100000, CRC(75fe850e) SHA1(ab8cf24ae6e5cf80f6a9a34e46f2b1596879643b) )
@@ -622,7 +611,7 @@ ROM_START( sshooter ) /* Rev 0.5B PCB , unknown program rom date */
 	ROM_LOAD32_BYTE( "ss-u111.v17", 0x00002, 0x40000, CRC(4240fa2f) SHA1(54223207c1e228d6b836918601c0f65c2692e5bc) ) // 1:3
 	ROM_LOAD32_BYTE( "ss-u110.v17", 0x00003, 0x40000, CRC(8ae744ce) SHA1(659cd27865cf5507aae6b064c5bc24b927cf5f5a) ) // 1:4
 
-	ROM_REGION( 0x600000, "bsmt", 0 ) /* Sound v1.2 */
+	ROM_REGION( 0x1000000, "bsmt", 0 ) /* Sound v1.2 */
 	ROM_LOAD( "ss-u160.bin", 0x000000, 0x100000, CRC(1c603d42) SHA1(880992871be52129684052d542946de0cc32ba9a) ) // 1:1
 	ROM_RELOAD(              0x3f8000, 0x100000 )
 	ROM_LOAD( "ss-u162.bin", 0x100000, 0x100000, CRC(40ef448a) SHA1(c96f7b169be2576e9f3783af84c07259efefb812) ) // 2:1
@@ -647,7 +636,7 @@ ROM_START( sshooter12 ) /* Rev 0.5B PCB , program roms dated 04/17/98 */
 	ROM_LOAD32_BYTE( "ss-u111.v12", 0x00002, 0x40000, CRC(0b291731) SHA1(bd04f0b1b52198344df625fcddfc6c6ccb0bd923) ) // 1:3
 	ROM_LOAD32_BYTE( "ss-u110.v12", 0x00003, 0x40000, CRC(76841008) SHA1(ccbb88c8d63bf929814144a9d8757c9c7048fdef) ) // 1:4
 
-	ROM_REGION( 0x600000, "bsmt", 0 ) /* Sound v1.2 */
+	ROM_REGION( 0x1000000, "bsmt", 0 ) /* Sound v1.2 */
 	ROM_LOAD( "ss-u160.bin", 0x000000, 0x100000, CRC(1c603d42) SHA1(880992871be52129684052d542946de0cc32ba9a) ) // 1:1
 	ROM_RELOAD(              0x3f8000, 0x100000 )
 	ROM_LOAD( "ss-u162.bin", 0x100000, 0x100000, CRC(40ef448a) SHA1(c96f7b169be2576e9f3783af84c07259efefb812) ) // 2:1
@@ -672,7 +661,7 @@ ROM_START( sshooter11 ) /* Rev 0.5B PCB , program roms dated 04/03/98 */
 	ROM_LOAD32_BYTE( "ss-u111.v11", 0x00002, 0x40000, CRC(ec209b5f) SHA1(1408b509853b325e865d0b23d237bca321e73f60) ) // 1:3
 	ROM_LOAD32_BYTE( "ss-u110.v11", 0x00003, 0x40000, CRC(0f1de201) SHA1(5001de3349357545a6a45102340caf0008b50d7b) ) // 1:4
 
-	ROM_REGION( 0x600000, "bsmt", 0 ) /* Sound v1.2 */
+	ROM_REGION( 0x1000000, "bsmt", 0 ) /* Sound v1.2 */
 	ROM_LOAD( "ss-u160.bin", 0x000000, 0x100000, CRC(1c603d42) SHA1(880992871be52129684052d542946de0cc32ba9a) ) // 1:1
 	ROM_RELOAD(              0x3f8000, 0x100000 )
 	ROM_LOAD( "ss-u162.bin", 0x100000, 0x100000, CRC(40ef448a) SHA1(c96f7b169be2576e9f3783af84c07259efefb812) ) // 2:1
@@ -689,27 +678,31 @@ ROM_END
 
 static DRIVER_INIT( policetr )
 {
-	speedup_data = memory_install_write32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x00000fc8, 0x00000fcb, 0, 0, speedup_w);
-	speedup_pc = 0x1fc028ac;
+	policetr_state *state = machine.driver_data<policetr_state>();
+	state->m_speedup_data = machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0x00000fc8, 0x00000fcb, FUNC(speedup_w));
+	state->m_speedup_pc = 0x1fc028ac;
 }
 
 static DRIVER_INIT( plctr13b )
 {
-	speedup_data = memory_install_write32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x00000fc8, 0x00000fcb, 0, 0, speedup_w);
-	speedup_pc = 0x1fc028bc;
+	policetr_state *state = machine.driver_data<policetr_state>();
+	state->m_speedup_data = machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0x00000fc8, 0x00000fcb, FUNC(speedup_w));
+	state->m_speedup_pc = 0x1fc028bc;
 }
 
 
 static DRIVER_INIT( sshooter )
 {
-	speedup_data = memory_install_write32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x00018fd8, 0x00018fdb, 0, 0, speedup_w);
-	speedup_pc = 0x1fc03470;
+	policetr_state *state = machine.driver_data<policetr_state>();
+	state->m_speedup_data = machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0x00018fd8, 0x00018fdb, FUNC(speedup_w));
+	state->m_speedup_pc = 0x1fc03470;
 }
 
 static DRIVER_INIT( sshoot12 )
 {
-	speedup_data = memory_install_write32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x00018fd8, 0x00018fdb, 0, 0, speedup_w);
-	speedup_pc = 0x1fc033e0;
+	policetr_state *state = machine.driver_data<policetr_state>();
+	state->m_speedup_data = machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_write_handler(0x00018fd8, 0x00018fdb, FUNC(speedup_w));
+	state->m_speedup_pc = 0x1fc033e0;
 }
 
 
