@@ -36,30 +36,31 @@ static WRITE16_DEVICE_HANDLER( magicstk_coin_eeprom_w )
 {
 	if (ACCESSING_BITS_0_7)
 	{
-		coin_counter_w(device->machine, 0, data & 0x20);
+		coin_counter_w(device->machine(), 0, data & 0x20);
 
-		eeprom_set_cs_line(device, (data & 8) ? CLEAR_LINE : ASSERT_LINE);
-		eeprom_write_bit(device, data & 2);
-		eeprom_set_clock_line(device, (data & 4) ? CLEAR_LINE : ASSERT_LINE);
+		eeprom_device *eeprom = downcast<eeprom_device *>(device);
+		eeprom->set_cs_line((data & 8) ? CLEAR_LINE : ASSERT_LINE);
+		eeprom->write_bit(data & 2);
+		eeprom->set_clock_line((data & 4) ? CLEAR_LINE : ASSERT_LINE);
 	}
 }
 
 static WRITE16_HANDLER( magicstk_bgvideoram_w )
 {
-	playmark_state *state = space->machine->driver_data<playmark_state>();
+	playmark_state *state = space->machine().driver_data<playmark_state>();
 
-	COMBINE_DATA(&state->videoram1[offset]);
-	tilemap_mark_tile_dirty(state->bg_tilemap, offset);
+	COMBINE_DATA(&state->m_videoram1[offset]);
+	tilemap_mark_tile_dirty(state->m_bg_tilemap, offset);
 }
 
 static WRITE16_HANDLER( tile_banking_w )
 {
-	playmark_state *state = space->machine->driver_data<playmark_state>();
+	playmark_state *state = space->machine().driver_data<playmark_state>();
 
-	if (((data >> 12) & 0x0f) != state->tilebank)
+	if (((data >> 12) & 0x0f) != state->m_tilebank)
 	{
-		state->tilebank = (data >> 12) & 0x0f;
-		tilemap_mark_all_tiles_dirty(state->bg_tilemap);
+		state->m_tilebank = (data >> 12) & 0x0f;
+		tilemap_mark_all_tiles_dirty(state->m_bg_tilemap);
 	}
 }
 
@@ -69,18 +70,18 @@ static WRITE16_DEVICE_HANDLER( oki_banking )
 	{
 		int addr = 0x40000 * ((data & 3) - 1);
 
-		if (addr < device->machine->region("oki")->bytes())
+		if (addr < device->machine().region("oki")->bytes())
 			downcast<okim6295_device *>(device)->set_bank_base(addr);
 	}
 }
 
-static ADDRESS_MAP_START( magicstk_main_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( magicstk_main_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
 	AM_RANGE(0x088000, 0x0883ff) AM_RAM_WRITE(bigtwin_paletteram_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x094000, 0x094001) AM_WRITENOP
 	AM_RANGE(0x094002, 0x094003) AM_WRITENOP
 	AM_RANGE(0x094004, 0x094005) AM_WRITE(tile_banking_w)
-	AM_RANGE(0x098180, 0x09917f) AM_RAM_WRITE(magicstk_bgvideoram_w) AM_BASE_MEMBER(playmark_state, videoram1)
+	AM_RANGE(0x098180, 0x09917f) AM_RAM_WRITE(magicstk_bgvideoram_w) AM_BASE_MEMBER(playmark_state, m_videoram1)
 	AM_RANGE(0x0c2010, 0x0c2011) AM_READ_PORT("IN0")
 	AM_RANGE(0x0c2012, 0x0c2013) AM_READ_PORT("IN1")
 	AM_RANGE(0x0c2014, 0x0c2015) AM_READ_PORT("IN2") AM_DEVWRITE("eeprom", magicstk_coin_eeprom_w)
@@ -90,16 +91,16 @@ static ADDRESS_MAP_START( magicstk_main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x0c201e, 0x0c201f) AM_DEVREADWRITE8_MODERN("oki", okim6295_device, read, write, 0x00ff)
 	AM_RANGE(0x0c4000, 0x0c4001) AM_WRITENOP
 	AM_RANGE(0x0e0000, 0x0fffff) AM_RAM
-	AM_RANGE(0x100000, 0x100fff) AM_RAM AM_BASE_SIZE_MEMBER(playmark_state, spriteram, spriteram_size)
+	AM_RANGE(0x100000, 0x100fff) AM_RAM AM_BASE_SIZE_MEMBER(playmark_state, m_spriteram, m_spriteram_size)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( powerbal_main_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( powerbal_main_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	AM_RANGE(0x088000, 0x0883ff) AM_RAM_WRITE(bigtwin_paletteram_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x094000, 0x094001) AM_WRITENOP
 	AM_RANGE(0x094002, 0x094003) AM_WRITENOP
 	AM_RANGE(0x094004, 0x094005) AM_WRITE(tile_banking_w)
-	AM_RANGE(0x098000, 0x098fff) AM_RAM_WRITE(magicstk_bgvideoram_w) AM_BASE_MEMBER(playmark_state, videoram1)
+	AM_RANGE(0x098000, 0x098fff) AM_RAM_WRITE(magicstk_bgvideoram_w) AM_BASE_MEMBER(playmark_state, m_videoram1)
 	AM_RANGE(0x099000, 0x09bfff) AM_RAM // not used
 	AM_RANGE(0x0c2010, 0x0c2011) AM_READ_PORT("IN0")
 	AM_RANGE(0x0c2012, 0x0c2013) AM_READ_PORT("IN1")
@@ -110,7 +111,7 @@ static ADDRESS_MAP_START( powerbal_main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x0c201e, 0x0c201f) AM_DEVREADWRITE8_MODERN("oki", okim6295_device, read, write, 0x00ff)
 	AM_RANGE(0x0c4000, 0x0c4001) AM_WRITENOP
 	AM_RANGE(0x0f0000, 0x0fffff) AM_RAM
-	AM_RANGE(0x101000, 0x101fff) AM_RAM AM_BASE_SIZE_MEMBER(playmark_state, spriteram, spriteram_size)
+	AM_RANGE(0x101000, 0x101fff) AM_RAM AM_BASE_SIZE_MEMBER(playmark_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x102000, 0x10200d) AM_WRITENOP // not used scroll regs?
 	AM_RANGE(0x103000, 0x103fff) AM_RAM
 ADDRESS_MAP_END
@@ -220,7 +221,7 @@ static INPUT_PORTS_START( magicstk )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START("IN2")
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_READ_LINE_DEVICE("eeprom", eeprom_read_bit)	/* EEPROM data */
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_READ_LINE_DEVICE_MEMBER("eeprom", eeprom_device, read_bit)	/* EEPROM data */
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -317,7 +318,7 @@ static INPUT_PORTS_START( hotminda )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START("IN2")
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_READ_LINE_DEVICE("eeprom", eeprom_read_bit)	/* EEPROM data */
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_READ_LINE_DEVICE_MEMBER("eeprom", eeprom_device, read_bit)	/* EEPROM data */
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -377,24 +378,24 @@ INPUT_PORTS_END
 
 static TILE_GET_INFO( powerbal_get_bg_tile_info )
 {
-	playmark_state *state = machine->driver_data<playmark_state>();
-	int code = (state->videoram1[tile_index] & 0x07ff) + state->tilebank * 0x800;
-	int colr = state->videoram1[tile_index] & 0xf000;
+	playmark_state *state = machine.driver_data<playmark_state>();
+	int code = (state->m_videoram1[tile_index] & 0x07ff) + state->m_tilebank * 0x800;
+	int colr = state->m_videoram1[tile_index] & 0xf000;
 
-	if (state->videoram1[tile_index] & 0x800)
+	if (state->m_videoram1[tile_index] & 0x800)
 		code |= 0x8000;
 
 	SET_TILE_INFO(1, code, colr >> 12, 0);
 }
 
-static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect )
+static void draw_sprites( running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect )
 {
-	playmark_state *state = machine->driver_data<playmark_state>();
-	UINT16 *spriteram = state->spriteram;
+	playmark_state *state = machine.driver_data<playmark_state>();
+	UINT16 *spriteram = state->m_spriteram;
 	int offs;
-	int height = machine->gfx[0]->height;
+	int height = machine.gfx[0]->height;
 
-	for (offs = 4; offs < state->spriteram_size / 2; offs += 4)
+	for (offs = 4; offs < state->m_spriteram_size / 2; offs += 4)
 	{
 		int sx, sy, code, color, flipx;
 
@@ -408,31 +409,31 @@ static void draw_sprites( running_machine *machine, bitmap_t *bitmap, const rect
 		code = spriteram[offs + 2];
 		color = (spriteram[offs + 1] & 0xf000) >> 12;
 
-		drawgfx_transpen(bitmap,cliprect,machine->gfx[0],
+		drawgfx_transpen(bitmap,cliprect,machine.gfx[0],
 				code,
 				color,
 				flipx,0,
-				sx + state->xoffset,sy + state->yoffset,0);
+				sx + state->m_xoffset,sy + state->m_yoffset,0);
 	}
 }
 
 static VIDEO_START( powerbal )
 {
-	playmark_state *state = machine->driver_data<playmark_state>();
+	playmark_state *state = machine.driver_data<playmark_state>();
 
-	state->bg_tilemap = tilemap_create(machine, powerbal_get_bg_tile_info, tilemap_scan_rows, 8, 8, 64, 32);
+	state->m_bg_tilemap = tilemap_create(machine, powerbal_get_bg_tile_info, tilemap_scan_rows, 8, 8, 64, 32);
 
-	state->xoffset = -20;
+	state->m_xoffset = -20;
 
-	tilemap_set_scrolly(state->bg_tilemap, 0, state->bg_yoffset);
+	tilemap_set_scrolly(state->m_bg_tilemap, 0, state->m_bg_yoffset);
 }
 
-static VIDEO_UPDATE( powerbal )
+static SCREEN_UPDATE( powerbal )
 {
-	playmark_state *state = screen->machine->driver_data<playmark_state>();
+	playmark_state *state = screen->machine().driver_data<playmark_state>();
 
-	tilemap_draw(bitmap, cliprect, state->bg_tilemap, 0, 0);
-	draw_sprites(screen->machine, bitmap, cliprect);
+	tilemap_draw(bitmap, cliprect, state->m_bg_tilemap, 0, 0);
+	draw_sprites(screen->machine(), bitmap, cliprect);
 	return 0;
 }
 
@@ -471,16 +472,16 @@ GFXDECODE_END
 
 static MACHINE_START( powerbal )
 {
-	playmark_state *state = machine->driver_data<playmark_state>();
+	playmark_state *state = machine.driver_data<playmark_state>();
 
-	state_save_register_global(machine, state->tilebank);
+	state->save_item(NAME(state->m_tilebank));
 }
 
 static MACHINE_RESET( powerbal )
 {
-	playmark_state *state = machine->driver_data<playmark_state>();
+	playmark_state *state = machine.driver_data<playmark_state>();
 
-	state->tilebank = 0;
+	state->m_tilebank = 0;
 }
 
 static MACHINE_CONFIG_START( powerbal, playmark_state )
@@ -500,12 +501,12 @@ static MACHINE_CONFIG_START( powerbal, playmark_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(128*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(powerbal)
 
 	MCFG_GFXDECODE(powerbal)
 	MCFG_PALETTE_LENGTH(512)
 
 	MCFG_VIDEO_START(powerbal)
-	MCFG_VIDEO_UPDATE(powerbal)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -534,12 +535,12 @@ static MACHINE_CONFIG_START( magicstk, playmark_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(128*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(powerbal)
 
 	MCFG_GFXDECODE(powerbal)
 	MCFG_PALETTE_LENGTH(512)
 
 	MCFG_VIDEO_START(powerbal)
-	MCFG_VIDEO_UPDATE(powerbal)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -682,18 +683,18 @@ ROM_END
 
 static DRIVER_INIT( powerbal )
 {
-	playmark_state *state = machine->driver_data<playmark_state>();
+	playmark_state *state = machine.driver_data<playmark_state>();
 
-	state->bg_yoffset = 16;
-	state->yoffset = -8;
+	state->m_bg_yoffset = 16;
+	state->m_yoffset = -8;
 }
 
 static DRIVER_INIT( magicstk )
 {
-	playmark_state *state = machine->driver_data<playmark_state>();
+	playmark_state *state = machine.driver_data<playmark_state>();
 
-	state->bg_yoffset = 0;
-	state->yoffset = -5;
+	state->m_bg_yoffset = 0;
+	state->m_yoffset = -5;
 }
 
 /*************************
