@@ -43,18 +43,18 @@ TODO:
 
 ***************************************************************************/
 
-static int oki_bank;
 
 static WRITE16_HANDLER( powerins_okibank_w )
 {
+	powerins_state *state = space->machine().driver_data<powerins_state>();
 	if (ACCESSING_BITS_0_7)
 	{
-		UINT8 *RAM = space->machine->region("oki1")->base();
+		UINT8 *RAM = space->machine().region("oki1")->base();
 		int new_bank = data & 0x7;
 
-		if (new_bank != oki_bank)
+		if (new_bank != state->m_oki_bank)
 		{
-			oki_bank = new_bank;
+			state->m_oki_bank = new_bank;
 			memcpy(&RAM[0x30000],&RAM[0x40000 + 0x10000*new_bank],0x10000);
 		}
 	}
@@ -72,7 +72,7 @@ static READ8_HANDLER( powerinb_fake_ym2203_r )
 }
 
 
-static ADDRESS_MAP_START( powerins_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( powerins_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM															// ROM
 	AM_RANGE(0x100000, 0x100001) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x100002, 0x100003) AM_READ_PORT("P1_P2")
@@ -84,15 +84,15 @@ static ADDRESS_MAP_START( powerins_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x10001e, 0x10001f) AM_WRITE(powerins_soundlatch_w)								// Sound Latch
 	AM_RANGE(0x100030, 0x100031) AM_WRITE(powerins_okibank_w)									// Sound
 	AM_RANGE(0x120000, 0x120fff) AM_RAM_WRITE(powerins_paletteram16_w) AM_BASE_GENERIC(paletteram)	// Palette
-	AM_RANGE(0x130000, 0x130007) AM_RAM AM_BASE(&powerins_vctrl_0)								// VRAM 0 Control
-	AM_RANGE(0x140000, 0x143fff) AM_RAM_WRITE(powerins_vram_0_w) AM_BASE(&powerins_vram_0)		// VRAM 0
-	AM_RANGE(0x170000, 0x170fff) AM_RAM_WRITE(powerins_vram_1_w) AM_BASE(&powerins_vram_1)		// VRAM 1
+	AM_RANGE(0x130000, 0x130007) AM_RAM AM_BASE_MEMBER(powerins_state, m_vctrl_0)								// VRAM 0 Control
+	AM_RANGE(0x140000, 0x143fff) AM_RAM_WRITE(powerins_vram_0_w) AM_BASE_MEMBER(powerins_state, m_vram_0)		// VRAM 0
+	AM_RANGE(0x170000, 0x170fff) AM_RAM_WRITE(powerins_vram_1_w) AM_BASE_MEMBER(powerins_state, m_vram_1)		// VRAM 1
 	AM_RANGE(0x171000, 0x171fff) AM_WRITE(powerins_vram_1_w)									// Mirror of VRAM 1?
-	AM_RANGE(0x180000, 0x18ffff) AM_RAM AM_BASE_GENERIC(spriteram)									// RAM + Sprites
+	AM_RANGE(0x180000, 0x18ffff) AM_RAM AM_BASE_MEMBER(powerins_state, m_spriteram)									// RAM + Sprites
 ADDRESS_MAP_END
 
 /* powerina: same as the original one but without the sound cpu (and inferior sound HW) */
-static ADDRESS_MAP_START( powerina_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( powerina_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM															// ROM
 	AM_RANGE(0x100000, 0x100001) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x100002, 0x100003) AM_READ_PORT("P1_P2")
@@ -105,14 +105,14 @@ static ADDRESS_MAP_START( powerina_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x100030, 0x100031) AM_WRITE(powerins_okibank_w)									// Sound
 	AM_RANGE(0x10003e, 0x10003f) AM_DEVREADWRITE8_MODERN("oki1", okim6295_device, read, write, 0x00ff)		// (used by powerina)
 	AM_RANGE(0x120000, 0x120fff) AM_RAM_WRITE(powerins_paletteram16_w) AM_BASE_GENERIC(paletteram)	// Palette
-	AM_RANGE(0x130000, 0x130007) AM_RAM AM_BASE(&powerins_vctrl_0)								// VRAM 0 Control
-	AM_RANGE(0x140000, 0x143fff) AM_RAM_WRITE(powerins_vram_0_w) AM_BASE(&powerins_vram_0)		// VRAM 0
-	AM_RANGE(0x170000, 0x170fff) AM_RAM_WRITE(powerins_vram_1_w) AM_BASE(&powerins_vram_1)		// VRAM 1
+	AM_RANGE(0x130000, 0x130007) AM_RAM AM_BASE_MEMBER(powerins_state, m_vctrl_0)								// VRAM 0 Control
+	AM_RANGE(0x140000, 0x143fff) AM_RAM_WRITE(powerins_vram_0_w) AM_BASE_MEMBER(powerins_state, m_vram_0)		// VRAM 0
+	AM_RANGE(0x170000, 0x170fff) AM_RAM_WRITE(powerins_vram_1_w) AM_BASE_MEMBER(powerins_state, m_vram_1)		// VRAM 1
 	AM_RANGE(0x171000, 0x171fff) AM_WRITE(powerins_vram_1_w)									// Mirror of VRAM 1?
-	AM_RANGE(0x180000, 0x18ffff) AM_RAM AM_BASE_GENERIC(spriteram)									// RAM + Sprites
+	AM_RANGE(0x180000, 0x18ffff) AM_RAM AM_BASE_MEMBER(powerins_state, m_spriteram)									// RAM + Sprites
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( powerins_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( powerins_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xdfff) AM_RAM
 	AM_RANGE(0xe000, 0xe000) AM_READ(soundlatch_r)
@@ -120,7 +120,7 @@ static ADDRESS_MAP_START( powerins_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 //  AM_RANGE(0xe001, 0xe001) AM_WRITENOP // ?
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( powerins_sound_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( powerins_sound_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x01) AM_DEVREADWRITE("ym2203", ym2203_r, ym2203_w)
 	AM_RANGE(0x80, 0x80) AM_DEVREADWRITE_MODERN("oki1", okim6295_device, read, write)
@@ -128,7 +128,7 @@ static ADDRESS_MAP_START( powerins_sound_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x90, 0x97) AM_DEVWRITE("nmk112", nmk112_okibank_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( powerinb_sound_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( powerinb_sound_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(powerinb_fake_ym2203_r) AM_WRITENOP
 	AM_RANGE(0x01, 0x01) AM_NOP
@@ -315,12 +315,13 @@ GFXDECODE_END
 
 static MACHINE_RESET( powerins )
 {
-	oki_bank = -1;	// samples bank "unitialised"
+	powerins_state *state = machine.driver_data<powerins_state>();
+	state->m_oki_bank = -1;	// samples bank "unitialised"
 }
 
 static void irqhandler(device_t *device, int irq)
 {
-	cputag_set_input_line(device->machine, "soundcpu", 0, irq ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine(), "soundcpu", 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static const ym2203_interface ym2203_config =
@@ -339,7 +340,7 @@ static const nmk112_interface powerins_nmk112_intf =
 };
 
 
-static MACHINE_CONFIG_START( powerins, driver_device )
+static MACHINE_CONFIG_START( powerins, powerins_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M68000, 12000000)	/* 12MHz */
@@ -359,12 +360,12 @@ static MACHINE_CONFIG_START( powerins, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(320, 256)
 	MCFG_SCREEN_VISIBLE_AREA(0, 320-1, 0+16, 256-16-1)
+	MCFG_SCREEN_UPDATE(powerins)
 
 	MCFG_GFXDECODE(powerins)
 	MCFG_PALETTE_LENGTH(2048)
 
 	MCFG_VIDEO_START(powerins)
-	MCFG_VIDEO_UPDATE(powerins)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -399,6 +400,7 @@ static MACHINE_CONFIG_DERIVED( powerina, powerins )
 
 	MCFG_DEVICE_REMOVE("oki2")
 	MCFG_DEVICE_REMOVE("ym2203")
+	MCFG_DEVICE_REMOVE("nmk112")
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( powerinb, powerins )
