@@ -25,14 +25,10 @@ GP1 HDD data contents:
 #include "machine/idectrl.h"
 #include "sound/k054539.h"
 #include "video/konicdev.h"
+#include "machine/k053252.h"
 #include "machine/nvram.h"
 #include "includes/qdrmfgp.h"
 
-static UINT8 *sndram;
-static UINT16 *workram;
-static UINT16 control;
-static INT32 qdrmfgp_pal;
-static INT32 gp2_irq_control;
 
 /*************************************
  *
@@ -42,9 +38,10 @@ static INT32 gp2_irq_control;
 
 static CUSTOM_INPUT( inputs_r )
 {
+	qdrmfgp_state *state = field.machine().driver_data<qdrmfgp_state>();
 	const char *tag1 = (const char *)param;
 	const char *tag2 = tag1 + strlen(tag1) + 1;
-	return input_port_read(field->port->machine, (control & 0x0080) ? tag1 : tag2);
+	return input_port_read(field.machine(), (state->m_control & 0x0080) ? tag1 : tag2);
 }
 
 static CUSTOM_INPUT( battery_sensor_r )
@@ -54,13 +51,10 @@ static CUSTOM_INPUT( battery_sensor_r )
 }
 
 
-int qdrmfgp_get_palette(void)
-{
-	return qdrmfgp_pal;
-}
-
 static WRITE16_HANDLER( gp_control_w )
 {
+	qdrmfgp_state *state = space->machine().driver_data<qdrmfgp_state>();
+
 	/* bit 0        enable irq 1 (sound) */
 	/* bit 1        enable irq 2 (not used) */
 	/* bit 2        enable irq 3 (vblank) */
@@ -73,16 +67,16 @@ static WRITE16_HANDLER( gp_control_w )
 	/* bit 11       headphone volume: 1=up, 0=down */
 	/* bit 15       gfxrom bankswitch */
 
-	COMBINE_DATA(&control);
-	qdrmfgp_pal = control & 0x70;
+	COMBINE_DATA(&state->m_control);
+	state->m_pal = state->m_control & 0x70;
 
-	if (control & 0x0100)
+	if (state->m_control & 0x0100)
 	{
-		qdrmfgp_state *state = space->machine->driver_data<qdrmfgp_state>();
+		qdrmfgp_state *state = space->machine().driver_data<qdrmfgp_state>();
 		int vol = state->m_nvram[0x10] & 0xff;
 		if (vol)
 		{
-			device_t *k054539 = space->machine->device("konami");
+			device_t *k054539 = space->machine().device("konami");
 			int i;
 			double gain = vol / 90.0;
 
@@ -94,6 +88,8 @@ static WRITE16_HANDLER( gp_control_w )
 
 static WRITE16_HANDLER( gp2_control_w )
 {
+	qdrmfgp_state *state = space->machine().driver_data<qdrmfgp_state>();
+
 	/* bit 2        enable irq 3 (sound) */
 	/* bit 3        enable irq 4 (vblank) */
 	/* bit 4        enable irq 5 (hdd) */
@@ -104,16 +100,16 @@ static WRITE16_HANDLER( gp2_control_w )
 	/* bit 11       headphone volume: 1=up, 0=down */
 	/* bit 15       gfxrom bankswitch */
 
-	COMBINE_DATA(&control);
-	qdrmfgp_pal = 0;
+	COMBINE_DATA(&state->m_control);
+	state->m_pal = 0;
 
-	if (control & 0x0100)
+	if (state->m_control & 0x0100)
 	{
-		qdrmfgp_state *state = space->machine->driver_data<qdrmfgp_state>();
+		qdrmfgp_state *state = space->machine().driver_data<qdrmfgp_state>();
 		int vol = state->m_nvram[0x8] & 0xff;
 		if (vol)
 		{
-			device_t *k054539 = space->machine->device("konami");
+			device_t *k054539 = space->machine().device("konami");
 			int i;
 			double gain = vol / 90.0;
 
@@ -126,13 +122,14 @@ static WRITE16_HANDLER( gp2_control_w )
 
 static READ16_HANDLER( v_rom_r )
 {
-	device_t *k056832 = space->machine->device("k056832");
-	UINT8 *mem8 = space->machine->region("gfx1")->base();
+	qdrmfgp_state *state = space->machine().driver_data<qdrmfgp_state>();
+	device_t *k056832 = space->machine().device("k056832");
+	UINT8 *mem8 = space->machine().region("gfx1")->base();
 	int bank = k056832_word_r(k056832, 0x34/2, 0xffff);
 
 	offset += bank * 0x800 * 4;
 
-	if (control & 0x8000)
+	if (state->m_control & 0x8000)
 		offset += 0x800 * 2;
 
 	return (mem8[offset + 1] << 8) + mem8[offset];
@@ -141,7 +138,7 @@ static READ16_HANDLER( v_rom_r )
 
 static READ16_HANDLER( gp2_vram_r )
 {
-	device_t *k056832 = space->machine->device("k056832");
+	device_t *k056832 = space->machine().device("k056832");
 
 	if (offset < 0x1000 / 2)
 		return k056832_ram_word_r(k056832, offset * 2 + 1, mem_mask);
@@ -151,7 +148,7 @@ static READ16_HANDLER( gp2_vram_r )
 
 static READ16_HANDLER( gp2_vram_mirror_r )
 {
-	device_t *k056832 = space->machine->device("k056832");
+	device_t *k056832 = space->machine().device("k056832");
 
 	if (offset < 0x1000 / 2)
 		return k056832_ram_word_r(k056832, offset * 2, mem_mask);
@@ -161,7 +158,7 @@ static READ16_HANDLER( gp2_vram_mirror_r )
 
 static WRITE16_HANDLER( gp2_vram_w )
 {
-	device_t *k056832 = space->machine->device("k056832");
+	device_t *k056832 = space->machine().device("k056832");
 
 	if (offset < 0x1000 / 2)
 		k056832_ram_word_w(k056832, offset * 2 + 1, data, mem_mask);
@@ -171,7 +168,7 @@ static WRITE16_HANDLER( gp2_vram_w )
 
 static WRITE16_HANDLER( gp2_vram_mirror_w )
 {
-	device_t *k056832 = space->machine->device("k056832");
+	device_t *k056832 = space->machine().device("k056832");
 
 	if (offset < 0x1000 / 2)
 		k056832_ram_word_w(k056832, offset * 2, data, mem_mask);
@@ -184,19 +181,21 @@ static WRITE16_HANDLER( gp2_vram_mirror_w )
 
 static READ16_HANDLER( sndram_r )
 {
+	qdrmfgp_state *state = space->machine().driver_data<qdrmfgp_state>();
 	if (ACCESSING_BITS_0_7)
-		return sndram[offset];
+		return state->m_sndram[offset];
 
 	return 0;
 }
 
 static WRITE16_HANDLER( sndram_w )
 {
+	qdrmfgp_state *state = space->machine().driver_data<qdrmfgp_state>();
 	if (ACCESSING_BITS_0_7)
 	{
-		sndram[offset] = data & 0xff;
+		state->m_sndram[offset] = data & 0xff;
 		if (offset >= 0x40000)
-			sndram[offset+0xc00000-0x900000] = data & 0xff;
+			state->m_sndram[offset+0xc00000-0x900000] = data & 0xff;
 	}
 }
 
@@ -238,19 +237,20 @@ static WRITE16_DEVICE_HANDLER( ide_alt_w )
 
 static READ16_HANDLER( gp2_ide_std_r )
 {
-	device_t *device = space->machine->device("ide");
+	qdrmfgp_state *state = space->machine().driver_data<qdrmfgp_state>();
+	device_t *device = space->machine().device("ide");
 	if (offset & 0x01)
 	{
 		if (offset == 0x07)
 		{
-			switch (cpu_get_previouspc(space->cpu))
+			switch (cpu_get_previouspc(&space->device()))
 			{
 				case 0xdb4c:
-					if ((workram[0x5fa4/2] - cpu_get_reg(space->cpu, M68K_D0)) <= 0x10)
-						gp2_irq_control = 1;
+					if ((state->m_workram[0x5fa4/2] - cpu_get_reg(&space->device(), M68K_D0)) <= 0x10)
+						state->m_gp2_irq_control = 1;
 					break;
 				case 0xdec2:
-					gp2_irq_control = 1;
+					state->m_gp2_irq_control = 1;
 				default:
 					break;
 			}
@@ -270,29 +270,31 @@ static READ16_HANDLER( gp2_ide_std_r )
 
 static INTERRUPT_GEN(qdrmfgp_interrupt)
 {
+	qdrmfgp_state *state = device->machine().driver_data<qdrmfgp_state>();
 	switch (cpu_getiloops(device))
 	{
 		case 0:
-			if (control & 0x0001)
-				cpu_set_input_line(device, 1, HOLD_LINE);
+			if (state->m_control & 0x0001)
+				device_set_input_line(device, 1, HOLD_LINE);
 			break;
 
 		case 1:
 			/* trigger V-blank interrupt */
-			if (control & 0x0004)
-				cpu_set_input_line(device, 3, HOLD_LINE);
+			if (state->m_control & 0x0004)
+				device_set_input_line(device, 3, ASSERT_LINE);
 			break;
 	}
 }
 
 static void ide_interrupt(device_t *device, int state)
 {
-	if (control & 0x0008)
+	qdrmfgp_state *drvstate = device->machine().driver_data<qdrmfgp_state>();
+	if (drvstate->m_control & 0x0008)
 	{
 		if (state != CLEAR_LINE)
-			cputag_set_input_line(device->machine, "maincpu", 4, HOLD_LINE);
+			cputag_set_input_line(device->machine(), "maincpu", 4, HOLD_LINE);
 		else
-			cputag_set_input_line(device->machine, "maincpu", 4, CLEAR_LINE);
+			cputag_set_input_line(device->machine(), "maincpu", 4, CLEAR_LINE);
 	}
 }
 
@@ -300,31 +302,34 @@ static void ide_interrupt(device_t *device, int state)
 
 static TIMER_CALLBACK( gp2_timer_callback )
 {
-	if (control & 0x0004)
-		cputag_set_input_line(machine, "maincpu", 3, HOLD_LINE);
+	qdrmfgp_state *state = machine.driver_data<qdrmfgp_state>();
+	if (state->m_control & 0x0004)
+		cputag_set_input_line(machine, "maincpu", 3, ASSERT_LINE);
 }
 
 static INTERRUPT_GEN(qdrmfgp2_interrupt)
 {
+	qdrmfgp_state *state = device->machine().driver_data<qdrmfgp_state>();
 	/* trigger V-blank interrupt */
-	if (control & 0x0008)
-		cpu_set_input_line(device, 4, HOLD_LINE);
+	if (state->m_control & 0x0008)
+		device_set_input_line(device, 4, ASSERT_LINE);
 }
 
 static void gp2_ide_interrupt(device_t *device, int state)
 {
-	if (control & 0x0010)
+	qdrmfgp_state *drvstate = device->machine().driver_data<qdrmfgp_state>();
+	if (drvstate->m_control & 0x0010)
 	{
 		if (state != CLEAR_LINE)
 		{
-			if (gp2_irq_control)
-				gp2_irq_control = 0;
+			if (drvstate->m_gp2_irq_control)
+				drvstate->m_gp2_irq_control = 0;
 			else
-				cputag_set_input_line(device->machine, "maincpu", 5, HOLD_LINE);
+				cputag_set_input_line(device->machine(), "maincpu", 5, HOLD_LINE);
 		}
 		else
 		{
-			cputag_set_input_line(device->machine, "maincpu", 5, CLEAR_LINE);
+			cputag_set_input_line(device->machine(), "maincpu", 5, CLEAR_LINE);
 		}
 	}
 }
@@ -336,13 +341,13 @@ static void gp2_ide_interrupt(device_t *device, int state)
  *
  *************************************/
 
-static ADDRESS_MAP_START( qdrmfgp_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( qdrmfgp_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
-	AM_RANGE(0x100000, 0x10ffff) AM_RAM AM_BASE(&workram)										/* work ram */
+	AM_RANGE(0x100000, 0x10ffff) AM_RAM AM_BASE_MEMBER(qdrmfgp_state, m_workram)										/* work ram */
 	AM_RANGE(0x180000, 0x183fff) AM_RAM AM_SHARE("nvram")	/* backup ram */
 	AM_RANGE(0x280000, 0x280fff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x300000, 0x30003f) AM_DEVWRITE("k056832", k056832_word_w)										/* video reg */
-	AM_RANGE(0x320000, 0x32001f) AM_DEVREADWRITE("k053252", k053252_word_r, k053252_word_w)					/* ccu */
+	AM_RANGE(0x320000, 0x32001f) AM_DEVREADWRITE8("k053252", k053252_r, k053252_w,0x00ff)					/* ccu */
 	AM_RANGE(0x330000, 0x330001) AM_READ_PORT("SENSOR")											/* battery power & service sw */
 	AM_RANGE(0x340000, 0x340001) AM_READ_PORT("340000")											/* inputport */
 	AM_RANGE(0x350000, 0x350001) AM_WRITENOP													/* unknown */
@@ -359,13 +364,13 @@ static ADDRESS_MAP_START( qdrmfgp_map, ADDRESS_SPACE_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( qdrmfgp2_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( qdrmfgp2_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
-	AM_RANGE(0x100000, 0x110fff) AM_RAM AM_BASE(&workram)										/* work ram */
+	AM_RANGE(0x100000, 0x110fff) AM_RAM AM_BASE_MEMBER(qdrmfgp_state, m_workram)										/* work ram */
 	AM_RANGE(0x180000, 0x183fff) AM_RAM AM_SHARE("nvram")	/* backup ram */
 	AM_RANGE(0x280000, 0x280fff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x300000, 0x30003f) AM_DEVWRITE("k056832", k056832_word_w)										/* video reg */
-	AM_RANGE(0x320000, 0x32001f) AM_DEVREADWRITE("k053252", k053252_word_r, k053252_word_w)					/* ccu */
+	AM_RANGE(0x320000, 0x32001f) AM_DEVREADWRITE8("k053252", k053252_r, k053252_w,0xff00)					/* ccu */
 	AM_RANGE(0x330000, 0x330001) AM_READ_PORT("SENSOR")											/* battery power & service */
 	AM_RANGE(0x340000, 0x340001) AM_READ_PORT("340000")											/* inputport */
 	AM_RANGE(0x350000, 0x350001) AM_WRITENOP													/* unknown */
@@ -570,8 +575,9 @@ INPUT_PORTS_END
 
 static void sound_irq(device_t *device)
 {
-	if (control & 0x0001)
-		cputag_set_input_line(device->machine, "maincpu", 1, HOLD_LINE);
+	qdrmfgp_state *state = device->machine().driver_data<qdrmfgp_state>();
+	if (state->m_control & 0x0001)
+		cputag_set_input_line(device->machine(), "maincpu", 1, HOLD_LINE);
 }
 
 static const k054539_interface k054539_config =
@@ -606,27 +612,59 @@ static const k056832_interface qdrmfgp2_k056832_intf =
 	qdrmfgp2_tile_callback, "none"
 };
 
+static WRITE_LINE_DEVICE_HANDLER( qdrmfgp_irq3_ack_w )
+{
+	cputag_set_input_line(device->machine(), "maincpu", M68K_IRQ_3, CLEAR_LINE);
+}
+
+static WRITE_LINE_DEVICE_HANDLER( qdrmfgp_irq4_ack_w )
+{
+	cputag_set_input_line(device->machine(), "maincpu", M68K_IRQ_4, CLEAR_LINE);
+}
+
+static const k053252_interface qdrmfgp_k053252_intf =
+{
+	"screen",
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_LINE(qdrmfgp_irq3_ack_w),
+	DEVCB_NULL,
+	40, 16
+};
+
+static const k053252_interface qdrmfgp2_k053252_intf =
+{
+	"screen",
+	DEVCB_NULL,
+	DEVCB_NULL,
+	DEVCB_LINE(qdrmfgp_irq4_ack_w),
+	DEVCB_LINE(qdrmfgp_irq3_ack_w),
+	40, 16
+};
+
 static MACHINE_START( qdrmfgp )
 {
-	state_save_register_global(machine, control);
-	state_save_register_global(machine, qdrmfgp_pal);
-	state_save_register_global(machine, gp2_irq_control);
+	qdrmfgp_state *state = machine.driver_data<qdrmfgp_state>();
+	state_save_register_global(machine, state->m_control);
+	state_save_register_global(machine, state->m_pal);
+	state_save_register_global(machine, state->m_gp2_irq_control);
 }
 
 static MACHINE_START( qdrmfgp2 )
 {
 	/* sound irq (CCU? 240Hz) */
-	timer_pulse(machine, ATTOTIME_IN_HZ(18432000/76800), NULL, 0, gp2_timer_callback);
+	machine.scheduler().timer_pulse(attotime::from_hz(18432000/76800), FUNC(gp2_timer_callback));
 
 	MACHINE_START_CALL( qdrmfgp );
 }
 
 static MACHINE_RESET( qdrmfgp )
 {
-	sndram = machine->region("konami")->base() + 0x100000;
+	qdrmfgp_state *state = machine.driver_data<qdrmfgp_state>();
+	state->m_sndram = machine.region("konami")->base() + 0x100000;
 
 	/* reset the IDE controller */
-	gp2_irq_control = 0;
+	state->m_gp2_irq_control = 0;
 	devtag_reset(machine, "ide");
 }
 
@@ -657,14 +695,14 @@ static MACHINE_CONFIG_START( qdrmfgp, qdrmfgp_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(40, 40+384-1, 16, 16+224-1)
+	MCFG_SCREEN_UPDATE(qdrmfgp)
 
 	MCFG_PALETTE_LENGTH(2048)
 
 	MCFG_VIDEO_START(qdrmfgp)
-	MCFG_VIDEO_UPDATE(qdrmfgp)
 
 	MCFG_K056832_ADD("k056832", qdrmfgp_k056832_intf)
-	MCFG_K053252_ADD("k053252")
+	MCFG_K053252_ADD("k053252", 32000000/4, qdrmfgp_k053252_intf)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
@@ -695,14 +733,14 @@ static MACHINE_CONFIG_START( qdrmfgp2, qdrmfgp_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(40, 40+384-1, 16, 16+224-1)
+	MCFG_SCREEN_UPDATE(qdrmfgp)
 
 	MCFG_PALETTE_LENGTH(2048)
 
 	MCFG_VIDEO_START(qdrmfgp2)
-	MCFG_VIDEO_UPDATE(qdrmfgp)
 
 	MCFG_K056832_ADD("k056832", qdrmfgp2_k056832_intf)
-	MCFG_K053252_ADD("k053252")
+	MCFG_K053252_ADD("k053252", 32000000/4, qdrmfgp2_k053252_intf)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
