@@ -116,13 +116,6 @@
 #define MASTER_CLOCK		16000000
 
 
-static UINT8 sound_data;
-static UINT8 sound_busy;
-static UINT8 ym2151_irq;
-static UINT8 upd_rom_bank;
-
-
-
 /*************************************
  *
  *  Interrupt handling
@@ -131,14 +124,15 @@ static UINT8 upd_rom_bank;
 
 static void ym2151_irq_gen(device_t *device, int state)
 {
-	ym2151_irq = state;
-	cputag_set_input_line(device->machine, "audiocpu", 0, (ym2151_irq | sound_busy) ? ASSERT_LINE : CLEAR_LINE);
+	rpunch_state *drvstate = device->machine().driver_data<rpunch_state>();
+	drvstate->m_ym2151_irq = state;
+	cputag_set_input_line(device->machine(), "audiocpu", 0, (drvstate->m_ym2151_irq | drvstate->m_sound_busy) ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static MACHINE_RESET( rpunch )
 {
-	UINT8 *snd = machine->region("upd")->base();
+	UINT8 *snd = machine.region("upd")->base();
 	memcpy(snd, snd + 0x20000, 0x20000);
 }
 
@@ -152,7 +146,7 @@ static MACHINE_RESET( rpunch )
 
 static CUSTOM_INPUT( hi_bits_r )
 {
-	return input_port_read(field->port->machine, "SERVICE");
+	return input_port_read(field.machine(), "SERVICE");
 }
 
 
@@ -164,30 +158,33 @@ static CUSTOM_INPUT( hi_bits_r )
 
 static TIMER_CALLBACK( sound_command_w_callback )
 {
-	sound_busy = 1;
-	sound_data = param;
-	cputag_set_input_line(machine, "audiocpu", 0, (ym2151_irq | sound_busy) ? ASSERT_LINE : CLEAR_LINE);
+	rpunch_state *state = machine.driver_data<rpunch_state>();
+	state->m_sound_busy = 1;
+	state->m_sound_data = param;
+	cputag_set_input_line(machine, "audiocpu", 0, (state->m_ym2151_irq | state->m_sound_busy) ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static WRITE16_HANDLER( sound_command_w )
 {
 	if (ACCESSING_BITS_0_7)
-		timer_call_after_resynch(space->machine, NULL, data & 0xff, sound_command_w_callback);
+		space->machine().scheduler().synchronize(FUNC(sound_command_w_callback), data & 0xff);
 }
 
 
 static READ8_HANDLER( sound_command_r )
 {
-	sound_busy = 0;
-	cputag_set_input_line(space->machine, "audiocpu", 0, (ym2151_irq | sound_busy) ? ASSERT_LINE : CLEAR_LINE);
-	return sound_data;
+	rpunch_state *state = space->machine().driver_data<rpunch_state>();
+	state->m_sound_busy = 0;
+	cputag_set_input_line(space->machine(), "audiocpu", 0, (state->m_ym2151_irq | state->m_sound_busy) ? ASSERT_LINE : CLEAR_LINE);
+	return state->m_sound_data;
 }
 
 
 static READ16_HANDLER( sound_busy_r )
 {
-	return sound_busy;
+	rpunch_state *state = space->machine().driver_data<rpunch_state>();
+	return state->m_sound_busy;
 }
 
 
@@ -200,11 +197,12 @@ static READ16_HANDLER( sound_busy_r )
 
 static WRITE8_DEVICE_HANDLER( upd_control_w )
 {
-	if ((data & 1) != upd_rom_bank)
+	rpunch_state *state = device->machine().driver_data<rpunch_state>();
+	if ((data & 1) != state->m_upd_rom_bank)
 	{
-		UINT8 *snd = device->machine->region("upd")->base();
-		upd_rom_bank = data & 1;
-		memcpy(snd, snd + 0x20000 * (upd_rom_bank + 1), 0x20000);
+		UINT8 *snd = device->machine().region("upd")->base();
+		state->m_upd_rom_bank = data & 1;
+		memcpy(snd, snd + 0x20000 * (state->m_upd_rom_bank + 1), 0x20000);
 	}
 	upd7759_reset_w(device, data >> 7);
 }
@@ -225,12 +223,12 @@ static WRITE8_DEVICE_HANDLER( upd_data_w )
  *
  *************************************/
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 16 )
 	ADDRESS_MAP_GLOBAL_MASK(0xfffff)
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
-	AM_RANGE(0x040000, 0x04ffff) AM_RAM AM_BASE(&rpunch_bitmapram) AM_SIZE(&rpunch_bitmapram_size)
-	AM_RANGE(0x060000, 0x060fff) AM_RAM AM_BASE_GENERIC(spriteram)
-	AM_RANGE(0x080000, 0x083fff) AM_RAM_WRITE(rpunch_videoram_w) AM_BASE_MEMBER(rpunch_state, videoram)
+	AM_RANGE(0x040000, 0x04ffff) AM_RAM AM_BASE_MEMBER(rpunch_state, m_bitmapram) AM_SIZE_MEMBER(rpunch_state, m_bitmapram_size)
+	AM_RANGE(0x060000, 0x060fff) AM_RAM AM_BASE_MEMBER(rpunch_state, m_spriteram)
+	AM_RANGE(0x080000, 0x083fff) AM_RAM_WRITE(rpunch_videoram_w) AM_BASE_MEMBER(rpunch_state, m_videoram)
 	AM_RANGE(0x0a0000, 0x0a07ff) AM_RAM_WRITE(paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x0c0000, 0x0c0007) AM_WRITE(rpunch_scrollreg_w)
 	AM_RANGE(0x0c0008, 0x0c0009) AM_WRITE(rpunch_crtc_data_w)
@@ -253,7 +251,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xefff) AM_ROM
 	AM_RANGE(0xf000, 0xf001) AM_DEVREADWRITE("ymsnd", ym2151_r, ym2151_w)
 	AM_RANGE(0xf200, 0xf200) AM_READ(sound_command_r)
@@ -481,12 +479,12 @@ static MACHINE_CONFIG_START( rpunch, rpunch_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(304, 224)
 	MCFG_SCREEN_VISIBLE_AREA(8, 303-8, 0, 223-8)
+	MCFG_SCREEN_UPDATE(rpunch)
 
 	MCFG_GFXDECODE(rpunch)
 	MCFG_PALETTE_LENGTH(1024)
 
 	MCFG_VIDEO_START(rpunch)
-	MCFG_VIDEO_UPDATE(rpunch)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -699,16 +697,18 @@ ROM_END
 
 static DRIVER_INIT( rabiolep )
 {
-	rpunch_sprite_palette = 0x300;
+	rpunch_state *state = machine.driver_data<rpunch_state>();
+	state->m_sprite_palette = 0x300;
 }
 
 
 static DRIVER_INIT( svolley )
 {
+	rpunch_state *state = machine.driver_data<rpunch_state>();
 	/* the main differences between Super Volleyball and Rabbit Punch are */
 	/* the lack of direct-mapped bitmap and a different palette base for sprites */
-	rpunch_sprite_palette = 0x080;
-	rpunch_bitmapram = NULL;
+	state->m_sprite_palette = 0x080;
+	state->m_bitmapram = NULL;
 }
 
 
