@@ -151,7 +151,7 @@ lev 7 : 0x7c : 0000 11d0 - just rte
 
 static WRITE16_HANDLER( shadfrce_flip_screen )
 {
-	flip_screen_set(space->machine, data & 0x01);
+	flip_screen_set(space->machine(), data & 0x01);
 }
 
 
@@ -236,22 +236,22 @@ static WRITE16_HANDLER( shadfrce_flip_screen )
 
 static READ16_HANDLER( shadfrce_input_ports_r )
 {
-	shadfrce_state *state = space->machine->driver_data<shadfrce_state>();
+	shadfrce_state *state = space->machine().driver_data<shadfrce_state>();
 	UINT16 data = 0xffff;
 
 	switch (offset)
 	{
 		case 0 :
-			data = (input_port_read(space->machine, "P1") & 0xff) | ((input_port_read(space->machine, "DSW2") & 0xc0) << 6) | ((input_port_read(space->machine, "SYSTEM") & 0x0f) << 8);
+			data = (input_port_read(space->machine(), "P1") & 0xff) | ((input_port_read(space->machine(), "DSW2") & 0xc0) << 6) | ((input_port_read(space->machine(), "SYSTEM") & 0x0f) << 8);
 			break;
 		case 1 :
-			data = (input_port_read(space->machine, "P2") & 0xff) | ((input_port_read(space->machine, "DSW2") & 0x3f) << 8);
+			data = (input_port_read(space->machine(), "P2") & 0xff) | ((input_port_read(space->machine(), "DSW2") & 0x3f) << 8);
 			break;
 		case 2 :
-			data = (input_port_read(space->machine, "EXTRA") & 0xff) | ((input_port_read(space->machine, "DSW1") & 0x3f) << 8);
+			data = (input_port_read(space->machine(), "EXTRA") & 0xff) | ((input_port_read(space->machine(), "DSW1") & 0x3f) << 8);
 			break;
 		case 3 :
-			data = (input_port_read(space->machine, "OTHER") & 0xff) | ((input_port_read(space->machine, "DSW1") & 0xc0) << 2) | ((input_port_read(space->machine, "MISC") & 0x38) << 8) | (state->vblank << 8);
+			data = (input_port_read(space->machine(), "OTHER") & 0xff) | ((input_port_read(space->machine(), "DSW1") & 0xc0) << 2) | ((input_port_read(space->machine(), "MISC") & 0x38) << 8) | (state->m_vblank << 8);
 			break;
 	}
 
@@ -264,7 +264,7 @@ static WRITE16_HANDLER ( shadfrce_sound_brt_w )
 	if (ACCESSING_BITS_8_15)
 	{
 		soundlatch_w(space, 1, data >> 8);
-		cputag_set_input_line(space->machine, "audiocpu", INPUT_LINE_NMI, PULSE_LINE );
+		cputag_set_input_line(space->machine(), "audiocpu", INPUT_LINE_NMI, PULSE_LINE );
 	}
 	else
 	{
@@ -272,90 +272,90 @@ static WRITE16_HANDLER ( shadfrce_sound_brt_w )
 		double brt = (data & 0xff) / 255.0;
 
 		for (i = 0; i < 0x4000; i++)
-			palette_set_pen_contrast(space->machine, i, brt);
+			palette_set_pen_contrast(space->machine(), i, brt);
 	}
 }
 
 static WRITE16_HANDLER( shadfrce_irq_ack_w )
 {
-	cputag_set_input_line(space->machine, "maincpu", offset ^ 3, CLEAR_LINE);
+	cputag_set_input_line(space->machine(), "maincpu", offset ^ 3, CLEAR_LINE);
 }
 
 static WRITE16_HANDLER( shadfrce_irq_w )
 {
-	shadfrce_state *state = space->machine->driver_data<shadfrce_state>();
+	shadfrce_state *state = space->machine().driver_data<shadfrce_state>();
 
-	state->irqs_enable = data & 1;	/* maybe, it's set/unset inside every trap instruction which is executed */
-	state->video_enable = data & 8;	/* probably */
+	state->m_irqs_enable = data & 1;	/* maybe, it's set/unset inside every trap instruction which is executed */
+	state->m_video_enable = data & 8;	/* probably */
 
 	/* check if there's a high transition to enable the raster IRQ */
-	if((~state->prev_value & 4) && (data & 4))
+	if((~state->m_prev_value & 4) && (data & 4))
 	{
-		state->raster_irq_enable = 1;
+		state->m_raster_irq_enable = 1;
 	}
 
 	/* check if there's a low transition to disable the raster IRQ */
-	if((state->prev_value & 4) && (~data & 4))
+	if((state->m_prev_value & 4) && (~data & 4))
 	{
-		state->raster_irq_enable = 0;
+		state->m_raster_irq_enable = 0;
 	}
 
-	state->prev_value = data;
+	state->m_prev_value = data;
 }
 
 static WRITE16_HANDLER( shadfrce_scanline_w )
 {
-	shadfrce_state *state = space->machine->driver_data<shadfrce_state>();
+	shadfrce_state *state = space->machine().driver_data<shadfrce_state>();
 
-	state->raster_scanline = data;	/* guess, 0 is always written */
+	state->m_raster_scanline = data;	/* guess, 0 is always written */
 }
 
 static TIMER_DEVICE_CALLBACK( shadfrce_scanline )
 {
-	shadfrce_state *state = timer.machine->driver_data<shadfrce_state>();
+	shadfrce_state *state = timer.machine().driver_data<shadfrce_state>();
 	int scanline = param;
 
 	/* Vblank is lowered on scanline 0 */
 	if (scanline == 0)
 	{
-		state->vblank = 0;
+		state->m_vblank = 0;
 	}
 	/* Hack */
 	else if (scanline == (248-1))		/* -1 is an hack needed to avoid deadlocks */
 	{
-		state->vblank = 4;
+		state->m_vblank = 4;
 	}
 
 	/* Raster interrupt - Perform raster effect on given scanline */
-	if (state->raster_irq_enable)
+	if (state->m_raster_irq_enable)
 	{
-		if (scanline == state->raster_scanline)
+		if (scanline == state->m_raster_scanline)
 		{
-			state->raster_scanline = (state->raster_scanline + 1) % 240;
-			if (state->raster_scanline > 0)
-				timer.machine->primary_screen->update_partial(state->raster_scanline - 1);
-			cputag_set_input_line(timer.machine, "maincpu", 1, ASSERT_LINE);
+			state->m_raster_scanline = (state->m_raster_scanline + 1) % 240;
+			if (state->m_raster_scanline > 0)
+				timer.machine().primary_screen->update_partial(state->m_raster_scanline - 1);
+			cputag_set_input_line(timer.machine(), "maincpu", 1, ASSERT_LINE);
 		}
 	}
 
 	/* An interrupt is generated every 16 scanlines */
-	if (state->irqs_enable)
+	if (state->m_irqs_enable)
 	{
 		if (scanline % 16 == 0)
 		{
 			if (scanline > 0)
-				timer.machine->primary_screen->update_partial(scanline - 1);
-			cputag_set_input_line(timer.machine, "maincpu", 2, ASSERT_LINE);
+				timer.machine().primary_screen->update_partial(scanline - 1);
+			cputag_set_input_line(timer.machine(), "maincpu", 2, ASSERT_LINE);
 		}
 	}
 
 	/* Vblank is raised on scanline 248 */
-	if (state->irqs_enable)
+	if (state->m_irqs_enable)
 	{
 		if (scanline == 248)
 		{
-			timer.machine->primary_screen->update_partial(scanline - 1);
-			cputag_set_input_line(timer.machine, "maincpu", 3, ASSERT_LINE);
+			timer.machine().primary_screen->update_partial(scanline - 1);
+			cputag_set_input_line(timer.machine(), "maincpu", 3, ASSERT_LINE);
 		}
 	}
 }
@@ -364,14 +364,14 @@ static TIMER_DEVICE_CALLBACK( shadfrce_scanline )
 
 /* Memory Maps */
 
-static ADDRESS_MAP_START( shadfrce_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( shadfrce_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
-	AM_RANGE(0x100000, 0x100fff) AM_RAM_WRITE(shadfrce_bg0videoram_w) AM_BASE_MEMBER(shadfrce_state,bg0videoram) /* video */
+	AM_RANGE(0x100000, 0x100fff) AM_RAM_WRITE(shadfrce_bg0videoram_w) AM_BASE_MEMBER(shadfrce_state,m_bg0videoram) /* video */
 	AM_RANGE(0x101000, 0x101fff) AM_RAM
-	AM_RANGE(0x102000, 0x1027ff) AM_RAM_WRITE(shadfrce_bg1videoram_w) AM_BASE_MEMBER(shadfrce_state,bg1videoram) /* bg 2 */
+	AM_RANGE(0x102000, 0x1027ff) AM_RAM_WRITE(shadfrce_bg1videoram_w) AM_BASE_MEMBER(shadfrce_state,m_bg1videoram) /* bg 2 */
 	AM_RANGE(0x102800, 0x103fff) AM_RAM
-	AM_RANGE(0x140000, 0x141fff) AM_RAM_WRITE(shadfrce_fgvideoram_w) AM_BASE_MEMBER(shadfrce_state,fgvideoram)
-	AM_RANGE(0x142000, 0x143fff) AM_RAM AM_BASE_MEMBER(shadfrce_state,spvideoram) AM_SIZE_MEMBER(shadfrce_state,spvideoram_size) /* sprites */
+	AM_RANGE(0x140000, 0x141fff) AM_RAM_WRITE(shadfrce_fgvideoram_w) AM_BASE_MEMBER(shadfrce_state,m_fgvideoram)
+	AM_RANGE(0x142000, 0x143fff) AM_RAM AM_BASE_MEMBER(shadfrce_state,m_spvideoram) AM_SIZE_MEMBER(shadfrce_state,m_spvideoram_size) /* sprites */
 	AM_RANGE(0x180000, 0x187fff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x1c0000, 0x1c0001) AM_WRITE(shadfrce_bg0scrollx_w) /* SCROLL X */
 	AM_RANGE(0x1c0002, 0x1c0003) AM_WRITE(shadfrce_bg0scrolly_w) /* SCROLL Y */
@@ -399,7 +399,7 @@ static WRITE8_DEVICE_HANDLER( oki_bankswitch_w )
 	downcast<okim6295_device *>(device)->set_bank_base((data & 1) * 0x40000);
 }
 
-static ADDRESS_MAP_START( shadfrce_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( shadfrce_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xc7ff) AM_RAM
 	AM_RANGE(0xc800, 0xc801) AM_DEVREADWRITE("ymsnd", ym2151_r, ym2151_w)
@@ -548,7 +548,7 @@ GFXDECODE_END
 
 static void irq_handler(device_t *device, int irq)
 {
-	cputag_set_input_line(device->machine, "audiocpu", 0, irq ? ASSERT_LINE : CLEAR_LINE );
+	cputag_set_input_line(device->machine(), "audiocpu", 0, irq ? ASSERT_LINE : CLEAR_LINE );
 }
 
 static const ym2151_interface ym2151_config =
@@ -568,13 +568,13 @@ static MACHINE_CONFIG_START( shadfrce, shadfrce_state )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_RAW_PARAMS(PIXEL_CLOCK, 432, 0, 320, 272, 8, 248)	/* HTOTAL and VTOTAL are guessed */
+	MCFG_SCREEN_UPDATE(shadfrce)
+	MCFG_SCREEN_EOF(shadfrce)
 
 	MCFG_GFXDECODE(shadfrce)
 	MCFG_PALETTE_LENGTH(0x4000)
 
 	MCFG_VIDEO_START(shadfrce)
-	MCFG_VIDEO_EOF(shadfrce)
-	MCFG_VIDEO_UPDATE(shadfrce)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
