@@ -44,22 +44,22 @@ write    read
 */
 static READ16_HANDLER( shangha3_prot_r )
 {
-	shangha3_state *state = space->machine->driver_data<shangha3_state>();
+	shangha3_state *state = space->machine().driver_data<shangha3_state>();
 	static const int result[] = { 0x0,0x1,0x3,0x7,0xf,0xe,0xc,0x8,0x0};
 
-	logerror("PC %04x: read 20004e\n",cpu_get_pc(space->cpu));
+	logerror("PC %04x: read 20004e\n",cpu_get_pc(&space->device()));
 
-	return result[state->prot_count++ % 9];
+	return result[state->m_prot_count++ % 9];
 }
 static WRITE16_HANDLER( shangha3_prot_w )
 {
-	logerror("PC %04x: write %02x to 20004e\n",cpu_get_pc(space->cpu),data);
+	logerror("PC %04x: write %02x to 20004e\n",cpu_get_pc(&space->device()),data);
 }
 
 
 static READ16_HANDLER( heberpop_gfxrom_r )
 {
-	UINT8 *ROM = space->machine->region("gfx1")->base();
+	UINT8 *ROM = space->machine().region("gfx1")->base();
 
 	return ROM[2*offset] | (ROM[2*offset+1] << 8);
 }
@@ -70,10 +70,10 @@ static WRITE16_HANDLER( shangha3_coinctrl_w )
 {
 	if (ACCESSING_BITS_8_15)
 	{
-		coin_lockout_w(space->machine, 0,~data & 0x0400);
-		coin_lockout_w(space->machine, 1,~data & 0x0400);
-		coin_counter_w(space->machine, 0,data & 0x0100);
-		coin_counter_w(space->machine, 1,data & 0x0200);
+		coin_lockout_w(space->machine(), 0,~data & 0x0400);
+		coin_lockout_w(space->machine(), 1,~data & 0x0400);
+		coin_counter_w(space->machine(), 0,data & 0x0100);
+		coin_counter_w(space->machine(), 1,data & 0x0200);
 	}
 }
 
@@ -82,12 +82,12 @@ static WRITE16_HANDLER( heberpop_coinctrl_w )
 	if (ACCESSING_BITS_0_7)
 	{
 		/* the sound ROM bank is selected by the main CPU! */
-		space->machine->device<okim6295_device>("oki")->set_bank_base((data & 0x08) ? 0x40000 : 0x00000);
+		space->machine().device<okim6295_device>("oki")->set_bank_base((data & 0x08) ? 0x40000 : 0x00000);
 
-		coin_lockout_w(space->machine, 0,~data & 0x04);
-		coin_lockout_w(space->machine, 1,~data & 0x04);
-		coin_counter_w(space->machine, 0,data & 0x01);
-		coin_counter_w(space->machine, 1,data & 0x02);
+		coin_lockout_w(space->machine(), 0,~data & 0x04);
+		coin_lockout_w(space->machine(), 1,~data & 0x04);
+		coin_counter_w(space->machine(), 0,data & 0x01);
+		coin_counter_w(space->machine(), 1,data & 0x02);
 	}
 }
 
@@ -96,12 +96,12 @@ static WRITE16_HANDLER( blocken_coinctrl_w )
 	if (ACCESSING_BITS_0_7)
 	{
 		/* the sound ROM bank is selected by the main CPU! */
-		space->machine->device<okim6295_device>("oki")->set_bank_base(((data >> 4) & 3) * 0x40000);
+		space->machine().device<okim6295_device>("oki")->set_bank_base(((data >> 4) & 3) * 0x40000);
 
-		coin_lockout_w(space->machine, 0,~data & 0x04);
-		coin_lockout_w(space->machine, 1,~data & 0x04);
-		coin_counter_w(space->machine, 0,data & 0x01);
-		coin_counter_w(space->machine, 1,data & 0x02);
+		coin_lockout_w(space->machine(), 0,~data & 0x04);
+		coin_lockout_w(space->machine(), 1,~data & 0x04);
+		coin_counter_w(space->machine(), 0,data & 0x01);
+		coin_counter_w(space->machine(), 1,data & 0x02);
 	}
 }
 
@@ -111,13 +111,13 @@ static WRITE16_HANDLER( heberpop_sound_command_w )
 	if (ACCESSING_BITS_0_7)
 	{
 		soundlatch_w(space, 0, data & 0xff);
-		cputag_set_input_line_and_vector(space->machine, "audiocpu", 0, HOLD_LINE, 0xff);	/* RST 38h */
+		cputag_set_input_line_and_vector(space->machine(), "audiocpu", 0, HOLD_LINE, 0xff);	/* RST 38h */
 	}
 }
 
 
 
-static ADDRESS_MAP_START( shangha3_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( shangha3_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	AM_RANGE(0x100000, 0x100fff) AM_RAM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x200000, 0x200001) AM_READ_PORT("INPUTS")
@@ -130,12 +130,12 @@ static ADDRESS_MAP_START( shangha3_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x20003e, 0x20003f) AM_DEVWRITE8("aysnd", ay8910_address_w, 0x00ff)
 	AM_RANGE(0x20004e, 0x20004f) AM_READWRITE(shangha3_prot_r,shangha3_prot_w)
 	AM_RANGE(0x20006e, 0x20006f) AM_DEVREADWRITE8_MODERN("oki", okim6295_device, read, write, 0x00ff)
-	AM_RANGE(0x300000, 0x30ffff) AM_RAM AM_BASE_SIZE_MEMBER(shangha3_state, ram, ram_size)	/* gfx & work ram */
+	AM_RANGE(0x300000, 0x30ffff) AM_RAM AM_BASE_SIZE_MEMBER(shangha3_state, m_ram, m_ram_size)	/* gfx & work ram */
 	AM_RANGE(0x340000, 0x340001) AM_WRITE(shangha3_flipscreen_w)
 	AM_RANGE(0x360000, 0x360001) AM_WRITE(shangha3_gfxlist_addr_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( heberpop_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( heberpop_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x100000, 0x100fff) AM_RAM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0x200000, 0x200001) AM_READ_PORT("INPUTS")
@@ -145,13 +145,13 @@ static ADDRESS_MAP_START( heberpop_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x20000a, 0x20000b) AM_WRITENOP	/* irq ack? */
 	AM_RANGE(0x20000c, 0x20000d) AM_WRITE(heberpop_coinctrl_w)
 	AM_RANGE(0x20000e, 0x20000f) AM_WRITE(heberpop_sound_command_w)
-	AM_RANGE(0x300000, 0x30ffff) AM_RAM AM_BASE_SIZE_MEMBER(shangha3_state, ram, ram_size)	/* gfx & work ram */
+	AM_RANGE(0x300000, 0x30ffff) AM_RAM AM_BASE_SIZE_MEMBER(shangha3_state, m_ram, m_ram_size)	/* gfx & work ram */
 	AM_RANGE(0x340000, 0x340001) AM_WRITE(shangha3_flipscreen_w)
 	AM_RANGE(0x360000, 0x360001) AM_WRITE(shangha3_gfxlist_addr_w)
 	AM_RANGE(0x800000, 0xb7ffff) AM_READ(heberpop_gfxrom_r)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( blocken_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( blocken_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x100000, 0x100001) AM_READ_PORT("INPUTS")
 	AM_RANGE(0x100002, 0x100003) AM_READ_PORT("SYSTEM")
@@ -161,19 +161,19 @@ static ADDRESS_MAP_START( blocken_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x10000c, 0x10000d) AM_WRITE(blocken_coinctrl_w)
 	AM_RANGE(0x10000e, 0x10000f) AM_WRITE(heberpop_sound_command_w)
 	AM_RANGE(0x200000, 0x200fff) AM_RAM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0x300000, 0x30ffff) AM_RAM AM_BASE_SIZE_MEMBER(shangha3_state, ram, ram_size)	/* gfx & work ram */
+	AM_RANGE(0x300000, 0x30ffff) AM_RAM AM_BASE_SIZE_MEMBER(shangha3_state, m_ram, m_ram_size)	/* gfx & work ram */
 	AM_RANGE(0x340000, 0x340001) AM_WRITE(shangha3_flipscreen_w)
 	AM_RANGE(0x360000, 0x360001) AM_WRITE(shangha3_gfxlist_addr_w)
 	AM_RANGE(0x800000, 0xb7ffff) AM_READ(heberpop_gfxrom_r)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( heberpop_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( heberpop_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xf7ff) AM_ROM
 	AM_RANGE(0xf800, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( heberpop_sound_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( heberpop_sound_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x03) AM_DEVREADWRITE("ymsnd", ym3438_r, ym3438_w)
 	AM_RANGE(0x80, 0x80) AM_DEVREADWRITE_MODERN("oki", okim6295_device, read, write)
@@ -458,7 +458,7 @@ static const ay8910_interface ay8910_config =
 
 static void irqhandler(device_t *device, int linestate)
 {
-	cputag_set_input_line(device->machine, "audiocpu", INPUT_LINE_NMI, linestate);
+	cputag_set_input_line(device->machine(), "audiocpu", INPUT_LINE_NMI, linestate);
 }
 
 static const ym3438_interface ym3438_config =
@@ -483,12 +483,12 @@ static MACHINE_CONFIG_START( shangha3, shangha3_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(24*16, 16*16)
 	MCFG_SCREEN_VISIBLE_AREA(0*16, 24*16-1, 1*16, 15*16-1)
+	MCFG_SCREEN_UPDATE(shangha3)
 
 	MCFG_GFXDECODE(shangha3)
 	MCFG_PALETTE_LENGTH(2048)
 
 	MCFG_VIDEO_START(shangha3)
-	MCFG_VIDEO_UPDATE(shangha3)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -522,12 +522,12 @@ static MACHINE_CONFIG_START( heberpop, shangha3_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(24*16, 16*16)
 	MCFG_SCREEN_VISIBLE_AREA(0*16, 24*16-1, 1*16, 15*16-1)
+	MCFG_SCREEN_UPDATE(shangha3)
 
 	MCFG_GFXDECODE(shangha3)
 	MCFG_PALETTE_LENGTH(2048)
 
 	MCFG_VIDEO_START(shangha3)
-	MCFG_VIDEO_UPDATE(shangha3)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -562,12 +562,12 @@ static MACHINE_CONFIG_START( blocken, shangha3_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(24*16, 16*16)
 	MCFG_SCREEN_VISIBLE_AREA(0*16, 24*16-1, 1*16, 15*16-1)
+	MCFG_SCREEN_UPDATE(shangha3)
 
 	MCFG_GFXDECODE(shangha3)
 	MCFG_PALETTE_LENGTH(2048)
 
 	MCFG_VIDEO_START(shangha3)
-	MCFG_VIDEO_UPDATE(shangha3)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -657,16 +657,16 @@ ROM_END
 
 static DRIVER_INIT( shangha3 )
 {
-	shangha3_state *state = machine->driver_data<shangha3_state>();
+	shangha3_state *state = machine.driver_data<shangha3_state>();
 
-	state->do_shadows = 1;
+	state->m_do_shadows = 1;
 }
 
 static DRIVER_INIT( heberpop )
 {
-	shangha3_state *state = machine->driver_data<shangha3_state>();
+	shangha3_state *state = machine.driver_data<shangha3_state>();
 
-	state->do_shadows = 0;
+	state->m_do_shadows = 0;
 }
 
 GAME( 1993, shangha3, 0, shangha3, shangha3, shangha3, ROT0, "Sunsoft", "Shanghai III (Japan)", 0 )
