@@ -95,7 +95,7 @@ Are the OKI M6295 clocks from Heavy Smash are correct at least for the Mitchell
 #include "machine/eeprom.h"
 #include "sound/okim6295.h"
 #include "video/deco16ic.h"
-
+#include "video/decospr.h"
 
 static INPUT_PORTS_START( simpl156 )
 	PORT_START("IN0")
@@ -129,9 +129,9 @@ INPUT_PORTS_END
 
 static READ32_HANDLER( simpl156_inputs_read )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
-	int eep = eeprom_read_bit(state->eeprom);
-	UINT32 returndata = input_port_read(space->machine, "IN0") ^ 0xffff0000;
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
+	int eep = state->m_eeprom->read_bit();
+	UINT32 returndata = input_port_read(space->machine(), "IN0") ^ 0xffff0000;
 
 	returndata ^= ((eep << 8));
 	return returndata;
@@ -139,7 +139,7 @@ static READ32_HANDLER( simpl156_inputs_read )
 
 static READ32_HANDLER( simpl156_palette_r )
 {
-	return space->machine->generic.paletteram.u16[offset]^0xffff0000;
+	return space->machine().generic.paletteram.u16[offset]^0xffff0000;
 }
 
 static WRITE32_HANDLER( simpl156_palette_w )
@@ -150,11 +150,11 @@ static WRITE32_HANDLER( simpl156_palette_w )
 	data &= 0x0000ffff;
 	mem_mask &= 0x0000ffff;
 
-	COMBINE_DATA(&space->machine->generic.paletteram.u16[offset]);
+	COMBINE_DATA(&space->machine().generic.paletteram.u16[offset]);
 	color = offset;
 
-	dat = space->machine->generic.paletteram.u16[offset] & 0xffff;
-	palette_set_color_rgb(space->machine,color,pal5bit(dat >> 0),pal5bit(dat >> 5),pal5bit(dat >> 10));
+	dat = space->machine().generic.paletteram.u16[offset] & 0xffff;
+	palette_set_color_rgb(space->machine(),color,pal5bit(dat >> 0),pal5bit(dat >> 5),pal5bit(dat >> 10));
 }
 
 
@@ -162,23 +162,23 @@ static READ32_HANDLER(  simpl156_system_r )
 {
 	UINT32 returndata;
 
-	returndata = input_port_read(space->machine, "IN1");
+	returndata = input_port_read(space->machine(), "IN1");
 
 	return returndata;
 }
 
 static WRITE32_HANDLER( simpl156_eeprom_w )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
 	//int okibank;
 
 	//okibank = data & 0x07;
 
-	state->okimusic->set_bank_base(0x40000 * (data & 0x7));
+	state->m_okimusic->set_bank_base(0x40000 * (data & 0x7));
 
-	eeprom_set_clock_line(state->eeprom, BIT(data, 5) ? ASSERT_LINE : CLEAR_LINE);
-	eeprom_write_bit(state->eeprom, BIT(data, 4));
-	eeprom_set_cs_line(state->eeprom, BIT(data, 6) ? CLEAR_LINE : ASSERT_LINE);
+	state->m_eeprom->set_clock_line(BIT(data, 5) ? ASSERT_LINE : CLEAR_LINE);
+	state->m_eeprom->write_bit(BIT(data, 4));
+	state->m_eeprom->set_cs_line(BIT(data, 6) ? CLEAR_LINE : ASSERT_LINE);
 }
 
 
@@ -186,100 +186,102 @@ static WRITE32_HANDLER( simpl156_eeprom_w )
 
 static READ32_HANDLER( simpl156_spriteram_r )
 {
-	return space->machine->generic.spriteram.u32[offset] ^ 0xffff0000;
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
+	return state->m_spriteram[offset] ^ 0xffff0000;
 }
 
 static WRITE32_HANDLER( simpl156_spriteram_w )
 {
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
 	data &= 0x0000ffff;
 	mem_mask &= 0x0000ffff;
 
-	COMBINE_DATA(&space->machine->generic.spriteram.u32[offset]);
+	COMBINE_DATA(&state->m_spriteram[offset]);
 }
 
 
 static READ32_HANDLER( simpl156_mainram_r )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
-	return state->mainram[offset]^0xffff0000;
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
+	return state->m_mainram[offset]^0xffff0000;
 }
 
 static WRITE32_HANDLER( simpl156_mainram_w )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
 	data &= 0x0000ffff;
 	mem_mask &= 0x0000ffff;
 
-	COMBINE_DATA(&state->mainram[offset]);
+	COMBINE_DATA(&state->m_mainram[offset]);
 }
 
 static READ32_HANDLER( simpl156_pf1_rowscroll_r )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
-	return state->pf1_rowscroll[offset] ^ 0xffff0000;
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
+	return state->m_pf1_rowscroll[offset] ^ 0xffff0000;
 }
 
 static WRITE32_HANDLER( simpl156_pf1_rowscroll_w )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
 	data &= 0x0000ffff;
 	mem_mask &= 0x0000ffff;
 
-	COMBINE_DATA(&state->pf1_rowscroll[offset]);
+	COMBINE_DATA(&state->m_pf1_rowscroll[offset]);
 }
 
 static READ32_HANDLER( simpl156_pf2_rowscroll_r )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
-	return state->pf2_rowscroll[offset] ^ 0xffff0000;
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
+	return state->m_pf2_rowscroll[offset] ^ 0xffff0000;
 }
 
 static WRITE32_HANDLER( simpl156_pf2_rowscroll_w )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
 	data &= 0x0000ffff;
 	mem_mask &= 0x0000ffff;
 
-	COMBINE_DATA(&state->pf2_rowscroll[offset]);
+	COMBINE_DATA(&state->m_pf2_rowscroll[offset]);
 }
 
 /* Memory Map controled by PALs */
 
 /* Joe and Mac Returns */
-static ADDRESS_MAP_START( joemacr_map, ADDRESS_SPACE_PROGRAM, 32 )
+static ADDRESS_MAP_START( joemacr_map, AS_PROGRAM, 32 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
-	AM_RANGE(0x100000, 0x107fff) AM_READWRITE(simpl156_mainram_r, simpl156_mainram_w) AM_BASE_MEMBER(simpl156_state, mainram) // main ram
-	AM_RANGE(0x110000, 0x111fff) AM_READWRITE(simpl156_spriteram_r, simpl156_spriteram_w) AM_BASE_SIZE_GENERIC(spriteram)
+	AM_RANGE(0x100000, 0x107fff) AM_READWRITE(simpl156_mainram_r, simpl156_mainram_w) AM_BASE_MEMBER(simpl156_state, m_mainram) // main ram
+	AM_RANGE(0x110000, 0x111fff) AM_READWRITE(simpl156_spriteram_r, simpl156_spriteram_w)
 	AM_RANGE(0x120000, 0x120fff) AM_READWRITE(simpl156_palette_r, simpl156_palette_w)
 	AM_RANGE(0x130000, 0x130003) AM_READWRITE(simpl156_system_r, simpl156_eeprom_w)
-	AM_RANGE(0x140000, 0x14001f) AM_DEVREADWRITE("deco_custom", deco16ic_pf12_control_dword_r, deco16ic_pf12_control_dword_w)
-	AM_RANGE(0x150000, 0x151fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
-	AM_RANGE(0x152000, 0x153fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
-	AM_RANGE(0x154000, 0x155fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
+	AM_RANGE(0x140000, 0x14001f) AM_DEVREADWRITE("tilegen1", deco16ic_pf_control_dword_r, deco16ic_pf_control_dword_w)
+	AM_RANGE(0x150000, 0x151fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
+	AM_RANGE(0x152000, 0x153fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
+	AM_RANGE(0x154000, 0x155fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
 	AM_RANGE(0x160000, 0x161fff) AM_READWRITE(simpl156_pf1_rowscroll_r, simpl156_pf1_rowscroll_w)
 	AM_RANGE(0x164000, 0x165fff) AM_READWRITE(simpl156_pf2_rowscroll_r, simpl156_pf2_rowscroll_w)
 	AM_RANGE(0x170000, 0x170003) AM_READONLY AM_WRITENOP // ?
 	AM_RANGE(0x180000, 0x180003) AM_DEVREADWRITE8_MODERN("okisfx", okim6295_device, read, write, 0x000000ff)
 	AM_RANGE(0x1c0000, 0x1c0003) AM_DEVREADWRITE8_MODERN("okimusic", okim6295_device, read, write, 0x000000ff)
 	AM_RANGE(0x200000, 0x200003) AM_READ(simpl156_inputs_read)
-	AM_RANGE(0x201000, 0x201fff) AM_RAM AM_BASE_MEMBER(simpl156_state, systemram) // work ram (32-bit)
+	AM_RANGE(0x201000, 0x201fff) AM_RAM AM_BASE_MEMBER(simpl156_state, m_systemram) // work ram (32-bit)
 ADDRESS_MAP_END
 
 
 /* Chain Reaction */
-static ADDRESS_MAP_START( chainrec_map, ADDRESS_SPACE_PROGRAM, 32 )
+static ADDRESS_MAP_START( chainrec_map, AS_PROGRAM, 32 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM // rom (32-bit)
 	AM_RANGE(0x200000, 0x200003) AM_READ(simpl156_inputs_read)
-	AM_RANGE(0x201000, 0x201fff) AM_RAM AM_BASE_MEMBER(simpl156_state, systemram) // work ram (32-bit)
+	AM_RANGE(0x201000, 0x201fff) AM_RAM AM_BASE_MEMBER(simpl156_state, m_systemram) // work ram (32-bit)
 	AM_RANGE(0x3c0000, 0x3c0003) AM_DEVREADWRITE8_MODERN("okimusic", okim6295_device, read, write, 0x000000ff)
-	AM_RANGE(0x400000, 0x407fff) AM_READWRITE(simpl156_mainram_r, simpl156_mainram_w) AM_BASE_MEMBER(simpl156_state, mainram) // main ram?
-	AM_RANGE(0x410000, 0x411fff) AM_READWRITE(simpl156_spriteram_r, simpl156_spriteram_w) AM_BASE_SIZE_GENERIC(spriteram)
+	AM_RANGE(0x400000, 0x407fff) AM_READWRITE(simpl156_mainram_r, simpl156_mainram_w) AM_BASE_MEMBER(simpl156_state, m_mainram) // main ram?
+	AM_RANGE(0x410000, 0x411fff) AM_READWRITE(simpl156_spriteram_r, simpl156_spriteram_w)
 	AM_RANGE(0x420000, 0x420fff) AM_READWRITE(simpl156_palette_r,simpl156_palette_w)
 	AM_RANGE(0x430000, 0x430003) AM_READWRITE(simpl156_system_r,simpl156_eeprom_w)
-	AM_RANGE(0x440000, 0x44001f) AM_DEVREADWRITE("deco_custom", deco16ic_pf12_control_dword_r, deco16ic_pf12_control_dword_w)
-	AM_RANGE(0x450000, 0x451fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
-	AM_RANGE(0x452000, 0x453fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
-	AM_RANGE(0x454000, 0x455fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
+	AM_RANGE(0x440000, 0x44001f) AM_DEVREADWRITE("tilegen1", deco16ic_pf_control_dword_r, deco16ic_pf_control_dword_w)
+	AM_RANGE(0x450000, 0x451fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
+	AM_RANGE(0x452000, 0x453fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
+	AM_RANGE(0x454000, 0x455fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
 	AM_RANGE(0x460000, 0x461fff) AM_READWRITE(simpl156_pf1_rowscroll_r, simpl156_pf1_rowscroll_w)
 	AM_RANGE(0x464000, 0x465fff) AM_READWRITE(simpl156_pf2_rowscroll_r, simpl156_pf2_rowscroll_w)
 	AM_RANGE(0x470000, 0x470003) AM_READONLY AM_WRITENOP // ??
@@ -288,19 +290,19 @@ ADDRESS_MAP_END
 
 
 /* Magical Drop */
-static ADDRESS_MAP_START( magdrop_map, ADDRESS_SPACE_PROGRAM, 32 )
+static ADDRESS_MAP_START( magdrop_map, AS_PROGRAM, 32 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	AM_RANGE(0x200000, 0x200003) AM_READ(simpl156_inputs_read)
-	AM_RANGE(0x201000, 0x201fff) AM_RAM AM_BASE_MEMBER(simpl156_state, systemram) // work ram (32-bit)
+	AM_RANGE(0x201000, 0x201fff) AM_RAM AM_BASE_MEMBER(simpl156_state, m_systemram) // work ram (32-bit)
 	AM_RANGE(0x340000, 0x340003) AM_DEVREADWRITE8_MODERN("okimusic", okim6295_device, read, write, 0x000000ff)
-	AM_RANGE(0x380000, 0x387fff) AM_READWRITE(simpl156_mainram_r, simpl156_mainram_w) AM_BASE_MEMBER(simpl156_state, mainram) // main ram?
-	AM_RANGE(0x390000, 0x391fff) AM_READWRITE(simpl156_spriteram_r, simpl156_spriteram_w) AM_BASE_SIZE_GENERIC(spriteram)
+	AM_RANGE(0x380000, 0x387fff) AM_READWRITE(simpl156_mainram_r, simpl156_mainram_w) AM_BASE_MEMBER(simpl156_state, m_mainram) // main ram?
+	AM_RANGE(0x390000, 0x391fff) AM_READWRITE(simpl156_spriteram_r, simpl156_spriteram_w)
 	AM_RANGE(0x3a0000, 0x3a0fff) AM_READWRITE(simpl156_palette_r,simpl156_palette_w)
 	AM_RANGE(0x3b0000, 0x3b0003) AM_READWRITE(simpl156_system_r,simpl156_eeprom_w)
-	AM_RANGE(0x3c0000, 0x3c001f) AM_DEVREADWRITE("deco_custom", deco16ic_pf12_control_dword_r, deco16ic_pf12_control_dword_w)
-	AM_RANGE(0x3d0000, 0x3d1fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
-	AM_RANGE(0x3d2000, 0x3d3fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
-	AM_RANGE(0x3d4000, 0x3d5fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
+	AM_RANGE(0x3c0000, 0x3c001f) AM_DEVREADWRITE("tilegen1", deco16ic_pf_control_dword_r, deco16ic_pf_control_dword_w)
+	AM_RANGE(0x3d0000, 0x3d1fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
+	AM_RANGE(0x3d2000, 0x3d3fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
+	AM_RANGE(0x3d4000, 0x3d5fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
 	AM_RANGE(0x3e0000, 0x3e1fff) AM_READWRITE(simpl156_pf1_rowscroll_r, simpl156_pf1_rowscroll_w)
 	AM_RANGE(0x3e4000, 0x3e5fff) AM_READWRITE(simpl156_pf2_rowscroll_r, simpl156_pf2_rowscroll_w)
 	AM_RANGE(0x3f0000, 0x3f0003) AM_READONLY AM_WRITENOP //?
@@ -309,19 +311,19 @@ ADDRESS_MAP_END
 
 
 /* Magical Drop Plus 1 */
-static ADDRESS_MAP_START( magdropp_map, ADDRESS_SPACE_PROGRAM, 32 )
+static ADDRESS_MAP_START( magdropp_map, AS_PROGRAM, 32 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	AM_RANGE(0x200000, 0x200003) AM_READ(simpl156_inputs_read)
-	AM_RANGE(0x201000, 0x201fff) AM_RAM AM_BASE_MEMBER(simpl156_state, systemram) // work ram (32-bit)
+	AM_RANGE(0x201000, 0x201fff) AM_RAM AM_BASE_MEMBER(simpl156_state, m_systemram) // work ram (32-bit)
 	AM_RANGE(0x4c0000, 0x4c0003) AM_DEVREADWRITE8_MODERN("okimusic", okim6295_device, read, write, 0x000000ff)
-	AM_RANGE(0x680000, 0x687fff) AM_READWRITE(simpl156_mainram_r, simpl156_mainram_w) AM_BASE_MEMBER(simpl156_state, mainram) // main ram?
-	AM_RANGE(0x690000, 0x691fff) AM_READWRITE(simpl156_spriteram_r, simpl156_spriteram_w) AM_BASE_SIZE_GENERIC(spriteram)
+	AM_RANGE(0x680000, 0x687fff) AM_READWRITE(simpl156_mainram_r, simpl156_mainram_w) AM_BASE_MEMBER(simpl156_state, m_mainram) // main ram?
+	AM_RANGE(0x690000, 0x691fff) AM_READWRITE(simpl156_spriteram_r, simpl156_spriteram_w)
 	AM_RANGE(0x6a0000, 0x6a0fff) AM_READWRITE(simpl156_palette_r,simpl156_palette_w)
 	AM_RANGE(0x6b0000, 0x6b0003) AM_READWRITE(simpl156_system_r,simpl156_eeprom_w)
-	AM_RANGE(0x6c0000, 0x6c001f) AM_DEVREADWRITE("deco_custom", deco16ic_pf12_control_dword_r, deco16ic_pf12_control_dword_w)
-	AM_RANGE(0x6d0000, 0x6d1fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
-	AM_RANGE(0x6d2000, 0x6d3fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
-	AM_RANGE(0x6d4000, 0x6d5fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
+	AM_RANGE(0x6c0000, 0x6c001f) AM_DEVREADWRITE("tilegen1", deco16ic_pf_control_dword_r, deco16ic_pf_control_dword_w)
+	AM_RANGE(0x6d0000, 0x6d1fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
+	AM_RANGE(0x6d2000, 0x6d3fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
+	AM_RANGE(0x6d4000, 0x6d5fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
 	AM_RANGE(0x6e0000, 0x6e1fff) AM_READWRITE(simpl156_pf1_rowscroll_r, simpl156_pf1_rowscroll_w)
 	AM_RANGE(0x6e4000, 0x6e5fff) AM_READWRITE(simpl156_pf2_rowscroll_r, simpl156_pf2_rowscroll_w)
 	AM_RANGE(0x6f0000, 0x6f0003) AM_READONLY AM_WRITENOP // ?
@@ -330,23 +332,23 @@ ADDRESS_MAP_END
 
 
 /* Mitchell MT5601-0 PCB (prtytime, charlien, osman) */
-static ADDRESS_MAP_START( mitchell156_map, ADDRESS_SPACE_PROGRAM, 32 )
+static ADDRESS_MAP_START( mitchell156_map, AS_PROGRAM, 32 )
 	AM_RANGE(0x000000, 0x07ffff) AM_ROM
 	AM_RANGE(0x100000, 0x100003) AM_DEVREADWRITE8_MODERN("okisfx", okim6295_device, read, write, 0x000000ff)
 	AM_RANGE(0x140000, 0x140003) AM_DEVREADWRITE8_MODERN("okimusic", okim6295_device, read, write, 0x000000ff)
-	AM_RANGE(0x180000, 0x187fff) AM_READWRITE(simpl156_mainram_r, simpl156_mainram_w) AM_BASE_MEMBER(simpl156_state, mainram) // main ram
-	AM_RANGE(0x190000, 0x191fff) AM_READWRITE(simpl156_spriteram_r, simpl156_spriteram_w) AM_BASE_SIZE_GENERIC(spriteram)
+	AM_RANGE(0x180000, 0x187fff) AM_READWRITE(simpl156_mainram_r, simpl156_mainram_w) AM_BASE_MEMBER(simpl156_state, m_mainram) // main ram
+	AM_RANGE(0x190000, 0x191fff) AM_READWRITE(simpl156_spriteram_r, simpl156_spriteram_w)
 	AM_RANGE(0x1a0000, 0x1a0fff) AM_READWRITE(simpl156_palette_r,simpl156_palette_w)
 	AM_RANGE(0x1b0000, 0x1b0003) AM_READWRITE(simpl156_system_r,simpl156_eeprom_w)
-	AM_RANGE(0x1c0000, 0x1c001f) AM_DEVREADWRITE("deco_custom", deco16ic_pf12_control_dword_r, deco16ic_pf12_control_dword_w)
-	AM_RANGE(0x1d0000, 0x1d1fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
-	AM_RANGE(0x1d2000, 0x1d3fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
-	AM_RANGE(0x1d4000, 0x1d5fff) AM_DEVREADWRITE("deco_custom", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
+	AM_RANGE(0x1c0000, 0x1c001f) AM_DEVREADWRITE("tilegen1", deco16ic_pf_control_dword_r, deco16ic_pf_control_dword_w)
+	AM_RANGE(0x1d0000, 0x1d1fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
+	AM_RANGE(0x1d2000, 0x1d3fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_dword_r, deco16ic_pf1_data_dword_w)
+	AM_RANGE(0x1d4000, 0x1d5fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf2_data_dword_r, deco16ic_pf2_data_dword_w)
 	AM_RANGE(0x1e0000, 0x1e1fff) AM_READWRITE(simpl156_pf1_rowscroll_r, simpl156_pf1_rowscroll_w)
 	AM_RANGE(0x1e4000, 0x1e5fff) AM_READWRITE(simpl156_pf2_rowscroll_r, simpl156_pf2_rowscroll_w)
 	AM_RANGE(0x1f0000, 0x1f0003) AM_READONLY AM_WRITENOP // ?
 	AM_RANGE(0x200000, 0x200003) AM_READ(simpl156_inputs_read)
-	AM_RANGE(0x201000, 0x201fff) AM_RAM AM_BASE_MEMBER(simpl156_state, systemram) // work ram (32-bit)
+	AM_RANGE(0x201000, 0x201fff) AM_RAM AM_BASE_MEMBER(simpl156_state, m_systemram) // work ram (32-bit)
 ADDRESS_MAP_END
 
 
@@ -393,7 +395,7 @@ GFXDECODE_END
 
 static INTERRUPT_GEN( simpl156_vbl_interrupt )
 {
-	cpu_set_input_line(device, ARM_IRQ_LINE, HOLD_LINE);
+	device_set_input_line(device, ARM_IRQ_LINE, HOLD_LINE);
 }
 
 
@@ -402,19 +404,32 @@ static int simpl156_bank_callback(const int bank)
 	return ((bank >> 4) & 0x7) * 0x1000;
 }
 
-static const deco16ic_interface simpl156_deco16ic_intf =
+static const deco16ic_interface simpl156_deco16ic_tilegen1_intf =
 {
 	"screen",
-	1, 0, 1,
-	0x0f, 0x0f, 0x0f, 0x0f,	/* trans masks (default values) */
-	0, 16, 0, 16, /* color base (default values) */
-	0x0f, 0x0f, 0x0f, 0x0f,	/* color masks (default values) */
+	0, 1,
+	0x0f, 0x0f, /* trans masks (default values) */
+	0, 16,/* color base (default values) */
+	0x0f, 0x0f, /* color masks (default values) */
 	simpl156_bank_callback,
 	simpl156_bank_callback,
-	NULL,
-	NULL
+	0,1,
 };
 
+UINT16 simpl156_pri_callback(UINT16 x)
+{
+	switch (x & 0xc000)
+	{
+		case 0x0000: return 0;
+		case 0x4000: return 0xf0;
+		case 0x8000: return 0xf0 | 0xcc;
+		case 0xc000: return 0xf0 | 0xcc;; /*  or 0xf0|0xcc|0xaa ? */
+	}
+
+	return 0;
+}
+
+
 static MACHINE_CONFIG_START( chainrec, simpl156_state )
 
 	/* basic machine hardware */
@@ -431,13 +446,16 @@ static MACHINE_CONFIG_START( chainrec, simpl156_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_UPDATE(simpl156)
 
 	MCFG_PALETTE_LENGTH(4096)
 	MCFG_GFXDECODE(simpl156)
 	MCFG_VIDEO_START(simpl156)
-	MCFG_VIDEO_UPDATE(simpl156)
 
-	MCFG_DECO16IC_ADD("deco_custom", simpl156_deco16ic_intf)
+	MCFG_DECO16IC_ADD("tilegen1", simpl156_deco16ic_tilegen1_intf)
+	MCFG_DEVICE_ADD("spritegen", DECO_SPRITE, 0)
+	decospr_device::set_gfx_region(*device, 2);
+	decospr_device::set_pri_callback(*device, simpl156_pri_callback);
 
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
 
@@ -1015,8 +1033,8 @@ ROM_END
 
 static DRIVER_INIT( simpl156 )
 {
-	UINT8 *rom = machine->region("okimusic")->base();
-	int length = machine->region("okimusic")->bytes();
+	UINT8 *rom = machine.region("okimusic")->base();
+	int length = machine.region("okimusic")->bytes();
 	UINT8 *buf1 = auto_alloc_array(machine, UINT8, length);
 
 	UINT32 x;
@@ -1047,73 +1065,73 @@ static DRIVER_INIT( simpl156 )
 /* Everything seems more stable if we run the CPU speed x4 and use Idle skips.. maybe it has an internal multipler? */
 static READ32_HANDLER( joemacr_speedup_r )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
-	if (cpu_get_pc(space->cpu) == 0x284)
-		cpu_spinuntil_time(space->cpu, ATTOTIME_IN_USEC(400));
-	return state->systemram[0x18/4];
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
+	if (cpu_get_pc(&space->device()) == 0x284)
+		device_spin_until_time(&space->device(), attotime::from_usec(400));
+	return state->m_systemram[0x18/4];
 }
 
 
 static DRIVER_INIT( joemacr )
 {
-	memory_install_read32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x0201018, 0x020101b, 0, 0, joemacr_speedup_r );
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x0201018, 0x020101b, FUNC(joemacr_speedup_r) );
 	DRIVER_INIT_CALL(simpl156);
 }
 
 static READ32_HANDLER( chainrec_speedup_r )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
-	if (cpu_get_pc(space->cpu) == 0x2d4)
-		cpu_spinuntil_time(space->cpu, ATTOTIME_IN_USEC(400));
-	return state->systemram[0x18/4];
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
+	if (cpu_get_pc(&space->device()) == 0x2d4)
+		device_spin_until_time(&space->device(), attotime::from_usec(400));
+	return state->m_systemram[0x18/4];
 }
 
 static DRIVER_INIT( chainrec )
 {
-	memory_install_read32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x0201018, 0x020101b, 0, 0, chainrec_speedup_r );
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x0201018, 0x020101b, FUNC(chainrec_speedup_r) );
 	DRIVER_INIT_CALL(simpl156);
 }
 
 static READ32_HANDLER( prtytime_speedup_r )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
-	if (cpu_get_pc(space->cpu) == 0x4f0)
-		cpu_spinuntil_time(space->cpu, ATTOTIME_IN_USEC(400));
-	return state->systemram[0xae0/4];
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
+	if (cpu_get_pc(&space->device()) == 0x4f0)
+		device_spin_until_time(&space->device(), attotime::from_usec(400));
+	return state->m_systemram[0xae0/4];
 }
 
 static DRIVER_INIT( prtytime )
 {
-	memory_install_read32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x0201ae0, 0x0201ae3, 0, 0, prtytime_speedup_r );
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x0201ae0, 0x0201ae3, FUNC(prtytime_speedup_r) );
 	DRIVER_INIT_CALL(simpl156);
 }
 
 
 static READ32_HANDLER( charlien_speedup_r )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
-	if (cpu_get_pc(space->cpu) == 0xc8c8)
-		cpu_spinuntil_time(space->cpu, ATTOTIME_IN_USEC(400));
-	return state->systemram[0x10/4];
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
+	if (cpu_get_pc(&space->device()) == 0xc8c8)
+		device_spin_until_time(&space->device(), attotime::from_usec(400));
+	return state->m_systemram[0x10/4];
 }
 
 static DRIVER_INIT( charlien )
 {
-	memory_install_read32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x0201010, 0x0201013, 0, 0, charlien_speedup_r );
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x0201010, 0x0201013, FUNC(charlien_speedup_r) );
 	DRIVER_INIT_CALL(simpl156);
 }
 
 static READ32_HANDLER( osman_speedup_r )
 {
-	simpl156_state *state = space->machine->driver_data<simpl156_state>();
-	if (cpu_get_pc(space->cpu) == 0x5974)
-		cpu_spinuntil_time(space->cpu, ATTOTIME_IN_USEC(400));
-	return state->systemram[0x10/4];
+	simpl156_state *state = space->machine().driver_data<simpl156_state>();
+	if (cpu_get_pc(&space->device()) == 0x5974)
+		device_spin_until_time(&space->device(), attotime::from_usec(400));
+	return state->m_systemram[0x10/4];
 }
 
 static DRIVER_INIT( osman )
 {
-	memory_install_read32_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0x0201010, 0x0201013, 0, 0, osman_speedup_r );
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0x0201010, 0x0201013, FUNC(osman_speedup_r) );
 	DRIVER_INIT_CALL(simpl156);
 
 }
