@@ -36,12 +36,12 @@ static PALETTE_INIT( skyraid )
 
 static READ8_HANDLER( skyraid_port_0_r )
 {
-	skyraid_state *state = space->machine->driver_data<skyraid_state>();
-	UINT8 val = input_port_read(space->machine, "LANGUAGE");
+	skyraid_state *state = space->machine().driver_data<skyraid_state>();
+	UINT8 val = input_port_read(space->machine(), "LANGUAGE");
 
-	if (input_port_read(space->machine, "STICKY") > state->analog_range)
+	if (input_port_read(space->machine(), "STICKY") > state->m_analog_range)
 		val |= 0x40;
-	if (input_port_read(space->machine, "STICKX") > state->analog_range)
+	if (input_port_read(space->machine(), "STICKX") > state->m_analog_range)
 		val |= 0x80;
 
 	return val;
@@ -50,37 +50,37 @@ static READ8_HANDLER( skyraid_port_0_r )
 
 static WRITE8_HANDLER( skyraid_range_w )
 {
-	skyraid_state *state = space->machine->driver_data<skyraid_state>();
+	skyraid_state *state = space->machine().driver_data<skyraid_state>();
 
-	state->analog_range = data & 0x3f;
+	state->m_analog_range = data & 0x3f;
 }
 
 
 static WRITE8_HANDLER( skyraid_offset_w )
 {
-	skyraid_state *state = space->machine->driver_data<skyraid_state>();
+	skyraid_state *state = space->machine().driver_data<skyraid_state>();
 
-	state->analog_offset = data & 0x3f;
+	state->m_analog_offset = data & 0x3f;
 }
 
 
 static WRITE8_HANDLER( skyraid_scroll_w )
 {
-	skyraid_state *state = space->machine->driver_data<skyraid_state>();
+	skyraid_state *state = space->machine().driver_data<skyraid_state>();
 
-	state->scroll = data;
+	state->m_scroll = data;
 }
 
 
-static ADDRESS_MAP_START( skyraid_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( skyraid_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x00ff) AM_RAM AM_MIRROR(0x300)
-	AM_RANGE(0x0400, 0x040f) AM_WRITEONLY AM_BASE_MEMBER(skyraid_state, pos_ram)
-	AM_RANGE(0x0800, 0x087f) AM_RAM AM_MIRROR(0x480) AM_BASE_MEMBER(skyraid_state, alpha_num_ram)
+	AM_RANGE(0x0400, 0x040f) AM_WRITEONLY AM_BASE_MEMBER(skyraid_state, m_pos_ram)
+	AM_RANGE(0x0800, 0x087f) AM_RAM AM_MIRROR(0x480) AM_BASE_MEMBER(skyraid_state, m_alpha_num_ram)
 	AM_RANGE(0x1000, 0x1000) AM_READ(skyraid_port_0_r)
 	AM_RANGE(0x1001, 0x1001) AM_READ_PORT("DSW")
 	AM_RANGE(0x1400, 0x1400) AM_READ_PORT("COIN")
 	AM_RANGE(0x1400, 0x1401) AM_READ_PORT("SYSTEM")
-	AM_RANGE(0x1c00, 0x1c0f) AM_WRITEONLY AM_BASE_MEMBER(skyraid_state, obj_ram)
+	AM_RANGE(0x1c00, 0x1c0f) AM_WRITEONLY AM_BASE_MEMBER(skyraid_state, m_obj_ram)
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(skyraid_scroll_w)
 	AM_RANGE(0x4400, 0x4400) AM_DEVWRITE("discrete", skyraid_sound_w)
 	AM_RANGE(0x4800, 0x4800) AM_WRITE(skyraid_range_w)
@@ -234,6 +234,7 @@ static MACHINE_CONFIG_START( skyraid, skyraid_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(512, 240)
 	MCFG_SCREEN_VISIBLE_AREA(0, 511, 0, 239)
+	MCFG_SCREEN_UPDATE(skyraid)
 
 	MCFG_GFXDECODE(skyraid)
 
@@ -241,7 +242,6 @@ static MACHINE_CONFIG_START( skyraid, skyraid_state )
 	MCFG_PALETTE_LENGTH(20)
 
 	MCFG_VIDEO_START(skyraid)
-	MCFG_VIDEO_UPDATE(skyraid)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
