@@ -74,22 +74,22 @@ Dumped 06/15/2000
 class srmp6_state : public driver_device
 {
 public:
-	srmp6_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	srmp6_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	UINT16* tileram;
-	UINT16* dmaram;
+	UINT16* m_tileram;
+	UINT16* m_dmaram;
 
-	UINT16 *sprram;
-	UINT16 *sprram_old;
+	UINT16 *m_sprram;
+	UINT16 *m_sprram_old;
 
-	int brightness;
-	UINT16 input_select;
-	UINT16 *video_regs;
+	int m_brightness;
+	UINT16 m_input_select;
+	UINT16 *m_video_regs;
 
-	unsigned short lastb;
-	unsigned short lastb2;
-	int destl;
+	unsigned short m_lastb;
+	unsigned short m_lastb2;
+	int m_destl;
 };
 
 #define VERBOSE 0
@@ -106,18 +106,18 @@ static const gfx_layout tiles8x8_layout =
 	8*64
 };
 
-static void update_palette(running_machine *machine)
+static void update_palette(running_machine &machine)
 {
-	srmp6_state *state = machine->driver_data<srmp6_state>();
+	srmp6_state *state = machine.driver_data<srmp6_state>();
 	INT8 r, g ,b;
-	int brg = state->brightness - 0x60;
+	int brg = state->m_brightness - 0x60;
 	int i;
 
 	for(i = 0; i < 0x800; i++)
 	{
-		r = machine->generic.paletteram.u16[i] >>  0 & 0x1F;
-		g = machine->generic.paletteram.u16[i] >>  5 & 0x1F;
-		b = machine->generic.paletteram.u16[i] >> 10 & 0x1F;
+		r = machine.generic.paletteram.u16[i] >>  0 & 0x1F;
+		g = machine.generic.paletteram.u16[i] >>  5 & 0x1F;
+		b = machine.generic.paletteram.u16[i] >> 10 & 0x1F;
 
 		if(brg < 0) {
 			r += (r * brg) >> 5;
@@ -141,29 +141,29 @@ static void update_palette(running_machine *machine)
 
 static VIDEO_START(srmp6)
 {
-	srmp6_state *state = machine->driver_data<srmp6_state>();
+	srmp6_state *state = machine.driver_data<srmp6_state>();
 
-	state->tileram = auto_alloc_array_clear(machine, UINT16, 0x100000*16/2);
-	state->dmaram = auto_alloc_array(machine, UINT16, 0x100/2);
-	state->sprram_old = auto_alloc_array_clear(machine, UINT16, 0x80000/2);
+	state->m_tileram = auto_alloc_array_clear(machine, UINT16, 0x100000*16/2);
+	state->m_dmaram = auto_alloc_array(machine, UINT16, 0x100/2);
+	state->m_sprram_old = auto_alloc_array_clear(machine, UINT16, 0x80000/2);
 
 	/* create the char set (gfx will then be updated dynamically from RAM) */
-	machine->gfx[0] = gfx_element_alloc(machine, &tiles8x8_layout, (UINT8*)state->tileram, machine->total_colors() / 256, 0);
-	machine->gfx[0]->color_granularity=256;
+	machine.gfx[0] = gfx_element_alloc(machine, &tiles8x8_layout, (UINT8*)state->m_tileram, machine.total_colors() / 256, 0);
+	machine.gfx[0]->color_granularity=256;
 
-	state->brightness = 0x60;
+	state->m_brightness = 0x60;
 }
 
 #if 0
 static int xixi=0;
 #endif
 
-static VIDEO_UPDATE(srmp6)
+static SCREEN_UPDATE(srmp6)
 {
-	srmp6_state *state = screen->machine->driver_data<srmp6_state>();
+	srmp6_state *state = screen->machine().driver_data<srmp6_state>();
 	int alpha;
 	int x,y,tileno,height,width,xw,yw,sprite,xb,yb;
-	UINT16 *sprite_list = state->sprram_old;
+	UINT16 *sprite_list = state->m_sprram_old;
 	UINT16 mainlist_offset = 0;
 
 	union
@@ -176,13 +176,13 @@ static VIDEO_UPDATE(srmp6)
 
 #if 0
 	/* debug */
-	if(input_code_pressed_once(screen->machine, KEYCODE_Q))
+	if(screen->machine().input().code_pressed_once(KEYCODE_Q))
 	{
 		++xixi;
 		printf("%x\n",xixi);
 	}
 
-	if(input_code_pressed_once(screen->machine, KEYCODE_W))
+	if(screen->machine().input().code_pressed_once(KEYCODE_W))
 	{
 		--xixi;
 		printf("%x\n",xixi);
@@ -193,7 +193,7 @@ static VIDEO_UPDATE(srmp6)
 	while (mainlist_offset<0x2000/2)
 	{
 
-		UINT16 *sprite_sublist = &state->sprram_old[sprite_list[mainlist_offset+1]<<3];
+		UINT16 *sprite_sublist = &state->m_sprram_old[sprite_list[mainlist_offset+1]<<3];
 		UINT16 sublist_length=sprite_list[mainlist_offset+0]&0x7fff; //+1 ?
 		INT16 global_x,global_y, flip_x, flip_y;
 		UINT16 global_pal;
@@ -259,7 +259,7 @@ static VIDEO_UPDATE(srmp6)
 						else
 							yb=y+(height-yw-1)*8+global_y;
 
-						drawgfx_alpha(bitmap,cliprect,screen->machine->gfx[0],tileno,global_pal,flip_x,flip_y,xb,yb,0,alpha);
+						drawgfx_alpha(bitmap,cliprect,screen->machine().gfx[0],tileno,global_pal,flip_x,flip_y,xb,yb,0,alpha);
 						tileno++;
 					}
 				}
@@ -271,12 +271,12 @@ static VIDEO_UPDATE(srmp6)
 		mainlist_offset+=8;
 	}
 
-	memcpy(state->sprram_old, state->sprram, 0x80000);
+	memcpy(state->m_sprram_old, state->m_sprram, 0x80000);
 
-	if(input_code_pressed_once(screen->machine, KEYCODE_Q))
+	if(screen->machine().input().code_pressed_once(KEYCODE_Q))
 	{
 		FILE *p=fopen("tileram.bin","wb");
-		fwrite(state->tileram, 1, 0x100000*16, p);
+		fwrite(state->m_tileram, 1, 0x100000*16, p);
 		fclose(p);
 	}
 
@@ -290,24 +290,24 @@ static VIDEO_UPDATE(srmp6)
 
 static WRITE16_HANDLER( srmp6_input_select_w )
 {
-	srmp6_state *state = space->machine->driver_data<srmp6_state>();
+	srmp6_state *state = space->machine().driver_data<srmp6_state>();
 
-	state->input_select = data & 0x0f;
+	state->m_input_select = data & 0x0f;
 }
 
 static READ16_HANDLER( srmp6_inputs_r )
 {
-	srmp6_state *state = space->machine->driver_data<srmp6_state>();
+	srmp6_state *state = space->machine().driver_data<srmp6_state>();
 
 	if (offset == 0)			// DSW
-		return input_port_read(space->machine, "DSW");
+		return input_port_read(space->machine(), "DSW");
 
-	switch (state->input_select)	// inputs
+	switch (state->m_input_select)	// inputs
 	{
-		case 1<<0: return input_port_read(space->machine, "KEY0");
-		case 1<<1: return input_port_read(space->machine, "KEY1");
-		case 1<<2: return input_port_read(space->machine, "KEY2");
-		case 1<<3: return input_port_read(space->machine, "KEY3");
+		case 1<<0: return input_port_read(space->machine(), "KEY0");
+		case 1<<1: return input_port_read(space->machine(), "KEY1");
+		case 1<<2: return input_port_read(space->machine(), "KEY2");
+		case 1<<3: return input_port_read(space->machine(), "KEY3");
 	}
 
 	return 0;
@@ -316,16 +316,16 @@ static READ16_HANDLER( srmp6_inputs_r )
 
 static WRITE16_HANDLER( video_regs_w )
 {
-	srmp6_state *state = space->machine->driver_data<srmp6_state>();
+	srmp6_state *state = space->machine().driver_data<srmp6_state>();
 
 	switch(offset)
 	{
 
 		case 0x5e/2: // bank switch, used by ROM check
 		{
-			const UINT8 *rom = space->machine->region("nile")->base();
+			const UINT8 *rom = space->machine().region("nile")->base();
 			LOG(("%x\n",data));
-			memory_set_bankptr(space->machine, "bank1",(UINT16 *)(rom + (data & 0x0f)*0x200000));
+			memory_set_bankptr(space->machine(), "bank1",(UINT16 *)(rom + (data & 0x0f)*0x200000));
 			break;
 		}
 
@@ -333,9 +333,9 @@ static WRITE16_HANDLER( video_regs_w )
 		case 0x5c/2: // either 0x40 explicitely in many places, or according $2083b0 (IT4)
 			//Fade in/out (0x40(dark)-0x60(normal)-0x7e?(bright) reset by 0x00?
 			data = (!data)?0x60:(data == 0x5e)?0x60:data;
-			if (state->brightness != data) {
-				state->brightness = data;
-				update_palette(space->machine);
+			if (state->m_brightness != data) {
+				state->m_brightness = data;
+				update_palette(space->machine());
 			}
 			break;
 
@@ -350,52 +350,52 @@ static WRITE16_HANDLER( video_regs_w )
 		case 0x56/2: // written 8,9,8,9 successively
 
 		default:
-			logerror("video_regs_w (PC=%06X): %04x = %04x & %04x\n", cpu_get_previouspc(space->cpu), offset*2, data, mem_mask);
+			logerror("video_regs_w (PC=%06X): %04x = %04x & %04x\n", cpu_get_previouspc(&space->device()), offset*2, data, mem_mask);
 			break;
 	}
-	COMBINE_DATA(&state->video_regs[offset]);
+	COMBINE_DATA(&state->m_video_regs[offset]);
 }
 
 static READ16_HANDLER( video_regs_r )
 {
-	srmp6_state *state = space->machine->driver_data<srmp6_state>();
+	srmp6_state *state = space->machine().driver_data<srmp6_state>();
 
-	logerror("video_regs_r (PC=%06X): %04x\n", cpu_get_previouspc(space->cpu), offset*2);
-	return state->video_regs[offset];
+	logerror("video_regs_r (PC=%06X): %04x\n", cpu_get_previouspc(&space->device()), offset*2);
+	return state->m_video_regs[offset];
 }
 
 
 /* DMA RLE stuff - the same as CPS3 */
-static UINT32 process(running_machine *machine,UINT8 b,UINT32 dst_offset)
+static UINT32 process(running_machine &machine,UINT8 b,UINT32 dst_offset)
 {
-	srmp6_state *state = machine->driver_data<srmp6_state>();
+	srmp6_state *state = machine.driver_data<srmp6_state>();
 	int l=0;
 
-	UINT8 *tram=(UINT8*)state->tileram;
+	UINT8 *tram=(UINT8*)state->m_tileram;
 
-	if (state->lastb == state->lastb2)	//rle
+	if (state->m_lastb == state->m_lastb2)	//rle
 	{
 		int i;
 		int rle=(b+1)&0xff;
 
 		for(i=0;i<rle;++i)
 		{
-			tram[dst_offset + state->destl] = state->lastb;
-			gfx_element_mark_dirty(machine->gfx[0], (dst_offset + state->destl)/0x40);
+			tram[dst_offset + state->m_destl] = state->m_lastb;
+			gfx_element_mark_dirty(machine.gfx[0], (dst_offset + state->m_destl)/0x40);
 
 			dst_offset++;
 			++l;
 		}
-		state->lastb2 = 0xffff;
+		state->m_lastb2 = 0xffff;
 
 		return l;
 	}
 	else
 	{
-		state->lastb2 = state->lastb;
-		state->lastb = b;
-		tram[dst_offset + state->destl] = b;
-		gfx_element_mark_dirty(machine->gfx[0], (dst_offset + state->destl)/0x40);
+		state->m_lastb2 = state->m_lastb;
+		state->m_lastb = b;
+		tram[dst_offset + state->m_destl] = b;
+		gfx_element_mark_dirty(machine.gfx[0], (dst_offset + state->m_destl)/0x40);
 
 		return 1;
 	}
@@ -404,13 +404,13 @@ static UINT32 process(running_machine *machine,UINT8 b,UINT32 dst_offset)
 
 static WRITE16_HANDLER(srmp6_dma_w)
 {
-	srmp6_state *state = space->machine->driver_data<srmp6_state>();
-	UINT16* dmaram = state->dmaram;
+	srmp6_state *state = space->machine().driver_data<srmp6_state>();
+	UINT16* dmaram = state->m_dmaram;
 
 	COMBINE_DATA(&dmaram[offset]);
 	if (offset==13 && dmaram[offset]==0x40)
 	{
-		const UINT8 *rom = space->machine->region("nile")->base();
+		const UINT8 *rom = space->machine().region("nile")->base();
 		UINT32 srctab=2*((((UINT32)dmaram[5])<<16)|dmaram[4]);
 		UINT32 srcdata=2*((((UINT32)dmaram[11])<<16)|dmaram[10]);
 		UINT32 len=4*(((((UINT32)dmaram[7]&3)<<16)|dmaram[6])+1); //??? WRONG!
@@ -433,10 +433,10 @@ static WRITE16_HANDLER(srmp6_dma_w)
 				dmaram[0x18/2],
 				dmaram[0x1a/2]));
 
-		state->destl = dmaram[9]*0x40000;
+		state->m_destl = dmaram[9]*0x40000;
 
-		state->lastb = 0xfffe;
-		state->lastb2 = 0xffff;
+		state->m_lastb = 0xfffe;
+		state->m_lastb2 = 0xffff;
 
 		while(1)
 		{
@@ -452,13 +452,13 @@ static WRITE16_HANDLER(srmp6_dma_w)
 				{
 					UINT8 real_byte;
 					real_byte = rom[srctab+p*2];
-					tempidx+=process(space->machine,real_byte,tempidx);
+					tempidx+=process(space->machine(),real_byte,tempidx);
 					real_byte = rom[srctab+p*2+1];//px[DMA_XOR((current_table_address+p*2+1))];
-					tempidx+=process(space->machine,real_byte,tempidx);
+					tempidx+=process(space->machine(),real_byte,tempidx);
 				}
 				else
 				{
-					tempidx+=process(space->machine,p,tempidx);
+					tempidx+=process(space->machine(),p,tempidx);
 				}
 
 				ctrl<<=1;
@@ -478,14 +478,14 @@ static WRITE16_HANDLER(srmp6_dma_w)
 /* if tileram is actually bigger than the mapped area, how do we access the rest? */
 static READ16_HANDLER(tileram_r)
 {
-	//return state->tileram[offset];
+	//return state->m_tileram[offset];
 	return 0x0000;
 }
 
 static WRITE16_HANDLER(tileram_w)
 {
 	//UINT16 tmp;
-	//COMBINE_DATA(&state->tileram[offset]);
+	//COMBINE_DATA(&state->m_tileram[offset]);
 
 	/* are the DMA registers enabled some other way, or always mapped here, over RAM? */
 	if (offset >= 0xfff00/2 && offset <= 0xfff1a/2 )
@@ -497,9 +497,9 @@ static WRITE16_HANDLER(tileram_w)
 
 static WRITE16_HANDLER(paletteram_w)
 {
-	srmp6_state *state = space->machine->driver_data<srmp6_state>();
+	srmp6_state *state = space->machine().driver_data<srmp6_state>();
 	INT8 r, g, b;
-	int brg = state->brightness - 0x60;
+	int brg = state->m_brightness - 0x60;
 
 	paletteram16_xBBBBBGGGGGRRRRR_word_w(space, offset, data, mem_mask);
 
@@ -526,11 +526,11 @@ static WRITE16_HANDLER(paletteram_w)
 			if(b > 0x1F) b = 0x1F;
 		}
 
-		palette_set_color(space->machine, offset, MAKE_RGB(r << 3, g << 3, b << 3));
+		palette_set_color(space->machine(), offset, MAKE_RGB(r << 3, g << 3, b << 3));
 	}
 }
 
-static ADDRESS_MAP_START( srmp6, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( srmp6, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x200000, 0x23ffff) AM_RAM					// work RAM
 	AM_RANGE(0x600000, 0x7fffff) AM_ROMBANK("bank1")		// banked ROM (used by ROM check)
@@ -541,13 +541,13 @@ static ADDRESS_MAP_START( srmp6, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x4d0000, 0x4d0001) AM_READWRITE(watchdog_reset16_r, watchdog_reset16_w)	// watchdog
 
 	// OBJ RAM: checked [$400000-$47dfff]
-	AM_RANGE(0x400000, 0x47ffff) AM_RAM AM_BASE_MEMBER(srmp6_state,sprram)
+	AM_RANGE(0x400000, 0x47ffff) AM_RAM AM_BASE_MEMBER(srmp6_state,m_sprram)
 
 	// CHR RAM: checked [$500000-$5fffff]
-	AM_RANGE(0x500000, 0x5fffff) AM_READWRITE(tileram_r,tileram_w)//AM_RAM AM_BASE_MEMBER(srmp6_state,tileram)
-	//AM_RANGE(0x5fff00, 0x5fffff) AM_WRITE(dma_w) AM_BASE_MEMBER(srmp6_state,dmaram)
+	AM_RANGE(0x500000, 0x5fffff) AM_READWRITE(tileram_r,tileram_w)//AM_RAM AM_BASE_MEMBER(srmp6_state,m_tileram)
+	//AM_RANGE(0x5fff00, 0x5fffff) AM_WRITE(dma_w) AM_BASE_MEMBER(srmp6_state,m_dmaram)
 
-	AM_RANGE(0x4c0000, 0x4c006f) AM_READWRITE(video_regs_r, video_regs_w) AM_BASE_MEMBER(srmp6_state,video_regs)	// ? gfx regs ST-0026 NiLe
+	AM_RANGE(0x4c0000, 0x4c006f) AM_READWRITE(video_regs_r, video_regs_w) AM_BASE_MEMBER(srmp6_state,m_video_regs)	// ? gfx regs ST-0026 NiLe
 	AM_RANGE(0x4e0000, 0x4e00ff) AM_DEVREADWRITE("nile", nile_snd_r, nile_snd_w)
 	AM_RANGE(0x4e0100, 0x4e0101) AM_DEVREADWRITE("nile", nile_sndctrl_r, nile_sndctrl_w)
 	//AM_RANGE(0x4e0110, 0x4e0111) AM_NOP // ? accessed once ($268dc, written $b.w)
@@ -658,9 +658,9 @@ INPUT_PORTS_END
 static INTERRUPT_GEN(srmp6_interrupt)
 {
 	if(!cpu_getiloops(device))
-		cpu_set_input_line(device,3,HOLD_LINE);
+		device_set_input_line(device,3,HOLD_LINE);
 	else
-		cpu_set_input_line(device,4,HOLD_LINE);
+		device_set_input_line(device,4,HOLD_LINE);
 }
 
 static MACHINE_CONFIG_START( srmp6, srmp6_state )
@@ -676,11 +676,11 @@ static MACHINE_CONFIG_START( srmp6, srmp6_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(64*8, 64*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 42*8-1, 0*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(srmp6)
 
 	MCFG_PALETTE_LENGTH(0x800)
 
 	MCFG_VIDEO_START(srmp6)
-	MCFG_VIDEO_UPDATE(srmp6)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker")
