@@ -18,6 +18,11 @@
 
   Emulation by Bryan McPhail, mish@tendril.co.uk
 
+  ToDo:
+
+  Palette handling is somewhat hacked, see paletteram16_xbgr_word_be_sprites_w
+
+  ----
 
 Stephh's notes (based on the games M68000 code and some tests) :
 
@@ -38,17 +43,6 @@ Stephh's notes (based on the games M68000 code and some tests) :
   - The "Use Mahjong Tiles" Dip Switch only has an effect when playing
     "Shanghai Advanced".
 
-1) 'sshangha'
-
-  - There are writes to 0x100000-0x10000f (code from 0x000964 to 0x000a8c),
-    but their effect is unknown.
-
-2) 'sshanghb'
-
-  - There are writes to 0x101000-0x10100f (code from 0x000964 to 0x000a8c),
-    but their effect is unknown. Note that the code is the SAME as the one
-    in 'sshangha' (only the 0x10?00? addresses are different).
-
 ***************************************************************************/
 
 #include "emu.h"
@@ -57,54 +51,57 @@ Stephh's notes (based on the games M68000 code and some tests) :
 #include "sound/2203intf.h"
 #include "sound/okim6295.h"
 #include "includes/sshangha.h"
+#include "video/decospr.h"
+#include "video/deco16ic.h"
 
 #define SSHANGHA_HACK	0
 
-static UINT16 *sshangha_prot_data;
 
-static UINT16 *sshangha_sound_shared_ram;
 
 /******************************************************************************/
 
 static WRITE16_HANDLER( sshangha_protection16_w )
 {
-	COMBINE_DATA(&sshangha_prot_data[offset]);
+	sshangha_state *state = space->machine().driver_data<sshangha_state>();
+	COMBINE_DATA(&state->m_prot_data[offset]);
 
-	logerror("CPU #0 PC %06x: warning - write unmapped control address %06x %04x\n",cpu_get_pc(space->cpu),offset<<1,data);
+	logerror("CPU #0 PC %06x: warning - write unmapped control address %06x %04x\n",cpu_get_pc(&space->device()),offset<<1,data);
 }
 
 /* Protection/IO chip 146 */
 static READ16_HANDLER( sshangha_protection16_r )
 {
+	sshangha_state *state = space->machine().driver_data<sshangha_state>();
 	switch (offset)
 	{
 		case 0x050 >> 1:
-			return input_port_read(space->machine, "INPUTS");
+			return input_port_read(space->machine(), "INPUTS");
 		case 0x76a >> 1:
-			return input_port_read(space->machine, "SYSTEM");
+			return input_port_read(space->machine(), "SYSTEM");
 		case 0x0ac >> 1:
-			return input_port_read(space->machine, "DSW");
+			return input_port_read(space->machine(), "DSW");
 
 		// Protection TODO
 	}
 
-	logerror("CPU #0 PC %06x: warning - read unmapped control address %06x\n",cpu_get_pc(space->cpu),offset<<1);
-	return sshangha_prot_data[offset];
+	logerror("CPU #0 PC %06x: warning - read unmapped control address %06x\n",cpu_get_pc(&space->device()),offset<<1);
+	return state->m_prot_data[offset];
 }
 
 static READ16_HANDLER( sshanghb_protection16_r )
 {
+	sshangha_state *state = space->machine().driver_data<sshangha_state>();
 	switch (offset)
 	{
 		case 0x050 >> 1:
-			return input_port_read(space->machine, "INPUTS");
+			return input_port_read(space->machine(), "INPUTS");
 		case 0x76a >> 1:
-			return input_port_read(space->machine, "SYSTEM");
+			return input_port_read(space->machine(), "SYSTEM");
 		case 0x0ac >> 1:
-			return input_port_read(space->machine, "DSW");
+			return input_port_read(space->machine(), "DSW");
 	}
 
-	return sshangha_prot_data[offset];
+	return state->m_prot_data[offset];
 }
 
 /* Probably returns 0xffff when sprite DMA is complete, the game waits on it */
@@ -117,28 +114,61 @@ static READ16_HANDLER( deco_71_r )
 
 static MACHINE_RESET( sshangha )
 {
-	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
-	/* Such thing is needed as there is no code to turn the screen
-       to normal orientation when the game is reset.
-       I'm using the value that forces the screen to be in normal
-         orientation when entering the "test mode"
-         (check the game code from 0x0006b8 to 0x0006f0).
-       I can't tell however if this is accurate or not. */
-	sshangha_control_0_w(space, 0, 0x10, 0x00ff);
 }
 
 /******************************************************************************/
 
-static ADDRESS_MAP_START( sshangha_map, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x03ffff) AM_ROM
-	AM_RANGE(0x100000, 0x10000f) AM_RAM AM_BASE(&sshangha_sound_shared_ram)
+INLINE void set_color_888(running_machine &machine, pen_t color, int rshift, int gshift, int bshift, UINT32 data)
+{
+	palette_set_color_rgb(machine, color, (data >> rshift) & 0xff, (data >> gshift) & 0xff, (data >> bshift) & 0xff);
+}
 
-	AM_RANGE(0x200000, 0x201fff) AM_RAM_WRITE(sshangha_pf1_data_w) AM_BASE(&sshangha_pf1_data)
-	AM_RANGE(0x202000, 0x203fff) AM_RAM_WRITE(sshangha_pf2_data_w) AM_BASE(&sshangha_pf2_data)
-	AM_RANGE(0x204000, 0x2047ff) AM_RAM AM_BASE(&sshangha_pf1_rowscroll)
-	AM_RANGE(0x206000, 0x2067ff) AM_RAM AM_BASE(&sshangha_pf2_rowscroll)
+
+WRITE16_HANDLER( paletteram16_xbgr_word_be_sprites2_w )
+{
+	sshangha_state *state = space->machine().driver_data<sshangha_state>();
+	COMBINE_DATA(&state->m_sprite_paletteram2[offset]);
+	set_color_888(space->machine(), (offset/2)+0x100, 0, 8, 16, state->m_sprite_paletteram2[(offset) | 1] | (state->m_sprite_paletteram2[(offset) & ~1] << 16) );
+}
+
+WRITE16_HANDLER( paletteram16_xbgr_word_be_sprites_w )
+{
+	// hack??? we have to call this otherwise the sprite colours for some selected tiles are wrong (most noticable on the 2nd level of quest mode)
+	// however if we simply mirror the memory both ways the how to play screen ends up with bad colours
+	// we use the 2nd copy of palette ram for low priority tiles only..
+	// is this related to the bootleg only, or does the original have this issue too?
+	// maybe related to sprite DMA on the original, or the apparent lack of a 2nd sprite controller on the bootleg.
+	paletteram16_xbgr_word_be_sprites2_w(space,offset,data,mem_mask);
+
+	sshangha_state *state = space->machine().driver_data<sshangha_state>();
+	COMBINE_DATA(&state->m_sprite_paletteram[offset]);
+	set_color_888(space->machine(), (offset/2)+0x000, 0, 8, 16, state->m_sprite_paletteram[(offset) | 1] | (state->m_sprite_paletteram[(offset) & ~1] << 16) );
+}
+
+WRITE16_HANDLER( paletteram16_xbgr_word_be_tilelow_w )
+{
+	sshangha_state *state = space->machine().driver_data<sshangha_state>();
+	COMBINE_DATA(&state->m_tile_paletteram1[offset]);
+	set_color_888(space->machine(), (offset/2)+0x200, 0, 8, 16, state->m_tile_paletteram1[(offset) | 1] | (state->m_tile_paletteram1[(offset) & ~1] << 16) );
+}
+
+WRITE16_HANDLER( paletteram16_xbgr_word_be_tilehigh_w )
+{
+	sshangha_state *state = space->machine().driver_data<sshangha_state>();
+	COMBINE_DATA(&state->m_tile_paletteram2[offset]);
+	set_color_888(space->machine(), (offset/2)+0x300, 0, 8, 16, state->m_tile_paletteram2[(offset) | 1] | (state->m_tile_paletteram2[(offset) & ~1] << 16) );
+}
+
+static ADDRESS_MAP_START( sshangha_map, AS_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x03ffff) AM_ROM
+	AM_RANGE(0x100000, 0x10000f) AM_RAM AM_BASE_MEMBER(sshangha_state, m_sound_shared_ram)
+
+	AM_RANGE(0x200000, 0x201fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_r, deco16ic_pf1_data_w)
+	AM_RANGE(0x202000, 0x203fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf2_data_r, deco16ic_pf2_data_w)
+	AM_RANGE(0x204000, 0x2047ff) AM_RAM AM_BASE_MEMBER(sshangha_state, m_pf1_rowscroll)
+	AM_RANGE(0x206000, 0x2067ff) AM_RAM AM_BASE_MEMBER(sshangha_state, m_pf2_rowscroll)
 	AM_RANGE(0x206800, 0x207fff) AM_RAM
-	AM_RANGE(0x300000, 0x30000f) AM_WRITE(sshangha_control_0_w)
+	AM_RANGE(0x300000, 0x30000f) AM_DEVWRITE("tilegen1", deco16ic_pf_control_w)
 	AM_RANGE(0x320000, 0x320001) AM_WRITE(sshangha_video_w)
 	AM_RANGE(0x320002, 0x320005) AM_WRITENOP
 	AM_RANGE(0x320006, 0x320007) AM_READNOP //irq ack
@@ -149,35 +179,41 @@ static ADDRESS_MAP_START( sshangha_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x360000, 0x360fff) AM_RAM AM_BASE_GENERIC(spriteram2)
 	AM_RANGE(0x370000, 0x370001) AM_READ(deco_71_r)
 	AM_RANGE(0x370000, 0x370007) AM_WRITENOP
-	AM_RANGE(0x380000, 0x383fff) AM_RAM_WRITE(paletteram16_xbgr_word_be_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0x3c0000, 0x3c0fff) AM_RAM	/* Sprite ram buffer on bootleg only?? */
+
+	AM_RANGE(0x380000, 0x3803ff) AM_RAM_WRITE(paletteram16_xbgr_word_be_sprites_w) AM_BASE_MEMBER(sshangha_state, m_sprite_paletteram)
+	AM_RANGE(0x380400, 0x3807ff) AM_RAM_WRITE(paletteram16_xbgr_word_be_tilehigh_w) AM_BASE_MEMBER(sshangha_state, m_tile_paletteram2)
+	AM_RANGE(0x380800, 0x380bff) AM_RAM_WRITE(paletteram16_xbgr_word_be_sprites2_w) AM_BASE_MEMBER(sshangha_state, m_sprite_paletteram2)
+	AM_RANGE(0x380c00, 0x380fff) AM_RAM_WRITE(paletteram16_xbgr_word_be_tilelow_w) AM_BASE_MEMBER(sshangha_state, m_tile_paletteram1)
+	AM_RANGE(0x381000, 0x383fff) AM_RAM // unused palette area
+
 	AM_RANGE(0xfec000, 0xff3fff) AM_RAM
-	AM_RANGE(0xff4000, 0xff47ff) AM_READWRITE(sshangha_protection16_r,sshangha_protection16_w) AM_BASE(&sshangha_prot_data)
+	AM_RANGE(0xff4000, 0xff47ff) AM_READWRITE(sshangha_protection16_r,sshangha_protection16_w) AM_BASE_MEMBER(sshangha_state, m_prot_data)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sshanghb_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( sshanghb_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
 	AM_RANGE(0x084000, 0x0847ff) AM_READ(sshanghb_protection16_r)
-	AM_RANGE(0x101000, 0x10100f) AM_RAM AM_BASE(&sshangha_sound_shared_ram) /* the bootleg writes here */
+	AM_RANGE(0x101000, 0x10100f) AM_RAM AM_BASE_MEMBER(sshangha_state, m_sound_shared_ram) /* the bootleg writes here */
 
-	AM_RANGE(0x200000, 0x201fff) AM_RAM_WRITE(sshangha_pf1_data_w) AM_BASE(&sshangha_pf1_data)
-	AM_RANGE(0x202000, 0x203fff) AM_RAM_WRITE(sshangha_pf2_data_w) AM_BASE(&sshangha_pf2_data)
-	AM_RANGE(0x204000, 0x2047ff) AM_RAM AM_BASE(&sshangha_pf1_rowscroll)
-	AM_RANGE(0x206000, 0x2067ff) AM_RAM AM_BASE(&sshangha_pf2_rowscroll)
+	AM_RANGE(0x200000, 0x201fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf1_data_r, deco16ic_pf1_data_w)
+	AM_RANGE(0x202000, 0x203fff) AM_DEVREADWRITE("tilegen1", deco16ic_pf2_data_r, deco16ic_pf2_data_w)
+	AM_RANGE(0x204000, 0x2047ff) AM_RAM AM_BASE_MEMBER(sshangha_state, m_pf1_rowscroll)
+	AM_RANGE(0x206000, 0x2067ff) AM_RAM AM_BASE_MEMBER(sshangha_state, m_pf2_rowscroll)
 	AM_RANGE(0x206800, 0x207fff) AM_RAM
-	AM_RANGE(0x300000, 0x30000f) AM_WRITE(sshangha_control_0_w)
+	AM_RANGE(0x300000, 0x30000f) AM_DEVWRITE("tilegen1", deco16ic_pf_control_w)
 	AM_RANGE(0x320000, 0x320001) AM_WRITE(sshangha_video_w)
 	AM_RANGE(0x320002, 0x320005) AM_WRITENOP
 	AM_RANGE(0x320006, 0x320007) AM_READNOP //irq ack
 
-	AM_RANGE(0x340000, 0x340fff) AM_RAM AM_BASE_GENERIC(spriteram)
-	AM_RANGE(0x350000, 0x350001) AM_READ(deco_71_r)
-	AM_RANGE(0x350000, 0x350007) AM_WRITENOP
-	AM_RANGE(0x360000, 0x360fff) AM_RAM AM_BASE_GENERIC(spriteram2)
-	AM_RANGE(0x370000, 0x370001) AM_READ(deco_71_r)
-	AM_RANGE(0x370000, 0x370007) AM_WRITENOP
-	AM_RANGE(0x380000, 0x383fff) AM_RAM_WRITE(paletteram16_xbgr_word_be_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0x3c0000, 0x3c0fff) AM_RAM	/* Sprite ram buffer on bootleg only?? */
+	AM_RANGE(0x340000, 0x340fff) AM_RAM // original spriteram
+
+	AM_RANGE(0x380000, 0x3803ff) AM_RAM_WRITE(paletteram16_xbgr_word_be_sprites_w) AM_BASE_MEMBER(sshangha_state, m_sprite_paletteram)
+	AM_RANGE(0x380400, 0x3807ff) AM_RAM_WRITE(paletteram16_xbgr_word_be_tilehigh_w) AM_BASE_MEMBER(sshangha_state, m_tile_paletteram2)
+	AM_RANGE(0x380800, 0x380bff) AM_RAM_WRITE(paletteram16_xbgr_word_be_sprites2_w) AM_BASE_MEMBER(sshangha_state, m_sprite_paletteram2)
+	AM_RANGE(0x380c00, 0x380fff) AM_RAM_WRITE(paletteram16_xbgr_word_be_tilelow_w) AM_BASE_MEMBER(sshangha_state, m_tile_paletteram1)
+	AM_RANGE(0x381000, 0x383fff) AM_RAM // unused palette area
+
+	AM_RANGE(0x3c0000, 0x3c0fff) AM_RAM AM_BASE_GENERIC(spriteram) // bootleg spriteram
 	AM_RANGE(0xfec000, 0xff3fff) AM_RAM
 	AM_RANGE(0xff4000, 0xff47ff) AM_RAM
 ADDRESS_MAP_END
@@ -188,16 +224,18 @@ ADDRESS_MAP_END
 
 static READ8_HANDLER(sshangha_sound_shared_r)
 {
-	return sshangha_sound_shared_ram[offset] & 0xff;
+	sshangha_state *state = space->machine().driver_data<sshangha_state>();
+	return state->m_sound_shared_ram[offset] & 0xff;
 }
 
 static WRITE8_HANDLER(sshangha_sound_shared_w)
 {
-	sshangha_sound_shared_ram[offset] = data & 0xff;
+	sshangha_state *state = space->machine().driver_data<sshangha_state>();
+	state->m_sound_shared_ram[offset] = data & 0xff;
 }
 
 /* Note: there's rom data after 0x8000 but the game never seem to call a rom bank, left-over? */
-static ADDRESS_MAP_START( sshangha_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sshangha_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0xc000, 0xc001) AM_DEVREADWRITE("ymsnd", ym2203_r,ym2203_w)
 	AM_RANGE(0xc200, 0xc201) AM_DEVREADWRITE_MODERN("oki", okim6295_device, read, write)
@@ -320,16 +358,16 @@ static const gfx_layout tilelayout =
 };
 
 static GFXDECODE_START( sshangha )
-	GFXDECODE_ENTRY( "gfx1", 0, charlayout,  256, 64 ) /* Characters 8x8 */
-	GFXDECODE_ENTRY( "gfx1", 0, tilelayout,  256, 64 ) /* Tiles 16x16 */
-	GFXDECODE_ENTRY( "gfx2", 0, tilelayout,    0, 32 ) /* Sprites 16x16 */
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout,  0x200, 64 ) /* Characters 8x8 */
+	GFXDECODE_ENTRY( "gfx1", 0, tilelayout,  0x200, 64 ) /* Tiles 16x16 */
+	GFXDECODE_ENTRY( "gfx2", 0, tilelayout,    0, 64 ) /* Sprites 16x16 */
 GFXDECODE_END
 
 /******************************************************************************/
 
 static void irqhandler(device_t *device, int state)
 {
-	cputag_set_input_line(device->machine, "audiocpu", 0, state);
+	cputag_set_input_line(device->machine(), "audiocpu", 0, state);
 }
 
 static const ym2203_interface ym2203_config =
@@ -342,7 +380,26 @@ static const ym2203_interface ym2203_config =
 	irqhandler
 };
 
-static MACHINE_CONFIG_START( sshangha, driver_device )
+static int sshangha_bank_callback( int bank )
+{
+	bank = bank >> 4;
+	return bank * 0x1000;
+}
+
+static const deco16ic_interface sshangha_deco16ic_tilegen1_intf =
+{
+	"screen",
+	0, 1,
+	0x0f, 0x0f,	/* trans masks (default values) */
+	0x10, 0x00, /* color base */
+	0x0f, 0x0f,	/* color masks (default values) */
+	sshangha_bank_callback,
+	sshangha_bank_callback,
+	0,1
+};
+
+
+static MACHINE_CONFIG_START( sshangha, sshangha_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M68000, 28000000/2)
@@ -352,25 +409,31 @@ static MACHINE_CONFIG_START( sshangha, driver_device )
 	MCFG_CPU_ADD("audiocpu", Z80, 16000000/4)
 	MCFG_CPU_PROGRAM_MAP(sshangha_sound_map)
 
-	MCFG_QUANTUM_TIME(HZ(6000))
+	MCFG_QUANTUM_TIME(attotime::from_hz(6000))
 
 	MCFG_MACHINE_RESET(sshangha)	/* init machine */
 
-	/* video hardware */
-	/*MCFG_VIDEO_ATTRIBUTES(VIDEO_BUFFERS_SPRITERAM)*/
-
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(529))
-	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_UPDATE(sshangha)
 
 	MCFG_GFXDECODE(sshangha)
-	MCFG_PALETTE_LENGTH(4096)
+	MCFG_PALETTE_LENGTH(0x4000)
+
+	MCFG_DECO16IC_ADD("tilegen1", sshangha_deco16ic_tilegen1_intf)
+
+	MCFG_DEVICE_ADD("spritegen1", DECO_SPRITE, 0)
+	decospr_device::set_gfx_region(*device, 2);
+
+	MCFG_DEVICE_ADD("spritegen2", DECO_SPRITE, 0)
+	decospr_device::set_gfx_region(*device, 2);
+
 
 	MCFG_VIDEO_START(sshangha)
-	MCFG_VIDEO_UPDATE(sshangha)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_STEREO("lspeaker", "rspeaker") /* sure it's stereo? */
@@ -439,7 +502,7 @@ static DRIVER_INIT( sshangha )
 #if SSHANGHA_HACK
 	/* This is a hack to allow you to use the extra features
          of the first "Unused" Dip Switch (see notes above). */
-	UINT16 *RAM = (UINT16 *)machine->region("maincpu")->base();
+	UINT16 *RAM = (UINT16 *)machine.region("maincpu")->base();
 	RAM[0x000384/2] = 0x4e71;
 	RAM[0x000386/2] = 0x4e71;
 	RAM[0x000388/2] = 0x4e71;
