@@ -19,21 +19,21 @@
 
 static WRITE16_HANDLER( sound_command_w )
 {
-	tail2nos_state *state = space->machine->driver_data<tail2nos_state>();
+	tail2nos_state *state = space->machine().driver_data<tail2nos_state>();
 
 	if (ACCESSING_BITS_0_7)
 	{
 		soundlatch_w(space, offset, data & 0xff);
-		cpu_set_input_line(state->audiocpu, INPUT_LINE_NMI, PULSE_LINE);
+		device_set_input_line(state->m_audiocpu, INPUT_LINE_NMI, PULSE_LINE);
 	}
 }
 
 static WRITE8_DEVICE_HANDLER( sound_bankswitch_w )
 {
-	memory_set_bank(device->machine, "bank3", data & 0x01);
+	memory_set_bank(device->machine(), "bank3", data & 0x01);
 }
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
 	AM_RANGE(0x200000, 0x27ffff) AM_ROMBANK("bank1")	/* extra ROM */
 	AM_RANGE(0x2c0000, 0x2dffff) AM_ROMBANK("bank2")
@@ -41,22 +41,22 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x500000, 0x500fff) AM_DEVREADWRITE8("k051316", k051316_r, k051316_w, 0x00ff)
 	AM_RANGE(0x510000, 0x51001f) AM_DEVWRITE8("k051316", k051316_ctrl_w, 0x00ff)
 	AM_RANGE(0xff8000, 0xffbfff) AM_RAM								/* work RAM */
-	AM_RANGE(0xffc000, 0xffc2ff) AM_RAM AM_BASE_SIZE_MEMBER(tail2nos_state, spriteram, spriteram_size)
+	AM_RANGE(0xffc000, 0xffc2ff) AM_RAM AM_BASE_SIZE_MEMBER(tail2nos_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0xffc300, 0xffcfff) AM_RAM
-	AM_RANGE(0xffd000, 0xffdfff) AM_RAM_WRITE(tail2nos_bgvideoram_w) AM_BASE_MEMBER(tail2nos_state, bgvideoram)
+	AM_RANGE(0xffd000, 0xffdfff) AM_RAM_WRITE(tail2nos_bgvideoram_w) AM_BASE_MEMBER(tail2nos_state, m_bgvideoram)
 	AM_RANGE(0xffe000, 0xffefff) AM_RAM_WRITE(paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0xfff000, 0xfff001) AM_READ_PORT("INPUTS") AM_WRITE(tail2nos_gfxbank_w)
 	AM_RANGE(0xfff004, 0xfff005) AM_READ_PORT("DSW")
 	AM_RANGE(0xfff008, 0xfff009) AM_WRITE(sound_command_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x77ff) AM_ROM
 	AM_RANGE(0x7800, 0x7fff) AM_RAM
 	AM_RANGE(0x8000, 0xffff) AM_ROMBANK("bank3")
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_port_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( sound_port_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x07, 0x07) AM_READ(soundlatch_r) AM_WRITENOP	/* the write is a clear pending command */
 	AM_RANGE(0x08, 0x0b) AM_DEVWRITE("ymsnd", ym2608_w)
@@ -180,8 +180,8 @@ GFXDECODE_END
 
 static void irqhandler( device_t *device, int irq )
 {
-	tail2nos_state *state = device->machine->driver_data<tail2nos_state>();
-	cpu_set_input_line(state->audiocpu, 0, irq ? ASSERT_LINE : CLEAR_LINE);
+	tail2nos_state *state = device->machine().driver_data<tail2nos_state>();
+	device_set_input_line(state->m_audiocpu, 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static const ym2608_interface ym2608_config =
@@ -208,32 +208,32 @@ static const k051316_interface tail2nos_k051316_intf =
 
 static MACHINE_START( tail2nos )
 {
-	tail2nos_state *state = machine->driver_data<tail2nos_state>();
-	UINT8 *ROM = machine->region("audiocpu")->base();
+	tail2nos_state *state = machine.driver_data<tail2nos_state>();
+	UINT8 *ROM = machine.region("audiocpu")->base();
 
 	memory_configure_bank(machine, "bank3", 0, 2, &ROM[0x10000], 0x8000);
 	memory_set_bank(machine, "bank3", 0);
 
-	state->maincpu = machine->device("maincpu");
-	state->audiocpu = machine->device("audiocpu");
-	state->k051316 = machine->device("k051316");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_audiocpu = machine.device("audiocpu");
+	state->m_k051316 = machine.device("k051316");
 
-	state_save_register_global(machine, state->charbank);
-	state_save_register_global(machine, state->charpalette);
-	state_save_register_global(machine, state->video_enable);
+	state->save_item(NAME(state->m_charbank));
+	state->save_item(NAME(state->m_charpalette));
+	state->save_item(NAME(state->m_video_enable));
 }
 
 static MACHINE_RESET( tail2nos )
 {
-	tail2nos_state *state = machine->driver_data<tail2nos_state>();
+	tail2nos_state *state = machine.driver_data<tail2nos_state>();
 
 	/* point to the extra ROMs */
-	memory_set_bankptr(machine, "bank1", machine->region("user1")->base());
-	memory_set_bankptr(machine, "bank2", machine->region("user2")->base());
+	memory_set_bankptr(machine, "bank1", machine.region("user1")->base());
+	memory_set_bankptr(machine, "bank2", machine.region("user2")->base());
 
-	state->charbank = 0;
-	state->charpalette = 0;
-	state->video_enable = 0;
+	state->m_charbank = 0;
+	state->m_charpalette = 0;
+	state->m_video_enable = 0;
 }
 
 static MACHINE_CONFIG_START( tail2nos, tail2nos_state )
@@ -257,12 +257,12 @@ static MACHINE_CONFIG_START( tail2nos, tail2nos_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
+	MCFG_SCREEN_UPDATE(tail2nos)
 
 	MCFG_GFXDECODE(tail2nos)
 	MCFG_PALETTE_LENGTH(2048)
 
 	MCFG_VIDEO_START(tail2nos)
-	MCFG_VIDEO_UPDATE(tail2nos)
 
 	MCFG_K051316_ADD("k051316", tail2nos_k051316_intf)
 
