@@ -17,19 +17,31 @@
 #include "machine/pckeybrd.h"
 #include "machine/idectrl.h"
 
+
+class taitowlf_state : public driver_device
+{
+public:
+	taitowlf_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT32 *m_cga_ram;
+	UINT32 *m_bios_ram;
+	UINT8 m_mxtc_config_reg[256];
+	UINT8 m_piix4_config_reg[4][256];
+	int m_dma_channel;
+	UINT8 m_dma_offset[2][4];
+	UINT8 m_at_pages[0x10];
+
+	device_t	*m_pit8254;
+	device_t	*m_pic8259_1;
+	device_t	*m_pic8259_2;
+	device_t	*m_dma8237_1;
+	device_t	*m_dma8237_2;
+};
+
+
 static void ide_interrupt(device_t *device, int state);
 
-static UINT32 *cga_ram;
-static UINT32 *bios_ram;
-
-static struct {
-	device_t	*pit8254;
-	device_t	*pic8259_1;
-	device_t	*pic8259_2;
-	device_t	*dma8237_1;
-	device_t	*dma8237_2;
-} taitowlf_devices;
-
 
 static const rgb_t cga_palette[16] =
 {
@@ -69,11 +81,12 @@ static void draw_char(bitmap_t *bitmap, const rectangle *cliprect, const gfx_ele
 	}
 }
 
-static VIDEO_UPDATE(taitowlf)
+static SCREEN_UPDATE(taitowlf)
 {
+	taitowlf_state *state = screen->machine().driver_data<taitowlf_state>();
 	int i, j;
-	const gfx_element *gfx = screen->machine->gfx[0];
-	UINT32 *cga = cga_ram;
+	const gfx_element *gfx = screen->machine().gfx[0];
+	UINT32 *cga = state->m_cga_ram;
 	int index = 0;
 
 	bitmap_fill(bitmap, cliprect, 0);
@@ -118,18 +131,19 @@ static WRITE32_DEVICE_HANDLER(at32_dma8237_2_w)
 
 
 // Intel 82439TX System Controller (MXTC)
-static UINT8 mxtc_config_reg[256];
 
 static UINT8 mxtc_config_r(device_t *busdevice, device_t *device, int function, int reg)
 {
+	taitowlf_state *state = busdevice->machine().driver_data<taitowlf_state>();
 //  mame_printf_debug("MXTC: read %d, %02X\n", function, reg);
 
-	return mxtc_config_reg[reg];
+	return state->m_mxtc_config_reg[reg];
 }
 
 static void mxtc_config_w(device_t *busdevice, device_t *device, int function, int reg, UINT8 data)
 {
-//  mame_printf_debug("%s:MXTC: write %d, %02X, %02X\n", cpuexec_describe_context(machine), function, reg, data);
+	taitowlf_state *state = busdevice->machine().driver_data<taitowlf_state>();
+//  mame_printf_debug("%s:MXTC: write %d, %02X, %02X\n", machine.describe_context(), function, reg, data);
 
 	switch(reg)
 	{
@@ -137,27 +151,28 @@ static void mxtc_config_w(device_t *busdevice, device_t *device, int function, i
 		{
 			if (data & 0x10)		// enable RAM access to region 0xf0000 - 0xfffff
 			{
-				memory_set_bankptr(busdevice->machine, "bank1", bios_ram);
+				memory_set_bankptr(busdevice->machine(), "bank1", state->m_bios_ram);
 			}
 			else					// disable RAM access (reads go to BIOS ROM)
 			{
-				memory_set_bankptr(busdevice->machine, "bank1", busdevice->machine->region("user1")->base() + 0x30000);
+				memory_set_bankptr(busdevice->machine(), "bank1", busdevice->machine().region("user1")->base() + 0x30000);
 			}
 			break;
 		}
 	}
 
-	mxtc_config_reg[reg] = data;
+	state->m_mxtc_config_reg[reg] = data;
 }
 
-static void intel82439tx_init(void)
+static void intel82439tx_init(running_machine &machine)
 {
-	mxtc_config_reg[0x60] = 0x02;
-	mxtc_config_reg[0x61] = 0x02;
-	mxtc_config_reg[0x62] = 0x02;
-	mxtc_config_reg[0x63] = 0x02;
-	mxtc_config_reg[0x64] = 0x02;
-	mxtc_config_reg[0x65] = 0x02;
+	taitowlf_state *state = machine.driver_data<taitowlf_state>();
+	state->m_mxtc_config_reg[0x60] = 0x02;
+	state->m_mxtc_config_reg[0x61] = 0x02;
+	state->m_mxtc_config_reg[0x62] = 0x02;
+	state->m_mxtc_config_reg[0x63] = 0x02;
+	state->m_mxtc_config_reg[0x64] = 0x02;
+	state->m_mxtc_config_reg[0x65] = 0x02;
 }
 
 static UINT32 intel82439tx_pci_r(device_t *busdevice, device_t *device, int function, int reg, UINT32 mem_mask)
@@ -203,18 +218,19 @@ static void intel82439tx_pci_w(device_t *busdevice, device_t *device, int functi
 }
 
 // Intel 82371AB PCI-to-ISA / IDE bridge (PIIX4)
-static UINT8 piix4_config_reg[4][256];
 
 static UINT8 piix4_config_r(device_t *busdevice, device_t *device, int function, int reg)
 {
+	taitowlf_state *state = busdevice->machine().driver_data<taitowlf_state>();
 //  mame_printf_debug("PIIX4: read %d, %02X\n", function, reg);
-	return piix4_config_reg[function][reg];
+	return state->m_piix4_config_reg[function][reg];
 }
 
 static void piix4_config_w(device_t *busdevice, device_t *device, int function, int reg, UINT8 data)
 {
-//  mame_printf_debug("%s:PIIX4: write %d, %02X, %02X\n", cpuexec_describe_context(machine), function, reg, data);
-	piix4_config_reg[function][reg] = data;
+	taitowlf_state *state = busdevice->machine().driver_data<taitowlf_state>();
+//  mame_printf_debug("%s:PIIX4: write %d, %02X, %02X\n", machine.describe_context(), function, reg, data);
+	state->m_piix4_config_reg[function][reg] = data;
 }
 
 static UINT32 intel82371ab_pci_r(device_t *busdevice, device_t *device, int function, int reg, UINT32 mem_mask)
@@ -303,9 +319,10 @@ static WRITE32_DEVICE_HANDLER( fdc_w )
 
 static WRITE32_HANDLER(bios_ram_w)
 {
-	if (mxtc_config_reg[0x59] & 0x20)		// write to RAM if this region is write-enabled
+	taitowlf_state *state = space->machine().driver_data<taitowlf_state>();
+	if (state->m_mxtc_config_reg[0x59] & 0x20)		// write to RAM if this region is write-enabled
 	{
-		COMBINE_DATA(bios_ram + offset);
+		COMBINE_DATA(state->m_bios_ram + offset);
 	}
 }
 
@@ -316,28 +333,26 @@ static WRITE32_HANDLER(bios_ram_w)
  *
  *************************************************************************/
 
-static int dma_channel;
-static UINT8 dma_offset[2][4];
-static UINT8 at_pages[0x10];
 
 
 static READ8_HANDLER(at_page8_r)
 {
-	UINT8 data = at_pages[offset % 0x10];
+	taitowlf_state *state = space->machine().driver_data<taitowlf_state>();
+	UINT8 data = state->m_at_pages[offset % 0x10];
 
 	switch(offset % 8)
 	{
 	case 1:
-		data = dma_offset[(offset / 8) & 1][2];
+		data = state->m_dma_offset[(offset / 8) & 1][2];
 		break;
 	case 2:
-		data = dma_offset[(offset / 8) & 1][3];
+		data = state->m_dma_offset[(offset / 8) & 1][3];
 		break;
 	case 3:
-		data = dma_offset[(offset / 8) & 1][1];
+		data = state->m_dma_offset[(offset / 8) & 1][1];
 		break;
 	case 7:
-		data = dma_offset[(offset / 8) & 1][0];
+		data = state->m_dma_offset[(offset / 8) & 1][0];
 		break;
 	}
 	return data;
@@ -346,21 +361,22 @@ static READ8_HANDLER(at_page8_r)
 
 static WRITE8_HANDLER(at_page8_w)
 {
-	at_pages[offset % 0x10] = data;
+	taitowlf_state *state = space->machine().driver_data<taitowlf_state>();
+	state->m_at_pages[offset % 0x10] = data;
 
 	switch(offset % 8)
 	{
 	case 1:
-		dma_offset[(offset / 8) & 1][2] = data;
+		state->m_dma_offset[(offset / 8) & 1][2] = data;
 		break;
 	case 2:
-		dma_offset[(offset / 8) & 1][3] = data;
+		state->m_dma_offset[(offset / 8) & 1][3] = data;
 		break;
 	case 3:
-		dma_offset[(offset / 8) & 1][1] = data;
+		state->m_dma_offset[(offset / 8) & 1][1] = data;
 		break;
 	case 7:
-		dma_offset[(offset / 8) & 1][0] = data;
+		state->m_dma_offset[(offset / 8) & 1][0] = data;
 		break;
 	}
 }
@@ -368,7 +384,7 @@ static WRITE8_HANDLER(at_page8_w)
 
 static WRITE_LINE_DEVICE_HANDLER( pc_dma_hrq_changed )
 {
-	cputag_set_input_line(device->machine, "maincpu", INPUT_LINE_HALT, state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine(), "maincpu", INPUT_LINE_HALT, state ? ASSERT_LINE : CLEAR_LINE);
 
 	/* Assert HLDA */
 	i8237_hlda_w( device, state );
@@ -377,7 +393,8 @@ static WRITE_LINE_DEVICE_HANDLER( pc_dma_hrq_changed )
 
 static READ8_HANDLER( pc_dma_read_byte )
 {
-	offs_t page_offset = (((offs_t) dma_offset[0][dma_channel]) << 16)
+	taitowlf_state *state = space->machine().driver_data<taitowlf_state>();
+	offs_t page_offset = (((offs_t) state->m_dma_offset[0][state->m_dma_channel]) << 16)
 		& 0xFF0000;
 
 	return space->read_byte(page_offset + offset);
@@ -386,17 +403,37 @@ static READ8_HANDLER( pc_dma_read_byte )
 
 static WRITE8_HANDLER( pc_dma_write_byte )
 {
-	offs_t page_offset = (((offs_t) dma_offset[0][dma_channel]) << 16)
+	taitowlf_state *state = space->machine().driver_data<taitowlf_state>();
+	offs_t page_offset = (((offs_t) state->m_dma_offset[0][state->m_dma_channel]) << 16)
 		& 0xFF0000;
 
 	space->write_byte(page_offset + offset, data);
 }
 
 
-static WRITE_LINE_DEVICE_HANDLER( pc_dack0_w ) { if (state) dma_channel = 0; }
-static WRITE_LINE_DEVICE_HANDLER( pc_dack1_w ) { if (state) dma_channel = 1; }
-static WRITE_LINE_DEVICE_HANDLER( pc_dack2_w ) { if (state) dma_channel = 2; }
-static WRITE_LINE_DEVICE_HANDLER( pc_dack3_w ) { if (state) dma_channel = 3; }
+static WRITE_LINE_DEVICE_HANDLER( pc_dack0_w )
+{
+	taitowlf_state *drvstate = device->machine().driver_data<taitowlf_state>();
+	if (state) drvstate->m_dma_channel = 0;
+}
+
+static WRITE_LINE_DEVICE_HANDLER( pc_dack1_w )
+{
+	taitowlf_state *drvstate = device->machine().driver_data<taitowlf_state>();
+	if (state) drvstate->m_dma_channel = 1;
+}
+
+static WRITE_LINE_DEVICE_HANDLER( pc_dack2_w )
+{
+	taitowlf_state *drvstate = device->machine().driver_data<taitowlf_state>();
+	if (state) drvstate->m_dma_channel = 2;
+}
+
+static WRITE_LINE_DEVICE_HANDLER( pc_dack3_w )
+{
+	taitowlf_state *drvstate = device->machine().driver_data<taitowlf_state>();
+	if (state) drvstate->m_dma_channel = 3;
+}
 
 static I8237_INTERFACE( dma8237_1_config )
 {
@@ -434,10 +471,10 @@ static WRITE32_HANDLER(at_page32_w)
 
 /*****************************************************************************/
 
-static ADDRESS_MAP_START( taitowlf_map, ADDRESS_SPACE_PROGRAM, 32 )
+static ADDRESS_MAP_START( taitowlf_map, AS_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x0009ffff) AM_RAM
 	AM_RANGE(0x000a0000, 0x000affff) AM_RAM
-	AM_RANGE(0x000b0000, 0x000b7fff) AM_RAM AM_BASE(&cga_ram)
+	AM_RANGE(0x000b0000, 0x000b7fff) AM_RAM AM_BASE_MEMBER(taitowlf_state, m_cga_ram)
 	AM_RANGE(0x000e0000, 0x000effff) AM_RAM
 	AM_RANGE(0x000f0000, 0x000fffff) AM_ROMBANK("bank1")
 	AM_RANGE(0x000f0000, 0x000fffff) AM_WRITE(bios_ram_w)
@@ -445,7 +482,7 @@ static ADDRESS_MAP_START( taitowlf_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0xfffc0000, 0xffffffff) AM_ROM AM_REGION("user1", 0)	/* System BIOS */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START(taitowlf_io, ADDRESS_SPACE_IO, 32)
+static ADDRESS_MAP_START(taitowlf_io, AS_IO, 32)
 	AM_RANGE(0x0000, 0x001f) AM_DEVREADWRITE8("dma8237_1", i8237_r, i8237_w, 0xffffffff)
 	AM_RANGE(0x0020, 0x003f) AM_DEVREADWRITE8("pic8259_1", pic8259_r, pic8259_w, 0xffffffff)
 	AM_RANGE(0x0040, 0x005f) AM_DEVREADWRITE8("pit8254", pit8253_r, pit8253_w, 0xffffffff)
@@ -489,7 +526,7 @@ static GFXDECODE_START( CGA )
 GFXDECODE_END
 
 #define AT_KEYB_HELPER(bit, text, key1) \
-	PORT_BIT( bit, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME(text) PORT_CODE(key1)
+	PORT_BIT( bit, IP_ACTIVE_HIGH, IPT_KEYPAD) PORT_NAME(text) PORT_CODE(key1)
 
 static INPUT_PORTS_START(taitowlf)
 	PORT_START("pc_keyboard_0")
@@ -524,29 +561,25 @@ INPUT_PORTS_END
 
 static IRQ_CALLBACK(irq_callback)
 {
-	int r = 0;
-	r = pic8259_acknowledge( taitowlf_devices.pic8259_2);
-	if (r==0)
-	{
-		r = pic8259_acknowledge( taitowlf_devices.pic8259_1);
-	}
-	return r;
+	taitowlf_state *state = device->machine().driver_data<taitowlf_state>();
+	return pic8259_acknowledge( state->m_pic8259_1);
 }
 
 static MACHINE_START(taitowlf)
 {
-	cpu_set_irq_callback(machine->device("maincpu"), irq_callback);
+	taitowlf_state *state = machine.driver_data<taitowlf_state>();
+	device_set_irq_callback(machine.device("maincpu"), irq_callback);
 
-	taitowlf_devices.pit8254 = machine->device( "pit8254" );
-	taitowlf_devices.pic8259_1 = machine->device( "pic8259_1" );
-	taitowlf_devices.pic8259_2 = machine->device( "pic8259_2" );
-	taitowlf_devices.dma8237_1 = machine->device( "dma8237_1" );
-	taitowlf_devices.dma8237_2 = machine->device( "dma8237_2" );
+	state->m_pit8254 = machine.device( "pit8254" );
+	state->m_pic8259_1 = machine.device( "pic8259_1" );
+	state->m_pic8259_2 = machine.device( "pic8259_2" );
+	state->m_dma8237_1 = machine.device( "dma8237_1" );
+	state->m_dma8237_2 = machine.device( "dma8237_2" );
 }
 
 static MACHINE_RESET(taitowlf)
 {
-	memory_set_bankptr(machine, "bank1", machine->region("user1")->base() + 0x30000);
+	memory_set_bankptr(machine, "bank1", machine.region("user1")->base() + 0x30000);
 }
 
 
@@ -558,17 +591,30 @@ static MACHINE_RESET(taitowlf)
 
 static WRITE_LINE_DEVICE_HANDLER( taitowlf_pic8259_1_set_int_line )
 {
-	cputag_set_input_line(device->machine, "maincpu", 0, state ? HOLD_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine(), "maincpu", 0, state ? HOLD_LINE : CLEAR_LINE);
+}
+
+static READ8_DEVICE_HANDLER( get_slave_ack )
+{
+	taitowlf_state *state = device->machine().driver_data<taitowlf_state>();
+	if (offset==2) { // IRQ = 2
+		return pic8259_acknowledge(state->m_pic8259_2);
+	}
+	return 0x00;
 }
 
 static const struct pic8259_interface taitowlf_pic8259_1_config =
 {
-	DEVCB_LINE(taitowlf_pic8259_1_set_int_line)
+	DEVCB_LINE(taitowlf_pic8259_1_set_int_line),
+	DEVCB_LINE_VCC,
+	DEVCB_HANDLER(get_slave_ack)
 };
 
 static const struct pic8259_interface taitowlf_pic8259_2_config =
 {
-	DEVCB_DEVICE_LINE("pic8259_1", pic8259_ir2_w)
+	DEVCB_DEVICE_LINE("pic8259_1", pic8259_ir2_w),
+	DEVCB_LINE_GND,
+	DEVCB_NULL
 };
 
 
@@ -597,7 +643,7 @@ static const struct pit8253_config taitowlf_pit8254_config =
 	}
 };
 
-static MACHINE_CONFIG_START( taitowlf, driver_device )
+static MACHINE_CONFIG_START( taitowlf, taitowlf_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", PENTIUM, 200000000)
@@ -612,17 +658,11 @@ static MACHINE_CONFIG_START( taitowlf, driver_device )
 	MCFG_PCI_BUS_DEVICE(7, NULL, intel82371ab_pci_r, intel82371ab_pci_w)
 
 	MCFG_PIT8254_ADD( "pit8254", taitowlf_pit8254_config )
-
 	MCFG_I8237_ADD( "dma8237_1", XTAL_14_31818MHz/3, dma8237_1_config )
-
 	MCFG_I8237_ADD( "dma8237_2", XTAL_14_31818MHz/3, dma8237_2_config )
-
 	MCFG_PIC8259_ADD( "pic8259_1", taitowlf_pic8259_1_config )
-
 	MCFG_PIC8259_ADD( "pic8259_2", taitowlf_pic8259_2_config )
-
 	MCFG_IDE_CONTROLLER_ADD("ide", ide_interrupt)
-
 	MCFG_MC146818_ADD( "rtc", MC146818_STANDARD )
 
 	/* video hardware */
@@ -632,33 +672,35 @@ static MACHINE_CONFIG_START( taitowlf, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(640, 480)
 	MCFG_SCREEN_VISIBLE_AREA(0, 639, 0, 199)
+	MCFG_SCREEN_UPDATE(taitowlf)
 
 	MCFG_GFXDECODE(CGA)
 	MCFG_PALETTE_LENGTH(16)
 
 	MCFG_VIDEO_START(taitowlf)
-	MCFG_VIDEO_UPDATE(taitowlf)
-
 MACHINE_CONFIG_END
 
-static void set_gate_a20(running_machine *machine, int a20)
+static void set_gate_a20(running_machine &machine, int a20)
 {
 	cputag_set_input_line(machine, "maincpu", INPUT_LINE_A20, a20);
 }
 
-static void keyboard_interrupt(running_machine *machine, int state)
+static void keyboard_interrupt(running_machine &machine, int state)
 {
-	pic8259_ir1_w(taitowlf_devices.pic8259_1, state);
+	taitowlf_state *drvstate = machine.driver_data<taitowlf_state>();
+	pic8259_ir1_w(drvstate->m_pic8259_1, state);
 }
 
 static void ide_interrupt(device_t *device, int state)
 {
-	pic8259_ir6_w(taitowlf_devices.pic8259_2, state);
+	taitowlf_state *drvstate = device->machine().driver_data<taitowlf_state>();
+	pic8259_ir6_w(drvstate->m_pic8259_2, state);
 }
 
-static int taitowlf_get_out2(running_machine *machine)
+static int taitowlf_get_out2(running_machine &machine)
 {
-	return pit8253_get_output(taitowlf_devices.pit8254, 2 );
+	taitowlf_state *state = machine.driver_data<taitowlf_state>();
+	return pit8253_get_output(state->m_pit8254, 2 );
 }
 
 static const struct kbdc8042_interface at8042 =
@@ -666,18 +708,20 @@ static const struct kbdc8042_interface at8042 =
 	KBDC8042_AT386, set_gate_a20, keyboard_interrupt, taitowlf_get_out2
 };
 
-static void taitowlf_set_keyb_int(running_machine *machine, int state)
+static void taitowlf_set_keyb_int(running_machine &machine, int state)
 {
-	pic8259_ir1_w(taitowlf_devices.pic8259_1, state);
+	taitowlf_state *drvstate = machine.driver_data<taitowlf_state>();
+	pic8259_ir1_w(drvstate->m_pic8259_1, state);
 }
 
 static DRIVER_INIT( taitowlf )
 {
-	bios_ram = auto_alloc_array(machine, UINT32, 0x10000/4);
+	taitowlf_state *state = machine.driver_data<taitowlf_state>();
+	state->m_bios_ram = auto_alloc_array(machine, UINT32, 0x10000/4);
 
 	init_pc_common(machine, PCCOMMON_KEYBOARD_AT, taitowlf_set_keyb_int);
 
-	intel82439tx_init();
+	intel82439tx_init(machine);
 
 	kbdc8042_init(machine, &at8042);
 }
