@@ -9,39 +9,42 @@ Atari Tank 8 driver
 #include "includes/tank8.h"
 #include "sound/discrete.h"
 
-static int collision_index;
 
 
-void tank8_set_collision(running_machine *machine, int index)
+void tank8_set_collision(running_machine &machine, int index)
 {
+	tank8_state *state = machine.driver_data<tank8_state>();
 	cputag_set_input_line(machine, "maincpu", 0, ASSERT_LINE);
 
-	collision_index = index;
+	state->m_collision_index = index;
 }
 
 
 static MACHINE_RESET( tank8 )
 {
-	collision_index = 0;
+	tank8_state *state = machine.driver_data<tank8_state>();
+	state->m_collision_index = 0;
 }
 
 
 static READ8_HANDLER( tank8_collision_r )
 {
-	return collision_index;
+	tank8_state *state = space->machine().driver_data<tank8_state>();
+	return state->m_collision_index;
 }
 
 static WRITE8_HANDLER( tank8_lockout_w )
 {
-	coin_lockout_w(space->machine, offset, ~data & 1);
+	coin_lockout_w(space->machine(), offset, ~data & 1);
 }
 
 
 static WRITE8_HANDLER( tank8_int_reset_w )
 {
-	collision_index &= ~0x3f;
+	tank8_state *state = space->machine().driver_data<tank8_state>();
+	state->m_collision_index &= ~0x3f;
 
-	cputag_set_input_line(space->machine, "maincpu", 0, CLEAR_LINE);
+	cputag_set_input_line(space->machine(), "maincpu", 0, CLEAR_LINE);
 }
 
 static WRITE8_DEVICE_HANDLER( tank8_crash_w )
@@ -93,7 +96,7 @@ static WRITE8_DEVICE_HANDLER( tank8_motor_w )
 	discrete_sound_w(device, NODE_RELATIVE(TANK8_MOTOR1_EN, offset), data);
 }
 
-static ADDRESS_MAP_START( tank8_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( tank8_cpu_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x00ff) AM_RAM
 	AM_RANGE(0x0400, 0x17ff) AM_ROM
 	AM_RANGE(0xf800, 0xffff) AM_ROM
@@ -113,10 +116,10 @@ static ADDRESS_MAP_START( tank8_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x1c0b, 0x1c0b) AM_READ_PORT("RC")
 	AM_RANGE(0x1c0f, 0x1c0f) AM_READ_PORT("VBLANK")
 
-	AM_RANGE(0x1800, 0x1bff) AM_WRITE(tank8_video_ram_w) AM_BASE(&tank8_video_ram)
-	AM_RANGE(0x1c00, 0x1c0f) AM_WRITEONLY AM_BASE(&tank8_pos_h_ram)
-	AM_RANGE(0x1c10, 0x1c1f) AM_WRITEONLY AM_BASE(&tank8_pos_v_ram)
-	AM_RANGE(0x1c20, 0x1c2f) AM_WRITEONLY AM_BASE(&tank8_pos_d_ram)
+	AM_RANGE(0x1800, 0x1bff) AM_WRITE(tank8_video_ram_w) AM_BASE_MEMBER(tank8_state, m_video_ram)
+	AM_RANGE(0x1c00, 0x1c0f) AM_WRITEONLY AM_BASE_MEMBER(tank8_state, m_pos_h_ram)
+	AM_RANGE(0x1c10, 0x1c1f) AM_WRITEONLY AM_BASE_MEMBER(tank8_state, m_pos_v_ram)
+	AM_RANGE(0x1c20, 0x1c2f) AM_WRITEONLY AM_BASE_MEMBER(tank8_state, m_pos_d_ram)
 
 	AM_RANGE(0x1c30, 0x1c37) AM_WRITE(tank8_lockout_w)
 	AM_RANGE(0x1d00, 0x1d00) AM_WRITE(tank8_int_reset_w)
@@ -124,7 +127,7 @@ static ADDRESS_MAP_START( tank8_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x1d02, 0x1d02) AM_DEVWRITE("discrete", tank8_explosion_w)
 	AM_RANGE(0x1d03, 0x1d03) AM_DEVWRITE("discrete", tank8_bugle_w)
 	AM_RANGE(0x1d04, 0x1d04) AM_DEVWRITE("discrete", tank8_bug_w)
-	AM_RANGE(0x1d05, 0x1d05) AM_WRITEONLY AM_BASE(&tank8_team)
+	AM_RANGE(0x1d05, 0x1d05) AM_WRITEONLY AM_BASE_MEMBER(tank8_state, m_team)
 	AM_RANGE(0x1d06, 0x1d06) AM_DEVWRITE("discrete", tank8_attract_w)
 	AM_RANGE(0x1e00, 0x1e07) AM_DEVWRITE("discrete", tank8_motor_w)
 
@@ -324,7 +327,7 @@ static GFXDECODE_START( tank8 )
 GFXDECODE_END
 
 
-static MACHINE_CONFIG_START( tank8, driver_device )
+static MACHINE_CONFIG_START( tank8, tank8_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M6800, 11055000 / 10) /* ? */
@@ -341,14 +344,14 @@ static MACHINE_CONFIG_START( tank8, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(512, 524)
 	MCFG_SCREEN_VISIBLE_AREA(16, 495, 0, 463)
+	MCFG_SCREEN_UPDATE(tank8)
+	MCFG_SCREEN_EOF(tank8)
 
 	MCFG_GFXDECODE(tank8)
 	MCFG_PALETTE_LENGTH(20)
 
 	MCFG_PALETTE_INIT(tank8)
 	MCFG_VIDEO_START(tank8)
-	MCFG_VIDEO_UPDATE(tank8)
-	MCFG_VIDEO_EOF(tank8)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -464,10 +467,10 @@ ROM_END
 
 static DRIVER_INIT( decode )
 {
-	const UINT8* DECODE = machine->region("user1")->base();
+	const UINT8* DECODE = machine.region("user1")->base();
 
-	UINT8* p1 = machine->region("maincpu")->base() + 0x00000;
-	UINT8* p2 = machine->region("maincpu")->base() + 0x10000;
+	UINT8* p1 = machine.region("maincpu")->base() + 0x00000;
+	UINT8* p2 = machine.region("maincpu")->base() + 0x10000;
 
 	int i;
 
