@@ -61,19 +61,17 @@ Known issues:
 #include "sound/samples.h"
 #include "includes/tankbatt.h"
 
-static int tankbatt_nmi_enable; /* No need to init this - the game will set it on reset */
-static int tankbatt_sound_enable;
 
 static WRITE8_HANDLER( tankbatt_led_w )
 {
-	set_led_status(space->machine, offset,data & 1);
+	set_led_status(space->machine(), offset,data & 1);
 }
 
 static READ8_HANDLER( tankbatt_in0_r )
 {
 	int val;
 
-	val = input_port_read(space->machine, "P1");
+	val = input_port_read(space->machine(), "P1");
 	return ((val << (7 - offset)) & 0x80);
 }
 
@@ -81,7 +79,7 @@ static READ8_HANDLER( tankbatt_in1_r )
 {
 	int val;
 
-	val = input_port_read(space->machine, "P2");
+	val = input_port_read(space->machine(), "P2");
 	return ((val << (7 - offset)) & 0x80);
 }
 
@@ -89,39 +87,43 @@ static READ8_HANDLER( tankbatt_dsw_r )
 {
 	int val;
 
-	val = input_port_read(space->machine, "DSW");
+	val = input_port_read(space->machine(), "DSW");
 	return ((val << (7 - offset)) & 0x80);
 }
 
 static WRITE8_HANDLER( tankbatt_interrupt_enable_w )
 {
-	tankbatt_nmi_enable = !data;
-	tankbatt_sound_enable = !data;
+	tankbatt_state *state = space->machine().driver_data<tankbatt_state>();
+	state->m_nmi_enable = !data;
+	state->m_sound_enable = !data;
 
 	/* hack - turn off the engine noise if the normal game nmi's are disabled */
-	if (data) sample_stop (space->machine->device("samples"), 2);
+	if (data) sample_stop (space->machine().device("samples"), 2);
 //  interrupt_enable_w (offset, !data);
 }
 
 static WRITE8_HANDLER( tankbatt_demo_interrupt_enable_w )
 {
-	tankbatt_nmi_enable = data;
+	tankbatt_state *state = space->machine().driver_data<tankbatt_state>();
+	state->m_nmi_enable = data;
 //  interrupt_enable_w (offset, data);
 }
 
 static WRITE8_HANDLER( tankbatt_sh_expl_w )
 {
-	if (tankbatt_sound_enable)
+	tankbatt_state *state = space->machine().driver_data<tankbatt_state>();
+	if (state->m_sound_enable)
 	{
-		device_t *samples = space->machine->device("samples");
+		device_t *samples = space->machine().device("samples");
 		sample_start (samples, 1, 3, 0);
 	}
 }
 
 static WRITE8_HANDLER( tankbatt_sh_engine_w )
 {
-	device_t *samples = space->machine->device("samples");
-	if (tankbatt_sound_enable)
+	tankbatt_state *state = space->machine().driver_data<tankbatt_state>();
+	device_t *samples = space->machine().device("samples");
+	if (state->m_sound_enable)
 	{
 		if (data)
 			sample_start (samples, 2, 2, 1);
@@ -133,9 +135,10 @@ static WRITE8_HANDLER( tankbatt_sh_engine_w )
 
 static WRITE8_HANDLER( tankbatt_sh_fire_w )
 {
-	if (tankbatt_sound_enable)
+	tankbatt_state *state = space->machine().driver_data<tankbatt_state>();
+	if (state->m_sound_enable)
 	{
-		device_t *samples = space->machine->device("samples");
+		device_t *samples = space->machine().device("samples");
 		sample_start (samples, 0, 0, 0);
 	}
 }
@@ -143,26 +146,26 @@ static WRITE8_HANDLER( tankbatt_sh_fire_w )
 static WRITE8_HANDLER( tankbatt_irq_ack_w )
 {
 	/* 0x6e written at the end of the irq routine, could be either irq ack or a coin sample */
-	cputag_set_input_line(space->machine, "maincpu", 0, CLEAR_LINE);
+	cputag_set_input_line(space->machine(), "maincpu", 0, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( tankbatt_coin_counter_w )
 {
-	coin_counter_w(space->machine, 0,data & 1);
-	coin_counter_w(space->machine, 1,data & 1);
+	coin_counter_w(space->machine(), 0,data & 1);
+	coin_counter_w(space->machine(), 1,data & 1);
 }
 
 static WRITE8_HANDLER( tankbatt_coin_lockout_w )
 {
-	coin_lockout_w(space->machine, 0,data & 1);
-	coin_lockout_w(space->machine, 1,data & 1);
+	coin_lockout_w(space->machine(), 0,data & 1);
+	coin_lockout_w(space->machine(), 1,data & 1);
 }
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x000f) AM_RAM AM_BASE(&tankbatt_bulletsram) AM_SIZE(&tankbatt_bulletsram_size)
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x000f) AM_RAM AM_BASE_MEMBER(tankbatt_state, m_bulletsram) AM_SIZE_MEMBER(tankbatt_state, m_bulletsram_size)
 	AM_RANGE(0x0010, 0x01ff) AM_RAM
 	AM_RANGE(0x0200, 0x07ff) AM_RAM
-	AM_RANGE(0x0800, 0x0bff) AM_RAM_WRITE(tankbatt_videoram_w) AM_BASE_MEMBER(tankbatt_state, videoram)
+	AM_RANGE(0x0800, 0x0bff) AM_RAM_WRITE(tankbatt_videoram_w) AM_BASE_MEMBER(tankbatt_state, m_videoram)
 	AM_RANGE(0x0c00, 0x0c07) AM_READ(tankbatt_in0_r)
 	AM_RANGE(0x0c00, 0x0c01) AM_WRITE(tankbatt_led_w)
 	AM_RANGE(0x0c02, 0x0c02) AM_WRITE(tankbatt_coin_counter_w)
@@ -185,12 +188,13 @@ ADDRESS_MAP_END
 
 static INTERRUPT_GEN( tankbatt_interrupt )
 {
-	if (tankbatt_nmi_enable) cpu_set_input_line(device,INPUT_LINE_NMI,PULSE_LINE);
+	tankbatt_state *state = device->machine().driver_data<tankbatt_state>();
+	if (state->m_nmi_enable) device_set_input_line(device,INPUT_LINE_NMI,PULSE_LINE);
 }
 
 static INPUT_CHANGED( coin_inserted )
 {
-	cputag_set_input_line(field->port->machine, "maincpu", 0, ASSERT_LINE);
+	cputag_set_input_line(field.machine(), "maincpu", 0, ASSERT_LINE);
 }
 
 static INPUT_PORTS_START( tankbatt )
@@ -303,13 +307,13 @@ static MACHINE_CONFIG_START( tankbatt, tankbatt_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(tankbatt)
 
 	MCFG_GFXDECODE(tankbatt)
 	MCFG_PALETTE_LENGTH(256*2)
 
 	MCFG_PALETTE_INIT(tankbatt)
 	MCFG_VIDEO_START(tankbatt)
-	MCFG_VIDEO_UPDATE(tankbatt)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
