@@ -49,110 +49,97 @@ f80b      ????
 #include "cpu/z80/z80.h"
 #include "sound/3812intf.h"
 #include "sound/msm5205.h"
-
-
-extern int tecmo_video_type;
-extern UINT8 *tecmo_txvideoram,*tecmo_fgvideoram,*tecmo_bgvideoram;
-
-WRITE8_HANDLER( tecmo_txvideoram_w );
-WRITE8_HANDLER( tecmo_fgvideoram_w );
-WRITE8_HANDLER( tecmo_bgvideoram_w );
-WRITE8_HANDLER( tecmo_fgscroll_w );
-WRITE8_HANDLER( tecmo_bgscroll_w );
-WRITE8_HANDLER( tecmo_flipscreen_w );
-
-VIDEO_START( tecmo );
-VIDEO_UPDATE( tecmo );
-
-static int adpcm_pos,adpcm_end;
-static int adpcm_data;
+#include "includes/tecmo.h"
 
 
 static WRITE8_HANDLER( tecmo_bankswitch_w )
 {
 	int bankaddress;
-	UINT8 *RAM = memory_region(space->machine, "maincpu");
+	UINT8 *RAM = space->machine().region("maincpu")->base();
 
 
 	bankaddress = 0x10000 + ((data & 0xf8) << 8);
-	memory_set_bankptr(space->machine, "bank1", &RAM[bankaddress]);
+	memory_set_bankptr(space->machine(), "bank1", &RAM[bankaddress]);
 }
 
 static WRITE8_HANDLER( tecmo_sound_command_w )
 {
 	soundlatch_w(space, offset, data);
-	cputag_set_input_line(space->machine, "soundcpu",INPUT_LINE_NMI,PULSE_LINE);
+	cputag_set_input_line(space->machine(), "soundcpu",INPUT_LINE_NMI,PULSE_LINE);
 }
 
 static WRITE8_DEVICE_HANDLER( tecmo_adpcm_start_w )
 {
-	adpcm_pos = data << 8;
+	tecmo_state *state = device->machine().driver_data<tecmo_state>();
+	state->m_adpcm_pos = data << 8;
 	msm5205_reset_w(device, 0);
 }
 static WRITE8_HANDLER( tecmo_adpcm_end_w )
 {
-	adpcm_end = (data + 1) << 8;
+	tecmo_state *state = space->machine().driver_data<tecmo_state>();
+	state->m_adpcm_end = (data + 1) << 8;
 }
 static WRITE8_DEVICE_HANDLER( tecmo_adpcm_vol_w )
 {
 	msm5205_set_volume(device,(data & 0x0f) * 100 / 15);
 }
-static void tecmo_adpcm_int(running_device *device)
+static void tecmo_adpcm_int(device_t *device)
 {
-	if (adpcm_pos >= adpcm_end ||
-				adpcm_pos >= memory_region_length(device->machine, "adpcm"))
+	tecmo_state *state = device->machine().driver_data<tecmo_state>();
+	if (state->m_adpcm_pos >= state->m_adpcm_end ||
+				state->m_adpcm_pos >= device->machine().region("adpcm")->bytes())
 		msm5205_reset_w(device,1);
-	else if (adpcm_data != -1)
+	else if (state->m_adpcm_data != -1)
 	{
-		msm5205_data_w(device,adpcm_data & 0x0f);
-		adpcm_data = -1;
+		msm5205_data_w(device,state->m_adpcm_data & 0x0f);
+		state->m_adpcm_data = -1;
 	}
 	else
 	{
-		UINT8 *ROM = memory_region(device->machine, "adpcm");
+		UINT8 *ROM = device->machine().region("adpcm")->base();
 
-		adpcm_data = ROM[adpcm_pos++];
-		msm5205_data_w(device,adpcm_data >> 4);
+		state->m_adpcm_data = ROM[state->m_adpcm_pos++];
+		msm5205_data_w(device,state->m_adpcm_data >> 4);
 	}
 }
 
 /* the 8-bit dipswitches are split across addresses */
 static READ8_HANDLER( tecmo_dswa_l_r )
 {
-	UINT8 port = input_port_read(space->machine, "DSWA");
+	UINT8 port = input_port_read(space->machine(), "DSWA");
 	port &= 0x0f;
 	return port;
 }
 
 static READ8_HANDLER( tecmo_dswa_h_r )
 {
-	UINT8 port = input_port_read(space->machine, "DSWA");
+	UINT8 port = input_port_read(space->machine(), "DSWA");
 	port &= 0xf0;
 	return port>>4;
 }
 
 static READ8_HANDLER( tecmo_dswb_l_r )
 {
-	UINT8 port = input_port_read(space->machine, "DSWB");
+	UINT8 port = input_port_read(space->machine(), "DSWB");
 	port &= 0x0f;
 	return port;
 }
 
 static READ8_HANDLER( tecmo_dswb_h_r )
 {
-	UINT8 port = input_port_read(space->machine, "DSWB");
+	UINT8 port = input_port_read(space->machine(), "DSWB");
 	port &= 0xf0;
 	return port>>4;
 }
 
 
-static ADDRESS_MAP_START( rygar_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( rygar_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xcfff) AM_RAM
-	AM_RANGE(0xd000, 0xd7ff) AM_RAM_WRITE(tecmo_txvideoram_w) AM_BASE(&tecmo_txvideoram)
-	AM_RANGE(0xd800, 0xdbff) AM_RAM_WRITE(tecmo_fgvideoram_w) AM_BASE(&tecmo_fgvideoram)
-	AM_RANGE(0xdc00, 0xdfff) AM_RAM_WRITE(tecmo_bgvideoram_w) AM_BASE(&tecmo_bgvideoram)
-	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_BASE_SIZE_GENERIC(spriteram)
+	AM_RANGE(0xd000, 0xd7ff) AM_RAM_WRITE(tecmo_txvideoram_w) AM_BASE_MEMBER(tecmo_state, m_txvideoram)
+	AM_RANGE(0xd800, 0xdbff) AM_RAM_WRITE(tecmo_fgvideoram_w) AM_BASE_MEMBER(tecmo_state, m_fgvideoram)
+	AM_RANGE(0xdc00, 0xdfff) AM_RAM_WRITE(tecmo_bgvideoram_w) AM_BASE_MEMBER(tecmo_state, m_bgvideoram)
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_BASE_SIZE_MEMBER(tecmo_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0xe800, 0xefff) AM_RAM_WRITE(paletteram_xxxxBBBBRRRRGGGG_be_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0xf000, 0xf7ff) AM_ROMBANK("bank1")
 	AM_RANGE(0xf800, 0xf800) AM_READ_PORT("JOY1")
@@ -174,14 +161,14 @@ static ADDRESS_MAP_START( rygar_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf80b, 0xf80b) AM_WRITE(watchdog_reset_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( gemini_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( gemini_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xcfff) AM_RAM
-	AM_RANGE(0xd000, 0xd7ff) AM_RAM_WRITE(tecmo_txvideoram_w) AM_BASE(&tecmo_txvideoram)
-	AM_RANGE(0xd800, 0xdbff) AM_RAM_WRITE(tecmo_fgvideoram_w) AM_BASE(&tecmo_fgvideoram)
-	AM_RANGE(0xdc00, 0xdfff) AM_RAM_WRITE(tecmo_bgvideoram_w) AM_BASE(&tecmo_bgvideoram)
+	AM_RANGE(0xd000, 0xd7ff) AM_RAM_WRITE(tecmo_txvideoram_w) AM_BASE_MEMBER(tecmo_state, m_txvideoram)
+	AM_RANGE(0xd800, 0xdbff) AM_RAM_WRITE(tecmo_fgvideoram_w) AM_BASE_MEMBER(tecmo_state, m_fgvideoram)
+	AM_RANGE(0xdc00, 0xdfff) AM_RAM_WRITE(tecmo_bgvideoram_w) AM_BASE_MEMBER(tecmo_state, m_bgvideoram)
 	AM_RANGE(0xe000, 0xe7ff) AM_RAM_WRITE(paletteram_xxxxBBBBRRRRGGGG_be_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0xe800, 0xefff) AM_RAM AM_BASE_SIZE_GENERIC(spriteram)
+	AM_RANGE(0xe800, 0xefff) AM_RAM AM_BASE_SIZE_MEMBER(tecmo_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0xf000, 0xf7ff) AM_ROMBANK("bank1")
 	AM_RANGE(0xf800, 0xf800) AM_READ_PORT("JOY1")
 	AM_RANGE(0xf801, 0xf801) AM_READ_PORT("BUTTONS1")
@@ -202,13 +189,13 @@ static ADDRESS_MAP_START( gemini_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf80b, 0xf80b) AM_WRITE(watchdog_reset_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( silkworm_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( silkworm_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
-	AM_RANGE(0xc000, 0xc3ff) AM_RAM_WRITE(tecmo_bgvideoram_w) AM_BASE(&tecmo_bgvideoram)
-	AM_RANGE(0xc400, 0xc7ff) AM_RAM_WRITE(tecmo_fgvideoram_w) AM_BASE(&tecmo_fgvideoram)
-	AM_RANGE(0xc800, 0xcfff) AM_RAM_WRITE(tecmo_txvideoram_w) AM_BASE(&tecmo_txvideoram)
+	AM_RANGE(0xc000, 0xc3ff) AM_RAM_WRITE(tecmo_bgvideoram_w) AM_BASE_MEMBER(tecmo_state, m_bgvideoram)
+	AM_RANGE(0xc400, 0xc7ff) AM_RAM_WRITE(tecmo_fgvideoram_w) AM_BASE_MEMBER(tecmo_state, m_fgvideoram)
+	AM_RANGE(0xc800, 0xcfff) AM_RAM_WRITE(tecmo_txvideoram_w) AM_BASE_MEMBER(tecmo_state, m_txvideoram)
 	AM_RANGE(0xd000, 0xdfff) AM_RAM
-	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_BASE_SIZE_GENERIC(spriteram)
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_BASE_SIZE_MEMBER(tecmo_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0xe800, 0xefff) AM_RAM_WRITE(paletteram_xxxxBBBBRRRRGGGG_be_w) AM_BASE_GENERIC(paletteram)
 	AM_RANGE(0xf000, 0xf7ff) AM_ROMBANK("bank1")
 	AM_RANGE(0xf800, 0xf800) AM_READ_PORT("JOY1")
@@ -231,7 +218,7 @@ static ADDRESS_MAP_START( silkworm_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf80b, 0xf80b) AM_WRITENOP	/* ? if mapped to watchdog like in the others, causes reset */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( rygar_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( rygar_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x47ff) AM_RAM
 	AM_RANGE(0x8000, 0x8001) AM_DEVWRITE("ymsnd", ym3812_w)
@@ -241,7 +228,7 @@ static ADDRESS_MAP_START( rygar_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf000, 0xf000) AM_WRITENOP	/* NMI acknowledge */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( tecmo_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( tecmo_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x2000, 0x207f) AM_RAM				/* Silkworm set #2 has a custom CPU which */
 												/* writes code to this area */
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
@@ -651,9 +638,9 @@ GFXDECODE_END
 
 
 
-static void irqhandler(running_device *device, int linestate)
+static void irqhandler(device_t *device, int linestate)
 {
-	cputag_set_input_line(device->machine, "soundcpu", 0, linestate);
+	cputag_set_input_line(device->machine(), "soundcpu", 0, linestate);
 }
 
 static const ym3812_interface ym3812_config =
@@ -670,108 +657,109 @@ static const msm5205_interface msm5205_config =
 
 static MACHINE_RESET( rygar )
 {
-	adpcm_pos = 0;
-	adpcm_end = 0;
-	adpcm_data = -1;
+	tecmo_state *state = machine.driver_data<tecmo_state>();
+	state->m_adpcm_pos = 0;
+	state->m_adpcm_end = 0;
+	state->m_adpcm_data = -1;
 }
 
-static MACHINE_DRIVER_START( rygar )
+static MACHINE_CONFIG_START( rygar, tecmo_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, XTAL_24MHz/4) /* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(rygar_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80, XTAL_24MHz/4) /* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(rygar_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("soundcpu", Z80, XTAL_4MHz) /* verified on pcb */
-	MDRV_CPU_PROGRAM_MAP(rygar_sound_map)
+	MCFG_CPU_ADD("soundcpu", Z80, XTAL_4MHz) /* verified on pcb */
+	MCFG_CPU_PROGRAM_MAP(rygar_sound_map)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0)	/* frames per second, vblank duration */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0)	/* frames per second, vblank duration */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(tecmo)
 
-	MDRV_GFXDECODE(tecmo)
-	MDRV_PALETTE_LENGTH(1024)
+	MCFG_GFXDECODE(tecmo)
+	MCFG_PALETTE_LENGTH(1024)
 
-	MDRV_VIDEO_START(tecmo)
-	MDRV_VIDEO_UPDATE(tecmo)
+	MCFG_VIDEO_START(tecmo)
 
-	MDRV_MACHINE_RESET( rygar )
+	MCFG_MACHINE_RESET( rygar )
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM3812, XTAL_4MHz) /* verified on pcb */
-	MDRV_SOUND_CONFIG(ym3812_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MCFG_SOUND_ADD("ymsnd", YM3812, XTAL_4MHz) /* verified on pcb */
+	MCFG_SOUND_CONFIG(ym3812_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_SOUND_ADD("msm", MSM5205, XTAL_400kHz) /* verified on pcb, even if schematics shows a 384khz resonator */
-	MDRV_SOUND_CONFIG(msm5205_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
-MACHINE_DRIVER_END
+	MCFG_SOUND_ADD("msm", MSM5205, XTAL_400kHz) /* verified on pcb, even if schematics shows a 384khz resonator */
+	MCFG_SOUND_CONFIG(msm5205_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( gemini )
+static MACHINE_CONFIG_DERIVED( gemini, rygar )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(rygar)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_CLOCK(6000000)
-	MDRV_CPU_PROGRAM_MAP(gemini_map)
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_CLOCK(6000000)
+	MCFG_CPU_PROGRAM_MAP(gemini_map)
 
-	MDRV_CPU_MODIFY("soundcpu")
-	MDRV_CPU_PROGRAM_MAP(tecmo_sound_map)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("soundcpu")
+	MCFG_CPU_PROGRAM_MAP(tecmo_sound_map)
+MACHINE_CONFIG_END
 
 
-static MACHINE_DRIVER_START( silkworm )
+static MACHINE_CONFIG_DERIVED( silkworm, gemini )
 
 	/* basic machine hardware */
-	MDRV_IMPORT_FROM(gemini)
-	MDRV_CPU_MODIFY("maincpu")
-	MDRV_CPU_CLOCK(6000000)
-	MDRV_CPU_PROGRAM_MAP(silkworm_map)
-MACHINE_DRIVER_END
+	MCFG_CPU_MODIFY("maincpu")
+	MCFG_CPU_CLOCK(6000000)
+	MCFG_CPU_PROGRAM_MAP(silkworm_map)
+MACHINE_CONFIG_END
 
-static MACHINE_DRIVER_START( backfirt )
+#ifdef UNUSED_CODE
+static MACHINE_CONFIG_START( backfirt, tecmo_state )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD("maincpu", Z80, XTAL_24MHz/4)
-	MDRV_CPU_PROGRAM_MAP(rygar_map)
-	MDRV_CPU_VBLANK_INT("screen", irq0_line_hold)
+	MCFG_CPU_ADD("maincpu", Z80, XTAL_24MHz/4)
+	MCFG_CPU_PROGRAM_MAP(rygar_map)
+	MCFG_CPU_VBLANK_INT("screen", irq0_line_hold)
 
-	MDRV_CPU_ADD("soundcpu", Z80, XTAL_8MHz/2)
-	MDRV_CPU_PROGRAM_MAP(rygar_sound_map)
+	MCFG_CPU_ADD("soundcpu", Z80, XTAL_8MHz/2)
+	MCFG_CPU_PROGRAM_MAP(rygar_sound_map)
 
 	/* video hardware */
-	MDRV_SCREEN_ADD("screen", RASTER)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0)	/* frames per second, vblank duration */)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_ADD("screen", RASTER)
+	MCFG_SCREEN_REFRESH_RATE(60)
+	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0)	/* frames per second, vblank duration */)
+	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MCFG_SCREEN_SIZE(32*8, 32*8)
+	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(tecmo)
 
-	MDRV_GFXDECODE(tecmo)
-	MDRV_PALETTE_LENGTH(1024)
+	MCFG_GFXDECODE(tecmo)
+	MCFG_PALETTE_LENGTH(1024)
 
-	MDRV_VIDEO_START(tecmo)
-	MDRV_VIDEO_UPDATE(tecmo)
+	MCFG_VIDEO_START(tecmo)
 
-	MDRV_MACHINE_RESET( rygar )
+	MCFG_MACHINE_RESET( rygar )
 
 	/* sound hardware */
-	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MCFG_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD("ymsnd", YM3812, XTAL_4MHz) /* verified on pcb */
-	MDRV_SOUND_CONFIG(ym3812_config)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MCFG_SOUND_ADD("ymsnd", YM3812, XTAL_4MHz) /* verified on pcb */
+	MCFG_SOUND_CONFIG(ym3812_config)
+	MCFG_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
 	/* no MSM on this PCB */
 
-MACHINE_DRIVER_END
+MACHINE_CONFIG_END
+#endif
 
 /***************************************************************************
 
@@ -1166,18 +1154,33 @@ ROM_END
    video_type is used to distinguish Rygar, Silkworm and Gemini Wing.
    This is needed because there is a difference in the tile and sprite indexing.
 */
-static DRIVER_INIT( rygar )    { tecmo_video_type = 0; }
-static DRIVER_INIT( silkworm ) { tecmo_video_type = 1; }
-static DRIVER_INIT( gemini )   { tecmo_video_type = 2; }
+static DRIVER_INIT( rygar )
+{
+	tecmo_state *state = machine.driver_data<tecmo_state>();
+	state->m_video_type = 0;
+}
+
+static DRIVER_INIT( silkworm )
+{
+	tecmo_state *state = machine.driver_data<tecmo_state>();
+	state->m_video_type = 1;
+}
+
+static DRIVER_INIT( gemini )
+{
+	tecmo_state *state = machine.driver_data<tecmo_state>();
+	state->m_video_type = 2;
+}
 
 static DRIVER_INIT( backfirt )
 {
-	tecmo_video_type = 2;
+	tecmo_state *state = machine.driver_data<tecmo_state>();
+	state->m_video_type = 2;
 
 	/* no MSM */
-	memory_nop_write(cputag_get_address_space(machine, "soundcpu", ADDRESS_SPACE_PROGRAM), 0xc000, 0xc000, 0, 0);
-	memory_nop_write(cputag_get_address_space(machine, "soundcpu", ADDRESS_SPACE_PROGRAM), 0xd000, 0xd000, 0, 0);
-	memory_nop_write(cputag_get_address_space(machine, "soundcpu", ADDRESS_SPACE_PROGRAM), 0xe000, 0xe000, 0, 0);
+	machine.device("soundcpu")->memory().space(AS_PROGRAM)->nop_write(0xc000, 0xc000);
+	machine.device("soundcpu")->memory().space(AS_PROGRAM)->nop_write(0xd000, 0xd000);
+	machine.device("soundcpu")->memory().space(AS_PROGRAM)->nop_write(0xe000, 0xe000);
 }
 
 
