@@ -19,28 +19,31 @@ use with Namco ROM carts.
 Games on this system include....
 
 Game                                                   Manufacturer              Media                Key Chip
-+----------------------------------------------------+-------------------------+--------------------+--------------|
-|Donkey Kong Jungle Fever                            | Capcom / Nintendo, 2005 | ROM Cart           |              |
-|F-Zero AX                                           | Sega / Nintendo, 2003   | GDROM GDT-0004     |              |
-|F-Zero AX Monster Ride                              | Sega / Nintendo, 2004   | GDROM              |              |
-|*Firmware Update                                    | Sega                    | GDROM GDT-0011     | ?            |
-|*Gekitou Pro Yakyuu                                 | Sega, 2003              | GDROM GDT-0008C    | 317-0371-JPN |
-|*Mario Kart Arcade GP                               | Namco / Nintendo, 2005  | ROM Cart           | 317-5109-COM |
-|Mario Kart Arcade GP 2                              | Namco / Nintendo, 2007  | ROM Cart           |              |
-|Starfox (planned, but not released)                 | Namco / Nintendo, 200?  | ?                  |              |
-|*The Key Of Avalon : The Wizard Master (server)     | Sega, 2003              | GDROM GDT-0005C    | ?            |
-|The Key Of Avalon : The Wizard Master (client)      | Sega, 2003              | GDROM GDT-0006C    |              |
-|*The Key Of Avalon Ver 1.3 (server)                 | Sega, 2004              | GDROM GDT-0009C    | ?            |
-|*The Key Of Avalon Ver 1.3 (client)                 | Sega, 2004              | GDROM GDT-0010C    | ?            |
-|The Key Of Avalon 2 (server)                        | Sega, 2005              | GDROM              |              |
-|*The Key Of Avalon 2 (client)                       | Sega, 2005              | GDROM GDT-0017B    | ?            |
-|*Virtua Striker 2002 (Japan)                        | Sega, 2002              | GDROM GDT-0001     | 317-0337-JPN |
-|*Virtua Striker 2002 (Export)                       | Sega, 2002              | GDROM GDT-0002     | 317-0337-EXP |
-|*Virtua Striker 4 (Japan)                           | Sega, 2005              | GDROM GDT-0013E    | 317-0391-JPN |
-|*Virtua Striker 4 (Export)                          | Sega, 2005              | GDROM GDT-0015     | 317-0393-EXP |
-|*Virtua Striker 4 Ver.2006 (Japan)                  | Sega, 2006              | GDROM GDT-0020D    | ?            |
-|Virtua Striker 4 Ver.2006 (Export)                  | Sega, 2006              | GDROM GDT-0021     |              |
-+----------------------------------------------------+-------------------------+--------------------+--------------+
++-+---------------------------------------------------------+-------------------------+-----------------+--------------|
+| |Donkey Kong Jungle Fever                                 | Capcom / Nintendo, 2005 | ROM Cart        | ?            |
+|*|Mario Kart Arcade GP                                     | Namco / Nintendo, 2005  | ROM Cart        | 317-5109-COM |
+| |Mario Kart Arcade GP 2                                   | Namco / Nintendo, 2007  | ROM Cart        | ?            |
+|*|Virtua Striker 2002 (Japan)                              | Sega, 2002              | GDROM GDT-0001  | 317-0337-JPN |
+|*|Virtua Striker 2002 (Export)                             | Sega, 2002              | GDROM GDT-0002  | 317-0337-EXP |
+| |F-Zero AX                                                | Sega / Nintendo, 2003   | GDROM GDT-0004  | ?            |
+|*|The Key Of Avalon: The Wizard Master (server) (Rev C)    | Sega, 2003              | GDROM GDT-0005C | ?            |
+| |The Key Of Avalon: The Wizard Master (client) (Rev C)    | Sega, 2003              | GDROM GDT-0006C | ?            |
+|*|Gekitou Pro Yakyuu (Rev C)                               | Sega, 2003              | GDROM GDT-0008C | 317-0371-JPN |
+|*|The Key Of Avalon 1.30: Chaotic Sabbat (server) (Rev C)  | Sega, 2004              | GDROM GDT-0009C | ?            |
+|*|The Key Of Avalon 1.30: Chaotic Sabbat (client) (Rev C)  | Sega, 2004              | GDROM GDT-0010C | ?            |
+|*|Firmware Update                                          | Sega                    | GDROM GDT-0011  | ?            |
+|*|Virtua Striker 4 (Japan) (Rev E)                         | Sega, 2005              | GDROM GDT-0013E | 317-0391-JPN |
+|*|Virtua Striker 4 (Export)                                | Sega, 2005              | GDROM GDT-0015  | 317-0393-EXP |
+| |The Key Of Avalon 2: Eutaxy Commandment (server)         | Sega, 2005              | GDROM GDT-0016  | ?            |
+|*|The Key Of Avalon 2: Eutaxy Commandment (client) (Rev B) | Sega, 2005              | GDROM GDT-0017B | ?            |
+|*|Virtua Striker 4 Ver.2006 (Japan) (Rev D)                | Sega, 2006              | GDROM GDT-0020D | ?            |
+| |Virtua Striker 4 Ver.2006 (Export)                       | Sega, 2006              | GDROM GDT-0021  | ?            |
+| |F-Zero AX - Monster Ride                                 | Sega / Nintendo, 2004   | GDROM ?         | ?            |
+| |The Key Of Avalon 1.10                                   | Sega, 2003              | GDROM ?         | ?            |
+| |The Key Of Avalon 1.20: Summon The New Monster           | Sega, 2003              | GDROM ?         | ?            |
+| |Donkey Kong:Banana Kingdom                               | Capcom / Nintendo, 2006 | ?               | ?            |
+| |Starfox Armada (planned, but not released)               | Namco / Nintendo, 200?  | ?               | ?            |
++-+---------------------------------------------------------+-------------------------+-----------------+--------------+
 * denotes these games are archived.
 If you can help with the undumped games or know of missing Triforce games, please contact...
 http://guru.mameworld.info/
@@ -400,7 +403,7 @@ Notes:
 #include "cpu/powerpc/ppc.h"
 #include "includes/naomibd.h"
 
-static ADDRESS_MAP_START( gc_map, ADDRESS_SPACE_PROGRAM, 32 )
+static ADDRESS_MAP_START( gc_map, AS_PROGRAM, 32 )
 	AM_RANGE(0x7fe00000, 0x7fffffff) AM_ROM AM_REGION("maincpu", 0) AM_SHARE("share2")	/* Program ROM */
 ADDRESS_MAP_END
 
@@ -410,7 +413,7 @@ static VIDEO_START(triforce)
 
 }
 
-static VIDEO_UPDATE(triforce)
+static SCREEN_UPDATE(triforce)
 {
 	return 0;
 }
@@ -424,7 +427,7 @@ static MACHINE_CONFIG_START( triforce_base, driver_device )
 	MCFG_CPU_ADD("maincpu", PPC403GA, 64000000) /* Wrong! */
 	MCFG_CPU_PROGRAM_MAP(gc_map)
 
-	MCFG_QUANTUM_TIME(HZ(6000))
+	MCFG_QUANTUM_TIME(attotime::from_hz(6000))
 
 	/* video hardware */
 	MCFG_SCREEN_ADD("screen", RASTER)
@@ -432,11 +435,11 @@ static MACHINE_CONFIG_START( triforce_base, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_SIZE(640, 480)
 	MCFG_SCREEN_VISIBLE_AREA(0, 639, 0, 479)
+	MCFG_SCREEN_UPDATE(triforce)
 
 	MCFG_PALETTE_LENGTH(65536)
 
 	MCFG_VIDEO_START(triforce)
-	MCFG_VIDEO_UPDATE(triforce)
 MACHINE_CONFIG_END
 
 static MACHINE_CONFIG_DERIVED( triforcegd, triforce_base )
