@@ -61,6 +61,15 @@ Windows showed a 5.94 gig partion empty and a 12.74 unallocated partition
 #include "cpu/mips/r3000.h"
 
 
+class turrett_state : public driver_device
+{
+public:
+	turrett_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+};
+
+
 #define R3041_CLOCK		25000000
 
 
@@ -69,13 +78,13 @@ static VIDEO_START(turrett)
 
 }
 
-static VIDEO_UPDATE(turrett)
+static SCREEN_UPDATE(turrett)
 {
 	return 0;
 }
 
 
-static ADDRESS_MAP_START( cpu_map, ADDRESS_SPACE_PROGRAM, 32 )
+static ADDRESS_MAP_START( cpu_map, AS_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x0007ffff) AM_RAM
 	AM_RANGE(0x1fc00000, 0x1fdfffff) AM_ROM AM_REGION("maincpu", 0)
 	AM_RANGE(0x02000010, 0x02000013) AM_RAM
@@ -103,7 +112,7 @@ static const r3000_cpu_core r3000_config =
 };
 
 
-static MACHINE_CONFIG_START( turrett, driver_device )
+static MACHINE_CONFIG_START( turrett, turrett_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", R3041BE, R3041_CLOCK)
 	MCFG_CPU_PROGRAM_MAP(cpu_map)
@@ -116,11 +125,11 @@ static MACHINE_CONFIG_START( turrett, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(64*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0, 64*8-1, 0*8, 32*8-1)
+	MCFG_SCREEN_UPDATE(turrett)
 
 	MCFG_PALETTE_LENGTH(0x2000)
 
 	MCFG_VIDEO_START(turrett)
-	MCFG_VIDEO_UPDATE(turrett)
 MACHINE_CONFIG_END
 
 
