@@ -52,19 +52,6 @@
 #include "buggybjr.lh"
 
 
-/*************************************
- *
- *  Globals
- *
- *************************************/
-
-UINT16 *tx1_math_ram;
-static UINT8  *z80_ram;
-static UINT8  tx1_ppi_latch_a;
-static UINT8  tx1_ppi_latch_b;
-static UINT32 ts;
-
-
 /*************************************
  *
  *  CPU Control
@@ -74,40 +61,40 @@ static UINT32 ts;
 /* Main CPU and Z80 synchronisation */
 static WRITE16_HANDLER( z80_busreq_w )
 {
-	cputag_set_input_line(space->machine, "audio_cpu", INPUT_LINE_HALT, (data & 1) ? CLEAR_LINE : ASSERT_LINE);
+	cputag_set_input_line(space->machine(), "audio_cpu", INPUT_LINE_HALT, (data & 1) ? CLEAR_LINE : ASSERT_LINE);
 }
 
 static WRITE16_HANDLER( resume_math_w )
 {
-	cputag_set_input_line(space->machine, "math_cpu", INPUT_LINE_TEST, ASSERT_LINE);
+	cputag_set_input_line(space->machine(), "math_cpu", INPUT_LINE_TEST, ASSERT_LINE);
 }
 
 static WRITE16_HANDLER( halt_math_w )
 {
-	cputag_set_input_line(space->machine, "math_cpu", INPUT_LINE_TEST, CLEAR_LINE);
+	cputag_set_input_line(space->machine(), "math_cpu", INPUT_LINE_TEST, CLEAR_LINE);
 }
 
 /* Z80 can trigger its own interrupts */
 static WRITE8_HANDLER( z80_intreq_w )
 {
-	cputag_set_input_line(space->machine, "audio_cpu", 0, HOLD_LINE);
+	cputag_set_input_line(space->machine(), "audio_cpu", 0, HOLD_LINE);
 }
 
 /* Periodic Z80 interrupt */
 static INTERRUPT_GEN( z80_irq )
 {
-	cpu_set_input_line(device, 0, HOLD_LINE);
+	device_set_input_line(device, 0, HOLD_LINE);
 }
 
 static READ16_HANDLER( z80_shared_r )
 {
-	address_space *cpu2space = cputag_get_address_space(space->machine, "audio_cpu", ADDRESS_SPACE_PROGRAM);
+	address_space *cpu2space = space->machine().device("audio_cpu")->memory().space(AS_PROGRAM);
 	return cpu2space->read_byte(offset);
 }
 
 static WRITE16_HANDLER( z80_shared_w )
 {
-	address_space *cpu2space = cputag_get_address_space(space->machine, "audio_cpu", ADDRESS_SPACE_PROGRAM);
+	address_space *cpu2space = space->machine().device("audio_cpu")->memory().space(AS_PROGRAM);
 	cpu2space->write_byte(offset, data & 0xff);
 }
 
@@ -394,7 +381,8 @@ INPUT_PORTS_END
 
 static READ16_HANDLER( dipswitches_r )
 {
-	return (input_port_read(space->machine, "DSW") & 0xfffe) | ts;
+	tx1_state *state = space->machine().driver_data<tx1_state>();
+	return (input_port_read(space->machine(), "DSW") & 0xfffe) | state->m_ts;
 }
 
 /*
@@ -403,45 +391,50 @@ static READ16_HANDLER( dipswitches_r )
 */
 static WRITE8_HANDLER( ts_w )
 {
+	tx1_state *state = space->machine().driver_data<tx1_state>();
 //  TS = 1;
-	z80_ram[offset] = data;
+	state->m_z80_ram[offset] = data;
 }
 
 static READ8_HANDLER( ts_r )
 {
+	tx1_state *state = space->machine().driver_data<tx1_state>();
 //  TS = 1;
-	return z80_ram[offset];
+	return state->m_z80_ram[offset];
 }
 
 
 static WRITE8_DEVICE_HANDLER( tx1_coin_cnt_w )
 {
-	coin_counter_w(device->machine, 0, data & 0x80);
-	coin_counter_w(device->machine, 1, data & 0x40);
-//  coin_counter_w(device->machine, 2, data & 0x40);
+	coin_counter_w(device->machine(), 0, data & 0x80);
+	coin_counter_w(device->machine(), 1, data & 0x40);
+//  coin_counter_w(device->machine(), 2, data & 0x40);
 }
 
 static WRITE8_DEVICE_HANDLER( bb_coin_cnt_w )
 {
-	coin_counter_w(device->machine, 0, data & 0x01);
-	coin_counter_w(device->machine, 1, data & 0x02);
-//  coin_counter_w(device->machine, 2, data & 0x04);
+	coin_counter_w(device->machine(), 0, data & 0x01);
+	coin_counter_w(device->machine(), 1, data & 0x02);
+//  coin_counter_w(device->machine(), 2, data & 0x04);
 }
 
 static WRITE8_HANDLER( tx1_ppi_latch_w )
 {
-	tx1_ppi_latch_a = ((input_port_read(space->machine, "AN_BRAKE") & 0xf) << 4) | (input_port_read(space->machine, "AN_ACCELERATOR") & 0xf);
-	tx1_ppi_latch_b = input_port_read(space->machine, "AN_STEERING");
+	tx1_state *state = space->machine().driver_data<tx1_state>();
+	state->m_ppi_latch_a = ((input_port_read(space->machine(), "AN_BRAKE") & 0xf) << 4) | (input_port_read(space->machine(), "AN_ACCELERATOR") & 0xf);
+	state->m_ppi_latch_b = input_port_read(space->machine(), "AN_STEERING");
 }
 
 static READ8_DEVICE_HANDLER( tx1_ppi_porta_r )
 {
-	return tx1_ppi_latch_a;
+	tx1_state *state = device->machine().driver_data<tx1_state>();
+	return state->m_ppi_latch_a;
 }
 
 static READ8_DEVICE_HANDLER( tx1_ppi_portb_r )
 {
-	return input_port_read(device->machine, "PPI_PORTD") | tx1_ppi_latch_b;
+	tx1_state *state = device->machine().driver_data<tx1_state>();
+	return input_port_read(device->machine(), "PPI_PORTD") | state->m_ppi_latch_b;
 }
 
 
@@ -457,17 +450,17 @@ static UINT8 bit_reverse8(UINT8 val)
 static READ8_HANDLER( bb_analog_r )
 {
 	if (offset == 0)
-		return bit_reverse8(((input_port_read(space->machine, "AN_ACCELERATOR") & 0xf) << 4) | input_port_read(space->machine, "AN_STEERING"));
+		return bit_reverse8(((input_port_read(space->machine(), "AN_ACCELERATOR") & 0xf) << 4) | input_port_read(space->machine(), "AN_STEERING"));
 	else
-		return bit_reverse8((input_port_read(space->machine, "AN_BRAKE") & 0xf) << 4);
+		return bit_reverse8((input_port_read(space->machine(), "AN_BRAKE") & 0xf) << 4);
 }
 
 static READ8_HANDLER( bbjr_analog_r )
 {
 	if (offset == 0)
-		return ((input_port_read(space->machine, "AN_ACCELERATOR") & 0xf) << 4) | input_port_read(space->machine, "AN_STEERING");
+		return ((input_port_read(space->machine(), "AN_ACCELERATOR") & 0xf) << 4) | input_port_read(space->machine(), "AN_STEERING");
 	else
-		return (input_port_read(space->machine, "AN_BRAKE") & 0xf) << 4;
+		return (input_port_read(space->machine(), "AN_BRAKE") & 0xf) << 4;
 }
 
 
@@ -506,13 +499,13 @@ static const ppi8255_interface tx1_ppi8255_intf =
  *
  *************************************/
 
-static ADDRESS_MAP_START( tx1_main, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( tx1_main, AS_PROGRAM, 16 )
 	AM_RANGE(0x00000, 0x00fff) AM_MIRROR(0x1000) AM_RAM
 	AM_RANGE(0x02000, 0x02fff) AM_MIRROR(0x1000) AM_RAM
 	AM_RANGE(0x04000, 0x04fff) AM_MIRROR(0x1000) AM_RAM	AM_SHARE("nvram")
 	AM_RANGE(0x06000, 0x06fff) AM_READWRITE(tx1_crtc_r, tx1_crtc_w)
-	AM_RANGE(0x08000, 0x09fff) AM_RAM AM_BASE(&tx1_vram)
-	AM_RANGE(0x0a000, 0x0afff) AM_RAM AM_SHARE("share1") AM_BASE(&tx1_rcram)
+	AM_RANGE(0x08000, 0x09fff) AM_RAM AM_BASE_MEMBER(tx1_state, m_vram)
+	AM_RANGE(0x0a000, 0x0afff) AM_RAM AM_SHARE("share1") AM_BASE_MEMBER(tx1_state, m_rcram)
 	AM_RANGE(0x0b000, 0x0b001) AM_READWRITE(dipswitches_r, z80_busreq_w)
 	AM_RANGE(0x0c000, 0x0c001) AM_WRITE(tx1_scolst_w)
 	AM_RANGE(0x0d000, 0x0d003) AM_WRITE(tx1_slincs_w)
@@ -522,11 +515,11 @@ static ADDRESS_MAP_START( tx1_main, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xf0000, 0xfffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( tx1_math, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x00000, 0x007ff) AM_RAM AM_BASE(&tx1_math_ram)
+static ADDRESS_MAP_START( tx1_math, AS_PROGRAM, 16 )
+	AM_RANGE(0x00000, 0x007ff) AM_RAM AM_BASE_MEMBER(tx1_state, m_math_ram)
 	AM_RANGE(0x00800, 0x00fff) AM_READWRITE(tx1_spcs_ram_r, tx1_spcs_ram_w)
 	AM_RANGE(0x01000, 0x01fff) AM_RAM AM_SHARE("share1")
-	AM_RANGE(0x02000, 0x022ff) AM_RAM AM_BASE(&tx1_objram) AM_SIZE(&tx1_objram_size)
+	AM_RANGE(0x02000, 0x022ff) AM_RAM AM_BASE_MEMBER(tx1_state, m_objram)
 	AM_RANGE(0x02400, 0x027ff) AM_WRITE(tx1_bankcs_w)
 	AM_RANGE(0x02800, 0x02bff) AM_WRITE(halt_math_w)
 	AM_RANGE(0x02C00, 0x02fff) AM_WRITE(tx1_flgcs_w)
@@ -537,9 +530,9 @@ static ADDRESS_MAP_START( tx1_math, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xfc000, 0xfffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( tx1_sound_prg, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( tx1_sound_prg, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
-	AM_RANGE(0x3000, 0x37ff) AM_RAM AM_MIRROR(0x800) AM_BASE(&z80_ram)
+	AM_RANGE(0x3000, 0x37ff) AM_RAM AM_MIRROR(0x800) AM_BASE_MEMBER(tx1_state, m_z80_ram)
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(z80_intreq_w)
 	AM_RANGE(0x5000, 0x5003) AM_DEVREADWRITE("ppi8255", ppi8255_r, ppi8255_w)
 	AM_RANGE(0x6000, 0x6003) AM_DEVREADWRITE("tx1", tx1_pit8253_r, tx1_pit8253_w)
@@ -547,7 +540,7 @@ static ADDRESS_MAP_START( tx1_sound_prg, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xb000, 0xbfff) AM_READWRITE(ts_r, ts_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( tx1_sound_io, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( tx1_sound_io, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x40, 0x41) AM_DEVWRITE("aysnd", ay8910_data_address_w)
 ADDRESS_MAP_END
@@ -559,14 +552,14 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static ADDRESS_MAP_START( buggyboy_main, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( buggyboy_main, AS_PROGRAM, 16 )
 	AM_RANGE(0x00000, 0x03fff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x04000, 0x04fff) AM_READWRITE(tx1_crtc_r, tx1_crtc_w)
-	AM_RANGE(0x08000, 0x09fff) AM_RAM AM_BASE(&buggyboy_vram)
-	AM_RANGE(0x0a000, 0x0afff) AM_RAM AM_SHARE("share1") AM_BASE(&buggyboy_rcram) AM_SIZE(&buggyboy_rcram_size)
+	AM_RANGE(0x08000, 0x09fff) AM_RAM AM_BASE_MEMBER(tx1_state, m_vram)
+	AM_RANGE(0x0a000, 0x0afff) AM_RAM AM_SHARE("share1") AM_BASE_MEMBER(tx1_state, m_rcram)
 	AM_RANGE(0x0b000, 0x0b001) AM_READWRITE(dipswitches_r, z80_busreq_w)
 	AM_RANGE(0x0c000, 0x0c001) AM_WRITE(buggyboy_scolst_w)
-	AM_RANGE(0x0d000, 0x0d003) AM_WRITE(buggyboy_slincs_w)
+	AM_RANGE(0x0d000, 0x0d003) AM_WRITE(tx1_slincs_w)
 	AM_RANGE(0x0e000, 0x0e001) AM_WRITE(buggyboy_sky_w)
 	AM_RANGE(0x0f000, 0x0f003) AM_READWRITE(watchdog_reset16_r, resume_math_w)
 	AM_RANGE(0x10000, 0x1ffff) AM_READWRITE(z80_shared_r, z80_shared_w)
@@ -574,14 +567,14 @@ static ADDRESS_MAP_START( buggyboy_main, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xf0000, 0xfffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( buggybjr_main, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( buggybjr_main, AS_PROGRAM, 16 )
 	AM_RANGE(0x00000, 0x03fff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x04000, 0x04fff) AM_READWRITE(tx1_crtc_r, tx1_crtc_w)
-	AM_RANGE(0x08000, 0x08fff) AM_RAM AM_BASE(&buggyboy_vram)
-	AM_RANGE(0x0a000, 0x0afff) AM_RAM AM_SHARE("share1") AM_BASE(&buggyboy_rcram) AM_SIZE(&buggyboy_rcram_size)
+	AM_RANGE(0x08000, 0x08fff) AM_RAM AM_BASE_MEMBER(tx1_state, m_vram)
+	AM_RANGE(0x0a000, 0x0afff) AM_RAM AM_SHARE("share1") AM_BASE_MEMBER(tx1_state, m_rcram)
 	AM_RANGE(0x0b000, 0x0b001) AM_READWRITE(dipswitches_r, z80_busreq_w)
 	AM_RANGE(0x0c000, 0x0c001) AM_WRITE(buggyboy_scolst_w)
-	AM_RANGE(0x0d000, 0x0d003) AM_WRITE(buggyboy_slincs_w)
+	AM_RANGE(0x0d000, 0x0d003) AM_WRITE(tx1_slincs_w)
 	AM_RANGE(0x0e000, 0x0e001) AM_WRITE(buggyboy_sky_w)
 	AM_RANGE(0x0f000, 0x0f003) AM_READWRITE(watchdog_reset16_r, resume_math_w)
 	AM_RANGE(0x10000, 0x1ffff) AM_READWRITE(z80_shared_r, z80_shared_w)
@@ -589,11 +582,11 @@ static ADDRESS_MAP_START( buggybjr_main, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xf0000, 0xfffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( buggyboy_math, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x00000, 0x007ff) AM_RAM AM_BASE(&tx1_math_ram)
+static ADDRESS_MAP_START( buggyboy_math, AS_PROGRAM, 16 )
+	AM_RANGE(0x00000, 0x007ff) AM_RAM AM_BASE_MEMBER(tx1_state, m_math_ram)
 	AM_RANGE(0x00800, 0x00fff) AM_READWRITE(buggyboy_spcs_ram_r, buggyboy_spcs_ram_w)
 	AM_RANGE(0x01000, 0x01fff) AM_RAM AM_SHARE("share1")
-	AM_RANGE(0x02000, 0x022ff) AM_RAM AM_BASE(&buggyboy_objram) AM_SIZE(&buggyboy_objram_size)
+	AM_RANGE(0x02000, 0x022ff) AM_RAM AM_BASE_MEMBER(tx1_state, m_objram)
 	AM_RANGE(0x02400, 0x024ff) AM_WRITE(buggyboy_gas_w)
 	AM_RANGE(0x03000, 0x03fff) AM_READWRITE(buggyboy_math_r, buggyboy_math_w)
 	AM_RANGE(0x04000, 0x04fff) AM_ROM
@@ -604,9 +597,9 @@ static ADDRESS_MAP_START( buggyboy_math, ADDRESS_SPACE_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 /* Buggy Boy Sound PCB TC033A */
-static ADDRESS_MAP_START( buggyboy_sound_prg, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( buggyboy_sound_prg, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
-	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_BASE(&z80_ram)
+	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_BASE_MEMBER(tx1_state, m_z80_ram)
 	AM_RANGE(0x6000, 0x6001) AM_READ(bb_analog_r)
 	AM_RANGE(0x6800, 0x6803) AM_DEVREADWRITE("ppi8255", ppi8255_r, ppi8255_w)
 	AM_RANGE(0x7000, 0x7003) AM_DEVREADWRITE("buggyboy", tx1_pit8253_r, tx1_pit8253_w)
@@ -615,9 +608,9 @@ static ADDRESS_MAP_START( buggyboy_sound_prg, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 /* Buggy Boy Jr Sound PCB TC043 */
-static ADDRESS_MAP_START( buggybjr_sound_prg, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( buggybjr_sound_prg, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
-	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_BASE(&z80_ram)
+	AM_RANGE(0x4000, 0x47ff) AM_RAM AM_BASE_MEMBER(tx1_state, m_z80_ram)
 	AM_RANGE(0x5000, 0x5003) AM_DEVREADWRITE("buggyboy", tx1_pit8253_r, tx1_pit8253_w)
 	AM_RANGE(0x6000, 0x6001) AM_READ(bbjr_analog_r)
 	AM_RANGE(0x7000, 0x7000) AM_WRITE(z80_intreq_w)
@@ -625,7 +618,7 @@ static ADDRESS_MAP_START( buggybjr_sound_prg, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 /* Common */
-static ADDRESS_MAP_START( buggyboy_sound_io, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( buggyboy_sound_io, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x40, 0x40) AM_DEVREAD("ym1", ay8910_r)
 	AM_RANGE(0x40, 0x41) AM_DEVWRITE("ym1", ay8910_data_address_w)
@@ -701,7 +694,7 @@ static const ay8910_interface buggybjr_ym2149_interface_2 =
  *
  *************************************/
 
-static MACHINE_CONFIG_START( tx1, driver_device )
+static MACHINE_CONFIG_START( tx1, tx1_state )
 	MCFG_CPU_ADD("main_cpu", I8086, CPU_MASTER_CLOCK / 3)
 	MCFG_CPU_PROGRAM_MAP(tx1_main)
 //  MCFG_WATCHDOG_TIME_INIT(5)
@@ -721,24 +714,26 @@ static MACHINE_CONFIG_START( tx1, driver_device )
 
 	MCFG_PALETTE_LENGTH(256)
 	MCFG_PALETTE_INIT(tx1)
-	MCFG_VIDEO_EOF(tx1)
 
 	MCFG_DEFAULT_LAYOUT(layout_triphsxs)
 
 	MCFG_SCREEN_ADD("lscreen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_RAW_PARAMS(TX1_PIXEL_CLOCK, TX1_HTOTAL, TX1_HBEND, TX1_HBSTART, TX1_VTOTAL, TX1_VBEND, TX1_VBSTART)
+	MCFG_SCREEN_UPDATE(tx1)
 
 	MCFG_SCREEN_ADD("cscreen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_RAW_PARAMS(TX1_PIXEL_CLOCK, TX1_HTOTAL, TX1_HBEND, TX1_HBSTART, TX1_VTOTAL, TX1_VBEND, TX1_VBSTART)
+	MCFG_SCREEN_UPDATE(tx1)
 
 	MCFG_SCREEN_ADD("rscreen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_RAW_PARAMS(TX1_PIXEL_CLOCK, TX1_HTOTAL, TX1_HBEND, TX1_HBSTART, TX1_VTOTAL, TX1_VBEND, TX1_VBSTART)
+	MCFG_SCREEN_UPDATE(tx1)
+	MCFG_SCREEN_EOF(tx1)
 
 	MCFG_VIDEO_START(tx1)
-	MCFG_VIDEO_UPDATE(tx1)
 
 	MCFG_SPEAKER_STANDARD_STEREO("frontleft", "frontright")
 //  MCFG_SPEAKER_STANDARD_STEREO("rearleft", "rearright")
@@ -754,7 +749,7 @@ static MACHINE_CONFIG_START( tx1, driver_device )
 MACHINE_CONFIG_END
 
 
-static MACHINE_CONFIG_START( buggyboy, driver_device )
+static MACHINE_CONFIG_START( buggyboy, tx1_state )
 	MCFG_CPU_ADD("main_cpu", I8086, CPU_MASTER_CLOCK / 3)
 	MCFG_CPU_PROGRAM_MAP(buggyboy_main)
 //  MCFG_WATCHDOG_TIME_INIT(5)
@@ -777,20 +772,22 @@ static MACHINE_CONFIG_START( buggyboy, driver_device )
 	MCFG_SCREEN_ADD("lscreen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_RAW_PARAMS(BB_PIXEL_CLOCK, BB_HTOTAL, BB_HBEND, BB_HBSTART, BB_VTOTAL, BB_VBEND, BB_VBSTART)
+	MCFG_SCREEN_UPDATE(buggyboy)
 
 	MCFG_SCREEN_ADD("cscreen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_RAW_PARAMS(BB_PIXEL_CLOCK, BB_HTOTAL, BB_HBEND, BB_HBSTART, BB_VTOTAL, BB_VBEND, BB_VBSTART)
+	MCFG_SCREEN_UPDATE(buggyboy)
 
 	MCFG_SCREEN_ADD("rscreen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_RAW_PARAMS(BB_PIXEL_CLOCK, BB_HTOTAL, BB_HBEND, BB_HBSTART, BB_VTOTAL, BB_VBEND, BB_VBSTART)
+	MCFG_SCREEN_UPDATE(buggyboy)
+	MCFG_SCREEN_EOF(buggyboy)
 
 	MCFG_PALETTE_LENGTH(256)
 	MCFG_PALETTE_INIT(buggyboy)
 	MCFG_VIDEO_START(buggyboy)
-	MCFG_VIDEO_UPDATE(buggyboy)
-	MCFG_VIDEO_EOF(buggyboy)
 
 	MCFG_SPEAKER_STANDARD_STEREO("frontleft", "frontright")
 //  MCFG_SPEAKER_STANDARD_STEREO("rearleft", "rearright")
@@ -809,7 +806,7 @@ static MACHINE_CONFIG_START( buggyboy, driver_device )
 MACHINE_CONFIG_END
 
 
-static MACHINE_CONFIG_START( buggybjr, driver_device )
+static MACHINE_CONFIG_START( buggybjr, tx1_state )
 	MCFG_CPU_ADD("main_cpu", I8086, CPU_MASTER_CLOCK / 3)
 	MCFG_CPU_PROGRAM_MAP(buggybjr_main)
 //  MCFG_WATCHDOG_TIME_INIT(5)
@@ -822,19 +819,18 @@ static MACHINE_CONFIG_START( buggybjr, driver_device )
 	MCFG_CPU_IO_MAP(buggyboy_sound_io)
 	MCFG_CPU_PERIODIC_INT(z80_irq, BUGGYBOY_ZCLK / 2 / 4 / 2048)
 
-	MCFG_MACHINE_RESET(buggybjr)
+	MCFG_MACHINE_RESET(buggyboy)
 	MCFG_NVRAM_ADD_0FILL("nvram")
 
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-
 	MCFG_SCREEN_RAW_PARAMS(BB_PIXEL_CLOCK, BB_HTOTAL, BB_HBEND, BB_HBSTART, BB_VTOTAL, BB_VBEND, BB_VBSTART)
+	MCFG_SCREEN_UPDATE(buggybjr)
+	MCFG_SCREEN_EOF(buggyboy)
 
 	MCFG_PALETTE_LENGTH(256)
 	MCFG_PALETTE_INIT(buggyboy)
 	MCFG_VIDEO_START(buggybjr)
-	MCFG_VIDEO_UPDATE(buggybjr)
-	MCFG_VIDEO_EOF(buggyboy)
 
 	MCFG_SPEAKER_STANDARD_STEREO("frontleft", "frontright")
 //  MCFG_SPEAKER_STANDARD_STEREO("rearleft", "rearright")
