@@ -90,24 +90,30 @@ TODO :  This is a partially working driver.  Most of the memory maps for
 #include "machine/nvram.h"
 
 
-static UINT16* m68k_framebuffer[2];
-static UINT16* i860_framebuffer[2][2];
-static UINT16* framebuffer_ctrl;
-
-static UINT16* vid_0_shared_RAM;
-static UINT16* vid_1_shared_RAM;
-
-static int crtc_select;
-
-
-static VIDEO_UPDATE( vcombat )
+class vcombat_state : public driver_device
 {
-	int y;
-	const rgb_t *const pens = tlc34076_get_pens(screen->machine->device("tlc34076"));
-	device_t *aux = screen->machine->device("aux");
+public:
+	vcombat_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	UINT16 *m68k_buf = m68k_framebuffer[(*framebuffer_ctrl & 0x20) ? 1 : 0];
-	UINT16 *i860_buf = i860_framebuffer[(screen == aux) ? 1 : 0][0];
+	UINT16* m_m68k_framebuffer[2];
+	UINT16* m_i860_framebuffer[2][2];
+	UINT16* m_framebuffer_ctrl;
+	UINT16* m_vid_0_shared_RAM;
+	UINT16* m_vid_1_shared_RAM;
+	int m_crtc_select;
+};
+
+
+static SCREEN_UPDATE( vcombat )
+{
+	vcombat_state *state = screen->machine().driver_data<vcombat_state>();
+	int y;
+	const rgb_t *const pens = tlc34076_get_pens(screen->machine().device("tlc34076"));
+	device_t *aux = screen->machine().device("aux");
+
+	UINT16 *m68k_buf = state->m_m68k_framebuffer[(*state->m_framebuffer_ctrl & 0x20) ? 1 : 0];
+	UINT16 *i860_buf = state->m_i860_framebuffer[(screen == aux) ? 1 : 0][0];
 
 	/* TODO: It looks like the leftmost chunk of the ground should really be on the right side? */
 	/*       But the i860 draws the background correctly, so it may be an original game issue. */
@@ -152,11 +158,12 @@ static VIDEO_UPDATE( vcombat )
 
 static WRITE16_HANDLER( main_video_write )
 {
-	int fb = (*framebuffer_ctrl & 0x20) ? 0 : 1;
-	UINT16 old_data = m68k_framebuffer[fb][offset];
+	vcombat_state *state = space->machine().driver_data<vcombat_state>();
+	int fb = (*state->m_framebuffer_ctrl & 0x20) ? 0 : 1;
+	UINT16 old_data = state->m_m68k_framebuffer[fb][offset];
 
 	/* Transparency mode? */
-	if (*framebuffer_ctrl & 0x40)
+	if (*state->m_framebuffer_ctrl & 0x40)
 	{
 		if (data == 0x0000)
 			return;
@@ -166,27 +173,27 @@ static WRITE16_HANDLER( main_video_write )
 		if ((data & 0xff00) == 0)
 			data = (data & 0x00ff) | (old_data & 0xff00);
 
-		COMBINE_DATA(&m68k_framebuffer[fb][offset]);
+		COMBINE_DATA(&state->m_m68k_framebuffer[fb][offset]);
 	}
 	else
 	{
-		COMBINE_DATA(&m68k_framebuffer[fb][offset]);
+		COMBINE_DATA(&state->m_m68k_framebuffer[fb][offset]);
 	}
 }
 
 static READ16_HANDLER( control_1_r )
 {
-	return (input_port_read(space->machine, "IN0") << 8);
+	return (input_port_read(space->machine(), "IN0") << 8);
 }
 
 static READ16_HANDLER( control_2_r )
 {
-	return (input_port_read(space->machine, "IN1") << 8);
+	return (input_port_read(space->machine(), "IN1") << 8);
 }
 
 static READ16_HANDLER( control_3_r )
 {
-	return (input_port_read(space->machine, "IN2") << 8);
+	return (input_port_read(space->machine(), "IN2") << 8);
 }
 
 static void wiggle_i860_common(device_t *device, UINT16 data)
@@ -218,34 +225,35 @@ static void wiggle_i860_common(device_t *device, UINT16 data)
 
 static WRITE16_HANDLER( wiggle_i860p0_pins_w )
 {
-	wiggle_i860_common(space->machine->device("vid_0"), data);
+	wiggle_i860_common(space->machine().device("vid_0"), data);
 }
 
 static WRITE16_HANDLER( wiggle_i860p1_pins_w )
 {
-	wiggle_i860_common(space->machine->device("vid_1"), data);
+	wiggle_i860_common(space->machine().device("vid_1"), data);
 }
 
 static READ16_HANDLER( main_irqiack_r )
 {
 	//fprintf(stderr, "M0: irq iack\n");
-	cpu_set_input_line(space->machine->device("maincpu"), M68K_IRQ_1, CLEAR_LINE);
-	//cpu_set_input_line(space->machine->device("maincpu"), INPUT_LINE_RESET, CLEAR_LINE);
+	device_set_input_line(space->machine().device("maincpu"), M68K_IRQ_1, CLEAR_LINE);
+	//device_set_input_line(space->machine().device("maincpu"), INPUT_LINE_RESET, CLEAR_LINE);
 	return 0;
 }
 
 static READ16_HANDLER( sound_resetmain_r )
 {
 	//fprintf(stderr, "M1: reset line to M0\n");
-	//cpu_set_input_line(space->machine->device("maincpu"), INPUT_LINE_RESET, PULSE_LINE);
+	//device_set_input_line(space->machine().device("maincpu"), INPUT_LINE_RESET, PULSE_LINE);
 	return 0;
 }
 
 static WRITE64_HANDLER( v0_fb_w )
 {
+	vcombat_state *state = space->machine().driver_data<vcombat_state>();
 	/* The frame buffer seems to sit on a 32-bit data bus, while the
        i860 uses a 64-bit data bus.  Adjust accordingly.  */
-	char *p = (char *)(i860_framebuffer[0][0]);
+	char *p = (char *)(state->m_i860_framebuffer[0][0]);
 	int m = mem_mask;
 	int o = (offset << 2);
 	if (m & 0xff000000) {
@@ -266,9 +274,10 @@ static WRITE64_HANDLER( v0_fb_w )
    framebuffer.  */
 static WRITE64_HANDLER( v1_fb_w )
 {
+	vcombat_state *state = space->machine().driver_data<vcombat_state>();
 	/* The frame buffer seems to sit on a 32-bit data bus, while the
        i860 uses a 64-bit data bus.  Adjust accordingly.  */
-	char *p = (char *)(i860_framebuffer[1][0]);
+	char *p = (char *)(state->m_i860_framebuffer[1][0]);
 	int m = mem_mask;
 	int o = (offset << 2);
 	if (m & 0xff000000) {
@@ -287,17 +296,18 @@ static WRITE64_HANDLER( v1_fb_w )
 
 static WRITE16_HANDLER( crtc_w )
 {
-	device_t *crtc = space->machine->device("crtc");
+	vcombat_state *state = space->machine().driver_data<vcombat_state>();
+	mc6845_device *crtc = space->machine().device<mc6845_device>("crtc");
 
 	if (crtc == NULL)
 		return;
 
-	if (crtc_select == 0)
-		mc6845_address_w(crtc, 0, data >> 8);
+	if (state->m_crtc_select == 0)
+		crtc->address_w(*space, 0, data >> 8);
 	else
-		mc6845_register_w(crtc, 0, data >> 8);
+		crtc->register_w(*space, 0, data >> 8);
 
-	crtc_select ^= 1;
+	state->m_crtc_select ^= 1;
 }
 
 static WRITE16_DEVICE_HANDLER( vcombat_dac_w )
@@ -306,17 +316,17 @@ static WRITE16_DEVICE_HANDLER( vcombat_dac_w )
 	dac_signed_data_16_w(device, newval + 0x8000);
 }
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x200000, 0x20ffff) AM_RAM
 	AM_RANGE(0x300000, 0x30ffff) AM_WRITE(main_video_write)
 
-	AM_RANGE(0x400000, 0x43ffff) AM_RAM AM_BASE(&vid_0_shared_RAM) AM_SHARE("share2")	/* First i860 shared RAM */
+	AM_RANGE(0x400000, 0x43ffff) AM_RAM AM_BASE_MEMBER(vcombat_state, m_vid_0_shared_RAM) AM_SHARE("share2")	/* First i860 shared RAM */
 	AM_RANGE(0x440000, 0x440003) AM_RAM AM_SHARE("share6")		/* M0->P0 i860 #1 com 1 */
 	AM_RANGE(0x480000, 0x480003) AM_RAM AM_SHARE("share7")		/* M0<-P0 i860 #1 com 2 */
 	AM_RANGE(0x4c0000, 0x4c0003) AM_WRITE(wiggle_i860p0_pins_w)	/* i860 #1 stop/start/reset */
 
-	AM_RANGE(0x500000, 0x53ffff) AM_RAM AM_BASE(&vid_1_shared_RAM) AM_SHARE("share3")	/* Second i860 shared RAM */
+	AM_RANGE(0x500000, 0x53ffff) AM_RAM AM_BASE_MEMBER(vcombat_state, m_vid_1_shared_RAM) AM_SHARE("share3")	/* Second i860 shared RAM */
 	AM_RANGE(0x540000, 0x540003) AM_RAM AM_SHARE("share8")		/* M0->P1 i860 #2 com 1 */
 	AM_RANGE(0x580000, 0x580003) AM_RAM AM_SHARE("share9")		/* M0<-P1 i860 #2 com 2 */
 	AM_RANGE(0x5c0000, 0x5c0003) AM_WRITE(wiggle_i860p1_pins_w)	/* i860 #2 stop/start/reset */
@@ -327,7 +337,7 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x60001c, 0x60001d) AM_NOP
 
 	AM_RANGE(0x60000c, 0x60000d) AM_WRITE(crtc_w)
-	AM_RANGE(0x600010, 0x600011) AM_RAM AM_BASE(&framebuffer_ctrl)
+	AM_RANGE(0x600010, 0x600011) AM_RAM AM_BASE_MEMBER(vcombat_state, m_framebuffer_ctrl)
 	AM_RANGE(0x700000, 0x7007ff) AM_RAM AM_SHARE("nvram")
 	AM_RANGE(0x701000, 0x701001) AM_READ(main_irqiack_r)
 	AM_RANGE(0x702000, 0x702001) AM_READ(control_3_r)
@@ -341,7 +351,7 @@ ADDRESS_MAP_END
 
 
 /* The first i860 - middle board */
-static ADDRESS_MAP_START( vid_0_map, ADDRESS_SPACE_PROGRAM, 64 )
+static ADDRESS_MAP_START( vid_0_map, AS_PROGRAM, 64 )
 	AM_RANGE(0x00000000, 0x0001ffff) AM_RAM_WRITE(v0_fb_w)		/* Shared framebuffer - half of the bits lost to 32-bit bus */
 	AM_RANGE(0x20000000, 0x20000007) AM_RAM AM_SHARE("share6")		/* M0<-P0 com 1 (0x440000 in 68k-land) */
 	AM_RANGE(0x40000000, 0x401fffff) AM_ROM AM_REGION("gfx", 0)
@@ -352,7 +362,7 @@ ADDRESS_MAP_END
 
 
 /* The second i860 - top board */
-static ADDRESS_MAP_START( vid_1_map, ADDRESS_SPACE_PROGRAM, 64 )
+static ADDRESS_MAP_START( vid_1_map, AS_PROGRAM, 64 )
 	AM_RANGE(0x00000000, 0x0001ffff) AM_RAM_WRITE(v1_fb_w)		/* Half of the bits lost to 32-bit bus */
 	AM_RANGE(0x20000000, 0x20000007) AM_RAM AM_SHARE("share8")		/* M0->P1 com 1 (0x540000 in 68k-land) */
 	AM_RANGE(0x40000000, 0x401fffff) AM_ROM AM_REGION("gfx", 0)
@@ -363,7 +373,7 @@ ADDRESS_MAP_END
 
 
 /* Sound CPU */
-static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( sound_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
 	AM_RANGE(0x080000, 0x08ffff) AM_RAM
 	AM_RANGE(0x0c0000, 0x0c0001) AM_DEVWRITE("dac", vcombat_dac_w)
@@ -376,25 +386,28 @@ ADDRESS_MAP_END
 
 static MACHINE_RESET( vcombat )
 {
-	i860_set_pin(machine->device("vid_0"), DEC_PIN_BUS_HOLD, 1);
-	i860_set_pin(machine->device("vid_1"), DEC_PIN_BUS_HOLD, 1);
+	vcombat_state *state = machine.driver_data<vcombat_state>();
+	i860_set_pin(machine.device("vid_0"), DEC_PIN_BUS_HOLD, 1);
+	i860_set_pin(machine.device("vid_1"), DEC_PIN_BUS_HOLD, 1);
 
-	crtc_select = 0;
+	state->m_crtc_select = 0;
 }
 
 static MACHINE_RESET( shadfgtr )
 {
-	i860_set_pin(machine->device("vid_0"), DEC_PIN_BUS_HOLD, 1);
+	vcombat_state *state = machine.driver_data<vcombat_state>();
+	i860_set_pin(machine.device("vid_0"), DEC_PIN_BUS_HOLD, 1);
 
-	crtc_select = 0;
+	state->m_crtc_select = 0;
 }
 
 
 DIRECT_UPDATE_HANDLER( vcombat_vid_0_direct_handler )
 {
+	vcombat_state *state = machine.driver_data<vcombat_state>();
 	if (address >= 0xfffc0000 && address <= 0xffffffff)
 	{
-		direct.explicit_configure(0xfffc0000, 0xffffffff, 0x3ffff, vid_0_shared_RAM);
+		direct.explicit_configure(0xfffc0000, 0xffffffff, 0x3ffff, state->m_vid_0_shared_RAM);
 		return ~0;
 	}
 	return address;
@@ -402,9 +415,10 @@ DIRECT_UPDATE_HANDLER( vcombat_vid_0_direct_handler )
 
 DIRECT_UPDATE_HANDLER( vcombat_vid_1_direct_handler )
 {
+	vcombat_state *state = machine.driver_data<vcombat_state>();
 	if (address >= 0xfffc0000 && address <= 0xffffffff)
 	{
-		direct.explicit_configure(0xfffc0000, 0xffffffff, 0x3ffff, vid_1_shared_RAM);
+		direct.explicit_configure(0xfffc0000, 0xffffffff, 0x3ffff, state->m_vid_1_shared_RAM);
 		return ~0;
 	}
 	return address;
@@ -413,26 +427,27 @@ DIRECT_UPDATE_HANDLER( vcombat_vid_1_direct_handler )
 
 static DRIVER_INIT( vcombat )
 {
-	UINT8 *ROM = machine->region("maincpu")->base();
+	vcombat_state *state = machine.driver_data<vcombat_state>();
+	UINT8 *ROM = machine.region("maincpu")->base();
 
 	/* The two i860s execute out of RAM */
-	address_space *space = machine->device<i860_device>("vid_0")->space(AS_PROGRAM);
-	space->set_direct_update_handler(direct_update_delegate_create_static(vcombat_vid_0_direct_handler, *machine));
+	address_space *space = machine.device<i860_device>("vid_0")->space(AS_PROGRAM);
+	space->set_direct_update_handler(direct_update_delegate(FUNC(vcombat_vid_0_direct_handler), &machine));
 
-	space = machine->device<i860_device>("vid_1")->space(AS_PROGRAM);
-	space->set_direct_update_handler(direct_update_delegate_create_static(vcombat_vid_1_direct_handler, *machine));
+	space = machine.device<i860_device>("vid_1")->space(AS_PROGRAM);
+	space->set_direct_update_handler(direct_update_delegate(FUNC(vcombat_vid_1_direct_handler), &machine));
 
 	/* Allocate the 68000 framebuffers */
-	m68k_framebuffer[0] = auto_alloc_array(machine, UINT16, 0x8000);
-	m68k_framebuffer[1] = auto_alloc_array(machine, UINT16, 0x8000);
+	state->m_m68k_framebuffer[0] = auto_alloc_array(machine, UINT16, 0x8000);
+	state->m_m68k_framebuffer[1] = auto_alloc_array(machine, UINT16, 0x8000);
 
 	/* First i860 */
-	i860_framebuffer[0][0] = auto_alloc_array(machine, UINT16, 0x8000);
-	i860_framebuffer[0][1] = auto_alloc_array(machine, UINT16, 0x8000);
+	state->m_i860_framebuffer[0][0] = auto_alloc_array(machine, UINT16, 0x8000);
+	state->m_i860_framebuffer[0][1] = auto_alloc_array(machine, UINT16, 0x8000);
 
 	/* Second i860 */
-	i860_framebuffer[1][0] = auto_alloc_array(machine, UINT16, 0x8000);
-	i860_framebuffer[1][1] = auto_alloc_array(machine, UINT16, 0x8000);
+	state->m_i860_framebuffer[1][0] = auto_alloc_array(machine, UINT16, 0x8000);
+	state->m_i860_framebuffer[1][1] = auto_alloc_array(machine, UINT16, 0x8000);
 
 	/* pc==4016 : jump 4038 ... There's something strange about how it waits at 402e (interrupts all masked out)
        I think what is happening here is that M0 snags the first time
@@ -452,19 +467,20 @@ static DRIVER_INIT( vcombat )
 
 static DRIVER_INIT( shadfgtr )
 {
+	vcombat_state *state = machine.driver_data<vcombat_state>();
 	/* Allocate th 68000 frame buffers */
-	m68k_framebuffer[0] = auto_alloc_array(machine, UINT16, 0x8000);
-	m68k_framebuffer[1] = auto_alloc_array(machine, UINT16, 0x8000);
+	state->m_m68k_framebuffer[0] = auto_alloc_array(machine, UINT16, 0x8000);
+	state->m_m68k_framebuffer[1] = auto_alloc_array(machine, UINT16, 0x8000);
 
 	/* Only one i860 */
-	i860_framebuffer[0][0] = auto_alloc_array(machine, UINT16, 0x8000);
-	i860_framebuffer[0][1] = auto_alloc_array(machine, UINT16, 0x8000);
-	i860_framebuffer[1][0] = NULL;
-	i860_framebuffer[1][1] = NULL;
+	state->m_i860_framebuffer[0][0] = auto_alloc_array(machine, UINT16, 0x8000);
+	state->m_i860_framebuffer[0][1] = auto_alloc_array(machine, UINT16, 0x8000);
+	state->m_i860_framebuffer[1][0] = NULL;
+	state->m_i860_framebuffer[1][1] = NULL;
 
 	/* The i860 executes out of RAM */
-	address_space *space = machine->device<i860_device>("vid_0")->space(AS_PROGRAM);
-	space->set_direct_update_handler(direct_update_delegate_create_static(vcombat_vid_0_direct_handler, *machine));
+	address_space *space = machine.device<i860_device>("vid_0")->space(AS_PROGRAM);
+	space->set_direct_update_handler(direct_update_delegate(FUNC(vcombat_vid_0_direct_handler), &machine));
 }
 
 
@@ -529,7 +545,7 @@ INPUT_PORTS_END
 static WRITE_LINE_DEVICE_HANDLER(sound_update)
 {
 	/* Seems reasonable */
-	cpu_set_input_line(device->machine->device("soundcpu"), M68K_IRQ_1, state ? ASSERT_LINE : CLEAR_LINE);
+	device_set_input_line(device->machine().device("soundcpu"), M68K_IRQ_1, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static const mc6845_interface mc6845_intf =
@@ -547,7 +563,7 @@ static const mc6845_interface mc6845_intf =
 };
 
 
-static MACHINE_CONFIG_START( vcombat, driver_device )
+static MACHINE_CONFIG_START( vcombat, vcombat_state )
 	MCFG_CPU_ADD("maincpu", M68000, XTAL_12MHz)
 	MCFG_CPU_PROGRAM_MAP(main_map)
 	MCFG_CPU_VBLANK_INT("screen", irq1_line_assert)
@@ -570,7 +586,7 @@ static MACHINE_CONFIG_START( vcombat, driver_device )
 
 /* Temporary hack for experimenting with timing. */
 #if 0
-	//MCFG_QUANTUM_TIME(HZ(1200))
+	//MCFG_QUANTUM_TIME(attotime::from_hz(1200))
 	MCFG_QUANTUM_PERFECT_CPU("maincpu")
 #endif
 
@@ -583,12 +599,12 @@ static MACHINE_CONFIG_START( vcombat, driver_device )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_RAW_PARAMS(XTAL_12MHz / 2, 400, 0, 256, 291, 0, 208)
+	MCFG_SCREEN_UPDATE(vcombat)
 
 	MCFG_SCREEN_ADD("aux", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_RAW_PARAMS(XTAL_12MHz / 2, 400, 0, 256, 291, 0, 208)
-
-	MCFG_VIDEO_UPDATE(vcombat)
+	MCFG_SCREEN_UPDATE(vcombat)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
@@ -597,7 +613,7 @@ static MACHINE_CONFIG_START( vcombat, driver_device )
 MACHINE_CONFIG_END
 
 
-static MACHINE_CONFIG_START( shadfgtr, driver_device )
+static MACHINE_CONFIG_START( shadfgtr, vcombat_state )
 	MCFG_CPU_ADD("maincpu", M68000, XTAL_12MHz)
 	MCFG_CPU_PROGRAM_MAP(main_map)
 	MCFG_CPU_VBLANK_INT("screen", irq1_line_assert)
@@ -620,8 +636,7 @@ static MACHINE_CONFIG_START( shadfgtr, driver_device )
 	MCFG_SCREEN_ADD("screen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MCFG_SCREEN_RAW_PARAMS(XTAL_20MHz / 4, 320, 0, 256, 277, 0, 224)
-
-	MCFG_VIDEO_UPDATE(vcombat)
+	MCFG_SCREEN_UPDATE(vcombat)
 
 	MCFG_SPEAKER_STANDARD_MONO("mono")
 
