@@ -13,11 +13,11 @@
 #include "cpu/m6805/m6805.h"
 #include "cpu/m68000/m68000.h"
 #include "video/vector.h"
-#include "includes/vertigo.h"
-#include "includes/exidy440.h"
 #include "machine/74148.h"
 #include "machine/pit8253.h"
 #include "machine/nvram.h"
+#include "audio/exidy440.h"
+#include "includes/vertigo.h"
 
 
 
@@ -30,10 +30,10 @@
 static READ16_DEVICE_HANDLER( vertigo_pit8254_lsb_r ) { return pit8253_r( device, offset ); }
 static WRITE16_DEVICE_HANDLER( vertigo_pit8254_lsb_w ) { if (ACCESSING_BITS_0_7) pit8253_w(device, offset, data); }
 
-static ADDRESS_MAP_START( vertigo_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( vertigo_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x000007) AM_ROM
 	AM_RANGE(0x000008, 0x001fff) AM_RAM AM_MIRROR(0x010000)
-	AM_RANGE(0x002000, 0x003fff) AM_RAM AM_BASE(&vertigo_vectorram)
+	AM_RANGE(0x002000, 0x003fff) AM_RAM AM_BASE_MEMBER(vertigo_state, m_vectorram)
 	AM_RANGE(0x004000, 0x00400f) AM_READ(vertigo_io_convert) AM_MIRROR(0x001000)
 	AM_RANGE(0x004010, 0x00401f) AM_READ(vertigo_io_adc) AM_MIRROR(0x001000)
 	AM_RANGE(0x004020, 0x00402f) AM_READ(vertigo_coin_r) AM_MIRROR(0x001000)
@@ -56,7 +56,7 @@ ADDRESS_MAP_END
  *************************************/
 
 #if 0
-static ADDRESS_MAP_START( vertigo_motor, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( vertigo_motor, AS_PROGRAM, 8 )
 	AM_RANGE(0x010, 0x07f) AM_RAM
 	AM_RANGE(0x080, 0x7ff) AM_ROM
 ADDRESS_MAP_END
@@ -105,7 +105,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static MACHINE_CONFIG_START( vertigo, driver_device )
+static MACHINE_CONFIG_START( vertigo, vertigo_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", M68000, 8000000)
@@ -132,9 +132,9 @@ static MACHINE_CONFIG_START( vertigo, driver_device )
 	MCFG_SCREEN_REFRESH_RATE(60)
 	MCFG_SCREEN_SIZE(400, 300)
 	MCFG_SCREEN_VISIBLE_AREA(0, 510, 0, 400)
+	MCFG_SCREEN_UPDATE(vector)
 
 	MCFG_VIDEO_START(vector)
-	MCFG_VIDEO_UPDATE(vector)
 MACHINE_CONFIG_END
 
 
