@@ -127,28 +127,37 @@ out:
 #include "emu.h"
 #include "cpu/z80/z80.h"
 #include "cpu/tms32010/tms32010.h"
+#include "sound/3812intf.h"
 #include "includes/toaplipt.h"
 #include "includes/twincobr.h"
-#include "sound/3812intf.h"
 
 
+class wardner_state : public twincobr_state
+{
+public:
+	wardner_state(const machine_config &mconfig, device_type type, const char *tag)
+		: twincobr_state(mconfig, type,tag) { }
+
+	UINT8 *m_rambase_ae00;
+	UINT8 *m_rambase_c000;
+};
 
-static UINT8 *rambase_ae00, *rambase_c000;
 
 static WRITE8_HANDLER( wardner_ramrom_bank_sw )
 {
-	if (wardner_membank != data) {
+	wardner_state *state = space->machine().driver_data<wardner_state>();
+	if (state->m_wardner_membank != data) {
 		int bankaddress = 0;
 
 		address_space *mainspace;
-		UINT8 *RAM = space->machine->region("maincpu")->base();
+		UINT8 *RAM = space->machine().region("maincpu")->base();
 
-		mainspace = cputag_get_address_space(space->machine, "maincpu", ADDRESS_SPACE_PROGRAM);
-		wardner_membank = data;
+		mainspace = space->machine().device("maincpu")->memory().space(AS_PROGRAM);
+		state->m_wardner_membank = data;
 
 		if (data)
 		{
-			memory_install_read_bank(mainspace, 0x8000, 0xffff, 0, 0, "bank1");
+			mainspace->install_read_bank(0x8000, 0xffff, "bank1");
 			switch (data)
 			{
 				case 2:  bankaddress = 0x10000; break;
@@ -160,34 +169,35 @@ static WRITE8_HANDLER( wardner_ramrom_bank_sw )
 				case 6:  bankaddress = 0x30000; break; /* not used */
 				default: bankaddress = 0x00000; break; /* not used */
 			}
-			memory_set_bankptr(space->machine, "bank1",&RAM[bankaddress]);
+			memory_set_bankptr(space->machine(), "bank1",&RAM[bankaddress]);
 		}
 		else
 		{
-			memory_install_read8_handler(mainspace, 0x8000, 0x8fff, 0, 0, wardner_sprite_r);
-			memory_install_read_bank(mainspace, 0xa000, 0xadff, 0, 0, "bank4");
-			memory_install_read_bank(mainspace, 0xae00, 0xafff, 0, 0, "bank2");
-			memory_install_read_bank(mainspace, 0xc000, 0xc7ff, 0, 0, "bank3");
-			memory_set_bankptr(space->machine, "bank1", &RAM[0x0000]);
-			memory_set_bankptr(space->machine, "bank2", rambase_ae00);
-			memory_set_bankptr(space->machine, "bank3", rambase_c000);
-			memory_set_bankptr(space->machine, "bank4", space->machine->generic.paletteram.v);
+			mainspace->install_legacy_read_handler(0x8000, 0x8fff, FUNC(wardner_sprite_r));
+			mainspace->install_read_bank(0xa000, 0xadff, "bank4");
+			mainspace->install_read_bank(0xae00, 0xafff, "bank2");
+			mainspace->install_read_bank(0xc000, 0xc7ff, "bank3");
+			memory_set_bankptr(space->machine(), "bank1", &RAM[0x0000]);
+			memory_set_bankptr(space->machine(), "bank2", state->m_rambase_ae00);
+			memory_set_bankptr(space->machine(), "bank3", state->m_rambase_c000);
+			memory_set_bankptr(space->machine(), "bank4", space->machine().generic.paletteram.v);
 		}
 	}
 }
 
-STATE_POSTLOAD( wardner_restore_bank )
+void wardner_restore_bank(running_machine &machine)
 {
-	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
+	wardner_state *state = machine.driver_data<wardner_state>();
+	address_space *space = machine.device("maincpu")->memory().space(AS_PROGRAM);
 
 	wardner_ramrom_bank_sw(space,0,1);	/* Dummy value to ensure restoration */
-	wardner_ramrom_bank_sw(space,0,wardner_membank);
+	wardner_ramrom_bank_sw(space,0,state->m_wardner_membank);
 }
 
 
 /***************************** Z80 Main Memory Map **************************/
 
-static ADDRESS_MAP_START( main_program_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( main_program_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x6fff) AM_ROM
 	AM_RANGE(0x7000, 0x7fff) AM_RAM
 
@@ -196,16 +206,16 @@ static ADDRESS_MAP_START( main_program_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8000, 0x8fff) AM_WRITE(wardner_sprite_w) AM_BASE_SIZE_GENERIC(spriteram)
 	AM_RANGE(0x9000, 0x9fff) AM_ROM
 	AM_RANGE(0xa000, 0xadff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_le_w) AM_BASE_GENERIC(paletteram)
-	AM_RANGE(0xae00, 0xafff) AM_RAM AM_BASE(&rambase_ae00)
+	AM_RANGE(0xae00, 0xafff) AM_RAM AM_BASE_MEMBER(wardner_state, m_rambase_ae00)
 	AM_RANGE(0xb000, 0xbfff) AM_ROM
-	AM_RANGE(0xc000, 0xc7ff) AM_RAM AM_BASE(&rambase_c000) AM_SHARE("share1")	/* Shared RAM with Sound Z80 */
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM AM_BASE_MEMBER(wardner_state, m_rambase_c000) AM_SHARE("share1")	/* Shared RAM with Sound Z80 */
 	AM_RANGE(0xc800, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( main_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( main_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
-	AM_RANGE(0x00, 0x00) AM_DEVWRITE("crtc", mc6845_address_w)
-	AM_RANGE(0x02, 0x02) AM_DEVWRITE("crtc", mc6845_register_w)
+	AM_RANGE(0x00, 0x00) AM_DEVWRITE_MODERN("crtc", mc6845_device, address_w)
+	AM_RANGE(0x02, 0x02) AM_DEVWRITE_MODERN("crtc", mc6845_device, register_w)
 	AM_RANGE(0x10, 0x13) AM_WRITE(wardner_txscroll_w)		/* scroll text layer */
 	AM_RANGE(0x14, 0x15) AM_WRITE(wardner_txlayer_w)		/* offset in text video RAM */
 	AM_RANGE(0x20, 0x23) AM_WRITE(wardner_bgscroll_w)		/* scroll bg layer */
@@ -227,7 +237,7 @@ ADDRESS_MAP_END
 
 /***************************** Z80 Sound Memory Map *************************/
 
-static ADDRESS_MAP_START( sound_program_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_program_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0x807f) AM_RAM
 	AM_RANGE(0xc000, 0xc7ff) AM_RAM AM_SHARE("share1")	/* Shared RAM with Main Z80 */
@@ -235,7 +245,7 @@ static ADDRESS_MAP_START( sound_program_map, ADDRESS_SPACE_PROGRAM, 8 )
 
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_io_map, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( sound_io_map, AS_IO, 8 )
 	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x01) AM_DEVREADWRITE("ymsnd", ym3812_r, ym3812_w)
 ADDRESS_MAP_END
@@ -243,13 +253,13 @@ ADDRESS_MAP_END
 
 /***************************** TMS32010 Memory Map **************************/
 
-static ADDRESS_MAP_START( DSP_program_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( DSP_program_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000, 0x5ff) AM_ROM
 ADDRESS_MAP_END
 
 	/* $000 - 08F  TMS32010 Internal Data RAM in Data Address Space */
 
-static ADDRESS_MAP_START( DSP_io_map, ADDRESS_SPACE_IO, 16 )
+static ADDRESS_MAP_START( DSP_io_map, AS_IO, 16 )
 	AM_RANGE(0, 0) AM_WRITE(wardner_dsp_addrsel_w)
 	AM_RANGE(1, 1) AM_READWRITE(wardner_dsp_r, wardner_dsp_w)
 	AM_RANGE(3, 3) AM_WRITE(twincobr_dsp_bio_w)
@@ -373,7 +383,7 @@ static const gfx_layout spritelayout =
 /* handler called by the 3812 emulator when the internal timers cause an IRQ */
 static void irqhandler(device_t *device, int linestate)
 {
-	cputag_set_input_line(device->machine, "audiocpu", 0, linestate);
+	cputag_set_input_line(device->machine(), "audiocpu", 0, linestate);
 }
 
 static const ym3812_interface ym3812_config =
@@ -392,7 +402,7 @@ GFXDECODE_END
 
 
 
-static MACHINE_CONFIG_START( wardner, driver_device )
+static MACHINE_CONFIG_START( wardner, wardner_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80, XTAL_24MHz/4)		/* 6MHz */
@@ -409,7 +419,7 @@ static MACHINE_CONFIG_START( wardner, driver_device )
 	/* Data Map is internal to the CPU */
 	MCFG_CPU_IO_MAP(DSP_io_map)
 
-	MCFG_QUANTUM_TIME(HZ(6000))						/* 100 CPU slices per frame */
+	MCFG_QUANTUM_TIME(attotime::from_hz(6000))						/* 100 CPU slices per frame */
 
 	MCFG_MACHINE_RESET(wardner)
 
@@ -419,18 +429,15 @@ static MACHINE_CONFIG_START( wardner, driver_device )
 	MCFG_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK | VIDEO_BUFFERS_SPRITERAM)
 
 	MCFG_SCREEN_ADD("screen", RASTER)
-	MCFG_SCREEN_REFRESH_RATE( (XTAL_14MHz / 2) / (446 * 286) )
-	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MCFG_SCREEN_RAW_PARAMS(XTAL_14MHz/2, 446, 0, 320, 286, 0, 240)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MCFG_SCREEN_SIZE(64*8, 64*8)
-	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(toaplan0)
+	MCFG_SCREEN_EOF(toaplan0)
 
 	MCFG_GFXDECODE(wardner)
 	MCFG_PALETTE_LENGTH(1792)
 
 	MCFG_VIDEO_START(toaplan0)
-	MCFG_VIDEO_EOF(toaplan0)
-	MCFG_VIDEO_UPDATE(toaplan0)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
