@@ -164,36 +164,36 @@ static MACHINE_RESET( taito_dualscreen );
                           SOUND
 ***********************************************************/
 
-static void reset_sound_region( running_machine *machine )
+static void reset_sound_region( running_machine &machine )
 {
-	warriorb_state *state = machine->driver_data<warriorb_state>();
-	memory_set_bank(machine, "bank10", state->banknum);
+	warriorb_state *state = machine.driver_data<warriorb_state>();
+	memory_set_bank(machine, "bank10", state->m_banknum);
 }
 
 static WRITE8_HANDLER( sound_bankswitch_w )
 {
-	warriorb_state *state = space->machine->driver_data<warriorb_state>();
+	warriorb_state *state = space->machine().driver_data<warriorb_state>();
 
-	state->banknum = data & 7;
-	reset_sound_region(space->machine);
+	state->m_banknum = data & 7;
+	reset_sound_region(space->machine());
 }
 
 static WRITE16_HANDLER( warriorb_sound_w )
 {
-	warriorb_state *state = space->machine->driver_data<warriorb_state>();
+	warriorb_state *state = space->machine().driver_data<warriorb_state>();
 
 	if (offset == 0)
-		tc0140syt_port_w(state->tc0140syt, 0, data & 0xff);
+		tc0140syt_port_w(state->m_tc0140syt, 0, data & 0xff);
 	else if (offset == 1)
-		tc0140syt_comm_w(state->tc0140syt, 0, data & 0xff);
+		tc0140syt_comm_w(state->m_tc0140syt, 0, data & 0xff);
 }
 
 static READ16_HANDLER( warriorb_sound_r )
 {
-	warriorb_state *state = space->machine->driver_data<warriorb_state>();
+	warriorb_state *state = space->machine().driver_data<warriorb_state>();
 
 	if (offset == 1)
-		return ((tc0140syt_comm_r(state->tc0140syt, 0) & 0xff));
+		return ((tc0140syt_comm_r(state->m_tc0140syt, 0) & 0xff));
 	else
 		return 0;
 }
@@ -201,37 +201,37 @@ static READ16_HANDLER( warriorb_sound_r )
 
 static WRITE8_HANDLER( warriorb_pancontrol )
 {
-	warriorb_state *state = space->machine->driver_data<warriorb_state>();
+	warriorb_state *state = space->machine().driver_data<warriorb_state>();
 	device_t *flt = NULL;
 	offset &= 3;
 
 	switch (offset)
 	{
-		case 0: flt = state->_2610_1l; break;
-		case 1: flt = state->_2610_1r; break;
-		case 2: flt = state->_2610_2l; break;
-		case 3: flt = state->_2610_2r; break;
+		case 0: flt = state->m_2610_1l; break;
+		case 1: flt = state->m_2610_1r; break;
+		case 2: flt = state->m_2610_2l; break;
+		case 3: flt = state->m_2610_2r; break;
 	}
 
-	state->pandata[offset] = (data << 1) + data;   /* original volume*3 */
-	//popmessage(" pan %02x %02x %02x %02x", state->pandata[0], state->pandata[1], state->pandata[2], state->pandata[3] );
-	flt_volume_set_volume(flt, state->pandata[offset] / 100.0);
+	state->m_pandata[offset] = (data << 1) + data;   /* original volume*3 */
+	//popmessage(" pan %02x %02x %02x %02x", state->m_pandata[0], state->m_pandata[1], state->m_pandata[2], state->m_pandata[3] );
+	flt_volume_set_volume(flt, state->m_pandata[offset] / 100.0);
 }
 
 
 static WRITE16_HANDLER( tc0100scn_dual_screen_w )
 {
-	warriorb_state *state = space->machine->driver_data<warriorb_state>();
+	warriorb_state *state = space->machine().driver_data<warriorb_state>();
 
-	tc0100scn_word_w(state->tc0100scn_1, offset, data, mem_mask);
-	tc0100scn_word_w(state->tc0100scn_2, offset, data, mem_mask);
+	tc0100scn_word_w(state->m_tc0100scn_1, offset, data, mem_mask);
+	tc0100scn_word_w(state->m_tc0100scn_2, offset, data, mem_mask);
 }
 
 /***********************************************************
                       MEMORY STRUCTURES
 ***********************************************************/
 
-static ADDRESS_MAP_START( darius2d_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( darius2d_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x100000, 0x10ffff) AM_RAM		/* main ram */
 	AM_RANGE(0x200000, 0x213fff) AM_DEVREAD("tc0100scn_1", tc0100scn_word_r) AM_WRITE(tc0100scn_dual_screen_w)	/* tilemaps (all screens) */
@@ -241,13 +241,13 @@ static ADDRESS_MAP_START( darius2d_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x260000, 0x26000f) AM_DEVREADWRITE("tc0100scn_2", tc0100scn_ctrl_word_r, tc0100scn_ctrl_word_w)
 	AM_RANGE(0x400000, 0x400007) AM_DEVREADWRITE("tc0110pcr_1", tc0110pcr_word_r, tc0110pcr_step1_word_w)	/* palette (1st screen) */
 	AM_RANGE(0x420000, 0x420007) AM_DEVREADWRITE("tc0110pcr_2", tc0110pcr_word_r, tc0110pcr_step1_word_w)	/* palette (2nd screen) */
-	AM_RANGE(0x600000, 0x6013ff) AM_RAM AM_BASE_SIZE_MEMBER(warriorb_state, spriteram, spriteram_size)
+	AM_RANGE(0x600000, 0x6013ff) AM_RAM AM_BASE_SIZE_MEMBER(warriorb_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x800000, 0x80000f) AM_DEVREADWRITE8("tc0220ioc", tc0220ioc_r, tc0220ioc_w, 0x00ff)
 //  AM_RANGE(0x820000, 0x820001) AM_WRITENOP    // ???
 	AM_RANGE(0x830000, 0x830003) AM_READWRITE(warriorb_sound_r, warriorb_sound_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( warriorb_map, ADDRESS_SPACE_PROGRAM, 16 )
+static ADDRESS_MAP_START( warriorb_map, AS_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x1fffff) AM_ROM
 	AM_RANGE(0x200000, 0x213fff) AM_RAM
 	AM_RANGE(0x300000, 0x313fff) AM_DEVREAD("tc0100scn_1", tc0100scn_word_r) AM_WRITE(tc0100scn_dual_screen_w)	/* tilemaps (all screens) */
@@ -256,7 +256,7 @@ static ADDRESS_MAP_START( warriorb_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x360000, 0x36000f) AM_DEVREADWRITE("tc0100scn_2", tc0100scn_ctrl_word_r, tc0100scn_ctrl_word_w)
 	AM_RANGE(0x400000, 0x400007) AM_DEVREADWRITE("tc0110pcr_1", tc0110pcr_word_r, tc0110pcr_step1_word_w)	/* palette (1st screen) */
 	AM_RANGE(0x420000, 0x420007) AM_DEVREADWRITE("tc0110pcr_2", tc0110pcr_word_r, tc0110pcr_step1_word_w)	/* palette (2nd screen) */
-	AM_RANGE(0x600000, 0x6013ff) AM_RAM AM_BASE_SIZE_MEMBER(warriorb_state, spriteram, spriteram_size)
+	AM_RANGE(0x600000, 0x6013ff) AM_RAM AM_BASE_SIZE_MEMBER(warriorb_state, m_spriteram, m_spriteram_size)
 	AM_RANGE(0x800000, 0x80000f) AM_DEVREADWRITE("tc0510nio", tc0510nio_halfword_r, tc0510nio_halfword_w)
 //  AM_RANGE(0x820000, 0x820001) AM_WRITENOP    // ? uses bits 0,2,3
 	AM_RANGE(0x830000, 0x830003) AM_READWRITE(warriorb_sound_r, warriorb_sound_w)
@@ -264,7 +264,7 @@ ADDRESS_MAP_END
 
 /***************************************************************************/
 
-static ADDRESS_MAP_START( z80_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( z80_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x7fff) AM_ROMBANK("bank10")
 	AM_RANGE(0xc000, 0xdfff) AM_RAM
@@ -419,8 +419,8 @@ GFXDECODE_END
 /* handler called by the YM2610 emulator when the internal timers cause an IRQ */
 static void irqhandler( device_t *device, int irq )
 {
-	warriorb_state *state = device->machine->driver_data<warriorb_state>();
-	cpu_set_input_line(state->audiocpu, 0, irq ? ASSERT_LINE : CLEAR_LINE);
+	warriorb_state *state = device->machine().driver_data<warriorb_state>();
+	device_set_input_line(state->m_audiocpu, 0, irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static const ym2610_interface ym2610_config =
@@ -531,44 +531,39 @@ static const tc0140syt_interface warriorb_tc0140syt_intf =
 };
 
 
-static STATE_POSTLOAD( warriorb_postload )
-{
-	reset_sound_region(machine);
-}
-
 static MACHINE_START( warriorb )
 {
-	warriorb_state *state = machine->driver_data<warriorb_state>();
+	warriorb_state *state = machine.driver_data<warriorb_state>();
 
-	memory_configure_bank(machine, "bank10", 0, 8, machine->region("audiocpu")->base() + 0xc000, 0x4000);
+	memory_configure_bank(machine, "bank10", 0, 8, machine.region("audiocpu")->base() + 0xc000, 0x4000);
 
-	state->maincpu = machine->device("maincpu");
-	state->audiocpu = machine->device("audiocpu");
-	state->tc0140syt = machine->device("tc0140syt");
-	state->tc0100scn_1 = machine->device("tc0100scn_1");
-	state->tc0100scn_2 = machine->device("tc0100scn_2");
+	state->m_maincpu = machine.device("maincpu");
+	state->m_audiocpu = machine.device("audiocpu");
+	state->m_tc0140syt = machine.device("tc0140syt");
+	state->m_tc0100scn_1 = machine.device("tc0100scn_1");
+	state->m_tc0100scn_2 = machine.device("tc0100scn_2");
 
-	state->lscreen = machine->device("lscreen");
-	state->rscreen = machine->device("rscreen");
+	state->m_lscreen = machine.device("lscreen");
+	state->m_rscreen = machine.device("rscreen");
 
-	state->_2610_1l = machine->device("2610.1.l");
-	state->_2610_1r = machine->device("2610.1.r");
-	state->_2610_2l = machine->device("2610.2.l");
-	state->_2610_2r = machine->device("2610.2.r");
+	state->m_2610_1l = machine.device("2610.1.l");
+	state->m_2610_1r = machine.device("2610.1.r");
+	state->m_2610_2l = machine.device("2610.2.l");
+	state->m_2610_2r = machine.device("2610.2.r");
 
-	state_save_register_global(machine, state->banknum);
-	state_save_register_global_array(machine, state->pandata);
-	state_save_register_postload(machine, warriorb_postload, NULL);
+	state->save_item(NAME(state->m_banknum));
+	state->save_item(NAME(state->m_pandata));
+	machine.save().register_postload(save_prepost_delegate(FUNC(reset_sound_region), &machine));
 }
 
 static MACHINE_RESET( taito_dualscreen )
 {
-	warriorb_state *state = machine->driver_data<warriorb_state>();
+	warriorb_state *state = machine.driver_data<warriorb_state>();
 
-	state->banknum = 0;
+	state->m_banknum = 0;
 
 	/**** mixer control enable ****/
-	sound_global_enable(machine, 1);	/* mixer enabled */
+	machine.sound().system_enable(true);	/* mixer enabled */
 }
 
 static MACHINE_CONFIG_START( darius2d, warriorb_state )
@@ -597,6 +592,7 @@ static MACHINE_CONFIG_START( darius2d, warriorb_state )
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 3*8, 32*8-1)
+	MCFG_SCREEN_UPDATE(warriorb)
 
 	MCFG_SCREEN_ADD("rscreen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -604,9 +600,9 @@ static MACHINE_CONFIG_START( darius2d, warriorb_state )
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 3*8, 32*8-1)
+	MCFG_SCREEN_UPDATE(warriorb)
 
 	MCFG_VIDEO_START(warriorb)
-	MCFG_VIDEO_UPDATE(warriorb)
 
 	MCFG_TC0100SCN_ADD("tc0100scn_1", darius2d_tc0100scn_intf_l)
 	MCFG_TC0100SCN_ADD("tc0100scn_2", darius2d_tc0100scn_intf_r)
@@ -664,6 +660,7 @@ static MACHINE_CONFIG_START( warriorb, warriorb_state )
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 2*8, 32*8-1)
+	MCFG_SCREEN_UPDATE(warriorb)
 
 	MCFG_SCREEN_ADD("rscreen", RASTER)
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
@@ -671,9 +668,9 @@ static MACHINE_CONFIG_START( warriorb, warriorb_state )
 	MCFG_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MCFG_SCREEN_SIZE(40*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 2*8, 32*8-1)
+	MCFG_SCREEN_UPDATE(warriorb)
 
 	MCFG_VIDEO_START(warriorb)
-	MCFG_VIDEO_UPDATE(warriorb)
 
 	MCFG_TC0100SCN_ADD("tc0100scn_1", warriorb_tc0100scn_intf_l)
 	MCFG_TC0100SCN_ADD("tc0100scn_2", warriorb_tc0100scn_intf_r)
