@@ -159,7 +159,6 @@ Stephh's notes (based on the games Z80 code and some tests) :
 
 #include "emu.h"
 #include "cpu/z80/z80.h"
-#include "deprecat.h"
 #include "sound/ay8910.h"
 #include "sound/discrete.h"
 #include "includes/wiz.h"
@@ -169,11 +168,11 @@ Stephh's notes (based on the games Z80 code and some tests) :
 #define STINGER_BOOM_EN1	NODE_03
 #define STINGER_BOOM_EN2	NODE_04
 
-static int dsc0, dsc1;
 
 static WRITE8_HANDLER( sound_command_w )
 {
-	device_t *discrete = space->machine->device("discrete");
+	wiz_state *state = space->machine().driver_data<wiz_state>();
+	device_t *discrete = space->machine().device("discrete");
 
 	switch (offset)
 	{
@@ -184,52 +183,60 @@ static WRITE8_HANDLER( sound_command_w )
 
 		// explosion sound trigger(analog?)
 		case 0x08:
-			discrete_sound_w(discrete, STINGER_BOOM_EN1, dsc1);
-			discrete_sound_w(discrete, STINGER_BOOM_EN2, dsc1^=1);
+			discrete_sound_w(discrete, STINGER_BOOM_EN1, state->m_dsc1);
+			discrete_sound_w(discrete, STINGER_BOOM_EN2, state->m_dsc1^=1);
 		break;
 
 		// player shot sound trigger(analog?)
 		case 0x0a:
-			discrete_sound_w(discrete, STINGER_SHOT_EN1, dsc0);
-			discrete_sound_w(discrete, STINGER_SHOT_EN2, dsc0^=1);
+			discrete_sound_w(discrete, STINGER_SHOT_EN1, state->m_dsc0);
+			discrete_sound_w(discrete, STINGER_SHOT_EN2, state->m_dsc0^=1);
 		break;
 	}
 }
 
 static READ8_HANDLER( wiz_protection_r )
 {
-	switch (wiz_colorram2[0])
+	wiz_state *state = space->machine().driver_data<wiz_state>();
+	switch (state->m_colorram2[0])
 	{
 	case 0x35: return 0x25;	/* FIX: sudden player death + free play afterwards   */
 	case 0x8f: return 0x1f;	/* FIX: early boss appearance with corrupt graphics  */
 	case 0xa0: return 0x00;	/* FIX: executing junk code after defeating the boss */
 	}
 
-	return wiz_colorram2[0];
+	return state->m_colorram2[0];
 }
 
 static WRITE8_HANDLER( wiz_coin_counter_w )
 {
-	coin_counter_w(space->machine, offset,data);
+	coin_counter_w(space->machine(), offset,data);
 }
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+static WRITE8_HANDLER( wiz_nmi_mask_w )
+{
+	wiz_state *state = space->machine().driver_data<wiz_state>();
+
+	state->m_nmi_mask = data & 1;
+}
+
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xc7ff) AM_RAM
 	AM_RANGE(0xc800, 0xc801) AM_WRITE(wiz_coin_counter_w)
-	AM_RANGE(0xd000, 0xd3ff) AM_BASE(&wiz_videoram2)					/* Fallthrough */
-	AM_RANGE(0xd400, 0xd7ff) AM_BASE(&wiz_colorram2)
-	AM_RANGE(0xd800, 0xd83f) AM_BASE(&wiz_attributesram2)
-	AM_RANGE(0xd840, 0xd85f) AM_BASE_GENERIC(spriteram2) AM_SIZE_GENERIC(spriteram)
+	AM_RANGE(0xd000, 0xd3ff) AM_BASE_MEMBER(wiz_state, m_videoram2)					/* Fallthrough */
+	AM_RANGE(0xd400, 0xd7ff) AM_BASE_MEMBER(wiz_state, m_colorram2)
+	AM_RANGE(0xd800, 0xd83f) AM_BASE_MEMBER(wiz_state, m_attributesram2)
+	AM_RANGE(0xd840, 0xd85f) AM_BASE_MEMBER(wiz_state, m_spriteram2) AM_SIZE_MEMBER(wiz_state, m_spriteram_size)
 	AM_RANGE(0xd000, 0xd85f) AM_RAM
-	AM_RANGE(0xe000, 0xe3ff) AM_BASE_MEMBER(wiz_state, videoram)	/* Fallthrough */
+	AM_RANGE(0xe000, 0xe3ff) AM_BASE_MEMBER(wiz_state, m_videoram)	/* Fallthrough */
 	AM_RANGE(0xe400, 0xe7ff) AM_RAM
-	AM_RANGE(0xe800, 0xe83f) AM_BASE(&wiz_attributesram)
-	AM_RANGE(0xe840, 0xe85f) AM_BASE_GENERIC(spriteram)
+	AM_RANGE(0xe800, 0xe83f) AM_BASE_MEMBER(wiz_state, m_attributesram)
+	AM_RANGE(0xe840, 0xe85f) AM_BASE_MEMBER(wiz_state, m_spriteram)
 	AM_RANGE(0xe000, 0xe85f) AM_RAM
 	AM_RANGE(0xf000, 0xf000) AM_READ_PORT("DSW0")
-	AM_RANGE(0xf000, 0xf000) AM_RAM AM_BASE(&wiz_sprite_bank)
-	AM_RANGE(0xf001, 0xf001) AM_WRITE(interrupt_enable_w)
+	AM_RANGE(0xf000, 0xf000) AM_RAM AM_BASE_MEMBER(wiz_state, m_sprite_bank)
+	AM_RANGE(0xf001, 0xf001) AM_WRITE(wiz_nmi_mask_w)
 	AM_RANGE(0xf002, 0xf003) AM_WRITE(wiz_palettebank_w)
 	AM_RANGE(0xf004, 0xf005) AM_WRITE(wiz_char_bank_select_w)
 	AM_RANGE(0xf006, 0xf006) AM_WRITE(wiz_flipx_w)
@@ -243,7 +250,7 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xf818, 0xf818) AM_WRITE(wiz_bgcolor_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x23ff) AM_RAM
 	AM_RANGE(0x3000, 0x3000) AM_READWRITE(soundlatch_r,interrupt_enable_w)	/* Stinger/Scion */
@@ -253,7 +260,7 @@ static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x7000, 0x7000) AM_READWRITE(soundlatch_r,interrupt_enable_w)	/* Wiz */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( stinger_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( stinger_sound_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x2000, 0x23ff) AM_RAM
 	AM_RANGE(0x3000, 0x3000) AM_READWRITE(soundlatch_r,interrupt_enable_w)	/* Stinger/Scion */
@@ -676,7 +683,16 @@ DISCRETE_SOUND_END
 
 static MACHINE_RESET( wiz )
 {
-	dsc0 = dsc1 = 1;
+	wiz_state *state = machine.driver_data<wiz_state>();
+	state->m_dsc0 = state->m_dsc1 = 1;
+}
+
+static INTERRUPT_GEN( wiz_vblank_irq )
+{
+	wiz_state *state = device->machine().driver_data<wiz_state>();
+
+	if(state->m_nmi_mask & 1)
+		device_set_input_line(device,INPUT_LINE_NMI,PULSE_LINE);
 }
 
 static MACHINE_CONFIG_START( wiz, wiz_state )
@@ -684,11 +700,11 @@ static MACHINE_CONFIG_START( wiz, wiz_state )
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80, 18432000/6)	/* 3.072 MHz ??? */
 	MCFG_CPU_PROGRAM_MAP(main_map)
-	MCFG_CPU_VBLANK_INT("screen", nmi_line_pulse)
+	MCFG_CPU_VBLANK_INT("screen", wiz_vblank_irq)
 
 	MCFG_CPU_ADD("audiocpu", Z80, 14318000/8)	/* ? */
 	MCFG_CPU_PROGRAM_MAP(sound_map)
-	MCFG_CPU_VBLANK_INT_HACK(nmi_line_pulse,4)	/* ??? */
+	MCFG_CPU_PERIODIC_INT(nmi_line_pulse,4*60)	/* ??? */
 
 	MCFG_MACHINE_RESET( wiz )
 
@@ -699,13 +715,13 @@ static MACHINE_CONFIG_START( wiz, wiz_state )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(wiz)
 
 	MCFG_GFXDECODE(wiz)
 	MCFG_PALETTE_LENGTH(256)
 
 	MCFG_PALETTE_INIT(wiz)
 	MCFG_VIDEO_START(wiz)
-	MCFG_VIDEO_UPDATE(wiz)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
@@ -730,7 +746,8 @@ static MACHINE_CONFIG_DERIVED( stinger, wiz )
 
 	/* video hardware */
 	MCFG_GFXDECODE(stinger)
-	MCFG_VIDEO_UPDATE(stinger)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_UPDATE(stinger)
 
 	/* sound hardware */
 	MCFG_SOUND_MODIFY("8910.1")
@@ -764,7 +781,8 @@ static MACHINE_CONFIG_DERIVED( kungfut, wiz )
 
 	/* video hardware */
 	MCFG_GFXDECODE(stinger)
-	MCFG_VIDEO_UPDATE(kungfut)
+	MCFG_SCREEN_MODIFY("screen")
+	MCFG_SCREEN_UPDATE(kungfut)
 
 MACHINE_CONFIG_END
 
@@ -1030,9 +1048,9 @@ static DRIVER_INIT( stinger )
 		{ 5,3,7, 0x80 },
 		{ 5,7,3, 0x28 }
 	};
-	address_space *space = cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM);
-	UINT8 *rom = machine->region("maincpu")->base();
-	int size = machine->region("maincpu")->bytes();
+	address_space *space = machine.device("maincpu")->memory().space(AS_PROGRAM);
+	UINT8 *rom = machine.region("maincpu")->base();
+	int size = machine.region("maincpu")->bytes();
 	UINT8 *decrypt = auto_alloc_array(machine, UINT8, size);
 	int A;
 	const UINT8 *tbl;
@@ -1067,13 +1085,13 @@ static DRIVER_INIT( stinger )
 
 static DRIVER_INIT( scion )
 {
-	memory_nop_write(cputag_get_address_space(machine, "audiocpu", ADDRESS_SPACE_PROGRAM), 0x4000, 0x4001, 0, 0);
+	machine.device("audiocpu")->memory().space(AS_PROGRAM)->nop_write(0x4000, 0x4001);
 }
 
 
 static DRIVER_INIT( wiz )
 {
-	memory_install_read8_handler(cputag_get_address_space(machine, "maincpu", ADDRESS_SPACE_PROGRAM), 0xd400, 0xd400, 0, 0, wiz_protection_r);
+	machine.device("maincpu")->memory().space(AS_PROGRAM)->install_legacy_read_handler(0xd400, 0xd400, FUNC(wiz_protection_r));
 }
 
 
