@@ -48,37 +48,35 @@ Notes:
 #include "includes/zaccaria.h"
 
 
-static int dsw;
-static int active_8910, port0a, acs;
-static int last_port0b;
-
 static WRITE8_DEVICE_HANDLER( zaccaria_dsw_sel_w )
 {
+	zaccaria_state *state = device->machine().driver_data<zaccaria_state>();
 	switch (data & 0xf0)
 	{
 		case 0xe0:
-			dsw = 0;
+			state->m_dsw = 0;
 			break;
 
 		case 0xd0:
-			dsw = 1;
+			state->m_dsw = 1;
 			break;
 
 		case 0xb0:
-			dsw = 2;
+			state->m_dsw = 2;
 			break;
 
 		default:
-			logerror("%s: portsel = %02x\n", cpuexec_describe_context(device->machine), data);
+			logerror("%s: portsel = %02x\n", device->machine().describe_context(), data);
 			break;
 	}
 }
 
 static READ8_HANDLER( zaccaria_dsw_r )
 {
+	zaccaria_state *state = space->machine().driver_data<zaccaria_state>();
 	static const char *const dswnames[] = { "IN0", "DSW0", "DSW1" };
 
-	return input_port_read(space->machine, dswnames[dsw]);
+	return input_port_read(space->machine(), dswnames[state->m_dsw]);
 }
 
 
@@ -100,73 +98,77 @@ static WRITE8_DEVICE_HANDLER( ay8910_port0a_w )
 	/* 150 below to scale to volume 100 */
 	v = (150 * table[ba]) / (4700 + table[ba]);
 	//printf("dac1w %02d %04d\n", ba, v);
-	ay8910_set_volume(device->machine->device("ay2"), 1, v);
+	ay8910_set_volume(device->machine().device("ay2"), 1, v);
 }
 
 
 static WRITE_LINE_DEVICE_HANDLER( zaccaria_irq0a )
 {
-	cputag_set_input_line(device->machine, "audiocpu", INPUT_LINE_NMI, state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine(), "audiocpu", INPUT_LINE_NMI, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static WRITE_LINE_DEVICE_HANDLER( zaccaria_irq0b )
 {
-	cputag_set_input_line(device->machine, "audiocpu", 0, state ? ASSERT_LINE : CLEAR_LINE);
+	cputag_set_input_line(device->machine(), "audiocpu", 0, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static READ8_DEVICE_HANDLER( zaccaria_port0a_r )
 {
-	return ay8910_r(device->machine->device((active_8910 == 0) ? "ay1" : "ay2"), 0);
+	zaccaria_state *state = device->machine().driver_data<zaccaria_state>();
+	return ay8910_r(device->machine().device((state->m_active_8910 == 0) ? "ay1" : "ay2"), 0);
 }
 
 static WRITE8_DEVICE_HANDLER( zaccaria_port0a_w )
 {
-	port0a = data;
+	zaccaria_state *state = device->machine().driver_data<zaccaria_state>();
+	state->m_port0a = data;
 }
 
 static WRITE8_DEVICE_HANDLER( zaccaria_port0b_w )
 {
+	zaccaria_state *state = device->machine().driver_data<zaccaria_state>();
 
 	/* bit 1 goes to 8910 #0 BDIR pin  */
-	if ((last_port0b & 0x02) == 0x02 && (data & 0x02) == 0x00)
+	if ((state->m_last_port0b & 0x02) == 0x02 && (data & 0x02) == 0x00)
 	{
 		/* bit 0 goes to the 8910 #0 BC1 pin */
-		ay8910_data_address_w(device->machine->device("ay1"), last_port0b, port0a);
+		ay8910_data_address_w(device->machine().device("ay1"), state->m_last_port0b, state->m_port0a);
 	}
-	else if ((last_port0b & 0x02) == 0x00 && (data & 0x02) == 0x02)
+	else if ((state->m_last_port0b & 0x02) == 0x00 && (data & 0x02) == 0x02)
 	{
 		/* bit 0 goes to the 8910 #0 BC1 pin */
-		if (last_port0b & 0x01)
-			active_8910 = 0;
+		if (state->m_last_port0b & 0x01)
+			state->m_active_8910 = 0;
 	}
 	/* bit 3 goes to 8910 #1 BDIR pin  */
-	if ((last_port0b & 0x08) == 0x08 && (data & 0x08) == 0x00)
+	if ((state->m_last_port0b & 0x08) == 0x08 && (data & 0x08) == 0x00)
 	{
 		/* bit 2 goes to the 8910 #1 BC1 pin */
-		ay8910_data_address_w(device->machine->device("ay2"), last_port0b >> 2, port0a);
+		ay8910_data_address_w(device->machine().device("ay2"), state->m_last_port0b >> 2, state->m_port0a);
 	}
-	else if ((last_port0b & 0x08) == 0x00 && (data & 0x08) == 0x08)
+	else if ((state->m_last_port0b & 0x08) == 0x00 && (data & 0x08) == 0x08)
 	{
 		/* bit 2 goes to the 8910 #1 BC1 pin */
-		if (last_port0b & 0x04)
-			active_8910 = 1;
+		if (state->m_last_port0b & 0x04)
+			state->m_active_8910 = 1;
 	}
 
-	last_port0b = data;
+	state->m_last_port0b = data;
 }
 
 static INTERRUPT_GEN( zaccaria_cb1_toggle )
 {
-	device_t *pia0 = device->machine->device("pia0");
-	static int toggle = 0;
+	zaccaria_state *state = device->machine().driver_data<zaccaria_state>();
+	pia6821_device *pia0 = device->machine().device<pia6821_device>("pia0");
 
-	pia6821_cb1_w(pia0, toggle & 1);
-	toggle ^= 1;
+	pia0->cb1_w(state->m_toggle & 1);
+	state->m_toggle ^= 1;
 }
 
 static WRITE8_DEVICE_HANDLER( zaccaria_port1b_w )
 {
-	device_t *tms = device->machine->device("tms");
+	zaccaria_state *state = device->machine().driver_data<zaccaria_state>();
+	device_t *tms = device->machine().device("tms");
 
 	// bit 0 = /RS
 	tms5220_rsq_w(tms, (data >> 0) & 0x01);
@@ -174,23 +176,23 @@ static WRITE8_DEVICE_HANDLER( zaccaria_port1b_w )
 	tms5220_wsq_w(tms, (data >> 1) & 0x01);
 
 	// bit 3 = "ACS" (goes, inverted, to input port 6 bit 3)
-	acs = ~data & 0x08;
+	state->m_acs = ~data & 0x08;
 
 	// bit 4 = led (for testing?)
-	set_led_status(device->machine, 0,~data & 0x10);
+	set_led_status(device->machine(), 0,~data & 0x10);
 }
 
 
 static WRITE8_HANDLER( sound_command_w )
 {
 	soundlatch_w(space, 0, data);
-	cputag_set_input_line(space->machine, "audio2", 0, (data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
+	cputag_set_input_line(space->machine(), "audio2", 0, (data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
 }
 
 static WRITE8_HANDLER( sound1_command_w )
 {
-	device_t *pia0 = space->machine->device("pia0");
-	pia6821_ca1_w(pia0, data & 0x80);
+	pia6821_device *pia0 = space->machine().device<pia6821_device>("pia0");
+	pia0->ca1_w(data & 0x80);
 	soundlatch2_w(space, 0, data);
 }
 
@@ -213,7 +215,7 @@ static READ8_HANDLER( zaccaria_prot1_r )
 			return 0x40;    /* Jack Rabbit */
 
 		case 6:
-			if (space->machine->gamedrv == &GAME_NAME(monymony))
+			if (&space->machine().system() == &GAME_NAME(monymony))
 				return 0x70;    /* Money Money */
 			return 0xa0;    /* Jack Rabbit */
 
@@ -227,7 +229,7 @@ static READ8_HANDLER( zaccaria_prot2_r )
 	switch (offset)
 	{
 		case 0:
-			return input_port_read(space->machine, "COINS");   /* bits 4 and 5 must be 0 in Jack Rabbit */
+			return input_port_read(space->machine(), "COINS");   /* bits 4 and 5 must be 0 in Jack Rabbit */
 
 		case 2:
 			return 0x10;    /* Jack Rabbit */
@@ -246,7 +248,7 @@ static READ8_HANDLER( zaccaria_prot2_r )
 
 static WRITE8_HANDLER( coin_w )
 {
-	coin_counter_w(space->machine, 0,data & 1);
+	coin_counter_w(space->machine(), 0,data & 1);
 }
 
 static WRITE8_HANDLER( nmienable_w )
@@ -256,14 +258,14 @@ static WRITE8_HANDLER( nmienable_w )
 
 
 
-static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( main_map, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x5fff) AM_ROM
 	AM_RANGE(0x6000, 0x63ff) AM_READONLY
 	AM_RANGE(0x6400, 0x6407) AM_READ(zaccaria_prot1_r)
-	AM_RANGE(0x6000, 0x67ff) AM_WRITE(zaccaria_videoram_w) AM_BASE(&zaccaria_videoram)	/* 6400-67ff is 4 bits wide */
-	AM_RANGE(0x6800, 0x683f) AM_WRITE(zaccaria_attributes_w) AM_BASE(&zaccaria_attributesram)
-	AM_RANGE(0x6840, 0x685f) AM_RAM AM_BASE_GENERIC(spriteram)
-	AM_RANGE(0x6881, 0x68c0) AM_RAM AM_BASE_GENERIC(spriteram2)
+	AM_RANGE(0x6000, 0x67ff) AM_WRITE(zaccaria_videoram_w) AM_BASE_MEMBER(zaccaria_state, m_videoram)	/* 6400-67ff is 4 bits wide */
+	AM_RANGE(0x6800, 0x683f) AM_WRITE(zaccaria_attributes_w) AM_BASE_MEMBER(zaccaria_state, m_attributesram)
+	AM_RANGE(0x6840, 0x685f) AM_RAM AM_BASE_MEMBER(zaccaria_state, m_spriteram)
+	AM_RANGE(0x6881, 0x68c0) AM_RAM AM_BASE_MEMBER(zaccaria_state, m_spriteram2)
 	AM_RANGE(0x6c00, 0x6c00) AM_WRITE(zaccaria_flip_screen_x_w)
 	AM_RANGE(0x6c01, 0x6c01) AM_WRITE(zaccaria_flip_screen_y_w)
 	AM_RANGE(0x6c02, 0x6c02) AM_WRITENOP    /* sound reset */
@@ -298,9 +300,9 @@ ADDRESS_MAP_END
 
      6821 PIA: CA1 comes from the master sound cpu's latch bit 7 (which is also connected to the AY chip at 4G's IOB1); CB1 comes from a periodic counter clocked by the 6802's clock, divided by 4096. CA2 and CB2 are disconnected. PA0-7 connect to the data busses of the AY-3-8910 chips; PB0 and PB1 connect to the BC1 and BDIR pins of the AY chip at 4G; PB2 and PB3 connect to the BC1 and BDIR pins of the AY chip at 4H.
 */
-static ADDRESS_MAP_START( sound_map_1, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_map_1, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x007f) AM_RAM
-	AM_RANGE(0x500c, 0x500f) AM_DEVREADWRITE("pia0", pia6821_r, pia6821_w) AM_MIRROR(0x1ff0)
+	AM_RANGE(0x500c, 0x500f) AM_DEVREADWRITE_MODERN("pia0", pia6821_device, read, write) AM_MIRROR(0x1ff0)
 	AM_RANGE(0x8000, 0x9fff) AM_ROM AM_MIRROR(0x2000) // rom 13
 	AM_RANGE(0xc000, 0xdfff) AM_ROM AM_MIRROR(0x2000) // rom 9
 ADDRESS_MAP_END
@@ -325,9 +327,9 @@ ADDRESS_MAP_END
 
      6821 PIA: PA0-7, CA2 and CB1 connect to the TMS5200; CA1 and CB2 are disconnected, though the test mode assumes there's something connected to CB2 (possibly another LED like the one connected to PB4); PB3 connects to 'ACS' which goes to the z80.
 */
-static ADDRESS_MAP_START( sound_map_2, ADDRESS_SPACE_PROGRAM, 8 )
+static ADDRESS_MAP_START( sound_map_2, AS_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x007f) AM_RAM /* 6802 internal ram */
-	AM_RANGE(0x0090, 0x0093) AM_DEVREADWRITE("pia1", pia6821_r, pia6821_w) AM_MIRROR(0x8F6C)
+	AM_RANGE(0x0090, 0x0093) AM_DEVREADWRITE_MODERN("pia1", pia6821_device, read, write) AM_MIRROR(0x8F6C)
 	AM_RANGE(0x1000, 0x1000) AM_DEVWRITE("dac2", mc1408_data_w) AM_MIRROR(0x83FF) /* MC1408 */
 	AM_RANGE(0x1400, 0x1400) AM_WRITE(sound1_command_w) AM_MIRROR(0xC3FF)
 	AM_RANGE(0x1800, 0x1800) AM_READ(soundlatch_r) AM_MIRROR(0xC3FF)
@@ -340,7 +342,8 @@ ADDRESS_MAP_END
 
 static CUSTOM_INPUT( acs_r )
 {
-	return (acs & 0x08) ? 1 : 0;
+	zaccaria_state *state = field.machine().driver_data<zaccaria_state>();
+	return (state->m_acs & 0x08) ? 1 : 0;
 }
 
 static INPUT_PORTS_START( monymony )
@@ -570,28 +573,28 @@ static const pia6821_interface pia_1_config =
 
 static const tms5220_interface tms5220_config =
 {
-	DEVCB_DEVICE_LINE("pia1", pia6821_cb1_w),	/* IRQ handler */
-	DEVCB_DEVICE_LINE("pia1", pia6821_ca2_w)		/* READYQ handler */
+	DEVCB_DEVICE_LINE_MEMBER("pia1", pia6821_device, cb1_w),	/* IRQ handler */
+	DEVCB_DEVICE_LINE_MEMBER("pia1", pia6821_device, ca2_w)		/* READYQ handler */
 };
 
 
 
-static MACHINE_CONFIG_START( zaccaria, driver_device )
+static MACHINE_CONFIG_START( zaccaria, zaccaria_state )
 
 	/* basic machine hardware */
 	MCFG_CPU_ADD("maincpu", Z80,XTAL_18_432MHz/6)	/* verified on pcb */
 	MCFG_CPU_PROGRAM_MAP(main_map)
 	MCFG_CPU_VBLANK_INT("screen", nmi_line_pulse)
-	MCFG_QUANTUM_TIME(HZ(1000000))
+	MCFG_QUANTUM_TIME(attotime::from_hz(1000000))
 
 	MCFG_CPU_ADD("audiocpu", M6802,XTAL_3_579545MHz) /* verified on pcb */
 	MCFG_CPU_PROGRAM_MAP(sound_map_1)
 	MCFG_CPU_PERIODIC_INT(zaccaria_cb1_toggle,(double)XTAL_3_579545MHz/4096)
-	MCFG_QUANTUM_TIME(HZ(1000000))
+	MCFG_QUANTUM_TIME(attotime::from_hz(1000000))
 
 	MCFG_CPU_ADD("audio2", M6802,XTAL_3_579545MHz) /* verified on pcb */
 	MCFG_CPU_PROGRAM_MAP(sound_map_2)
-	MCFG_QUANTUM_TIME(HZ(1000000))
+	MCFG_QUANTUM_TIME(attotime::from_hz(1000000))
 
 	MCFG_PPI8255_ADD( "ppi8255", ppi8255_config )
 	MCFG_PIA6821_ADD( "pia0", pia_0_config )
@@ -604,13 +607,13 @@ static MACHINE_CONFIG_START( zaccaria, driver_device )
 	MCFG_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MCFG_SCREEN_SIZE(32*8, 32*8)
 	MCFG_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MCFG_SCREEN_UPDATE(zaccaria)
 
 	MCFG_GFXDECODE(zaccaria)
 	MCFG_PALETTE_LENGTH(32*8+32*8)
 
 	MCFG_PALETTE_INIT(zaccaria)
 	MCFG_VIDEO_START(zaccaria)
-	MCFG_VIDEO_UPDATE(zaccaria)
 
 	/* sound hardware */
 	MCFG_SPEAKER_STANDARD_MONO("mono")
