@@ -7,22 +7,23 @@
 class _1942_state : public driver_device
 {
 public:
-	_1942_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	_1942_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 * fg_videoram;
-	UINT8 * bg_videoram;
-	UINT8 * spriteram;
-	size_t  spriteram_size;
+	UINT8 * m_fg_videoram;
+	UINT8 * m_bg_videoram;
+	UINT8 * m_spriteram;
+	size_t  m_spriteram_size;
 
 	/* video-related */
-	tilemap_t *fg_tilemap, *bg_tilemap;
-	int palette_bank;
-	UINT8 scroll[2];
+	tilemap_t *m_fg_tilemap;
+	tilemap_t *m_bg_tilemap;
+	int m_palette_bank;
+	UINT8 m_scroll[2];
 
 	/* devices */
-	device_t *audiocpu;
+	device_t *m_audiocpu;
 };
 
 
@@ -37,4 +38,4 @@ extern WRITE8_HANDLER( c1942_palette_bank_w );
 
 extern PALETTE_INIT( 1942 );
 extern VIDEO_START( 1942 );
-extern VIDEO_UPDATE( 1942 );
+extern SCREEN_UPDATE( 1942 );
