@@ -7,22 +7,22 @@
 class ambush_state : public driver_device
 {
 public:
-	ambush_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	ambush_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *    videoram;
-	UINT8 *    spriteram;
-	UINT8 *    colorram;
-	UINT8 *    scrollram;
-	UINT8 *    colorbank;
+	UINT8 *    m_videoram;
+	UINT8 *    m_spriteram;
+	UINT8 *    m_colorram;
+	UINT8 *    m_scrollram;
+	UINT8 *    m_colorbank;
 
-	size_t     videoram_size;
-	size_t     spriteram_size;
+	size_t     m_videoram_size;
+	size_t     m_spriteram_size;
 };
 
 
 /*----------- defined in video/ambush.c -----------*/
 
 PALETTE_INIT( ambush );
-VIDEO_UPDATE( ambush );
+SCREEN_UPDATE( ambush );
