@@ -7,16 +7,20 @@
 class battlex_state : public driver_device
 {
 public:
-	battlex_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	battlex_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 m_in0_b4;
 
 	/* memory pointers */
-	UINT8 * videoram;
-	UINT8 * spriteram;
+	UINT8 * m_videoram;
+	UINT8 * m_spriteram;
 
 	/* video-related */
-	tilemap_t *bg_tilemap;
-	int     scroll_lsb, scroll_msb;
+	tilemap_t *m_bg_tilemap;
+	UINT8 m_scroll_lsb;
+	UINT8 m_scroll_msb;
+	UINT8 m_starfield_enabled;
 };
 
 
@@ -26,8 +30,8 @@ extern WRITE8_HANDLER( battlex_palette_w );
 extern WRITE8_HANDLER( battlex_videoram_w );
 extern WRITE8_HANDLER( battlex_scroll_x_lsb_w );
 extern WRITE8_HANDLER( battlex_scroll_x_msb_w );
+extern WRITE8_HANDLER( battlex_scroll_starfield_w );
 extern WRITE8_HANDLER( battlex_flipscreen_w );
 
-extern PALETTE_INIT( battlex );
 extern VIDEO_START( battlex );
-extern VIDEO_UPDATE( battlex );
+extern SCREEN_UPDATE( battlex );
