@@ -7,28 +7,28 @@
 class battlnts_state : public driver_device
 {
 public:
-	battlnts_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	battlnts_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
 //  UINT8 *      paletteram;    // this currently uses generic palette handling
 
 	/* video-related */
-	int spritebank;
-	int layer_colorbase[2];
+	int m_spritebank;
+	int m_layer_colorbase[2];
 
 
 	/* devices */
-	device_t *audiocpu;
-	device_t *k007342;
-	device_t *k007420;
+	device_t *m_audiocpu;
+	device_t *m_k007342;
+	device_t *m_k007420;
 };
 
 /*----------- defined in video/battlnts.c -----------*/
 
 WRITE8_HANDLER( battlnts_spritebank_w );
 
-VIDEO_UPDATE( battlnts );
+SCREEN_UPDATE( battlnts );
 
-void battlnts_tile_callback(running_machine *machine, int layer, int bank, int *code, int *color, int *flags);
-void battlnts_sprite_callback(running_machine *machine, int *code, int *color);
+void battlnts_tile_callback(running_machine &machine, int layer, int bank, int *code, int *color, int *flags);
+void battlnts_sprite_callback(running_machine &machine, int *code, int *color);
