@@ -2,41 +2,51 @@
 class bigevglf_state : public driver_device
 {
 public:
-	bigevglf_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	bigevglf_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *  paletteram;
-	UINT8 *  spriteram1;
-	UINT8 *  spriteram2;
+	UINT8 *  m_paletteram;
+	UINT8 *  m_spriteram1;
+	UINT8 *  m_spriteram2;
 
 	/* video-related */
-	bitmap_t *tmp_bitmap[4];
-	UINT8    *vidram;
-	UINT32   vidram_bank, plane_selected, plane_visible;
+	bitmap_t *m_tmp_bitmap[4];
+	UINT8    *m_vidram;
+	UINT32   m_vidram_bank;
+	UINT32   m_plane_selected;
+	UINT32   m_plane_visible;
 
 	/* sound-related */
-	int      sound_nmi_enable, pending_nmi;
-	UINT8    for_sound;
-	UINT8    from_sound;
-	UINT8    sound_state;
+	int      m_sound_nmi_enable;
+	int      m_pending_nmi;
+	UINT8    m_for_sound;
+	UINT8    m_from_sound;
+	UINT8    m_sound_state;
 
 	/* MCU related */
-	UINT8    from_mcu;
-	int      mcu_sent, main_sent;
-	UINT8    port_a_in, port_a_out, ddr_a;
-	UINT8    port_b_in, port_b_out, ddr_b;
-	UINT8    port_c_in, port_c_out, ddr_c;
-	int      mcu_coin_bit5;
+	UINT8    m_from_mcu;
+	int      m_mcu_sent;
+	int      m_main_sent;
+	UINT8    m_port_a_in;
+	UINT8    m_port_a_out;
+	UINT8    m_ddr_a;
+	UINT8    m_port_b_in;
+	UINT8    m_port_b_out;
+	UINT8    m_ddr_b;
+	UINT8    m_port_c_in;
+	UINT8    m_port_c_out;
+	UINT8    m_ddr_c;
+	int      m_mcu_coin_bit5;
 
 	/* misc */
-	UINT32   beg_bank;
-	UINT8    beg13_ls74[2];
-	UINT8    port_select;     /* for muxed controls */
+	UINT32   m_beg_bank;
+	UINT8    m_beg13_ls74[2];
+	UINT8    m_port_select;     /* for muxed controls */
 
 	/* devices */
-	device_t *audiocpu;
-	device_t *mcu;
+	device_t *m_audiocpu;
+	device_t *m_mcu;
 };
 
 
@@ -60,7 +70,7 @@ READ8_HANDLER( bigevglf_mcu_status_r );
 /*----------- defined in video/bigevglf.c -----------*/
 
 VIDEO_START( bigevglf );
-VIDEO_UPDATE( bigevglf );
+SCREEN_UPDATE( bigevglf );
 
 READ8_HANDLER( bigevglf_vidram_r );
 WRITE8_HANDLER( bigevglf_vidram_w );
