@@ -7,30 +7,35 @@
 class blktiger_state : public driver_device
 {
 public:
-	blktiger_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	blktiger_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 * txvideoram;
-//  UINT8 * spriteram;  // currently this uses generic buffer_spriteram_w
-//  UINT8 * paletteram; // currently this uses generic palette handling
-//  UINT8 * paletteram2;    // currently this uses generic palette handling
+	UINT8 * m_txvideoram;
+//  UINT8 * m_spriteram;  // currently this uses generic buffer_spriteram_w
+//  UINT8 * m_paletteram; // currently this uses generic palette handling
+//  UINT8 * m_paletteram2;    // currently this uses generic palette handling
 
 	/* video-related */
-	tilemap_t *tx_tilemap, *bg_tilemap8x4, *bg_tilemap4x8;
-	UINT32  scroll_bank;
-	UINT8   scroll_x[2];
-	UINT8   scroll_y[2];
-	UINT8   *scroll_ram;
-	UINT8   screen_layout;
-	UINT8   chon, objon, bgon;
+	tilemap_t *m_tx_tilemap;
+	tilemap_t *m_bg_tilemap8x4;
+	tilemap_t *m_bg_tilemap4x8;
+	UINT32  m_scroll_bank;
+	UINT8   m_scroll_x[2];
+	UINT8   m_scroll_y[2];
+	UINT8   *m_scroll_ram;
+	UINT8   m_screen_layout;
+	UINT8   m_chon;
+	UINT8   m_objon;
+	UINT8   m_bgon;
 
 	/* mcu-related */
-	UINT8   z80_latch, i8751_latch;
+	UINT8   m_z80_latch;
+	UINT8   m_i8751_latch;
 
 	/* devices */
-	device_t *mcu;
-	device_t *audiocpu;
+	device_t *m_mcu;
+	device_t *m_audiocpu;
 };
 
 
@@ -48,5 +53,5 @@ WRITE8_HANDLER( blktiger_scrollx_w );
 WRITE8_HANDLER( blktiger_scrolly_w );
 
 VIDEO_START( blktiger );
-VIDEO_UPDATE( blktiger );
-VIDEO_EOF( blktiger );
+SCREEN_UPDATE( blktiger );
+SCREEN_EOF( blktiger );
