@@ -9,16 +9,16 @@
 class blstroid_state : public atarigen_state
 {
 public:
-	blstroid_state(running_machine &machine, const driver_device_config_base &config)
-		: atarigen_state(machine, config) { }
+	blstroid_state(const machine_config &mconfig, device_type type, const char *tag)
+		: atarigen_state(mconfig, type, tag) { }
 
-	UINT16 *		priorityram;
+	UINT16 *		m_priorityram;
 };
 
 
 /*----------- defined in video/blstroid.c -----------*/
 
 VIDEO_START( blstroid );
-VIDEO_UPDATE( blstroid );
+SCREEN_UPDATE( blstroid );
 
 void blstroid_scanline_update(screen_device &screen, int scanline);
