@@ -4,29 +4,28 @@
 
 ***************************************************************************/
 
-class blueprnt_state
+class blueprnt_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, blueprnt_state(machine)); }
-
-	blueprnt_state(running_machine &machine) { }
+	blueprnt_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 * videoram;
-	UINT8 * colorram;
-	UINT8 * spriteram;
-	UINT8 * scrollram;
-	size_t  spriteram_size;
+	UINT8 * m_videoram;
+	UINT8 * m_colorram;
+	UINT8 * m_spriteram;
+	UINT8 * m_scrollram;
+	size_t  m_spriteram_size;
 
 	/* video-related */
-	tilemap_t *bg_tilemap;
-	int     gfx_bank;
+	tilemap_t *m_bg_tilemap;
+	int     m_gfx_bank;
 
 	/* misc */
-	int     dipsw;
+	int     m_dipsw;
 
 	/* devices */
-	running_device *audiocpu;
+	device_t *m_audiocpu;
 };
 
 
@@ -38,4 +37,4 @@ WRITE8_HANDLER( blueprnt_flipscreen_w );
 
 PALETTE_INIT( blueprnt );
 VIDEO_START( blueprnt );
-VIDEO_UPDATE( blueprnt );
+SCREEN_UPDATE( blueprnt );
