@@ -6,27 +6,31 @@
 class chaknpop_state : public driver_device
 {
 public:
-	chaknpop_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	chaknpop_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *  mcu_ram;
-	UINT8 *  tx_ram;
-	UINT8 *  spr_ram;
-	UINT8 *  attr_ram;
-	size_t   spr_ram_size;
+	UINT8 *  m_mcu_ram;
+	UINT8 *  m_tx_ram;
+	UINT8 *  m_spr_ram;
+	UINT8 *  m_attr_ram;
+	size_t   m_spr_ram_size;
 
 	/* mcu-related */
-	UINT8 mcu_seed;
-	UINT8 mcu_select;
-	UINT8 mcu_result;
+	UINT8 m_mcu_seed;
+	UINT8 m_mcu_select;
+	UINT8 m_mcu_result;
 
 
 	/* video-related */
-	tilemap_t  *tx_tilemap;
-	UINT8    *vram1, *vram2, *vram3, *vram4;
-	UINT8    gfxmode;
-	UINT8    flip_x, flip_y;
+	tilemap_t  *m_tx_tilemap;
+	UINT8    *m_vram1;
+	UINT8    *m_vram2;
+	UINT8    *m_vram3;
+	UINT8    *m_vram4;
+	UINT8    m_gfxmode;
+	UINT8    m_flip_x;
+	UINT8    m_flip_y;
 };
 
 
@@ -45,7 +49,7 @@ WRITE8_HANDLER( chaknpop_mcu_port_c_w );
 
 PALETTE_INIT( chaknpop );
 VIDEO_START( chaknpop );
-VIDEO_UPDATE( chaknpop );
+SCREEN_UPDATE( chaknpop );
 
 READ8_HANDLER( chaknpop_gfxmode_r );
 WRITE8_HANDLER( chaknpop_gfxmode_w );
