@@ -7,21 +7,24 @@
 class compgolf_state : public driver_device
 {
 public:
-	compgolf_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	compgolf_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *        videoram;
-	UINT8 *        bg_ram;
-	UINT8 *        spriteram;
+	UINT8 *        m_videoram;
+	UINT8 *        m_bg_ram;
+	UINT8 *        m_spriteram;
 
 	/* video-related */
-	tilemap_t        *text_tilemap, *bg_tilemap;
-	int            scrollx_lo, scrollx_hi;
-	int            scrolly_lo, scrolly_hi;
+	tilemap_t        *m_text_tilemap;
+	tilemap_t        *m_bg_tilemap;
+	int            m_scrollx_lo;
+	int            m_scrollx_hi;
+	int            m_scrolly_lo;
+	int            m_scrolly_hi;
 
 	/* misc */
-	int            bank;
+	int            m_bank;
 };
 
 
@@ -31,4 +34,4 @@ WRITE8_HANDLER( compgolf_video_w );
 WRITE8_HANDLER( compgolf_back_w );
 PALETTE_INIT ( compgolf );
 VIDEO_START  ( compgolf );
-VIDEO_UPDATE ( compgolf );
+SCREEN_UPDATE( compgolf );
