@@ -8,6 +8,22 @@ Crazy Ballooon
 #define CRBALOON_MASTER_XTAL	(XTAL_9_987MHz)
 
 
+class crbaloon_state : public driver_device
+{
+public:
+	crbaloon_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 *m_pc3092_data;
+	UINT8 *m_videoram;
+	UINT8 *m_colorram;
+	UINT8 *m_spriteram;
+	UINT16 m_collision_address;
+	UINT8 m_collision_address_clear;
+	tilemap_t *m_bg_tilemap;
+};
+
+
 /*----------- defined in audio/crbaloon.c -----------*/
 
 WRITE8_DEVICE_HANDLER( crbaloon_audio_set_music_freq );
@@ -22,17 +38,12 @@ MACHINE_CONFIG_EXTERN( crbaloon_audio );
 
 /*----------- defined in video/crbaloon.c -----------*/
 
-extern UINT8 *crbaloon_videoram;
-extern UINT8 *crbaloon_colorram;
-extern UINT8 *crbaloon_spriteram;
-
 PALETTE_INIT( crbaloon );
 VIDEO_START( crbaloon );
-VIDEO_UPDATE( crbaloon );
+SCREEN_UPDATE( crbaloon );
 
 WRITE8_HANDLER( crbaloon_videoram_w );
 WRITE8_HANDLER( crbaloon_colorram_w );
 
-UINT16 crbaloon_get_collision_address(void);
-void crbaloon_set_clear_collision_address(int _crbaloon_collision_address_clear);
-
+UINT16 crbaloon_get_collision_address(running_machine &machine);
+void crbaloon_set_clear_collision_address(running_machine &machine, int _crbaloon_collision_address_clear);
