@@ -3,27 +3,29 @@
 class docastle_state : public driver_device
 {
 public:
-	docastle_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	docastle_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *  videoram;
-	UINT8 *  colorram;
-	UINT8 *  spriteram;
-	size_t   spriteram_size;
+	UINT8 *  m_videoram;
+	UINT8 *  m_colorram;
+	UINT8 *  m_spriteram;
+	size_t   m_spriteram_size;
 
 	/* video-related */
-	tilemap_t  *do_tilemap;
+	tilemap_t  *m_do_tilemap;
 
 	/* misc */
-	int      adpcm_pos, adpcm_idle;
-	int      adpcm_data;
-	int      adpcm_status;
-	UINT8    buffer0[9], buffer1[9];
+	int      m_adpcm_pos;
+	int      m_adpcm_idle;
+	int      m_adpcm_data;
+	int      m_adpcm_status;
+	UINT8    m_buffer0[9];
+	UINT8    m_buffer1[9];
 
 	/* devices */
-	cpu_device *maincpu;
-	cpu_device *slave;
+	cpu_device *m_maincpu;
+	cpu_device *m_slave;
 };
 
 
@@ -47,5 +49,5 @@ WRITE8_HANDLER( docastle_flipscreen_on_w );
 PALETTE_INIT( docastle );
 VIDEO_START( docastle );
 VIDEO_START( dorunrun );
-VIDEO_UPDATE( docastle );
+SCREEN_UPDATE( docastle );
 
