@@ -4,26 +4,25 @@
 
 **************************************************************************/
 
-class epos_state
+class epos_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, epos_state(machine)); }
-
-	epos_state(running_machine &machine) { }
+	epos_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *  videoram;
-	size_t   videoram_size;
+	UINT8 *  m_videoram;
+	size_t   m_videoram_size;
 
 	/* video-related */
-	UINT8    palette;
+	UINT8    m_palette;
 
 	/* misc */
-	int      counter;
+	int      m_counter;
 };
 
 
 /*----------- defined in video/epos.c -----------*/
 
 WRITE8_HANDLER( epos_port_1_w );
-VIDEO_UPDATE( epos );
+SCREEN_UPDATE( epos );
