@@ -25,28 +25,30 @@
 class fcombat_state : public driver_device
 {
 public:
-	fcombat_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	fcombat_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *    videoram;
-	UINT8 *    spriteram;
-	size_t     videoram_size;
-	size_t     spriteram_size;
+	UINT8 *    m_videoram;
+	UINT8 *    m_spriteram;
+	size_t     m_videoram_size;
+	size_t     m_spriteram_size;
 
 	/* video-related */
-	tilemap_t    *bgmap;
-	UINT8      cocktail_flip;
-	UINT8      char_palette, sprite_palette;
-	UINT8      char_bank;
+	tilemap_t    *m_bgmap;
+	UINT8      m_cocktail_flip;
+	UINT8      m_char_palette;
+	UINT8      m_sprite_palette;
+	UINT8      m_char_bank;
 
 	/* misc */
-	int        fcombat_sh;
-	int        fcombat_sv;
-	int        tx, ty;
+	int        m_fcombat_sh;
+	int        m_fcombat_sv;
+	int        m_tx;
+	int        m_ty;
 
 	/* devices */
-	device_t *maincpu;
+	device_t *m_maincpu;
 };
 
 
@@ -55,6 +57,6 @@ public:
 
 PALETTE_INIT( fcombat );
 VIDEO_START( fcombat );
-VIDEO_UPDATE( fcombat );
+SCREEN_UPDATE( fcombat );
 
 WRITE8_HANDLER( fcombat_videoreg_w );
