@@ -4,28 +4,27 @@
 
 *************************************************************************/
 
-class flkatck_state
+class flkatck_state : public driver_device
 {
 public:
-	static void *alloc(running_machine &machine) { return auto_alloc_clear(&machine, flkatck_state(machine)); }
-
-	flkatck_state(running_machine &machine) { }
+	flkatck_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *    k007121_ram;
+	UINT8 *    m_k007121_ram;
 //  UINT8 *    paletteram;  // this currently uses generic palette handling
 
 	/* video-related */
-	tilemap_t    *k007121_tilemap[2];
-	int        flipscreen;
+	tilemap_t    *m_k007121_tilemap[2];
+	int        m_flipscreen;
 
 	/* misc */
-	int        irq_enabled;
-	int        multiply_reg[2];
+	int        m_irq_enabled;
+	int        m_multiply_reg[2];
 
 	/* devices */
-	running_device *audiocpu;
-	running_device *k007121;
+	device_t *m_audiocpu;
+	device_t *m_k007121;
 };
 
 
@@ -38,4 +37,4 @@ WRITE8_HANDLER( flkatck_k007121_w );
 WRITE8_HANDLER( flkatck_k007121_regs_w );
 
 VIDEO_START( flkatck );
-VIDEO_UPDATE( flkatck );
+SCREEN_UPDATE( flkatck );
