@@ -3,16 +3,16 @@
 class funkybee_state : public driver_device
 {
 public:
-	funkybee_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	funkybee_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *    videoram;
-	UINT8 *    colorram;
+	UINT8 *    m_videoram;
+	UINT8 *    m_colorram;
 
 	/* video-related */
-	tilemap_t    *bg_tilemap;
-	int        gfx_bank;
+	tilemap_t    *m_bg_tilemap;
+	int        m_gfx_bank;
 };
 
 
@@ -26,4 +26,4 @@ WRITE8_HANDLER( funkybee_flipscreen_w );
 
 PALETTE_INIT( funkybee );
 VIDEO_START( funkybee );
-VIDEO_UPDATE( funkybee );
+SCREEN_UPDATE( funkybee );
