@@ -1,35 +1,90 @@
 /***************************************************************************
 
-  Galaxian hardware family
+  Galaxian hardware family (old)
 
   This include file is used by the following drivers:
-    - galaxian.c
+    - dambustr.c
+    - galaxold.c
     - scramble.c
     - scobra.c
-    - frogger.c
-    - amidar.c
-    - dambustr.c
 
 ***************************************************************************/
 
-#include "machine/8255ppi.h"
+#ifndef __GALAXOLD_H__
+#define __GALAXOLD_H__
+
+/* star circuit */
+#define STAR_COUNT  252
+struct star
+{
+	int x, y, color;
+};
+
+class galaxold_state : public driver_device
+{
+public:
+	galaxold_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 *m_videoram;
+	UINT8 *m_spriteram;
+	UINT8 *m_spriteram2;
+	UINT8 *m_attributesram;
+	UINT8 *m_bulletsram;
+	UINT8 *m_rockclim_videoram;
+	UINT8 *m_racknrol_tiles_bank;
+	size_t m_spriteram_size;
+	size_t m_spriteram2_size;
+	size_t m_bulletsram_size;
+	int m_irq_line;
+	UINT8 m__4in1_bank;
+	tilemap_t *m_bg_tilemap;
+	tilemap_t *m_rockclim_tilemap;
+	int m_mooncrst_gfxextend;
+	int m_spriteram2_present;
+	UINT8 m_gfxbank[5];
+	UINT8 m_flipscreen_x;
+	UINT8 m_flipscreen_y;
+	UINT8 m_color_mask;
+	tilemap_t *m_dambustr_tilemap2;
+	UINT8 *m_dambustr_videoram2;
+	void (*m_modify_charcode)(running_machine &machine, UINT16 *code, UINT8 x);		/* function to call to do character banking */
+	void (*m_modify_spritecode)(running_machine &machine, UINT8 *spriteram, int*, int*, int*, int);	/* function to call to do sprite banking */
+	void (*m_modify_color)(UINT8 *color);	/* function to call to do modify how the color codes map to the PROM */
+	void (*m_modify_ypos)(UINT8*);	/* function to call to do modify how vertical positioning bits are connected */
+	void (*m_tilemap_set_scroll)( tilemap_t *, int col, int value );
+
+	UINT8 m_timer_adjusted;
+	UINT8 m_darkplnt_bullet_color;
+	void (*m_draw_bullets)(running_machine &,bitmap_t *,const rectangle *, int, int, int);	/* function to call to draw a bullet */
+
+	UINT8 m_background_enable;
+	UINT8 m_background_red;
+	UINT8 m_background_green;
+	UINT8 m_background_blue;
+	void (*m_draw_background)(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect);	/* function to call to draw the background */
+	UINT16 m_rockclim_v;
+	UINT16 m_rockclim_h;
+	int m_dambustr_bg_split_line;
+	int m_dambustr_bg_color_1;
+	int m_dambustr_bg_color_2;
+	int m_dambustr_bg_priority;
+	int m_dambustr_char_bank;
+	bitmap_t *m_dambustr_tmpbitmap;
+
+	void (*m_draw_stars)(running_machine &machine, bitmap_t *, const rectangle *);		/* function to call to draw the star layer */
+	int m_stars_colors_start;
+	INT32 m_stars_scrollpos;
+	UINT8 m_stars_on;
+	UINT8 m_stars_blink_state;
+	emu_timer *m_stars_blink_timer;
+	emu_timer *m_stars_scroll_timer;
+	struct star m_stars[STAR_COUNT];
+};
+
 
 /*----------- defined in video/galaxold.c -----------*/
 
-extern UINT8 *galaxold_videoram;
-extern UINT8 *galaxold_spriteram;
-extern UINT8 *galaxold_spriteram2;
-extern UINT8 *galaxold_attributesram;
-extern UINT8 *galaxold_bulletsram;
-extern UINT8 *rockclim_videoram;
-extern UINT8 *racknrol_tiles_bank;
-
-
-extern size_t galaxold_spriteram_size;
-extern size_t galaxold_spriteram2_size;
-extern size_t galaxold_bulletsram_size;
-extern UINT8 galaxold_stars_on;
-
 PALETTE_INIT( galaxold );
 PALETTE_INIT( scrambold );
 PALETTE_INIT( darkplnt );
@@ -77,7 +132,6 @@ VIDEO_START( stratgyx );
 VIDEO_START( mimonkey );
 VIDEO_START( mariner );
 VIDEO_START( ckongs );
-VIDEO_START( newsin7 );
 VIDEO_START( rockclim );
 VIDEO_START( drivfrcg );
 VIDEO_START( bongo );
@@ -85,11 +139,11 @@ VIDEO_START( scorpion );
 VIDEO_START( racknrol );
 VIDEO_START( ad2083 );
 
-void galaxold_init_stars(running_machine *machine, int colors_offset);
-void galaxold_draw_stars(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect);
+void galaxold_init_stars(running_machine &machine, int colors_offset);
+void galaxold_draw_stars(running_machine &machine, bitmap_t *bitmap, const rectangle *cliprect);
 
-VIDEO_UPDATE( galaxold );
-VIDEO_UPDATE( dambustr );
+SCREEN_UPDATE( galaxold );
+SCREEN_UPDATE( dambustr );
 
 WRITE8_HANDLER( galaxold_gfxbank_w );
 WRITE8_HANDLER( galaxold_flip_screen_x_w );
@@ -127,65 +181,4 @@ CUSTOM_INPUT( _4in1_fake_port_r );
 
 INTERRUPT_GEN( hunchbks_vh_interrupt );
 
-
-/*----------- defined in machine/scramble.c -----------*/
-
-extern const ppi8255_interface scramble_ppi_0_intf;
-extern const ppi8255_interface scramble_ppi_1_intf;
-extern const ppi8255_interface stratgyx_ppi_1_intf;
-extern const ppi8255_interface scramble_protection_ppi_1_intf;
-extern const ppi8255_interface mrkougar_ppi_1_intf;
-
-
-DRIVER_INIT( scramble_ppi );
-DRIVER_INIT( stratgyx );
-DRIVER_INIT( tazmani2 );
-DRIVER_INIT( ckongs );
-DRIVER_INIT( mariner );
-DRIVER_INIT( devilfsh );
-DRIVER_INIT( mars );
-DRIVER_INIT( hotshock );
-DRIVER_INIT( cavelon );
-DRIVER_INIT( darkplnt );
-DRIVER_INIT( mimonkey );
-DRIVER_INIT( mimonsco );
-DRIVER_INIT( mimonscr );
-DRIVER_INIT( rescue );
-DRIVER_INIT( minefld );
-DRIVER_INIT( hustler );
-DRIVER_INIT( billiard );
-DRIVER_INIT( mrkougar );
-DRIVER_INIT( mrkougb );
-DRIVER_INIT( ad2083 );
-
-MACHINE_RESET( scramble );
-MACHINE_RESET( explorer );
-
-READ8_HANDLER( triplep_pip_r );
-READ8_HANDLER( triplep_pap_r );
-
-READ8_HANDLER( hunchbks_mirror_r );
-WRITE8_HANDLER( hunchbks_mirror_w );
-
-CUSTOM_INPUT( darkplnt_custom_r );
-
-
-/*----------- defined in audio/scramble.c -----------*/
-
-void scramble_sh_init(running_machine *machine);
-WRITE_LINE_DEVICE_HANDLER( scramble_sh_7474_q_callback );
-
-WRITE8_HANDLER( scramble_filter_w );
-WRITE8_HANDLER( frogger_filter_w );
-
-READ8_DEVICE_HANDLER( scramble_portB_r );
-READ8_DEVICE_HANDLER( frogger_portB_r );
-
-READ8_DEVICE_HANDLER( hotshock_soundlatch_r );
-
-WRITE8_DEVICE_HANDLER( scramble_sh_irqtrigger_w );
-WRITE8_DEVICE_HANDLER( mrkougar_sh_irqtrigger_w );
-WRITE8_HANDLER( hotshock_sh_irqtrigger_w );
-
-MACHINE_CONFIG_EXTERN( ad2083_audio );
-
+#endif
