@@ -9,13 +9,13 @@
 class gauntlet_state : public atarigen_state
 {
 public:
-	gauntlet_state(running_machine &machine, const driver_device_config_base &config)
-		: atarigen_state(machine, config) { }
+	gauntlet_state(const machine_config &mconfig, device_type type, const char *tag)
+		: atarigen_state(mconfig, type, tag) { }
 
-	UINT16			sound_reset_val;
-	UINT8			vindctr2_screen_refresh;
-	UINT8			playfield_tile_bank;
-	UINT8			playfield_color_bank;
+	UINT16			m_sound_reset_val;
+	UINT8			m_vindctr2_screen_refresh;
+	UINT8			m_playfield_tile_bank;
+	UINT8			m_playfield_color_bank;
 };
 
 
@@ -25,4 +25,4 @@ WRITE16_HANDLER( gauntlet_xscroll_w );
 WRITE16_HANDLER( gauntlet_yscroll_w );
 
 VIDEO_START( gauntlet );
-VIDEO_UPDATE( gauntlet );
+SCREEN_UPDATE( gauntlet );
