@@ -1,5 +1,21 @@
 #include "devlegcy.h"
 
+class gomoku_state : public driver_device
+{
+public:
+	gomoku_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 *m_videoram;
+	UINT8 *m_colorram;
+	UINT8 *m_bgram;
+	int m_flipscreen;
+	int m_bg_dispsw;
+	tilemap_t *m_fg_tilemap;
+	bitmap_t *m_bg_bitmap;
+};
+
+
 /*----------- defined in audio/gomoku.c -----------*/
 
 WRITE8_DEVICE_HANDLER( gomoku_sound1_w );
@@ -10,13 +26,9 @@ DECLARE_LEGACY_SOUND_DEVICE(GOMOKU, gomoku_sound);
 
 /*----------- defined in video/gomoku.c -----------*/
 
-extern UINT8 *gomoku_videoram;
-extern UINT8 *gomoku_colorram;
-extern UINT8 *gomoku_bgram;
-
 PALETTE_INIT( gomoku );
 VIDEO_START( gomoku );
-VIDEO_UPDATE( gomoku );
+SCREEN_UPDATE( gomoku );
 
 WRITE8_HANDLER( gomoku_videoram_w );
 WRITE8_HANDLER( gomoku_colorram_w );
