@@ -7,23 +7,23 @@
 class gundealr_state : public driver_device
 {
 public:
-	gundealr_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	gundealr_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *    bg_videoram;
-	UINT8 *    fg_videoram;
-	UINT8 *    rambase;
-	UINT8 *    paletteram;
+	UINT8 *    m_bg_videoram;
+	UINT8 *    m_fg_videoram;
+	UINT8 *    m_rambase;
+	UINT8 *    m_paletteram;
 
 	/* video-related */
-	tilemap_t    *bg_tilemap;
-	tilemap_t    *fg_tilemap;
-	int        flipscreen;
-	UINT8      scroll[4];
+	tilemap_t    *m_bg_tilemap;
+	tilemap_t    *m_fg_tilemap;
+	int        m_flipscreen;
+	UINT8      m_scroll[4];
 
 	/* misc */
-	int        input_ports_hack;
+	int        m_input_ports_hack;
 };
 
 
@@ -37,5 +37,5 @@ WRITE8_HANDLER( gundealr_fg_scroll_w );
 WRITE8_HANDLER( yamyam_fg_scroll_w );
 WRITE8_HANDLER( gundealr_flipscreen_w );
 
-VIDEO_UPDATE( gundealr );
+SCREEN_UPDATE( gundealr );
 VIDEO_START( gundealr );
