@@ -7,17 +7,17 @@
 class higemaru_state : public driver_device
 {
 public:
-	higemaru_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	higemaru_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *    videoram;
-	UINT8 *    colorram;
-	UINT8 *    spriteram;
-	size_t     spriteram_size;
+	UINT8 *    m_videoram;
+	UINT8 *    m_colorram;
+	UINT8 *    m_spriteram;
+	size_t     m_spriteram_size;
 
 	/* video-related */
-	tilemap_t    *bg_tilemap;
+	tilemap_t    *m_bg_tilemap;
 };
 
 
@@ -29,4 +29,4 @@ WRITE8_HANDLER( higemaru_c800_w );
 
 PALETTE_INIT( higemaru );
 VIDEO_START( higemaru );
-VIDEO_UPDATE( higemaru );
+SCREEN_UPDATE( higemaru );
