@@ -7,20 +7,20 @@
 class ikki_state : public driver_device
 {
 public:
-	ikki_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	ikki_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *    videoram;
-	UINT8 *    spriteram;
-	UINT8 *    scroll;
-	size_t     videoram_size;
-	size_t     spriteram_size;
+	UINT8 *    m_videoram;
+	UINT8 *    m_spriteram;
+	UINT8 *    m_scroll;
+	size_t     m_videoram_size;
+	size_t     m_spriteram_size;
 
 	/* video-related */
-	bitmap_t   *sprite_bitmap;
-	UINT8      flipscreen;
-	int        punch_through_pen;
+	bitmap_t   *m_sprite_bitmap;
+	UINT8      m_flipscreen;
+	int        m_punch_through_pen;
 };
 
 
@@ -30,4 +30,4 @@ WRITE8_HANDLER( ikki_scrn_ctrl_w );
 
 PALETTE_INIT( ikki );
 VIDEO_START( ikki );
-VIDEO_UPDATE( ikki );
+SCREEN_UPDATE( ikki );
