@@ -12,9 +12,10 @@
 #endif /* MESS */
 #endif
 
+/* CoJag and Jaguar have completely different XTALs, pixel clock in Jaguar is the same as the GPU one */
 #define COJAG_PIXEL_CLOCK		XTAL_14_31818MHz
-
-
+#define JAGUAR_CLOCK			XTAL_25_590906MHz // NTSC
+// XTAL_25_593900MHz PAL, TODO
 
 /*----------- defined in drivers/cojag.c -----------*/
 
@@ -30,10 +31,10 @@ extern UINT32 *jaguar_wave_rom;
 
 TIMER_DEVICE_CALLBACK( jaguar_serial_callback );
 
-void jaguar_dsp_suspend(running_machine *machine);
-void jaguar_dsp_resume(running_machine *machine);
+void jaguar_dsp_suspend(running_machine &machine);
+void jaguar_dsp_resume(running_machine &machine);
 
-void cojag_sound_init(running_machine *machine);
+void cojag_sound_init(running_machine &machine);
 
 void jaguar_external_int(device_t *device, int state);
 
@@ -50,8 +51,8 @@ WRITE32_HANDLER( jaguar_serial_w );
 
 extern UINT8 blitter_status;
 
-void jaguar_gpu_suspend(running_machine *machine);
-void jaguar_gpu_resume(running_machine *machine);
+void jaguar_gpu_suspend(running_machine &machine);
+void jaguar_gpu_resume(running_machine &machine);
 
 void jaguar_gpu_cpu_int(device_t *device);
 void jaguar_dsp_cpu_int(device_t *device);
@@ -67,4 +68,5 @@ WRITE32_HANDLER( jaguar_tom_regs32_w );
 READ32_HANDLER( cojag_gun_input_r );
 
 VIDEO_START( cojag );
-VIDEO_UPDATE( cojag );
+VIDEO_START( jaguar );
+SCREEN_UPDATE( cojag );
