@@ -7,29 +7,30 @@
 class kingofb_state : public driver_device
 {
 public:
-	kingofb_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	kingofb_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *    videoram;
-	UINT8 *    videoram2;
-	UINT8 *    colorram;
-	UINT8 *    colorram2;
-	UINT8 *    spriteram;
-	UINT8 *    scroll_y;
-	size_t     spriteram_size;
+	UINT8 *    m_videoram;
+	UINT8 *    m_videoram2;
+	UINT8 *    m_colorram;
+	UINT8 *    m_colorram2;
+	UINT8 *    m_spriteram;
+	UINT8 *    m_scroll_y;
+	size_t     m_spriteram_size;
 
 	/* video-related */
-	tilemap_t    *bg_tilemap, *fg_tilemap;
-	int        palette_bank;
+	tilemap_t    *m_bg_tilemap;
+	tilemap_t    *m_fg_tilemap;
+	int        m_palette_bank;
 
 	/* misc */
-	int        nmi_enable;
+	int        m_nmi_enable;
 
 	/* devices */
-	device_t *video_cpu;
-	device_t *sprite_cpu;
-	device_t *audio_cpu;
+	device_t *m_video_cpu;
+	device_t *m_sprite_cpu;
+	device_t *m_audio_cpu;
 };
 
 
@@ -43,8 +44,8 @@ WRITE8_HANDLER( kingofb_f800_w );
 
 PALETTE_INIT( kingofb );
 VIDEO_START( kingofb );
-VIDEO_UPDATE( kingofb );
+SCREEN_UPDATE( kingofb );
 
 PALETTE_INIT( ringking );
 VIDEO_START( ringking );
-VIDEO_UPDATE( ringking );
+SCREEN_UPDATE( ringking );
