@@ -9,8 +9,8 @@
 class klax_state : public atarigen_state
 {
 public:
-	klax_state(running_machine &machine, const driver_device_config_base &config)
-		: atarigen_state(machine, config) { }
+	klax_state(const machine_config &mconfig, device_type type, const char *tag)
+		: atarigen_state(mconfig, type, tag) { }
 };
 
 
@@ -19,4 +19,4 @@ public:
 WRITE16_HANDLER( klax_latch_w );
 
 VIDEO_START( klax );
-VIDEO_UPDATE( klax );
+SCREEN_UPDATE( klax );
