@@ -1,21 +1,23 @@
 class m52_state : public driver_device
 {
 public:
-	m52_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	m52_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *              videoram;
-	UINT8 *              spriteram;
-	size_t               spriteram_size;
+	UINT8 *              m_videoram;
+	UINT8 *              m_spriteram;
+	size_t               m_spriteram_size;
 
-	UINT8 *              colorram;
+	UINT8 *              m_colorram;
 
 	/* video-related */
-	tilemap_t*             bg_tilemap;
-	UINT8                bg1xpos, bg1ypos;
-	UINT8                bg2xpos, bg2ypos;
-	UINT8                bgcontrol;
+	tilemap_t*             m_bg_tilemap;
+	UINT8                m_bg1xpos;
+	UINT8                m_bg1ypos;
+	UINT8                m_bg2xpos;
+	UINT8                m_bg2ypos;
+	UINT8                m_bgcontrol;
 };
 
 /*----------- defined in video/m52.c -----------*/
@@ -34,4 +36,4 @@ WRITE8_HANDLER( m52_colorram_w );
 
 PALETTE_INIT( m52 );
 VIDEO_START( m52 );
-VIDEO_UPDATE( m52 );
+SCREEN_UPDATE( m52 );
