@@ -8,21 +8,21 @@
 class malzak_state : public driver_device
 {
 public:
-	malzak_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	malzak_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* misc */
 //  int playfield_x[256];
 //  int playfield_y[256];
-	int playfield_code[256];
-	int malzak_x;
-	int malzak_y;
-	int collision_counter;
+	int m_playfield_code[256];
+	int m_malzak_x;
+	int m_malzak_y;
+	int m_collision_counter;
 
 	/* devices */
-	device_t *s2636_0;
-	device_t *s2636_1;
-	device_t *saa5050;
+	device_t *m_s2636_0;
+	device_t *m_s2636_1;
+	device_t *m_saa5050;
 };
 
 
@@ -30,4 +30,4 @@ public:
 
 WRITE8_HANDLER( malzak_playfield_w );
 
-VIDEO_UPDATE( malzak );
+SCREEN_UPDATE( malzak );
