@@ -6,13 +6,23 @@
 
 #define MIDZEUS_VIDEO_CLOCK		XTAL_66_6667MHz
 
+class midzeus_state : public driver_device
+{
+public:
+	midzeus_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag),
+		  m_nvram(*this, "nvram") { }
+
+	required_shared_ptr<UINT32>	m_nvram;
+};
+
 
 /*----------- defined in video/midzeus.c -----------*/
 
 extern UINT32 *zeusbase;
 
 VIDEO_START( midzeus );
-VIDEO_UPDATE( midzeus );
+SCREEN_UPDATE( midzeus );
 
 READ32_HANDLER( zeus_r );
 WRITE32_HANDLER( zeus_w );
@@ -20,7 +30,7 @@ WRITE32_HANDLER( zeus_w );
 /*----------- defined in video/midzeus2.c -----------*/
 
 VIDEO_START( midzeus2 );
-VIDEO_UPDATE( midzeus2 );
+SCREEN_UPDATE( midzeus2 );
 
 READ32_HANDLER( zeus2_r );
 WRITE32_HANDLER( zeus2_w );
