@@ -7,22 +7,22 @@
 class mouser_state : public driver_device
 {
 public:
-	mouser_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	mouser_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *    videoram;
-	UINT8 *    colorram;
-	UINT8 *    spriteram;
-	size_t     spriteram_size;
+	UINT8 *    m_videoram;
+	UINT8 *    m_colorram;
+	UINT8 *    m_spriteram;
+	size_t     m_spriteram_size;
 
 	/* misc */
-	UINT8      sound_byte;
-	UINT8      nmi_enable;
+	UINT8      m_sound_byte;
+	UINT8      m_nmi_enable;
 
 	/* devices */
-	device_t *maincpu;
-	device_t *audiocpu;
+	device_t *m_maincpu;
+	device_t *m_audiocpu;
 };
 
 /*----------- defined in video/mouser.c -----------*/
@@ -31,4 +31,4 @@ WRITE8_HANDLER( mouser_flip_screen_x_w );
 WRITE8_HANDLER( mouser_flip_screen_y_w );
 
 PALETTE_INIT( mouser );
-VIDEO_UPDATE( mouser );
+SCREEN_UPDATE( mouser );
