@@ -7,15 +7,15 @@
 class mrjong_state : public driver_device
 {
 public:
-	mrjong_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	mrjong_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *    videoram;
-	UINT8 *    colorram;
+	UINT8 *    m_videoram;
+	UINT8 *    m_colorram;
 
 	/* video-related */
-	tilemap_t *bg_tilemap;
+	tilemap_t *m_bg_tilemap;
 };
 
 
@@ -27,4 +27,4 @@ WRITE8_HANDLER( mrjong_flipscreen_w );
 
 PALETTE_INIT( mrjong );
 VIDEO_START( mrjong );
-VIDEO_UPDATE( mrjong );
+SCREEN_UPDATE( mrjong );
