@@ -9,8 +9,8 @@
 class _n64_state : public driver_device
 {
 public:
-	_n64_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	_n64_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* video-related */
 	N64::RDP::Processor m_rdp;
@@ -19,7 +19,7 @@ public:
 /*----------- defined in video/n64.c -----------*/
 
 extern VIDEO_START( n64 );
-extern VIDEO_UPDATE( n64 );
+extern SCREEN_UPDATE( n64 );
 
 #define DACRATE_NTSC	(48681812)
 #define DACRATE_PAL	(49656530)
@@ -69,9 +69,9 @@ extern UINT32 n64_vi_vstart;
 extern UINT32 n64_vi_xscale;
 extern UINT32 n64_vi_yscale;
 
-extern void dp_full_sync(running_machine *machine);
-extern void signal_rcp_interrupt(running_machine *machine, int interrupt);
-extern void clear_rcp_interrupt(running_machine *machine, int interrupt);
+extern void dp_full_sync(running_machine &machine);
+extern void signal_rcp_interrupt(running_machine &machine, int interrupt);
+extern void clear_rcp_interrupt(running_machine &machine, int interrupt);
 
 
 /* read/write handlers for the N64 subsystems */
