@@ -14,7 +14,7 @@ enum {
 
 /*----------- defined in machine/gdcrypt.c -----------*/
 
-extern void naomi_game_decrypt(running_machine* machine, UINT64 key, UINT8* region, int length);
+extern void naomi_game_decrypt(running_machine& machine, UINT64 key, UINT8* region, int length);
 
 
 /*----------- defined in machine/naomi.c -----------*/
