@@ -9,21 +9,22 @@
 class othldrby_state : public driver_device
 {
 public:
-	othldrby_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	othldrby_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT16 *     vram;
-	UINT16 *     buf_spriteram;
-	UINT16 *     buf_spriteram2;
+	UINT16 *     m_vram;
+	UINT16 *     m_buf_spriteram;
+	UINT16 *     m_buf_spriteram2;
 
 	/* video-related */
-	tilemap_t    *bg_tilemap[3];
-	UINT16       vreg[OTHLDRBY_VREG_SIZE];
-	UINT32       vram_addr, vreg_addr;
+	tilemap_t    *m_bg_tilemap[3];
+	UINT16       m_vreg[OTHLDRBY_VREG_SIZE];
+	UINT32       m_vram_addr;
+	UINT32       m_vreg_addr;
 
 	/* misc */
-	int          toggle;
+	int          m_toggle;
 };
 
 
@@ -36,5 +37,5 @@ WRITE16_HANDLER( othldrby_vreg_addr_w );
 WRITE16_HANDLER( othldrby_vreg_w );
 
 VIDEO_START( othldrby );
-VIDEO_EOF( othldrby );
-VIDEO_UPDATE( othldrby );
+SCREEN_EOF( othldrby );
+SCREEN_UPDATE( othldrby );
