@@ -8,6 +8,33 @@
 #include "sound/discrete.h"
 
 
+class polepos_state : public driver_device
+{
+public:
+	polepos_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 m_steer_last;
+	UINT8 m_steer_delta;
+	INT16 m_steer_accum;
+	INT16 m_last_result;
+	INT8 m_last_signed;
+	UINT8 m_last_unsigned;
+	int m_adc_input;
+	int m_auto_start_mask;
+	UINT16 *m_view16_memory;
+	UINT16 *m_road16_memory;
+	UINT16 *m_alpha16_memory;
+	UINT16 *m_sprite16_memory;
+	UINT16 m_vertical_position_modifier[256];
+	UINT16 m_road16_vscroll;
+	tilemap_t *m_bg_tilemap;
+	tilemap_t *m_tx_tilemap;
+	int m_chacl;
+	UINT16 m_scroll;
+};
+
+
 /*----------- defined in audio/polepos.c -----------*/
 
 DECLARE_LEGACY_SOUND_DEVICE(POLEPOS, polepos_sound);
@@ -20,14 +47,9 @@ DISCRETE_SOUND_EXTERN( polepos );
 
 /*----------- defined in video/polepos.c -----------*/
 
-extern UINT16 *polepos_view16_memory;
-extern UINT16 *polepos_road16_memory;
-extern UINT16 *polepos_alpha16_memory;
-extern UINT16 *polepos_sprite16_memory;
-
 VIDEO_START( polepos );
 PALETTE_INIT( polepos );
-VIDEO_UPDATE( polepos );
+SCREEN_UPDATE( polepos );
 
 WRITE16_HANDLER( polepos_view16_w );
 WRITE16_HANDLER( polepos_road16_w );
