@@ -1,23 +1,24 @@
 class pooyan_state : public driver_device
 {
 public:
-	pooyan_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	pooyan_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* memory pointers */
-	UINT8 *  videoram;
-	UINT8 *  colorram;
-	UINT8 *  spriteram;
-	UINT8 *  spriteram2;
+	UINT8 *  m_videoram;
+	UINT8 *  m_colorram;
+	UINT8 *  m_spriteram;
+	UINT8 *  m_spriteram2;
 
 	/* video-related */
-	tilemap_t  *bg_tilemap;
+	tilemap_t  *m_bg_tilemap;
 
 	/* misc */
-	UINT8    irq_toggle, irq_enable;
+	UINT8    m_irq_toggle;
+	UINT8    m_irq_enable;
 
 	/* devices */
-	cpu_device *maincpu;
+	cpu_device *m_maincpu;
 };
 
 
@@ -29,4 +30,4 @@ WRITE8_HANDLER( pooyan_flipscreen_w );
 
 PALETTE_INIT( pooyan );
 VIDEO_START( pooyan );
-VIDEO_UPDATE( pooyan );
+SCREEN_UPDATE( pooyan );
