@@ -17,27 +17,30 @@
 #define QIX_CHARACTER_CLOCK		(20000000/2/16)
 
 
+#define NUM_PENS	(0x100)
+
 class qix_state : public driver_device
 {
 public:
-	qix_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	qix_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
 	/* machine state */
-	UINT8 *_68705_port_out;
-	UINT8 *_68705_ddr;
-	UINT8  _68705_port_in[3];
-	UINT8  coinctrl;
+	UINT8 *m_68705_port_out;
+	UINT8 *m_68705_ddr;
+	UINT8  m_68705_port_in[3];
+	UINT8  m_coinctrl;
 
 	/* video state */
-	UINT8 *videoram;
-	UINT8 *videoram_address;
-	UINT8 *videoram_mask;
-	UINT8 *paletteram;
-	UINT8  flip;
-	UINT8  palette_bank;
-	UINT8  leds;
-	UINT8 *scanline_latch;
+	UINT8 *m_videoram;
+	UINT8 *m_videoram_address;
+	UINT8 *m_videoram_mask;
+	UINT8 *m_paletteram;
+	UINT8  m_flip;
+	UINT8  m_palette_bank;
+	UINT8  m_leds;
+	UINT8 *m_scanline_latch;
+	pen_t m_pens[NUM_PENS];
 };
 
 
