@@ -6,21 +6,18 @@
 
 #include "machine/atarigen.h"
 
-/* shared with arcadecl hardware */
 class rampart_state : public atarigen_state
 {
 public:
-	rampart_state(running_machine &machine, const driver_device_config_base &config)
-		: atarigen_state(machine, config) { }
+	rampart_state(const machine_config &mconfig, device_type type, const char *tag)
+		: atarigen_state(mconfig, type, tag) { }
 
-	UINT16 *		bitmap;
-	UINT8			has_mo;
+	UINT16 *		m_bitmap;
+	UINT8			m_has_mo;
 };
 
 
 /*----------- defined in video/rampart.c -----------*/
 
 VIDEO_START( rampart );
-VIDEO_UPDATE( rampart );
-
-void rampart_bitmap_render(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect);
+SCREEN_UPDATE( rampart );
