@@ -1,18 +1,19 @@
 class sauro_state : public driver_device
 {
 public:
-	sauro_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	sauro_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	size_t spriteram_size;
-	UINT8 *spriteram;
-	UINT8 *videoram;
-	UINT8 *colorram;
-	UINT8 *videoram2;
-	UINT8 *colorram2;
+	size_t m_spriteram_size;
+	UINT8 *m_spriteram;
+	UINT8 *m_videoram;
+	UINT8 *m_colorram;
+	UINT8 *m_videoram2;
+	UINT8 *m_colorram2;
 
-	tilemap_t *bg_tilemap, *fg_tilemap;
-	UINT8 palette_bank;
+	tilemap_t *m_bg_tilemap;
+	tilemap_t *m_fg_tilemap;
+	UINT8 m_palette_bank;
 };
 
 
@@ -29,5 +30,5 @@ WRITE8_HANDLER( sauro_palette_bank_w );
 VIDEO_START( sauro );
 VIDEO_START( trckydoc );
 
-VIDEO_UPDATE( sauro );
-VIDEO_UPDATE( trckydoc );
+SCREEN_UPDATE( sauro );
+SCREEN_UPDATE( trckydoc );
