@@ -4,6 +4,28 @@
 
 *************************************************************************/
 
+#include "machine/segag80.h"
+
+class segag80v_state : public driver_device
+{
+public:
+	segag80v_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
+
+	UINT8 *m_mainram;
+	device_t *m_usb;
+	UINT8 m_mult_data[2];
+	UINT16 m_mult_result;
+	UINT8 m_spinner_select;
+	UINT8 m_spinner_sign;
+	UINT8 m_spinner_count;
+	segag80_decrypt_func m_decrypt;
+	UINT8 *m_vectorram;
+	size_t m_vectorram_size;
+	int m_min_x;
+	int m_min_y;
+};
+
 
 /*----------- defined in audio/segag80v.c -----------*/
 
@@ -17,8 +39,5 @@ WRITE8_HANDLER( zektor2_sh_w );
 
 /*----------- defined in video/segag80v.c -----------*/
 
-extern UINT8 *segag80v_vectorram;
-extern size_t segag80v_vectorram_size;
-
 VIDEO_START( segag80v );
-VIDEO_UPDATE( segag80v );
+SCREEN_UPDATE( segag80v );
