@@ -1,19 +1,19 @@
 class ssozumo_state : public driver_device
 {
 public:
-	ssozumo_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	ssozumo_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	size_t spriteram_size;
-	UINT8 *spriteram;
-	UINT8 *paletteram;
-	UINT8 *videoram;
-	UINT8 *colorram;
-	UINT8 *videoram2;
-	UINT8 *colorram2;
+	size_t m_spriteram_size;
+	UINT8 *m_spriteram;
+	UINT8 *m_paletteram;
+	UINT8 *m_videoram;
+	UINT8 *m_colorram;
+	UINT8 *m_videoram2;
+	UINT8 *m_colorram2;
 
-	tilemap_t *bg_tilemap;
-	tilemap_t *fg_tilemap;
+	tilemap_t *m_bg_tilemap;
+	tilemap_t *m_fg_tilemap;
 };
 
 
@@ -29,4 +29,4 @@ WRITE8_HANDLER( ssozumo_flipscreen_w );
 
 PALETTE_INIT( ssozumo );
 VIDEO_START( ssozumo );
-VIDEO_UPDATE( ssozumo );
+SCREEN_UPDATE( ssozumo );
