@@ -1,14 +1,14 @@
 class suna16_state : public driver_device
 {
 public:
-	suna16_state(running_machine &machine, const driver_device_config_base &config)
-		: driver_device(machine, config) { }
+	suna16_state(const machine_config &mconfig, device_type type, const char *tag)
+		: driver_device(mconfig, type, tag) { }
 
-	UINT16 prot;
-	UINT16 *paletteram;
-	UINT16 *spriteram;
-	UINT16 *spriteram2;
-	int color_bank;
+	UINT16 m_prot;
+	UINT16 *m_paletteram;
+	UINT16 *m_spriteram;
+	UINT16 *m_spriteram2;
+	int m_color_bank;
 };
 
 
@@ -21,5 +21,5 @@ READ16_HANDLER ( suna16_paletteram16_r );
 WRITE16_HANDLER( suna16_paletteram16_w );
 
 VIDEO_START( suna16 );
-VIDEO_UPDATE( suna16 );
-VIDEO_UPDATE( bestbest );
+SCREEN_UPDATE( suna16 );
+SCREEN_UPDATE( bestbest );
